(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2049252,      56330]*)
(*NotebookOutlinePosition[   2053095,      56424]*)
(*  CellTagsIndexPosition[   2052226,      56403]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["First-Order Ordinary Differential Equations", "Title"],

Cell["Background--simple iteration", "Subtitle",
  CellTags->"mmtag:19:simple_forward_time_interation"],

Cell["\<\
Suppose a function,  F[i], changes proportional to its current \
size, i.e.,  F[i+1] = F[i] + \[Alpha]F[i],\
\>", "Text"],

Cell[BoxData[
    \(ExampleFunction[i_, \ alpha_]\  := \ 
      ExampleFunction[i - 1, alpha]\  + \ 
        alpha*ExampleFunction[i - 1, alpha]\)], "Input"],

Cell["\<\
What would happen if the following functions were evaluated? (Note: \
if you execute the next step you may have to abort the calculation.)\
\>", \
"Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(ExampleFunction[25, 0.25]\ \[IndentingNewLine]
    ExampleFunction[25, \(-0.125\)]\)\(\ \)\)\)], "Input"],

Cell["\<\
It is clear that the function needs some value at some time (an \
initial condition) from which it obtains all its other values:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExampleFunction[0, 0.25]\  = \ \[Pi]/4\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExampleFunction[18, 0.25]\)], "Input"],

Cell[BoxData[
    \(43.598356225107906`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell["\<\
This function is fairly inefficient, it calculates the first value \
about 18 times before it returns the answer, the following function sets the \
initial value and remembers what \"trajectory\" it is on--i,e., the \
trajectory is determined from the start\
\>", "Text"],

Cell[BoxData[
    \(GrowsPropToSize[i_\ , \ alpha_\ , \ F0_]\  := \ 
      If[i \[Equal] 0, GrowsPropToSize[0, alpha, F0] = F0, 
        GrowsPropToSize[i, alpha, F0]\  = \ 
          GrowsPropToSize[i - 1, alpha, F0]\  + \ 
            alpha*GrowsPropToSize[i - 1, alpha, F0]\ \ ]\)], "Input"],

Cell["For example:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[GrowsPropToSize[i,  .01, 1], {i, 18}]\)], "Input"],

Cell[BoxData[
    \({1.01`, 1.0201`, 1.030301`, 1.0406040099999998`, 1.0510100500999997`, 
      1.0615201506009997`, 1.0721353521070096`, 1.0828567056280798`, 
      1.0936852726843607`, 1.1046221254112043`, 1.1156683466653163`, 
      1.1268250301319696`, 1.1380932804332893`, 1.1494742132376221`, 
      1.1609689553699982`, 1.1725786449236981`, 1.1843044313729352`, 
      1.1961474756866646`}\)], "Output"]
}, Open  ]],

Cell["\<\
Might as well write a function to calculate a vector representing \
trajectory, here is an implementation to compute a trajectory vector of \
length 300\
\>", "Text"],

Cell[BoxData[
    \(Trajectory[alpha_, \ F0_]\  := \ 
      Table[GrowsPropToSize[i, alpha, F0], {i, 300}]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Trajectory[0.01, 1], PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 0.0297448 [
[.18254 .00222 -12 -20 ]
[.18254 .00222 12 0 ]
[.34127 .00222 -17 -20 ]
[.34127 .00222 17 0 ]
[.5 .00222 -17 -20 ]
[.5 .00222 17 0 ]
[.65873 .00222 -17 -20 ]
[.65873 .00222 17 0 ]
[.81746 .00222 -17 -20 ]
[.81746 .00222 17 0 ]
[.97619 .00222 -17 -20 ]
[.97619 .00222 17 0 ]
[.01131 .16344 -14 -10 ]
[.01131 .16344 0 10 ]
[.01131 .31216 -24 -10 ]
[.01131 .31216 0 10 ]
[.01131 .46089 -24 -10 ]
[.01131 .46089 0 10 ]
[.01131 .60961 -24 -10 ]
[.01131 .60961 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
gsave
.18254 .00222 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 .01472 m
.34127 .02097 L
s
gsave
.34127 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 .01472 m
.65873 .02097 L
s
gsave
.65873 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 .01472 m
.81746 .02097 L
s
gsave
.81746 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .16344 m
.03006 .16344 L
s
gsave
.01131 .16344 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02381 .31216 m
.03006 .31216 L
s
gsave
.01131 .31216 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .46089 m
.03006 .46089 L
s
gsave
.01131 .46089 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.02381 .60961 m
.03006 .60961 L
s
gsave
.01131 .60961 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04446 m
.02756 .04446 L
s
.02381 .0742 m
.02756 .0742 L
s
.02381 .10395 m
.02756 .10395 L
s
.02381 .13369 m
.02756 .13369 L
s
.02381 .19318 m
.02756 .19318 L
s
.02381 .22293 m
.02756 .22293 L
s
.02381 .25267 m
.02756 .25267 L
s
.02381 .28242 m
.02756 .28242 L
s
.02381 .34191 m
.02756 .34191 L
s
.02381 .37165 m
.02756 .37165 L
s
.02381 .4014 m
.02756 .4014 L
s
.02381 .43114 m
.02756 .43114 L
s
.02381 .49063 m
.02756 .49063 L
s
.02381 .52038 m
.02756 .52038 L
s
.02381 .55012 m
.02756 .55012 L
s
.02381 .57987 m
.02756 .57987 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02698 .04476 m
.03016 .04506 L
.03333 .04536 L
.03651 .04567 L
.03968 .04598 L
.04286 .04629 L
.04603 .04661 L
.04921 .04692 L
.05238 .04725 L
.05556 .04757 L
.05873 .0479 L
.0619 .04823 L
.06508 .04857 L
.06825 .04891 L
.07143 .04925 L
.0746 .04959 L
.07778 .04994 L
.08095 .05029 L
.08413 .05065 L
.0873 .05101 L
.09048 .05137 L
.09365 .05174 L
.09683 .05211 L
.1 .05248 L
.10317 .05286 L
.10635 .05324 L
.10952 .05363 L
.1127 .05402 L
.11587 .05441 L
.11905 .05481 L
.12222 .05521 L
.1254 .05561 L
.12857 .05602 L
.13175 .05643 L
.13492 .05685 L
.1381 .05727 L
.14127 .0577 L
.14444 .05813 L
.14762 .05856 L
.15079 .059 L
.15397 .05944 L
.15714 .05989 L
.16032 .06034 L
.16349 .0608 L
.16667 .06126 L
.16984 .06173 L
.17302 .0622 L
.17619 .06267 L
.17937 .06315 L
.18254 .06363 L
Mistroke
.18571 .06412 L
.18889 .06462 L
.19206 .06512 L
.19524 .06562 L
.19841 .06613 L
.20159 .06664 L
.20476 .06716 L
.20794 .06769 L
.21111 .06822 L
.21429 .06875 L
.21746 .06929 L
.22063 .06984 L
.22381 .07039 L
.22698 .07095 L
.23016 .07151 L
.23333 .07208 L
.23651 .07265 L
.23968 .07323 L
.24286 .07381 L
.24603 .07441 L
.24921 .075 L
.25238 .07561 L
.25556 .07621 L
.25873 .07683 L
.2619 .07745 L
.26508 .07808 L
.26825 .07871 L
.27143 .07935 L
.2746 .08 L
.27778 .08065 L
.28095 .08131 L
.28413 .08198 L
.2873 .08265 L
.29048 .08333 L
.29365 .08401 L
.29683 .08471 L
.3 .08541 L
.30317 .08611 L
.30635 .08683 L
.30952 .08755 L
.3127 .08828 L
.31587 .08901 L
.31905 .08976 L
.32222 .09051 L
.3254 .09126 L
.32857 .09203 L
.33175 .0928 L
.33492 .09358 L
.3381 .09437 L
.34127 .09517 L
Mistroke
.34444 .09597 L
.34762 .09679 L
.35079 .09761 L
.35397 .09844 L
.35714 .09927 L
.36032 .10012 L
.36349 .10097 L
.36667 .10184 L
.36984 .10271 L
.37302 .10359 L
.37619 .10448 L
.37937 .10537 L
.38254 .10628 L
.38571 .1072 L
.38889 .10812 L
.39206 .10905 L
.39524 .11 L
.39841 .11095 L
.40159 .11191 L
.40476 .11288 L
.40794 .11387 L
.41111 .11486 L
.41429 .11586 L
.41746 .11687 L
.42063 .11789 L
.42381 .11892 L
.42698 .11997 L
.43016 .12102 L
.43333 .12208 L
.43651 .12316 L
.43968 .12424 L
.44286 .12533 L
.44603 .12644 L
.44921 .12756 L
.45238 .12869 L
.45556 .12983 L
.45873 .13098 L
.4619 .13214 L
.46508 .13331 L
.46825 .1345 L
.47143 .1357 L
.4746 .13691 L
.47778 .13813 L
.48095 .13936 L
.48413 .14061 L
.4873 .14187 L
.49048 .14314 L
.49365 .14443 L
.49683 .14572 L
.5 .14703 L
Mistroke
.50317 .14836 L
.50635 .14969 L
.50952 .15104 L
.5127 .15241 L
.51587 .15378 L
.51905 .15517 L
.52222 .15658 L
.5254 .158 L
.52857 .15943 L
.53175 .16088 L
.53492 .16234 L
.5381 .16381 L
.54127 .1653 L
.54444 .16681 L
.54762 .16833 L
.55079 .16987 L
.55397 .17142 L
.55714 .17299 L
.56032 .17457 L
.56349 .17617 L
.56667 .17778 L
.56984 .17941 L
.57302 .18106 L
.57619 .18272 L
.57937 .1844 L
.58254 .1861 L
.58571 .18781 L
.58889 .18954 L
.59206 .19129 L
.59524 .19306 L
.59841 .19484 L
.60159 .19664 L
.60476 .19846 L
.60794 .2003 L
.61111 .20216 L
.61429 .20403 L
.61746 .20592 L
.62063 .20784 L
.62381 .20977 L
.62698 .21172 L
.63016 .21369 L
.63333 .21568 L
.63651 .21769 L
.63968 .21972 L
.64286 .22177 L
.64603 .22384 L
.64921 .22593 L
.65238 .22804 L
.65556 .23017 L
.65873 .23233 L
Mistroke
.6619 .2345 L
.66508 .2367 L
.66825 .23892 L
.67143 .24116 L
.6746 .24343 L
.67778 .24572 L
.68095 .24803 L
.68413 .25036 L
.6873 .25272 L
.69048 .2551 L
.69365 .2575 L
.69683 .25993 L
.7 .26238 L
.70317 .26486 L
.70635 .26736 L
.70952 .26988 L
.7127 .27244 L
.71587 .27501 L
.71905 .27762 L
.72222 .28024 L
.7254 .2829 L
.72857 .28558 L
.73175 .28829 L
.73492 .29103 L
.7381 .29379 L
.74127 .29658 L
.74444 .2994 L
.74762 .30225 L
.75079 .30512 L
.75397 .30803 L
.75714 .31096 L
.76032 .31392 L
.76349 .31691 L
.76667 .31993 L
.76984 .32299 L
.77302 .32607 L
.77619 .32918 L
.77937 .33233 L
.78254 .3355 L
.78571 .33871 L
.78889 .34195 L
.79206 .34522 L
.79524 .34853 L
.79841 .35187 L
.80159 .35524 L
.80476 .35864 L
.80794 .36208 L
.81111 .36556 L
.81429 .36907 L
.81746 .37261 L
Mistroke
.82063 .37619 L
.82381 .3798 L
.82698 .38345 L
.83016 .38714 L
.83333 .39087 L
.83651 .39463 L
.83968 .39843 L
.84286 .40226 L
.84603 .40614 L
.84921 .41005 L
.85238 .41401 L
.85556 .418 L
.85873 .42203 L
.8619 .4261 L
.86508 .43022 L
.86825 .43437 L
.87143 .43857 L
.8746 .44281 L
.87778 .44709 L
.88095 .45141 L
.88413 .45578 L
.8873 .46019 L
.89048 .46465 L
.89365 .46915 L
.89683 .47369 L
.9 .47828 L
.90317 .48292 L
.90635 .4876 L
.90952 .49233 L
.9127 .4971 L
.91587 .50193 L
.91905 .5068 L
.92222 .51172 L
.9254 .51669 L
.92857 .52171 L
.93175 .52678 L
.93492 .5319 L
.9381 .53707 L
.94127 .54229 L
.94444 .54757 L
.94762 .5529 L
.95079 .55828 L
.95397 .56372 L
.95714 .56921 L
.96032 .57475 L
.96349 .58035 L
.96667 .58601 L
.96984 .59172 L
.97302 .59749 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00M?oonfX5o`00O`Gooo]Z1Ol007m3oook
JP?o001o1OoonfX5o`00O`Gooo]Z1Ol007lnoookJP?o001o1OoonfX5o`00O`Gooo]Z1Ol007ljoook
JPWo001o0ooonfX5o`00O`Gooo]Z1Ol007ljoookJPWo001o0ooonfX5o`00O`Gooo]Z1Ol007lloook
JPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l?oookJP00LooonfX7o`00O`?ooo]Z1ol007m2oookJP?o
001o1?oonfX7o`00O`?ooo]Z1ol007lmoookJP?o001o1?oonfX7o`00O`?ooo]Z1ol007lioookJPWo
001o0_oonfX7o`00O`?ooo]Z1ol007lioookJPWo001o0_oonfX7o`00O`?ooo]Z1ol007ljoookJPOo
001o0ooonfX7o`00O`?ooo]Z1ol007l>oookJP00L_oonfX4o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007m2oookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lmoookJP?o001o0ooonfX4o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lioookJPCo001o1ooonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lioookJPCo001o1_oonfX4
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lioookJP?o001o
0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o3_oonfX007;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Od7ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007ll
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o>Ooo
nfX4o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcWooo]Z
1?l007l5oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lhoookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o3OoonfX007Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o@OoonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Occooo]Z0ol0
07l9oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oc[ooo]Z1Ol007l3oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007ljoookJPGo001o2OoonfX3o`00O`04
oookJ_l007oo001oo`00O`?ooo]Z0ol007lnoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l=oookJP00N?oonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007m1oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o??oonfX3o`00O`Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o??oonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Occooo]Z1?l007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ockooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`gooo]Z
001coookJP;o001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m1oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o??oonfX3o`00O`Co
oo]Z0_l007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ocgooo]Z0ol007l2oook
JP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lmoookJP?o001o0ooonfX2
o`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o??oonfX4o`00O`;ooo]Z0ol0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`gooo]Z001coookJPOo001o0_oo
nfX3o`00O`?ooo]Z0ol007m1oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o??oonfX3o`00O`Cooo]Z1ol007l2oookJP?o001o0ooonfX3o`00Ockooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Ockooo]Z0ol007l2oookJPOo001o0_oonfX3o`00O`?ooo]Z0ol007lloookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o3OoonfX007?ooo]Z1_l007l3oook
JP?o001o0ooonfX3o`00Od7ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007lloookJP?o001o1?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o>?oonfX3
o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00OcSooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o
?_oonfX2o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`go
oo]Z001coookJP;o001o1ooonfX3o`00O`?ooo]Z0ol007lnoookJPKo001o0ooonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o>OoonfX6o`00O`Cooo]Z0_l007l7oookJP?o
001o0ooonfX3o`00OcSooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lhoookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l7
oookJP?o001o0ooonfX3o`00OcSooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l=oookJP009OoonfX5o`0004Wooo]Z0_l0
07l8oookJP?o001o00Cooo]Zo`00Ool007oo001o?ooonfX6o`00O`Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o>_oonfX6o`00O`Cooo]Z0_l007l8oook
JP?o001o00Cooo]Zo`00Ool007oo001o>OoonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00OcWooo]Z1?l007l2oookJP?o001o
0_oonfX2o`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007lioookJP?o001o0ooonfX3o`00O`;o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o3_oonfX0
02Gooo]Z1Ol0001:oookJPOo001o0_oonfX7o`00Od7ooo]Z1?l007l4oookJPOo001o0ooonfX7o`00
Occooo]Z1?l007l5oookJPOo001o0_oonfX7o`00Oc[ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00
Oc[ooo]Z1ol007l4oookJPOo001o0_oonfX7o`00Oc[ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00
O`kooo]Z000UoookJPGo0000B_oonfX7o`00O`?ooo]Z1Ol007m3oookJP?o001o1OoonfX5o`00O`Go
oo]Z1Ol007lnoookJP?o001o1OoonfX7o`00O`?ooo]Z1Ol007lloookJPGo001o1OoonfX5o`00O`Go
oo]Z1Ol007lloookJPGo001o1OoonfX7o`00O`?ooo]Z1Ol007lloookJPGo001o1OoonfX5o`00O`Go
oo]Z1Ol007l?oookJP009OoonfX5o`000?oooo]ZoooonfXHoookJP009OoonfX5o`000?oooo]Zoooo
nfXHoookJP009OoonfX5o`000?oooo]ZoooonfXHoookJP009OoonfX5o`000?oooo]ZoooonfXHoook
JP009OoonfX5o`000?oooo]ZoooonfXHoookJP006?oonf[oo`000?oo00007_l0000<oookJP006?oo
nf[oo`000?oo00007_l0000<oookJP006?oonf[oo`000?oo00007_l0000<oookJP006?oonf[oo`00
0?oo00007_l0000<oookJP006?oonf[oo`000?oo00007_l0000<oookJP009OoonfX5o`0005;ooo]Z
00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05;ooo]Z
00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z01Sooo]Z
000UoookJPGo0000D_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1BoookJP03o`000?oonf[ooo]Z05;ooo]Z00?o
0000oookJ_oonfX06?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003ooook
J_oooo]Z6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z
6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX0
02Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z
1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003ooookJ_oooo]Z6?oonfX002Gooo]Z1Ol0003o
oookJ_oooo]Z6?oonfX002Gooo]Z1ol0003ooookJ_oooo]Z5_oonfX002Gooo]Z1Ol00002oookJP[o
0000oooonf[ooookJPcooo]Z000UoookJPGo00003?oonfX9o`000?oooo]ZoooonfX3oookJP009Ooo
nfX5o`0001Gooo]Z2_l0003ooookJ_Sooo]Z000UoookJPGo00007ooonfX9o`000?oooo]ZkooonfX0
02Gooo]Z1Ol0000XoookJPSo0000oooonf[WoookJP009OoonfX5o`00033ooo]Z1ol0003ooookJ^3o
oo]Z000UoookJPGo0000=ooonfX8o`000?oooo]Zf?oonfX002Gooo]Z1Ol0000ooookJPOo0000oooo
nf[AoookJP009OoonfX5o`0004Kooo]Z1ol0003ooookJ/[ooo]Z000UoookJPGo0000COoonfX7o`00
0?oooo]Z`ooonfX002Gooo]Z1Ol0001DoookJPOo0000oooonfZloookJP009OoonfX5o`0005_ooo]Z
1Ol0003ooookJ[Oooo]Z000UoookJPGo0000H?oonfX6o`000?oooo]Z/OoonfX002Gooo]Z1Ol0001V
oookJPGo0000oooonfZ/oookJP009OoonfX5o`0006_ooo]Z1_l0003ooookJZKooo]Z000UoookJPGo
0000LOoonfX6o`000?oooo]ZX?oonfX002Gooo]Z1Ol0001goookJPGo0000oooonfZKoookJP009Ooo
nfX5o`0007cooo]Z1_l0003ooookJYGooo]Z000UoookJPGo0000P_oonfX3o`000?oooo]ZT_oonfX0
02Gooo]Z1Ol00025oookJPGo0000oooonfZ=oookJP009OoonfX5o`0008[ooo]Z1Ol0003ooookJXSo
oo]Z000UoookJPGo0000SooonfX5o`000?oooo]ZPooonfX002Gooo]Z1Ol0002DoookJPCo0000oooo
nfYooookJP009OoonfX5o`0009Sooo]Z1Ol0003ooookJW[ooo]Z000UoookJPGo0000WOoonfX3o`00
0?oooo]ZMooonfX002Gooo]Z1Ol0002PoookJPGo0000oooonfYboookJP009OoonfX5o`000:Gooo]Z
1?l0003ooookJVkooo]Z000UoookJPGo0000ZOoonfX3o`000?oooo]ZJooonfX002Gooo]Z1Ol0002/
oookJPGo0000oooonfYVoookJP009OoonfX5o`000;7ooo]Z1?l0003ooookJV;ooo]Z000UoookJPGo
0000]OoonfX3o`000?oooo]ZGooonfX002Gooo]Z1Ol0002hoookJP?o0000oooonfYLoookJP009Ooo
nfX5o`000;_ooo]Z1?l0003ooookJUSooo]Z000UoookJPGo0000_ooonfX3o`000?oooo]ZEOoonfX0
02Gooo]Z1Ol00032oookJP?o0000oooonfYBoookJP009OoonfX5o`000<Gooo]Z1?l0003ooookJTko
oo]Z000UoookJPGo0000bOoonfX3o`000?oooo]ZBooonfX002Gooo]Z1Ol0003<oookJPCo0000oooo
nfY7oookJP009OoonfX5o`000=3ooo]Z0ol0003ooookJTCooo]Z000UoookJPGo0000dooonfX2o`00
0?oooo]Z@_oonfX002Gooo]Z1Ol0003EoookJP?o0000oooonfXooookJP009OoonfX5o`000=Sooo]Z
1?l0003ooookJS_ooo]Z000UoookJPGo0000g?oonfX3o`000?oooo]Z>?oonfX002Gooo]Z1Ol0003O
oookJP;o0000oooonfXfoookJP009OoonfX5o`000>7ooo]Z0ol0003ooookJS?ooo]Z000UoookJPGo
0000i?oonfX3o`000?oooo]Z<?oonfX002Gooo]Z1Ol0003WoookJP;o0000oooonfX^oookJP009Ooo
nfX5o`000>Wooo]Z1?l0003ooookJR[ooo]Z000UoookJPGo0000kOoonfX00ol0003ooo]ZoookJP3o
oookJROooo]Z000UoookJPGo0000k_oonfX4o`000?oooo]Z9OoonfX002Gooo]Z1Ol0003boookJP03
o`000?oonf[ooo]Z0?oooo]Z8_oonfX002Gooo]Z1Ol0003coookJPCo0000oooonfXPoookJP009Ooo
nfX5o`000?Oooo]Z00?o0000oookJ_oonfX0oooonfXMoookJP009OoonfX5o`000?Sooo]Z1?l0003o
oookJQ_ooo]Z000UoookJPGo0000o?oonfX2o`000?oooo]Z6OoonfX002Gooo]Z1Ol0003noookJP?o
0000oooonfXFoookJP009OoonfX5o`000?oooo]Z0_oonfX2o`000?oooo]Z5?oonfX002Gooo]Z1Ol0
003ooookJPCooo]Z00?o0000oookJ_oonfX0oooonfXAoookJP009OoonfX5o`000?oooo]Z1OoonfX4
o`000?oooo]Z3ooonfX001Kooo]Z1Ol007l:oookJPGo0000oooonfX9oookJP03o`000?oonf[ooo]Z
0?oooo]Z3?oonfX001Gooo]Z1ol007l9oookJPGo0000oooonfX:oookJP;o0000oooonfX<oookJP00
5?oonfX4o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJPcooo]Z1?l0003ooookJPSo
oo]Z000DoookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQ3ooo]Z00?o0000oookJ_oonfX0
oooonfX5oookJP006_oonfX3o`00O`Sooo]Z1_l0003ooookJQ3ooo]Z0_l0003ooookJPGooo]Z000J
oookJP?o001o2?oonfX5o`000?oooo]Z4ooonfX2o`000?oooo]Z0ooonfX001Gooo]Z0_l007l2oook
JPCo001o2?oonfX5o`000?oooo]Z5OoonfX3o`000?oooo]Z000EoookJPOo001o2OoonfX5o`000?oo
oo]Z6?oonfX2o`000?gooo]Z000EoookJPKo001o2_oonfX5o`000?oooo]Z6_oonfX00ol0003ooo]Z
oookJP3joookJP005OoonfX2o`00O`kooo]Z1Ol0003ooookJQ_ooo]Z0_l0003joookJP005OoonfX2
o`00O`kooo]Z1Ol0003ooookJQgooo]Z0_l0003hoookJP005_oonfX7o`00O`Sooo]Z1Ol0003ooook
JQoooo]Z0ol0003eoookJP005_oonfX7o`00O`Sooo]Z1Ol0003ooookJR;ooo]Z0_l0003coookJP00
9OoonfX5o`000?oooo]Z9?oonfX2o`000?7ooo]Z000UoookJPGo0000oooonfXVoookJP03o`000?oo
nf[ooo]Z0>kooo]Z000UoookJPGo0000oooonfXWoookJP;o0000k_oonfX002Gooo]Z1Ol0003ooook
JRWooo]Z0_l0003/oookJP009OoonfX5o`000?oooo]Z:ooonfX00ol0003ooo]ZoookJP3YoookJP00
9OoonfX5o`000?oooo]Z;?oonfX2o`000>Wooo]Z000UoookJPGo0000oooonfX^oookJP;o0000iooo
nfX002Gooo]Z1Ol0003ooookJS3ooo]Z00?o0000oookJ_oonfX0i?oonfX002Gooo]Z1Ol0003ooook
JS7ooo]Z0_l0003ToookJP009OoonfX5o`000?oooo]Z<ooonfX2o`000>;ooo]Z000UoookJPGo0000
oooonfXeoookJP;o0000h?oonfX002Gooo]Z1Ol0003ooookJSOooo]Z00?o0000oookJ_oonfX0gOoo
nfX002Gooo]Z1Ol0003ooookJSSooo]Z0_l0003MoookJP009OoonfX5o`000?oooo]Z>_oonfX2o`00
0=_ooo]Z000UoookJPGo0000oooonfXloookJP03o`000?oonf[ooo]Z0=Sooo]Z000UoookJPGo0000
oooonfXmoookJP;o0000f?oonfX002Gooo]Z1Ol0003ooookJSoooo]Z0_l0003FoookJP009OoonfX5
o`000?oooo]Z@OoonfX00ol0003ooo]ZoookJP3CoookJP009OoonfX5o`000?oooo]Z@_oonfX2o`00
0=?ooo]Z000UoookJPGo0000oooonfY4oookJP;o0000dOoonfX002Gooo]Z1Ol0003ooookJTKooo]Z
0_l0003?oookJP009OoonfX5o`000?oooo]ZB?oonfX00ol0003ooo]ZoookJP3<oookJP009OoonfX5
o`000?oooo]ZBOoonfX2o`000<cooo]Z000UoookJPGo0000oooonfY;oookJP;o0000b_oonfX002Go
oo]Z1Ol0003ooookJTgooo]Z00?o0000oookJ_oonfX0aooonfX002Gooo]Z1Ol0003ooookJTkooo]Z
00?o0000oookJ_oonfX0a_oonfX002Gooo]Z1Ol0003ooookJToooo]Z00?o0000oookJ_oonfX0aOoo
nfX002Gooo]Z1Ol0003ooookJU3ooo]Z0_l00035oookJP009OoonfX5o`000?oooo]ZD_oonfX00ol0
003ooo]ZoookJP32oookJP009OoonfX5o`000?oooo]ZDooonfX2o`000<;ooo]Z000UoookJPGo0000
oooonfYEoookJP;o0000`?oonfX002Gooo]Z1Ol0003ooookJUOooo]Z0_l0002noookJP009OoonfX5
o`000?oooo]ZFOoonfX00ol0003ooo]ZoookJP2koookJP009OoonfX5o`000?oooo]ZFOoonfX00ol0
003ooo]ZoookJP2koookJP009OoonfX5o`000?oooo]ZF_oonfX2o`000;_ooo]Z000UoookJPGo0000
oooonfYLoookJP;o0000^OoonfX002Gooo]Z1Ol0003ooookJUkooo]Z00?o0000oookJ_oonfX0]_oo
nfX002Gooo]Z1Ol0003ooookJUoooo]Z00?o0000oookJ_oonfX0]OoonfX002Gooo]Z1Ol0003ooook
JV3ooo]Z00?o0000oookJ_oonfX0]?oonfX002Gooo]Z1Ol0003ooookJV7ooo]Z0_l0002doookJP00
9OoonfX5o`000?oooo]ZHooonfX00ol0003ooo]ZoookJP2aoookJP009OoonfX5o`000?oooo]ZI?oo
nfX2o`000;7ooo]Z000UoookJPGo0000oooonfYVoookJP03o`000?oonf[ooo]Z0:kooo]Z000Uoook
JPGo0000oooonfYWoookJP03o`000?oonf[ooo]Z0:gooo]Z000UoookJPGo0000oooonfYXoookJP;o
0000[OoonfX002Gooo]Z1Ol0003ooookJV[ooo]Z00?o0000oookJ_oonfX0Z_oonfX002Gooo]Z1Ol0
003ooookJV_ooo]Z00?o0000oookJ_oonfX0ZOoonfX002Gooo]Z1Ol0003ooookJVcooo]Z00?o0000
oookJ_oonfX0Z?oonfX002Gooo]Z1Ol0003ooookJVgooo]Z0_l0002XoookJP009OoonfX5o`000?oo
oo]ZKooonfX00ol0003ooo]ZoookJP2UoookJP009OoonfX5o`000?oooo]ZL?oonfX00ol0003ooo]Z
oookJP2ToookJP009OoonfX5o`000?oooo]ZLOoonfX00ol0003ooo]ZoookJP2SoookJP009OoonfX5
o`000?oooo]ZL_oonfX2o`000:?ooo]Z000UoookJPGo0000oooonfYdoookJP03o`000?oonf[ooo]Z
0:3ooo]Z000UoookJPGo0000oooonfYdoookJP03o`000?oonf[ooo]Z0:3ooo]Z000UoookJPGo0000
oooonfYeoookJP;o0000X?oonfX002Gooo]Z1Ol0003ooookJWOooo]Z00?o0000oookJ_oonfX0WOoo
nfX002Gooo]Z1Ol0003ooookJWSooo]Z00?o0000oookJ_oonfX0W?oonfX002Gooo]Z1Ol0003ooook
JWWooo]Z0_l0002LoookJP009OoonfX5o`000?oooo]ZNooonfX00ol0003ooo]ZoookJP2IoookJP00
9OoonfX5o`000?oooo]ZNooonfX00ol0003ooo]ZoookJP2IoookJP009OoonfX5o`000?oooo]ZO?oo
nfX2o`0009Wooo]Z000UoookJPGo0000oooonfYnoookJP03o`000?oonf[ooo]Z09Kooo]Z000Uoook
JPGo0000oooonfYooookJP03o`000?oonf[ooo]Z09Gooo]Z000UoookJPGo0000oooonfZ0oookJP03
o`000?oonf[ooo]Z09Cooo]Z000UoookJPGo0000oooonfZ1oookJP03o`000?oonf[ooo]Z09?ooo]Z
000>oookJP?o001o1OoonfX5o`00O`[ooo]Z1Ol0003ooookJX;ooo]Z00?o0000oookJ_oonfX0T_oo
nfX000kooo]Z0ol007l4oookJPOo001o2OoonfX5o`000?oooo]ZPooonfX2o`0009;ooo]Z000>oook
JP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJXGooo]Z00?o0000
oookJ_oonfX0SooonfX000kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooook
JXGooo]Z00?o0000oookJ_oonfX0SooonfX000kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`So
oo]Z1_l0003ooookJXGooo]Z0_l0002?oookJP003_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o
2?oonfX5o`000?oooo]ZR?oonfX00ol0003ooo]ZoookJP2<oookJP003_oonfX3o`00O`?ooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`000?oooo]ZROoonfX00ol0003ooo]ZoookJP2;oookJP003_oonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]ZR_oonfX00ol0003ooo]ZoookJP2:
oookJP003_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oooo]ZRooonfX00ol0
003ooo]ZoookJP29oookJP002ooonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o2?oonfX5o`000?oo
oo]ZS?oonfX00ol0003ooo]ZoookJP28oookJP002ooonfX6o`00O`Cooo]Z0ol007l01?oonf[o001o
o`00Ool007l9oookJPGo0000oooonfZ=oookJP03o`000?oonf[ooo]Z08Oooo]Z000=oookJPCo001o
1?oonfX7o`00O`Wooo]Z1Ol0003ooookJXkooo]Z00?o0000oookJ_oonfX0Q_oonfX000kooo]Z0ol0
07l5oookJPGo001o2_oonfX5o`000?oooo]ZSooonfX2o`0008Kooo]Z000UoookJPGo0000oooonfZA
oookJP03o`000?oonf[ooo]Z08?ooo]Z000UoookJPGo0000oooonfZAoookJP03o`000?oonf[ooo]Z
08?ooo]Z000UoookJPGo0000oooonfZBoookJP03o`000?oonf[ooo]Z08;ooo]Z000UoookJPGo0000
oooonfZCoookJP03o`000?oonf[ooo]Z087ooo]Z000UoookJPGo0000oooonfZDoookJP03o`000?oo
nf[ooo]Z083ooo]Z000UoookJPGo0000oooonfZEoookJP03o`000?oonf[ooo]Z07oooo]Z000Uoook
JPGo0000oooonfZFoookJP03o`000?oonf[ooo]Z07kooo]Z000UoookJPGo0000oooonfZGoookJP03
o`000?oonf[ooo]Z07gooo]Z000UoookJPGo0000oooonfZHoookJP03o`000?oonf[ooo]Z07cooo]Z
000UoookJPGo0000oooonfZIoookJP03o`000?oonf[ooo]Z07_ooo]Z000UoookJPGo0000oooonfZJ
oookJP03o`000?oonf[ooo]Z07[ooo]Z000UoookJPGo0000oooonfZKoookJP03o`000?oonf[ooo]Z
07Wooo]Z000UoookJPGo0000oooonfZKoookJP03o`000?oonf[ooo]Z07Wooo]Z000UoookJPGo0000
oooonfZLoookJP;o0000NOoonfX002Gooo]Z1Ol0003ooookJYkooo]Z00?o0000oookJ_oonfX0M_oo
nfX002Gooo]Z1Ol0003ooookJYoooo]Z00?o0000oookJ_oonfX0MOoonfX002Gooo]Z1Ol0003ooook
JZ3ooo]Z00?o0000oookJ_oonfX0M?oonfX002Gooo]Z1Ol0003ooookJZ7ooo]Z00?o0000oookJ_oo
nfX0LooonfX002Gooo]Z1Ol0003ooookJZ;ooo]Z00?o0000oookJ_oonfX0L_oonfX002Gooo]Z1Ol0
003ooookJZ;ooo]Z00?o0000oookJ_oonfX0L_oonfX002Gooo]Z1Ol0003ooookJZ?ooo]Z00?o0000
oookJ_oonfX0LOoonfX002Gooo]Z1Ol0003ooookJZCooo]Z00?o0000oookJ_oonfX0L?oonfX002Go
oo]Z1Ol0003ooookJZGooo]Z00?o0000oookJ_oonfX0KooonfX002Gooo]Z1Ol0003ooookJZKooo]Z
00?o0000oookJ_oonfX0K_oonfX002Gooo]Z1Ol0003ooookJZOooo]Z00?o0000oookJ_oonfX0KOoo
nfX002Gooo]Z1Ol0003ooookJZOooo]Z00?o0000oookJ_oonfX0KOoonfX002Gooo]Z1Ol0003ooook
JZSooo]Z00?o0000oookJ_oonfX0K?oonfX002Gooo]Z1Ol0003ooookJZWooo]Z00?o0000oookJ_oo
nfX0JooonfX002Gooo]Z1Ol0003ooookJZ[ooo]Z00?o0000oookJ_oonfX0J_oonfX002Gooo]Z1Ol0
003ooookJZ_ooo]Z00?o0000oookJ_oonfX0JOoonfX002Gooo]Z1Ol0003ooookJZcooo]Z00?o0000
oookJ_oonfX0J?oonfX002Gooo]Z1Ol0003ooookJZgooo]Z00?o0000oookJ_oonfX0IooonfX002Go
oo]Z1Ol0003ooookJZkooo]Z00?o0000oookJ_oonfX0I_oonfX002Gooo]Z1Ol0003ooookJZoooo]Z
00?o0000oookJ_oonfX0IOoonfX002Gooo]Z1Ol0003ooookJ[3ooo]Z00?o0000oookJ_oonfX0I?oo
nfX002Gooo]Z1Ol0003ooookJ[7ooo]Z00?o0000oookJ_oonfX0HooonfX002Gooo]Z1Ol0003ooook
J[7ooo]Z00?o0000oookJ_oonfX0HooonfX002Gooo]Z1Ol0003ooookJ[;ooo]Z00?o0000oookJ_oo
nfX0H_oonfX002Gooo]Z1Ol0003ooookJ[?ooo]Z00?o0000oookJ_oonfX0HOoonfX002Gooo]Z1Ol0
003ooookJ[?ooo]Z00?o0000oookJ_oonfX0HOoonfX002Gooo]Z1Ol0003ooookJ[Cooo]Z00?o0000
oookJ_oonfX0H?oonfX002Gooo]Z1Ol0003ooookJ[Gooo]Z00?o0000oookJ_oonfX0GooonfX002Go
oo]Z1Ol0003ooookJ[Kooo]Z00?o0000oookJ_oonfX0G_oonfX002Gooo]Z1Ol0003ooookJ[Oooo]Z
00?o0000oookJ_oonfX0GOoonfX002Gooo]Z1Ol0003ooookJ[Sooo]Z00?o0000oookJ_oonfX0G?oo
nfX002Gooo]Z1Ol0003ooookJ[Sooo]Z00?o0000oookJ_oonfX0G?oonfX002Gooo]Z1Ol0003ooook
J[Wooo]Z00?o0000oookJ_oonfX0FooonfX002Gooo]Z1Ol0003ooookJ[[ooo]Z00?o0000oookJ_oo
nfX0F_oonfX002Gooo]Z1Ol0003ooookJ[_ooo]Z00?o0000oookJ_oonfX0FOoonfX002Gooo]Z1Ol0
003ooookJ[cooo]Z00?o0000oookJ_oonfX0F?oonfX002Gooo]Z1Ol0003ooookJ[gooo]Z00?o0000
oookJ_oonfX0EooonfX002Gooo]Z1Ol0003ooookJ[gooo]Z00?o0000oookJ_oonfX0EooonfX002Go
oo]Z1Ol0003ooookJ[kooo]Z00?o0000oookJ_oonfX0E_oonfX002Gooo]Z1Ol0003ooookJ[kooo]Z
00?o0000oookJ_oonfX0E_oonfX002Gooo]Z1Ol0003ooookJ[oooo]Z00?o0000oookJ_oonfX0EOoo
nfX002Gooo]Z1Ol0003ooookJ/3ooo]Z00?o0000oookJ_oonfX0E?oonfX002Gooo]Z1Ol0003ooook
J/7ooo]Z00?o0000oookJ_oonfX0DooonfX002Gooo]Z1Ol0003ooookJ/;ooo]Z00?o0000oookJ_oo
nfX0D_oonfX002Gooo]Z1Ol0003ooookJ/?ooo]Z00?o0000oookJ_oonfX0DOoonfX002Gooo]Z1Ol0
003ooookJ/Cooo]Z00?o0000oookJ_oonfX0D?oonfX002Gooo]Z1Ol0003ooookJ/Cooo]Z00?o0000
oookJ_oonfX0D?oonfX002Gooo]Z1Ol0003ooookJ/Gooo]Z00?o0000oookJ_oonfX0CooonfX002Go
oo]Z1Ol0003ooookJ/Gooo]Z00?o0000oookJ_oonfX0CooonfX002Gooo]Z1Ol0003ooookJ/Kooo]Z
00?o0000oookJ_oonfX0C_oonfX002Gooo]Z1Ol0003ooookJ/Oooo]Z00?o0000oookJ_oonfX0COoo
nfX002Gooo]Z1Ol0003ooookJ/Sooo]Z00?o0000oookJ_oonfX0C?oonfX002Gooo]Z1Ol0003ooook
J/Wooo]Z00?o0000oookJ_oonfX0BooonfX000kooo]Z0ol007l5oookJPGo001o2_oonfX5o`000?oo
oo]ZbOoonfX00ol0003ooo]ZoookJP1;oookJP003_oonfX3o`00O`Cooo]Z1ol007l9oookJPGo0000
oooonf[:oookJP03o`000?oonf[ooo]Z04[ooo]Z000>oookJP?o001o0ooonfX4o`00O`04oookJ_l0
07oo001oo`00O`Wooo]Z1Ol0003ooookJ/[ooo]Z00?o0000oookJ_oonfX0B_oonfX000kooo]Z0ol0
07l3oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJ/_ooo]Z00?o0000oookJ_oonfX0BOoo
nfX000kooo]Z0ol007l9oookJP?o001o2?oonfX6o`000?oooo]ZbooonfX00ol0003ooo]ZoookJP18
oookJP003_oonfX3o`00O`Wooo]Z0ol007l8oookJPGo0000oooonf[=oookJP03o`000?oonf[ooo]Z
04Oooo]Z000>oookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000oooonf[>oookJP03
o`000?oonf[ooo]Z04Kooo]Z000>oookJP?o001o1?oonfX7o`00O`Wooo]Z1Ol0003ooookJ/kooo]Z
00?o0000oookJ_oonfX0A_oonfX000kooo]Z0ol007l4oookJPKo001o2_oonfX5o`000?oooo]Zcooo
nfX00ol0003ooo]ZoookJP15oookJP002ooonfX6o`00O`Cooo]Z0_l007l>oookJPGo0000oooonf[?
oookJP03o`000?oonf[ooo]Z04Gooo]Z000;oookJPKo001o1?oonfX2o`00O`kooo]Z1Ol0003ooook
J]3ooo]Z00?o0000oookJ_oonfX0A?oonfX000gooo]Z1?l007l5oookJPOo001o2?oonfX5o`000?oo
oo]ZdOoonfX00ol0003ooo]ZoookJP13oookJP003_oonfX3o`00O`Gooo]Z1ol007l8oookJPGo0000
oooonf[BoookJP03o`000?oonf[ooo]Z04;ooo]Z000UoookJPGo0000oooonf[CoookJP03o`000?oo
nf[ooo]Z047ooo]Z000UoookJPGo0000oooonf[CoookJP03o`000?oonf[ooo]Z047ooo]Z000Uoook
JPGo0000oooonf[DoookJP03o`000?oonf[ooo]Z043ooo]Z000UoookJPGo0000oooonf[EoookJP03
o`000?oonf[ooo]Z03oooo]Z000UoookJPGo0000oooonf[EoookJP03o`000?oonf[ooo]Z03oooo]Z
000UoookJPGo0000oooonf[FoookJP03o`000?oonf[ooo]Z03kooo]Z000UoookJPGo0000oooonf[F
oookJP03o`000?oonf[ooo]Z03kooo]Z000UoookJPGo0000oooonf[GoookJP03o`000?oonf[ooo]Z
03gooo]Z000UoookJPGo0000oooonf[HoookJP03o`000?oonf[ooo]Z03cooo]Z000UoookJPGo0000
oooonf[IoookJP03o`000?oonf[ooo]Z03_ooo]Z000UoookJPGo0000oooonf[JoookJP03o`000?oo
nf[ooo]Z03[ooo]Z000UoookJPGo0000oooonf[JoookJP03o`000?oonf[ooo]Z03[ooo]Z000Uoook
JPGo0000oooonf[KoookJP03o`000?oonf[ooo]Z03Wooo]Z000UoookJPGo0000oooonf[KoookJP03
o`000?oonf[ooo]Z03Wooo]Z000UoookJPGo0000oooonf[LoookJP03o`000?oonf[ooo]Z03Sooo]Z
000UoookJPGo0000oooonf[MoookJP03o`000?oonf[ooo]Z03Oooo]Z000UoookJPGo0000oooonf[M
oookJP03o`000?oonf[ooo]Z03Oooo]Z000UoookJPGo0000oooonf[NoookJP03o`000?oonf[ooo]Z
03Kooo]Z000UoookJPGo0000oooonf[OoookJP03o`000?oonf[ooo]Z03Gooo]Z000UoookJPGo0000
oooonf[OoookJP03o`000?oonf[ooo]Z03Gooo]Z000UoookJPGo0000oooonf[PoookJP03o`000?oo
nf[ooo]Z03Cooo]Z000UoookJPGo0000oooonf[PoookJP03o`000?oonf[ooo]Z03Cooo]Z000Uoook
JPGo0000oooonf[QoookJP03o`000?oonf[ooo]Z03?ooo]Z000UoookJPGo0000oooonf[RoookJP03
o`000?oonf[ooo]Z03;ooo]Z000UoookJPGo0000oooonf[RoookJP03o`000?oonf[ooo]Z03;ooo]Z
000UoookJPGo0000oooonf[SoookJP03o`000?oonf[ooo]Z037ooo]Z000UoookJPGo0000oooonf[T
oookJP03o`000?oonf[ooo]Z033ooo]Z000UoookJPGo0000oooonf[ToookJP03o`000?oonf[ooo]Z
033ooo]Z000UoookJPGo0000oooonf[UoookJP03o`000?oonf[ooo]Z02oooo]Z000UoookJPGo0000
oooonf[VoookJP03o`000?oonf[ooo]Z02kooo]Z000UoookJPGo0000oooonf[VoookJP03o`000?oo
nf[ooo]Z02kooo]Z000UoookJPGo0000oooonf[WoookJP03o`000?oonf[ooo]Z02gooo]Z000Uoook
JPGo0000oooonf[WoookJP03o`000?oonf[ooo]Z02gooo]Z000UoookJPGo0000oooonf[XoookJP03
o`000?oonf[ooo]Z02cooo]Z000UoookJPGo0000oooonf[YoookJP03o`000?oonf[ooo]Z02_ooo]Z
000UoookJPGo0000oooonf[YoookJP03o`000?oonf[ooo]Z02_ooo]Z000UoookJPGo0000oooonf[Z
oookJP03o`000?oonf[ooo]Z02[ooo]Z000UoookJPGo0000oooonf[[oookJP03o`000?oonf[ooo]Z
02Wooo]Z000UoookJPGo0000oooonf[[oookJP03o`000?oonf[ooo]Z02Wooo]Z000UoookJPGo0000
oooonf[/oookJP03o`000?oonf[ooo]Z02Sooo]Z000UoookJPGo0000oooonf[/oookJP03o`000?oo
nf[ooo]Z02Sooo]Z000UoookJPGo0000oooonf[/oookJP03o`000?oonf[ooo]Z02Sooo]Z000Uoook
JPGo0000oooonf[]oookJP03o`000?oonf[ooo]Z02Oooo]Z000UoookJPGo0000oooonf[^oookJP03
o`000?oonf[ooo]Z02Kooo]Z000UoookJPGo0000oooonf[^oookJP03o`000?oonf[ooo]Z02Kooo]Z
000UoookJPGo0000oooonf[_oookJP03o`000?oonf[ooo]Z02Gooo]Z000UoookJPGo0000oooonf[`
oookJP03o`000?oonf[ooo]Z02Cooo]Z000UoookJPGo0000oooonf[`oookJP03o`000?oonf[ooo]Z
02Cooo]Z000UoookJPGo0000oooonf[aoookJP03o`000?oonf[ooo]Z02?ooo]Z000UoookJPGo0000
oooonf[aoookJP03o`000?oonf[ooo]Z02?ooo]Z000UoookJPGo0000oooonf[aoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000UoookJPGo0000oooonf[boookJP03o`000?oonf[ooo]Z02;ooo]Z000Uoook
JPGo0000oooonf[coookJP03o`000?oonf[ooo]Z027ooo]Z000UoookJPGo0000oooonf[coookJP03
o`000?oonf[ooo]Z027ooo]Z000UoookJPGo0000oooonf[doookJP03o`000?oonf[ooo]Z023ooo]Z
000UoookJPGo0000oooonf[eoookJP03o`000?oonf[ooo]Z01oooo]Z000UoookJPGo0000oooonf[e
oookJP03o`000?oonf[ooo]Z01oooo]Z000UoookJPGo0000oooonf[foookJP03o`000?oonf[ooo]Z
01kooo]Z000UoookJPGo0000oooonf[foookJP03o`000?oonf[ooo]Z01kooo]Z000UoookJPGo0000
oooonf[foookJP03o`000?oonf[ooo]Z01kooo]Z000UoookJPGo0000oooonf[goookJP03o`000?oo
nf[ooo]Z01gooo]Z000UoookJPGo0000oooonf[hoookJP03o`000?oonf[ooo]Z01cooo]Z000Uoook
JPGo0000oooonf[hoookJP03o`000?oonf[ooo]Z01cooo]Z000UoookJPGo0000oooonf[ioookJP03
o`000?oonf[ooo]Z01_ooo]Z000UoookJPGo0000oooonf[joookJP03o`000?oonf[ooo]Z01[ooo]Z
000UoookJPGo0000oooonf[joookJP03o`000?oonf[ooo]Z01[ooo]Z000:oookJPWo001o0ooonfX5
o`00O`[ooo]Z1Ol0003ooookJ__ooo]Z00?o0000oookJ_oonfX06OoonfX000[ooo]Z2Ol007l2oook
JPOo001o2OoonfX5o`000?oooo]Zo?oonfX00ol0003ooo]ZoookJP0HoookJP002_oonfX4o`00O`Oo
oo]Z0ol007l01?oonf[o001oo`00Ool007l9oookJPGo0000oooonf[ooookJQSooo]Z000;oookJPCo
001o1OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonf[ooookJQSooo]Z000<oookJPGo001o
0ooonfX3o`00O`?ooo]Z0ol007l8oookJPKo0000oooonf[ooookJQOooo]Z000>oookJPCo001o0_oo
nfX3o`00O`?ooo]Z0ol007l8oookJPGo0000oooonf[ooookJQSooo]Z000?oookJP?o001o0_oonfX3
o`00O`?ooo]Z0ol007l8oookJPGo0000oooonf[ooookJQSooo]Z000@oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z6?oonfX000[ooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z6?oonfX0
00[ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003o
oookJ_oooo]Z6?oonfX000[ooo]Z1?l007l2oookJP?o001o0_oonfX3o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z6?oonfX000_ooo]Z1ol007l3oookJPOo001o2OoonfX5o`00
0?oooo]ZoooonfXHoookJP003?oonfX5o`00O`Gooo]Z1Ol007oooookJ_oooo]Z9ooonfX00?oooo]Z
oooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-23.3154, -1.67705, \
0.588821, 0.0628436}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    \(<< Graphics`MultipleListPlot`\)], "Input",
  CellTags->"mmtag:19:Graphics_Package__MultipleListPlot[]"],

Cell[BoxData[
    \(Trajectory[alpha_, \ F0_]\  := \ 
      Table[GrowsPropToSize[i, alpha, F0], {i, 300}]\)], "Input"],

Cell["\<\
Plotting a bunch of curves for the same \[Alpha] value, but each \
corresponding to a different initial value, demonstrates that a point in \
space \"belongs\" to a curve.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[Trajectory[ .01, \(- .5\)], Trajectory[ .01,  .5], 
      Trajectory[ .01, 1], Trajectory[ .01, 1.5], 
      PlotJoined \[Rule] True]\)], "Input",
  CellTags->"mmtag:19:MultipleListPlot[]"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.204713 0.0192028 [
[.18254 .19221 -12 -20 ]
[.18254 .19221 12 0 ]
[.34127 .19221 -17 -20 ]
[.34127 .19221 17 0 ]
[.5 .19221 -17 -20 ]
[.5 .19221 17 0 ]
[.65873 .19221 -17 -20 ]
[.65873 .19221 17 0 ]
[.81746 .19221 -17 -20 ]
[.81746 .19221 17 0 ]
[.97619 .19221 -17 -20 ]
[.97619 .19221 17 0 ]
[.01131 .01268 -36.9375 -10 ]
[.01131 .01268 0 10 ]
[.01131 .1087 -26.9375 -10 ]
[.01131 .1087 0 10 ]
[.01131 .30073 -14 -10 ]
[.01131 .30073 0 10 ]
[.01131 .39674 -24 -10 ]
[.01131 .39674 0 10 ]
[.01131 .49276 -24 -10 ]
[.01131 .49276 0 10 ]
[.01131 .58877 -24 -10 ]
[.01131 .58877 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .20471 m
.18254 .21096 L
s
gsave
.18254 .19221 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 .20471 m
.34127 .21096 L
s
gsave
.34127 .19221 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 .20471 m
.5 .21096 L
s
gsave
.5 .19221 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 .20471 m
.65873 .21096 L
s
gsave
.65873 .19221 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 .20471 m
.81746 .21096 L
s
gsave
.81746 .19221 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 .20471 m
.97619 .21096 L
s
gsave
.97619 .19221 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .20471 m
.05556 .20846 L
s
.0873 .20471 m
.0873 .20846 L
s
.11905 .20471 m
.11905 .20846 L
s
.15079 .20471 m
.15079 .20846 L
s
.21429 .20471 m
.21429 .20846 L
s
.24603 .20471 m
.24603 .20846 L
s
.27778 .20471 m
.27778 .20846 L
s
.30952 .20471 m
.30952 .20846 L
s
.37302 .20471 m
.37302 .20846 L
s
.40476 .20471 m
.40476 .20846 L
s
.43651 .20471 m
.43651 .20846 L
s
.46825 .20471 m
.46825 .20846 L
s
.53175 .20471 m
.53175 .20846 L
s
.56349 .20471 m
.56349 .20846 L
s
.59524 .20471 m
.59524 .20846 L
s
.62698 .20471 m
.62698 .20846 L
s
.69048 .20471 m
.69048 .20846 L
s
.72222 .20471 m
.72222 .20846 L
s
.75397 .20471 m
.75397 .20846 L
s
.78571 .20471 m
.78571 .20846 L
s
.84921 .20471 m
.84921 .20846 L
s
.88095 .20471 m
.88095 .20846 L
s
.9127 .20471 m
.9127 .20846 L
s
.94444 .20471 m
.94444 .20846 L
s
.01 w
0 .20471 m
1 .20471 L
s
.25 Mabswid
.02381 .01268 m
.03006 .01268 L
s
gsave
.01131 .01268 -97.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .1087 m
.03006 .1087 L
s
gsave
.01131 .1087 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02381 .30073 m
.03006 .30073 L
s
gsave
.01131 .30073 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.02381 .39674 m
.03006 .39674 L
s
gsave
.01131 .39674 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02381 .49276 m
.03006 .49276 L
s
gsave
.01131 .49276 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(15) show
1.000 setlinewidth
grestore
.02381 .58877 m
.03006 .58877 L
s
gsave
.01131 .58877 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03189 m
.02756 .03189 L
s
.02381 .05109 m
.02756 .05109 L
s
.02381 .07029 m
.02756 .07029 L
s
.02381 .0895 m
.02756 .0895 L
s
.02381 .1279 m
.02756 .1279 L
s
.02381 .1471 m
.02756 .1471 L
s
.02381 .16631 m
.02756 .16631 L
s
.02381 .18551 m
.02756 .18551 L
s
.02381 .22392 m
.02756 .22392 L
s
.02381 .24312 m
.02756 .24312 L
s
.02381 .26232 m
.02756 .26232 L
s
.02381 .28152 m
.02756 .28152 L
s
.02381 .31993 m
.02756 .31993 L
s
.02381 .33913 m
.02756 .33913 L
s
.02381 .35834 m
.02756 .35834 L
s
.02381 .37754 m
.02756 .37754 L
s
.02381 .41594 m
.02756 .41594 L
s
.02381 .43515 m
.02756 .43515 L
s
.02381 .45435 m
.02756 .45435 L
s
.02381 .47355 m
.02756 .47355 L
s
.02381 .51196 m
.02756 .51196 L
s
.02381 .53116 m
.02756 .53116 L
s
.02381 .55036 m
.02756 .55036 L
s
.02381 .56957 m
.02756 .56957 L
s
.02381 .60797 m
.02756 .60797 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02698 .19502 m
.03016 .19492 L
.03333 .19482 L
.03651 .19472 L
.03968 .19462 L
.04286 .19452 L
.04603 .19442 L
.04921 .19432 L
.05238 .19421 L
.05556 .19411 L
.05873 .194 L
.0619 .19389 L
.06508 .19379 L
.06825 .19368 L
.07143 .19357 L
.0746 .19345 L
.07778 .19334 L
.08095 .19323 L
.08413 .19311 L
.0873 .193 L
.09048 .19288 L
.09365 .19276 L
.09683 .19264 L
.1 .19252 L
.10317 .1924 L
.10635 .19228 L
.10952 .19215 L
.1127 .19203 L
.11587 .1919 L
.11905 .19177 L
.12222 .19164 L
.1254 .19151 L
.12857 .19138 L
.13175 .19125 L
.13492 .19111 L
.1381 .19098 L
.14127 .19084 L
.14444 .1907 L
.14762 .19056 L
.15079 .19042 L
.15397 .19027 L
.15714 .19013 L
.16032 .18998 L
.16349 .18984 L
.16667 .18969 L
.16984 .18954 L
.17302 .18939 L
.17619 .18923 L
.17937 .18908 L
.18254 .18892 L
Mistroke
.18571 .18876 L
.18889 .1886 L
.19206 .18844 L
.19524 .18828 L
.19841 .18812 L
.20159 .18795 L
.20476 .18778 L
.20794 .18761 L
.21111 .18744 L
.21429 .18727 L
.21746 .1871 L
.22063 .18692 L
.22381 .18674 L
.22698 .18656 L
.23016 .18638 L
.23333 .1862 L
.23651 .18601 L
.23968 .18582 L
.24286 .18564 L
.24603 .18544 L
.24921 .18525 L
.25238 .18506 L
.25556 .18486 L
.25873 .18466 L
.2619 .18446 L
.26508 .18426 L
.26825 .18405 L
.27143 .18385 L
.2746 .18364 L
.27778 .18343 L
.28095 .18322 L
.28413 .183 L
.2873 .18278 L
.29048 .18256 L
.29365 .18234 L
.29683 .18212 L
.3 .18189 L
.30317 .18167 L
.30635 .18143 L
.30952 .1812 L
.3127 .18097 L
.31587 .18073 L
.31905 .18049 L
.32222 .18025 L
.3254 .18 L
.32857 .17976 L
.33175 .17951 L
.33492 .17925 L
.3381 .179 L
.34127 .17874 L
Mistroke
.34444 .17848 L
.34762 .17822 L
.35079 .17796 L
.35397 .17769 L
.35714 .17742 L
.36032 .17714 L
.36349 .17687 L
.36667 .17659 L
.36984 .17631 L
.37302 .17603 L
.37619 .17574 L
.37937 .17545 L
.38254 .17516 L
.38571 .17486 L
.38889 .17456 L
.39206 .17426 L
.39524 .17396 L
.39841 .17365 L
.40159 .17334 L
.40476 .17302 L
.40794 .17271 L
.41111 .17239 L
.41429 .17206 L
.41746 .17174 L
.42063 .17141 L
.42381 .17107 L
.42698 .17074 L
.43016 .1704 L
.43333 .17006 L
.43651 .16971 L
.43968 .16936 L
.44286 .16901 L
.44603 .16865 L
.44921 .16829 L
.45238 .16792 L
.45556 .16756 L
.45873 .16718 L
.4619 .16681 L
.46508 .16643 L
.46825 .16605 L
.47143 .16566 L
.4746 .16527 L
.47778 .16488 L
.48095 .16448 L
.48413 .16407 L
.4873 .16367 L
.49048 .16326 L
.49365 .16284 L
.49683 .16242 L
.5 .162 L
Mistroke
.50317 .16157 L
.50635 .16114 L
.50952 .16071 L
.5127 .16027 L
.51587 .15982 L
.51905 .15937 L
.52222 .15892 L
.5254 .15846 L
.52857 .158 L
.53175 .15753 L
.53492 .15706 L
.5381 .15658 L
.54127 .1561 L
.54444 .15562 L
.54762 .15513 L
.55079 .15463 L
.55397 .15413 L
.55714 .15362 L
.56032 .15311 L
.56349 .1526 L
.56667 .15208 L
.56984 .15155 L
.57302 .15102 L
.57619 .15048 L
.57937 .14994 L
.58254 .14939 L
.58571 .14884 L
.58889 .14828 L
.59206 .14771 L
.59524 .14714 L
.59841 .14657 L
.60159 .14599 L
.60476 .1454 L
.60794 .14481 L
.61111 .14421 L
.61429 .1436 L
.61746 .14299 L
.62063 .14237 L
.62381 .14175 L
.62698 .14112 L
.63016 .14049 L
.63333 .13984 L
.63651 .13919 L
.63968 .13854 L
.64286 .13788 L
.64603 .13721 L
.64921 .13653 L
.65238 .13585 L
.65556 .13516 L
.65873 .13447 L
Mistroke
.6619 .13377 L
.66508 .13306 L
.66825 .13234 L
.67143 .13162 L
.6746 .13089 L
.67778 .13015 L
.68095 .1294 L
.68413 .12865 L
.6873 .12789 L
.69048 .12712 L
.69365 .12634 L
.69683 .12556 L
.7 .12477 L
.70317 .12397 L
.70635 .12316 L
.70952 .12235 L
.7127 .12152 L
.71587 .12069 L
.71905 .11985 L
.72222 .119 L
.7254 .11814 L
.72857 .11728 L
.73175 .1164 L
.73492 .11552 L
.7381 .11463 L
.74127 .11373 L
.74444 .11282 L
.74762 .1119 L
.75079 .11097 L
.75397 .11003 L
.75714 .10909 L
.76032 .10813 L
.76349 .10717 L
.76667 .10619 L
.76984 .1052 L
.77302 .10421 L
.77619 .1032 L
.77937 .10219 L
.78254 .10116 L
.78571 .10013 L
.78889 .09908 L
.79206 .09803 L
.79524 .09696 L
.79841 .09588 L
.80159 .09479 L
.80476 .09369 L
.80794 .09258 L
.81111 .09146 L
.81429 .09033 L
.81746 .08919 L
Mistroke
.82063 .08803 L
.82381 .08686 L
.82698 .08569 L
.83016 .0845 L
.83333 .08329 L
.83651 .08208 L
.83968 .08085 L
.84286 .07961 L
.84603 .07836 L
.84921 .0771 L
.85238 .07582 L
.85556 .07454 L
.85873 .07323 L
.8619 .07192 L
.86508 .07059 L
.86825 .06925 L
.87143 .06789 L
.8746 .06653 L
.87778 .06514 L
.88095 .06375 L
.88413 .06234 L
.8873 .06092 L
.89048 .05948 L
.89365 .05803 L
.89683 .05656 L
.9 .05508 L
.90317 .05358 L
.90635 .05207 L
.90952 .05054 L
.9127 .049 L
.91587 .04744 L
.91905 .04587 L
.92222 .04428 L
.9254 .04268 L
.92857 .04106 L
.93175 .03942 L
.93492 .03777 L
.9381 .0361 L
.94127 .03441 L
.94444 .03271 L
.94762 .03099 L
.95079 .02925 L
.95397 .0275 L
.95714 .02573 L
.96032 .02394 L
.96349 .02213 L
.96667 .0203 L
.96984 .01846 L
.97302 .0166 L
.97619 .01472 L
Mistroke
Mfstroke
.0001 w
.02698 .19502 -1.875 0 Mabsadd m
.02698 .19502 0 2.5 Mabsadd L
.02698 .19502 1.875 0 Mabsadd L
.02698 .19502 0 -2.5 Mabsadd L
.02698 .19502 -1.875 0 Mabsadd L closepath F
.03016 .19492 -1.875 0 Mabsadd m
.03016 .19492 0 2.5 Mabsadd L
.03016 .19492 1.875 0 Mabsadd L
.03016 .19492 0 -2.5 Mabsadd L
.03016 .19492 -1.875 0 Mabsadd L closepath F
.03333 .19482 -1.875 0 Mabsadd m
.03333 .19482 0 2.5 Mabsadd L
.03333 .19482 1.875 0 Mabsadd L
.03333 .19482 0 -2.5 Mabsadd L
.03333 .19482 -1.875 0 Mabsadd L closepath F
.03651 .19472 -1.875 0 Mabsadd m
.03651 .19472 0 2.5 Mabsadd L
.03651 .19472 1.875 0 Mabsadd L
.03651 .19472 0 -2.5 Mabsadd L
.03651 .19472 -1.875 0 Mabsadd L closepath F
.03968 .19462 -1.875 0 Mabsadd m
.03968 .19462 0 2.5 Mabsadd L
.03968 .19462 1.875 0 Mabsadd L
.03968 .19462 0 -2.5 Mabsadd L
.03968 .19462 -1.875 0 Mabsadd L closepath F
.04286 .19452 -1.875 0 Mabsadd m
.04286 .19452 0 2.5 Mabsadd L
.04286 .19452 1.875 0 Mabsadd L
.04286 .19452 0 -2.5 Mabsadd L
.04286 .19452 -1.875 0 Mabsadd L closepath F
.04603 .19442 -1.875 0 Mabsadd m
.04603 .19442 0 2.5 Mabsadd L
.04603 .19442 1.875 0 Mabsadd L
.04603 .19442 0 -2.5 Mabsadd L
.04603 .19442 -1.875 0 Mabsadd L closepath F
.04921 .19432 -1.875 0 Mabsadd m
.04921 .19432 0 2.5 Mabsadd L
.04921 .19432 1.875 0 Mabsadd L
.04921 .19432 0 -2.5 Mabsadd L
.04921 .19432 -1.875 0 Mabsadd L closepath F
.05238 .19421 -1.875 0 Mabsadd m
.05238 .19421 0 2.5 Mabsadd L
.05238 .19421 1.875 0 Mabsadd L
.05238 .19421 0 -2.5 Mabsadd L
.05238 .19421 -1.875 0 Mabsadd L closepath F
.05556 .19411 -1.875 0 Mabsadd m
.05556 .19411 0 2.5 Mabsadd L
.05556 .19411 1.875 0 Mabsadd L
.05556 .19411 0 -2.5 Mabsadd L
.05556 .19411 -1.875 0 Mabsadd L closepath F
.05873 .194 -1.875 0 Mabsadd m
.05873 .194 0 2.5 Mabsadd L
.05873 .194 1.875 0 Mabsadd L
.05873 .194 0 -2.5 Mabsadd L
.05873 .194 -1.875 0 Mabsadd L closepath F
.0619 .19389 -1.875 0 Mabsadd m
.0619 .19389 0 2.5 Mabsadd L
.0619 .19389 1.875 0 Mabsadd L
.0619 .19389 0 -2.5 Mabsadd L
.0619 .19389 -1.875 0 Mabsadd L closepath F
.06508 .19379 -1.875 0 Mabsadd m
.06508 .19379 0 2.5 Mabsadd L
.06508 .19379 1.875 0 Mabsadd L
.06508 .19379 0 -2.5 Mabsadd L
.06508 .19379 -1.875 0 Mabsadd L closepath F
.06825 .19368 -1.875 0 Mabsadd m
.06825 .19368 0 2.5 Mabsadd L
.06825 .19368 1.875 0 Mabsadd L
.06825 .19368 0 -2.5 Mabsadd L
.06825 .19368 -1.875 0 Mabsadd L closepath F
.07143 .19357 -1.875 0 Mabsadd m
.07143 .19357 0 2.5 Mabsadd L
.07143 .19357 1.875 0 Mabsadd L
.07143 .19357 0 -2.5 Mabsadd L
.07143 .19357 -1.875 0 Mabsadd L closepath F
.0746 .19345 -1.875 0 Mabsadd m
.0746 .19345 0 2.5 Mabsadd L
.0746 .19345 1.875 0 Mabsadd L
.0746 .19345 0 -2.5 Mabsadd L
.0746 .19345 -1.875 0 Mabsadd L closepath F
.07778 .19334 -1.875 0 Mabsadd m
.07778 .19334 0 2.5 Mabsadd L
.07778 .19334 1.875 0 Mabsadd L
.07778 .19334 0 -2.5 Mabsadd L
.07778 .19334 -1.875 0 Mabsadd L closepath F
.08095 .19323 -1.875 0 Mabsadd m
.08095 .19323 0 2.5 Mabsadd L
.08095 .19323 1.875 0 Mabsadd L
.08095 .19323 0 -2.5 Mabsadd L
.08095 .19323 -1.875 0 Mabsadd L closepath F
.08413 .19311 -1.875 0 Mabsadd m
.08413 .19311 0 2.5 Mabsadd L
.08413 .19311 1.875 0 Mabsadd L
.08413 .19311 0 -2.5 Mabsadd L
.08413 .19311 -1.875 0 Mabsadd L closepath F
.0873 .193 -1.875 0 Mabsadd m
.0873 .193 0 2.5 Mabsadd L
.0873 .193 1.875 0 Mabsadd L
.0873 .193 0 -2.5 Mabsadd L
.0873 .193 -1.875 0 Mabsadd L closepath F
.09048 .19288 -1.875 0 Mabsadd m
.09048 .19288 0 2.5 Mabsadd L
.09048 .19288 1.875 0 Mabsadd L
.09048 .19288 0 -2.5 Mabsadd L
.09048 .19288 -1.875 0 Mabsadd L closepath F
.09365 .19276 -1.875 0 Mabsadd m
.09365 .19276 0 2.5 Mabsadd L
.09365 .19276 1.875 0 Mabsadd L
.09365 .19276 0 -2.5 Mabsadd L
.09365 .19276 -1.875 0 Mabsadd L closepath F
.09683 .19264 -1.875 0 Mabsadd m
.09683 .19264 0 2.5 Mabsadd L
.09683 .19264 1.875 0 Mabsadd L
.09683 .19264 0 -2.5 Mabsadd L
.09683 .19264 -1.875 0 Mabsadd L closepath F
.1 .19252 -1.875 0 Mabsadd m
.1 .19252 0 2.5 Mabsadd L
.1 .19252 1.875 0 Mabsadd L
.1 .19252 0 -2.5 Mabsadd L
.1 .19252 -1.875 0 Mabsadd L closepath F
.10317 .1924 -1.875 0 Mabsadd m
.10317 .1924 0 2.5 Mabsadd L
.10317 .1924 1.875 0 Mabsadd L
.10317 .1924 0 -2.5 Mabsadd L
.10317 .1924 -1.875 0 Mabsadd L closepath F
.10635 .19228 -1.875 0 Mabsadd m
.10635 .19228 0 2.5 Mabsadd L
.10635 .19228 1.875 0 Mabsadd L
.10635 .19228 0 -2.5 Mabsadd L
.10635 .19228 -1.875 0 Mabsadd L closepath F
.10952 .19215 -1.875 0 Mabsadd m
.10952 .19215 0 2.5 Mabsadd L
.10952 .19215 1.875 0 Mabsadd L
.10952 .19215 0 -2.5 Mabsadd L
.10952 .19215 -1.875 0 Mabsadd L closepath F
.1127 .19203 -1.875 0 Mabsadd m
.1127 .19203 0 2.5 Mabsadd L
.1127 .19203 1.875 0 Mabsadd L
.1127 .19203 0 -2.5 Mabsadd L
.1127 .19203 -1.875 0 Mabsadd L closepath F
.11587 .1919 -1.875 0 Mabsadd m
.11587 .1919 0 2.5 Mabsadd L
.11587 .1919 1.875 0 Mabsadd L
.11587 .1919 0 -2.5 Mabsadd L
.11587 .1919 -1.875 0 Mabsadd L closepath F
.11905 .19177 -1.875 0 Mabsadd m
.11905 .19177 0 2.5 Mabsadd L
.11905 .19177 1.875 0 Mabsadd L
.11905 .19177 0 -2.5 Mabsadd L
.11905 .19177 -1.875 0 Mabsadd L closepath F
.12222 .19164 -1.875 0 Mabsadd m
.12222 .19164 0 2.5 Mabsadd L
.12222 .19164 1.875 0 Mabsadd L
.12222 .19164 0 -2.5 Mabsadd L
.12222 .19164 -1.875 0 Mabsadd L closepath F
.1254 .19151 -1.875 0 Mabsadd m
.1254 .19151 0 2.5 Mabsadd L
.1254 .19151 1.875 0 Mabsadd L
.1254 .19151 0 -2.5 Mabsadd L
.1254 .19151 -1.875 0 Mabsadd L closepath F
.12857 .19138 -1.875 0 Mabsadd m
.12857 .19138 0 2.5 Mabsadd L
.12857 .19138 1.875 0 Mabsadd L
.12857 .19138 0 -2.5 Mabsadd L
.12857 .19138 -1.875 0 Mabsadd L closepath F
.13175 .19125 -1.875 0 Mabsadd m
.13175 .19125 0 2.5 Mabsadd L
.13175 .19125 1.875 0 Mabsadd L
.13175 .19125 0 -2.5 Mabsadd L
.13175 .19125 -1.875 0 Mabsadd L closepath F
.13492 .19111 -1.875 0 Mabsadd m
.13492 .19111 0 2.5 Mabsadd L
.13492 .19111 1.875 0 Mabsadd L
.13492 .19111 0 -2.5 Mabsadd L
.13492 .19111 -1.875 0 Mabsadd L closepath F
.1381 .19098 -1.875 0 Mabsadd m
.1381 .19098 0 2.5 Mabsadd L
.1381 .19098 1.875 0 Mabsadd L
.1381 .19098 0 -2.5 Mabsadd L
.1381 .19098 -1.875 0 Mabsadd L closepath F
.14127 .19084 -1.875 0 Mabsadd m
.14127 .19084 0 2.5 Mabsadd L
.14127 .19084 1.875 0 Mabsadd L
.14127 .19084 0 -2.5 Mabsadd L
.14127 .19084 -1.875 0 Mabsadd L closepath F
.14444 .1907 -1.875 0 Mabsadd m
.14444 .1907 0 2.5 Mabsadd L
.14444 .1907 1.875 0 Mabsadd L
.14444 .1907 0 -2.5 Mabsadd L
.14444 .1907 -1.875 0 Mabsadd L closepath F
.14762 .19056 -1.875 0 Mabsadd m
.14762 .19056 0 2.5 Mabsadd L
.14762 .19056 1.875 0 Mabsadd L
.14762 .19056 0 -2.5 Mabsadd L
.14762 .19056 -1.875 0 Mabsadd L closepath F
.15079 .19042 -1.875 0 Mabsadd m
.15079 .19042 0 2.5 Mabsadd L
.15079 .19042 1.875 0 Mabsadd L
.15079 .19042 0 -2.5 Mabsadd L
.15079 .19042 -1.875 0 Mabsadd L closepath F
.15397 .19027 -1.875 0 Mabsadd m
.15397 .19027 0 2.5 Mabsadd L
.15397 .19027 1.875 0 Mabsadd L
.15397 .19027 0 -2.5 Mabsadd L
.15397 .19027 -1.875 0 Mabsadd L closepath F
.15714 .19013 -1.875 0 Mabsadd m
.15714 .19013 0 2.5 Mabsadd L
.15714 .19013 1.875 0 Mabsadd L
.15714 .19013 0 -2.5 Mabsadd L
.15714 .19013 -1.875 0 Mabsadd L closepath F
.16032 .18998 -1.875 0 Mabsadd m
.16032 .18998 0 2.5 Mabsadd L
.16032 .18998 1.875 0 Mabsadd L
.16032 .18998 0 -2.5 Mabsadd L
.16032 .18998 -1.875 0 Mabsadd L closepath F
.16349 .18984 -1.875 0 Mabsadd m
.16349 .18984 0 2.5 Mabsadd L
.16349 .18984 1.875 0 Mabsadd L
.16349 .18984 0 -2.5 Mabsadd L
.16349 .18984 -1.875 0 Mabsadd L closepath F
.16667 .18969 -1.875 0 Mabsadd m
.16667 .18969 0 2.5 Mabsadd L
.16667 .18969 1.875 0 Mabsadd L
.16667 .18969 0 -2.5 Mabsadd L
.16667 .18969 -1.875 0 Mabsadd L closepath F
.16984 .18954 -1.875 0 Mabsadd m
.16984 .18954 0 2.5 Mabsadd L
.16984 .18954 1.875 0 Mabsadd L
.16984 .18954 0 -2.5 Mabsadd L
.16984 .18954 -1.875 0 Mabsadd L closepath F
.17302 .18939 -1.875 0 Mabsadd m
.17302 .18939 0 2.5 Mabsadd L
.17302 .18939 1.875 0 Mabsadd L
.17302 .18939 0 -2.5 Mabsadd L
.17302 .18939 -1.875 0 Mabsadd L closepath F
.17619 .18923 -1.875 0 Mabsadd m
.17619 .18923 0 2.5 Mabsadd L
.17619 .18923 1.875 0 Mabsadd L
.17619 .18923 0 -2.5 Mabsadd L
.17619 .18923 -1.875 0 Mabsadd L closepath F
.17937 .18908 -1.875 0 Mabsadd m
.17937 .18908 0 2.5 Mabsadd L
.17937 .18908 1.875 0 Mabsadd L
.17937 .18908 0 -2.5 Mabsadd L
.17937 .18908 -1.875 0 Mabsadd L closepath F
.18254 .18892 -1.875 0 Mabsadd m
.18254 .18892 0 2.5 Mabsadd L
.18254 .18892 1.875 0 Mabsadd L
.18254 .18892 0 -2.5 Mabsadd L
.18254 .18892 -1.875 0 Mabsadd L closepath F
.18571 .18876 -1.875 0 Mabsadd m
.18571 .18876 0 2.5 Mabsadd L
.18571 .18876 1.875 0 Mabsadd L
.18571 .18876 0 -2.5 Mabsadd L
.18571 .18876 -1.875 0 Mabsadd L closepath F
.18889 .1886 -1.875 0 Mabsadd m
.18889 .1886 0 2.5 Mabsadd L
.18889 .1886 1.875 0 Mabsadd L
.18889 .1886 0 -2.5 Mabsadd L
.18889 .1886 -1.875 0 Mabsadd L closepath F
.19206 .18844 -1.875 0 Mabsadd m
.19206 .18844 0 2.5 Mabsadd L
.19206 .18844 1.875 0 Mabsadd L
.19206 .18844 0 -2.5 Mabsadd L
.19206 .18844 -1.875 0 Mabsadd L closepath F
.19524 .18828 -1.875 0 Mabsadd m
.19524 .18828 0 2.5 Mabsadd L
.19524 .18828 1.875 0 Mabsadd L
.19524 .18828 0 -2.5 Mabsadd L
.19524 .18828 -1.875 0 Mabsadd L closepath F
.19841 .18812 -1.875 0 Mabsadd m
.19841 .18812 0 2.5 Mabsadd L
.19841 .18812 1.875 0 Mabsadd L
.19841 .18812 0 -2.5 Mabsadd L
.19841 .18812 -1.875 0 Mabsadd L closepath F
.20159 .18795 -1.875 0 Mabsadd m
.20159 .18795 0 2.5 Mabsadd L
.20159 .18795 1.875 0 Mabsadd L
.20159 .18795 0 -2.5 Mabsadd L
.20159 .18795 -1.875 0 Mabsadd L closepath F
.20476 .18778 -1.875 0 Mabsadd m
.20476 .18778 0 2.5 Mabsadd L
.20476 .18778 1.875 0 Mabsadd L
.20476 .18778 0 -2.5 Mabsadd L
.20476 .18778 -1.875 0 Mabsadd L closepath F
.20794 .18761 -1.875 0 Mabsadd m
.20794 .18761 0 2.5 Mabsadd L
.20794 .18761 1.875 0 Mabsadd L
.20794 .18761 0 -2.5 Mabsadd L
.20794 .18761 -1.875 0 Mabsadd L closepath F
.21111 .18744 -1.875 0 Mabsadd m
.21111 .18744 0 2.5 Mabsadd L
.21111 .18744 1.875 0 Mabsadd L
.21111 .18744 0 -2.5 Mabsadd L
.21111 .18744 -1.875 0 Mabsadd L closepath F
.21429 .18727 -1.875 0 Mabsadd m
.21429 .18727 0 2.5 Mabsadd L
.21429 .18727 1.875 0 Mabsadd L
.21429 .18727 0 -2.5 Mabsadd L
.21429 .18727 -1.875 0 Mabsadd L closepath F
.21746 .1871 -1.875 0 Mabsadd m
.21746 .1871 0 2.5 Mabsadd L
.21746 .1871 1.875 0 Mabsadd L
.21746 .1871 0 -2.5 Mabsadd L
.21746 .1871 -1.875 0 Mabsadd L closepath F
.22063 .18692 -1.875 0 Mabsadd m
.22063 .18692 0 2.5 Mabsadd L
.22063 .18692 1.875 0 Mabsadd L
.22063 .18692 0 -2.5 Mabsadd L
.22063 .18692 -1.875 0 Mabsadd L closepath F
.22381 .18674 -1.875 0 Mabsadd m
.22381 .18674 0 2.5 Mabsadd L
.22381 .18674 1.875 0 Mabsadd L
.22381 .18674 0 -2.5 Mabsadd L
.22381 .18674 -1.875 0 Mabsadd L closepath F
.22698 .18656 -1.875 0 Mabsadd m
.22698 .18656 0 2.5 Mabsadd L
.22698 .18656 1.875 0 Mabsadd L
.22698 .18656 0 -2.5 Mabsadd L
.22698 .18656 -1.875 0 Mabsadd L closepath F
.23016 .18638 -1.875 0 Mabsadd m
.23016 .18638 0 2.5 Mabsadd L
.23016 .18638 1.875 0 Mabsadd L
.23016 .18638 0 -2.5 Mabsadd L
.23016 .18638 -1.875 0 Mabsadd L closepath F
.23333 .1862 -1.875 0 Mabsadd m
.23333 .1862 0 2.5 Mabsadd L
.23333 .1862 1.875 0 Mabsadd L
.23333 .1862 0 -2.5 Mabsadd L
.23333 .1862 -1.875 0 Mabsadd L closepath F
.23651 .18601 -1.875 0 Mabsadd m
.23651 .18601 0 2.5 Mabsadd L
.23651 .18601 1.875 0 Mabsadd L
.23651 .18601 0 -2.5 Mabsadd L
.23651 .18601 -1.875 0 Mabsadd L closepath F
.23968 .18582 -1.875 0 Mabsadd m
.23968 .18582 0 2.5 Mabsadd L
.23968 .18582 1.875 0 Mabsadd L
.23968 .18582 0 -2.5 Mabsadd L
.23968 .18582 -1.875 0 Mabsadd L closepath F
.24286 .18564 -1.875 0 Mabsadd m
.24286 .18564 0 2.5 Mabsadd L
.24286 .18564 1.875 0 Mabsadd L
.24286 .18564 0 -2.5 Mabsadd L
.24286 .18564 -1.875 0 Mabsadd L closepath F
.24603 .18544 -1.875 0 Mabsadd m
.24603 .18544 0 2.5 Mabsadd L
.24603 .18544 1.875 0 Mabsadd L
.24603 .18544 0 -2.5 Mabsadd L
.24603 .18544 -1.875 0 Mabsadd L closepath F
.24921 .18525 -1.875 0 Mabsadd m
.24921 .18525 0 2.5 Mabsadd L
.24921 .18525 1.875 0 Mabsadd L
.24921 .18525 0 -2.5 Mabsadd L
.24921 .18525 -1.875 0 Mabsadd L closepath F
.25238 .18506 -1.875 0 Mabsadd m
.25238 .18506 0 2.5 Mabsadd L
.25238 .18506 1.875 0 Mabsadd L
.25238 .18506 0 -2.5 Mabsadd L
.25238 .18506 -1.875 0 Mabsadd L closepath F
.25556 .18486 -1.875 0 Mabsadd m
.25556 .18486 0 2.5 Mabsadd L
.25556 .18486 1.875 0 Mabsadd L
.25556 .18486 0 -2.5 Mabsadd L
.25556 .18486 -1.875 0 Mabsadd L closepath F
.25873 .18466 -1.875 0 Mabsadd m
.25873 .18466 0 2.5 Mabsadd L
.25873 .18466 1.875 0 Mabsadd L
.25873 .18466 0 -2.5 Mabsadd L
.25873 .18466 -1.875 0 Mabsadd L closepath F
.2619 .18446 -1.875 0 Mabsadd m
.2619 .18446 0 2.5 Mabsadd L
.2619 .18446 1.875 0 Mabsadd L
.2619 .18446 0 -2.5 Mabsadd L
.2619 .18446 -1.875 0 Mabsadd L closepath F
.26508 .18426 -1.875 0 Mabsadd m
.26508 .18426 0 2.5 Mabsadd L
.26508 .18426 1.875 0 Mabsadd L
.26508 .18426 0 -2.5 Mabsadd L
.26508 .18426 -1.875 0 Mabsadd L closepath F
.26825 .18405 -1.875 0 Mabsadd m
.26825 .18405 0 2.5 Mabsadd L
.26825 .18405 1.875 0 Mabsadd L
.26825 .18405 0 -2.5 Mabsadd L
.26825 .18405 -1.875 0 Mabsadd L closepath F
.27143 .18385 -1.875 0 Mabsadd m
.27143 .18385 0 2.5 Mabsadd L
.27143 .18385 1.875 0 Mabsadd L
.27143 .18385 0 -2.5 Mabsadd L
.27143 .18385 -1.875 0 Mabsadd L closepath F
.2746 .18364 -1.875 0 Mabsadd m
.2746 .18364 0 2.5 Mabsadd L
.2746 .18364 1.875 0 Mabsadd L
.2746 .18364 0 -2.5 Mabsadd L
.2746 .18364 -1.875 0 Mabsadd L closepath F
.27778 .18343 -1.875 0 Mabsadd m
.27778 .18343 0 2.5 Mabsadd L
.27778 .18343 1.875 0 Mabsadd L
.27778 .18343 0 -2.5 Mabsadd L
.27778 .18343 -1.875 0 Mabsadd L closepath F
.28095 .18322 -1.875 0 Mabsadd m
.28095 .18322 0 2.5 Mabsadd L
.28095 .18322 1.875 0 Mabsadd L
.28095 .18322 0 -2.5 Mabsadd L
.28095 .18322 -1.875 0 Mabsadd L closepath F
.28413 .183 -1.875 0 Mabsadd m
.28413 .183 0 2.5 Mabsadd L
.28413 .183 1.875 0 Mabsadd L
.28413 .183 0 -2.5 Mabsadd L
.28413 .183 -1.875 0 Mabsadd L closepath F
.2873 .18278 -1.875 0 Mabsadd m
.2873 .18278 0 2.5 Mabsadd L
.2873 .18278 1.875 0 Mabsadd L
.2873 .18278 0 -2.5 Mabsadd L
.2873 .18278 -1.875 0 Mabsadd L closepath F
.29048 .18256 -1.875 0 Mabsadd m
.29048 .18256 0 2.5 Mabsadd L
.29048 .18256 1.875 0 Mabsadd L
.29048 .18256 0 -2.5 Mabsadd L
.29048 .18256 -1.875 0 Mabsadd L closepath F
.29365 .18234 -1.875 0 Mabsadd m
.29365 .18234 0 2.5 Mabsadd L
.29365 .18234 1.875 0 Mabsadd L
.29365 .18234 0 -2.5 Mabsadd L
.29365 .18234 -1.875 0 Mabsadd L closepath F
.29683 .18212 -1.875 0 Mabsadd m
.29683 .18212 0 2.5 Mabsadd L
.29683 .18212 1.875 0 Mabsadd L
.29683 .18212 0 -2.5 Mabsadd L
.29683 .18212 -1.875 0 Mabsadd L closepath F
.3 .18189 -1.875 0 Mabsadd m
.3 .18189 0 2.5 Mabsadd L
.3 .18189 1.875 0 Mabsadd L
.3 .18189 0 -2.5 Mabsadd L
.3 .18189 -1.875 0 Mabsadd L closepath F
.30317 .18167 -1.875 0 Mabsadd m
.30317 .18167 0 2.5 Mabsadd L
.30317 .18167 1.875 0 Mabsadd L
.30317 .18167 0 -2.5 Mabsadd L
.30317 .18167 -1.875 0 Mabsadd L closepath F
.30635 .18143 -1.875 0 Mabsadd m
.30635 .18143 0 2.5 Mabsadd L
.30635 .18143 1.875 0 Mabsadd L
.30635 .18143 0 -2.5 Mabsadd L
.30635 .18143 -1.875 0 Mabsadd L closepath F
.30952 .1812 -1.875 0 Mabsadd m
.30952 .1812 0 2.5 Mabsadd L
.30952 .1812 1.875 0 Mabsadd L
.30952 .1812 0 -2.5 Mabsadd L
.30952 .1812 -1.875 0 Mabsadd L closepath F
.3127 .18097 -1.875 0 Mabsadd m
.3127 .18097 0 2.5 Mabsadd L
.3127 .18097 1.875 0 Mabsadd L
.3127 .18097 0 -2.5 Mabsadd L
.3127 .18097 -1.875 0 Mabsadd L closepath F
.31587 .18073 -1.875 0 Mabsadd m
.31587 .18073 0 2.5 Mabsadd L
.31587 .18073 1.875 0 Mabsadd L
.31587 .18073 0 -2.5 Mabsadd L
.31587 .18073 -1.875 0 Mabsadd L closepath F
.31905 .18049 -1.875 0 Mabsadd m
.31905 .18049 0 2.5 Mabsadd L
.31905 .18049 1.875 0 Mabsadd L
.31905 .18049 0 -2.5 Mabsadd L
.31905 .18049 -1.875 0 Mabsadd L closepath F
.32222 .18025 -1.875 0 Mabsadd m
.32222 .18025 0 2.5 Mabsadd L
.32222 .18025 1.875 0 Mabsadd L
.32222 .18025 0 -2.5 Mabsadd L
.32222 .18025 -1.875 0 Mabsadd L closepath F
.3254 .18 -1.875 0 Mabsadd m
.3254 .18 0 2.5 Mabsadd L
.3254 .18 1.875 0 Mabsadd L
.3254 .18 0 -2.5 Mabsadd L
.3254 .18 -1.875 0 Mabsadd L closepath F
.32857 .17976 -1.875 0 Mabsadd m
.32857 .17976 0 2.5 Mabsadd L
.32857 .17976 1.875 0 Mabsadd L
.32857 .17976 0 -2.5 Mabsadd L
.32857 .17976 -1.875 0 Mabsadd L closepath F
.33175 .17951 -1.875 0 Mabsadd m
.33175 .17951 0 2.5 Mabsadd L
.33175 .17951 1.875 0 Mabsadd L
.33175 .17951 0 -2.5 Mabsadd L
.33175 .17951 -1.875 0 Mabsadd L closepath F
.33492 .17925 -1.875 0 Mabsadd m
.33492 .17925 0 2.5 Mabsadd L
.33492 .17925 1.875 0 Mabsadd L
.33492 .17925 0 -2.5 Mabsadd L
.33492 .17925 -1.875 0 Mabsadd L closepath F
.3381 .179 -1.875 0 Mabsadd m
.3381 .179 0 2.5 Mabsadd L
.3381 .179 1.875 0 Mabsadd L
.3381 .179 0 -2.5 Mabsadd L
.3381 .179 -1.875 0 Mabsadd L closepath F
.34127 .17874 -1.875 0 Mabsadd m
.34127 .17874 0 2.5 Mabsadd L
.34127 .17874 1.875 0 Mabsadd L
.34127 .17874 0 -2.5 Mabsadd L
.34127 .17874 -1.875 0 Mabsadd L closepath F
.34444 .17848 -1.875 0 Mabsadd m
.34444 .17848 0 2.5 Mabsadd L
.34444 .17848 1.875 0 Mabsadd L
.34444 .17848 0 -2.5 Mabsadd L
.34444 .17848 -1.875 0 Mabsadd L closepath F
.34762 .17822 -1.875 0 Mabsadd m
.34762 .17822 0 2.5 Mabsadd L
.34762 .17822 1.875 0 Mabsadd L
.34762 .17822 0 -2.5 Mabsadd L
.34762 .17822 -1.875 0 Mabsadd L closepath F
.35079 .17796 -1.875 0 Mabsadd m
.35079 .17796 0 2.5 Mabsadd L
.35079 .17796 1.875 0 Mabsadd L
.35079 .17796 0 -2.5 Mabsadd L
.35079 .17796 -1.875 0 Mabsadd L closepath F
.35397 .17769 -1.875 0 Mabsadd m
.35397 .17769 0 2.5 Mabsadd L
.35397 .17769 1.875 0 Mabsadd L
.35397 .17769 0 -2.5 Mabsadd L
.35397 .17769 -1.875 0 Mabsadd L closepath F
.35714 .17742 -1.875 0 Mabsadd m
.35714 .17742 0 2.5 Mabsadd L
.35714 .17742 1.875 0 Mabsadd L
.35714 .17742 0 -2.5 Mabsadd L
.35714 .17742 -1.875 0 Mabsadd L closepath F
.36032 .17714 -1.875 0 Mabsadd m
.36032 .17714 0 2.5 Mabsadd L
.36032 .17714 1.875 0 Mabsadd L
.36032 .17714 0 -2.5 Mabsadd L
.36032 .17714 -1.875 0 Mabsadd L closepath F
.36349 .17687 -1.875 0 Mabsadd m
.36349 .17687 0 2.5 Mabsadd L
.36349 .17687 1.875 0 Mabsadd L
.36349 .17687 0 -2.5 Mabsadd L
.36349 .17687 -1.875 0 Mabsadd L closepath F
.36667 .17659 -1.875 0 Mabsadd m
.36667 .17659 0 2.5 Mabsadd L
.36667 .17659 1.875 0 Mabsadd L
.36667 .17659 0 -2.5 Mabsadd L
.36667 .17659 -1.875 0 Mabsadd L closepath F
.36984 .17631 -1.875 0 Mabsadd m
.36984 .17631 0 2.5 Mabsadd L
.36984 .17631 1.875 0 Mabsadd L
.36984 .17631 0 -2.5 Mabsadd L
.36984 .17631 -1.875 0 Mabsadd L closepath F
.37302 .17603 -1.875 0 Mabsadd m
.37302 .17603 0 2.5 Mabsadd L
.37302 .17603 1.875 0 Mabsadd L
.37302 .17603 0 -2.5 Mabsadd L
.37302 .17603 -1.875 0 Mabsadd L closepath F
.37619 .17574 -1.875 0 Mabsadd m
.37619 .17574 0 2.5 Mabsadd L
.37619 .17574 1.875 0 Mabsadd L
.37619 .17574 0 -2.5 Mabsadd L
.37619 .17574 -1.875 0 Mabsadd L closepath F
.37937 .17545 -1.875 0 Mabsadd m
.37937 .17545 0 2.5 Mabsadd L
.37937 .17545 1.875 0 Mabsadd L
.37937 .17545 0 -2.5 Mabsadd L
.37937 .17545 -1.875 0 Mabsadd L closepath F
.38254 .17516 -1.875 0 Mabsadd m
.38254 .17516 0 2.5 Mabsadd L
.38254 .17516 1.875 0 Mabsadd L
.38254 .17516 0 -2.5 Mabsadd L
.38254 .17516 -1.875 0 Mabsadd L closepath F
.38571 .17486 -1.875 0 Mabsadd m
.38571 .17486 0 2.5 Mabsadd L
.38571 .17486 1.875 0 Mabsadd L
.38571 .17486 0 -2.5 Mabsadd L
.38571 .17486 -1.875 0 Mabsadd L closepath F
.38889 .17456 -1.875 0 Mabsadd m
.38889 .17456 0 2.5 Mabsadd L
.38889 .17456 1.875 0 Mabsadd L
.38889 .17456 0 -2.5 Mabsadd L
.38889 .17456 -1.875 0 Mabsadd L closepath F
.39206 .17426 -1.875 0 Mabsadd m
.39206 .17426 0 2.5 Mabsadd L
.39206 .17426 1.875 0 Mabsadd L
.39206 .17426 0 -2.5 Mabsadd L
.39206 .17426 -1.875 0 Mabsadd L closepath F
.39524 .17396 -1.875 0 Mabsadd m
.39524 .17396 0 2.5 Mabsadd L
.39524 .17396 1.875 0 Mabsadd L
.39524 .17396 0 -2.5 Mabsadd L
.39524 .17396 -1.875 0 Mabsadd L closepath F
.39841 .17365 -1.875 0 Mabsadd m
.39841 .17365 0 2.5 Mabsadd L
.39841 .17365 1.875 0 Mabsadd L
.39841 .17365 0 -2.5 Mabsadd L
.39841 .17365 -1.875 0 Mabsadd L closepath F
.40159 .17334 -1.875 0 Mabsadd m
.40159 .17334 0 2.5 Mabsadd L
.40159 .17334 1.875 0 Mabsadd L
.40159 .17334 0 -2.5 Mabsadd L
.40159 .17334 -1.875 0 Mabsadd L closepath F
.40476 .17302 -1.875 0 Mabsadd m
.40476 .17302 0 2.5 Mabsadd L
.40476 .17302 1.875 0 Mabsadd L
.40476 .17302 0 -2.5 Mabsadd L
.40476 .17302 -1.875 0 Mabsadd L closepath F
.40794 .17271 -1.875 0 Mabsadd m
.40794 .17271 0 2.5 Mabsadd L
.40794 .17271 1.875 0 Mabsadd L
.40794 .17271 0 -2.5 Mabsadd L
.40794 .17271 -1.875 0 Mabsadd L closepath F
.41111 .17239 -1.875 0 Mabsadd m
.41111 .17239 0 2.5 Mabsadd L
.41111 .17239 1.875 0 Mabsadd L
.41111 .17239 0 -2.5 Mabsadd L
.41111 .17239 -1.875 0 Mabsadd L closepath F
.41429 .17206 -1.875 0 Mabsadd m
.41429 .17206 0 2.5 Mabsadd L
.41429 .17206 1.875 0 Mabsadd L
.41429 .17206 0 -2.5 Mabsadd L
.41429 .17206 -1.875 0 Mabsadd L closepath F
.41746 .17174 -1.875 0 Mabsadd m
.41746 .17174 0 2.5 Mabsadd L
.41746 .17174 1.875 0 Mabsadd L
.41746 .17174 0 -2.5 Mabsadd L
.41746 .17174 -1.875 0 Mabsadd L closepath F
.42063 .17141 -1.875 0 Mabsadd m
.42063 .17141 0 2.5 Mabsadd L
.42063 .17141 1.875 0 Mabsadd L
.42063 .17141 0 -2.5 Mabsadd L
.42063 .17141 -1.875 0 Mabsadd L closepath F
.42381 .17107 -1.875 0 Mabsadd m
.42381 .17107 0 2.5 Mabsadd L
.42381 .17107 1.875 0 Mabsadd L
.42381 .17107 0 -2.5 Mabsadd L
.42381 .17107 -1.875 0 Mabsadd L closepath F
.42698 .17074 -1.875 0 Mabsadd m
.42698 .17074 0 2.5 Mabsadd L
.42698 .17074 1.875 0 Mabsadd L
.42698 .17074 0 -2.5 Mabsadd L
.42698 .17074 -1.875 0 Mabsadd L closepath F
.43016 .1704 -1.875 0 Mabsadd m
.43016 .1704 0 2.5 Mabsadd L
.43016 .1704 1.875 0 Mabsadd L
.43016 .1704 0 -2.5 Mabsadd L
.43016 .1704 -1.875 0 Mabsadd L closepath F
.43333 .17006 -1.875 0 Mabsadd m
.43333 .17006 0 2.5 Mabsadd L
.43333 .17006 1.875 0 Mabsadd L
.43333 .17006 0 -2.5 Mabsadd L
.43333 .17006 -1.875 0 Mabsadd L closepath F
.43651 .16971 -1.875 0 Mabsadd m
.43651 .16971 0 2.5 Mabsadd L
.43651 .16971 1.875 0 Mabsadd L
.43651 .16971 0 -2.5 Mabsadd L
.43651 .16971 -1.875 0 Mabsadd L closepath F
.43968 .16936 -1.875 0 Mabsadd m
.43968 .16936 0 2.5 Mabsadd L
.43968 .16936 1.875 0 Mabsadd L
.43968 .16936 0 -2.5 Mabsadd L
.43968 .16936 -1.875 0 Mabsadd L closepath F
.44286 .16901 -1.875 0 Mabsadd m
.44286 .16901 0 2.5 Mabsadd L
.44286 .16901 1.875 0 Mabsadd L
.44286 .16901 0 -2.5 Mabsadd L
.44286 .16901 -1.875 0 Mabsadd L closepath F
.44603 .16865 -1.875 0 Mabsadd m
.44603 .16865 0 2.5 Mabsadd L
.44603 .16865 1.875 0 Mabsadd L
.44603 .16865 0 -2.5 Mabsadd L
.44603 .16865 -1.875 0 Mabsadd L closepath F
.44921 .16829 -1.875 0 Mabsadd m
.44921 .16829 0 2.5 Mabsadd L
.44921 .16829 1.875 0 Mabsadd L
.44921 .16829 0 -2.5 Mabsadd L
.44921 .16829 -1.875 0 Mabsadd L closepath F
.45238 .16792 -1.875 0 Mabsadd m
.45238 .16792 0 2.5 Mabsadd L
.45238 .16792 1.875 0 Mabsadd L
.45238 .16792 0 -2.5 Mabsadd L
.45238 .16792 -1.875 0 Mabsadd L closepath F
.45556 .16756 -1.875 0 Mabsadd m
.45556 .16756 0 2.5 Mabsadd L
.45556 .16756 1.875 0 Mabsadd L
.45556 .16756 0 -2.5 Mabsadd L
.45556 .16756 -1.875 0 Mabsadd L closepath F
.45873 .16718 -1.875 0 Mabsadd m
.45873 .16718 0 2.5 Mabsadd L
.45873 .16718 1.875 0 Mabsadd L
.45873 .16718 0 -2.5 Mabsadd L
.45873 .16718 -1.875 0 Mabsadd L closepath F
.4619 .16681 -1.875 0 Mabsadd m
.4619 .16681 0 2.5 Mabsadd L
.4619 .16681 1.875 0 Mabsadd L
.4619 .16681 0 -2.5 Mabsadd L
.4619 .16681 -1.875 0 Mabsadd L closepath F
.46508 .16643 -1.875 0 Mabsadd m
.46508 .16643 0 2.5 Mabsadd L
.46508 .16643 1.875 0 Mabsadd L
.46508 .16643 0 -2.5 Mabsadd L
.46508 .16643 -1.875 0 Mabsadd L closepath F
.46825 .16605 -1.875 0 Mabsadd m
.46825 .16605 0 2.5 Mabsadd L
.46825 .16605 1.875 0 Mabsadd L
.46825 .16605 0 -2.5 Mabsadd L
.46825 .16605 -1.875 0 Mabsadd L closepath F
.47143 .16566 -1.875 0 Mabsadd m
.47143 .16566 0 2.5 Mabsadd L
.47143 .16566 1.875 0 Mabsadd L
.47143 .16566 0 -2.5 Mabsadd L
.47143 .16566 -1.875 0 Mabsadd L closepath F
.4746 .16527 -1.875 0 Mabsadd m
.4746 .16527 0 2.5 Mabsadd L
.4746 .16527 1.875 0 Mabsadd L
.4746 .16527 0 -2.5 Mabsadd L
.4746 .16527 -1.875 0 Mabsadd L closepath F
.47778 .16488 -1.875 0 Mabsadd m
.47778 .16488 0 2.5 Mabsadd L
.47778 .16488 1.875 0 Mabsadd L
.47778 .16488 0 -2.5 Mabsadd L
.47778 .16488 -1.875 0 Mabsadd L closepath F
.48095 .16448 -1.875 0 Mabsadd m
.48095 .16448 0 2.5 Mabsadd L
.48095 .16448 1.875 0 Mabsadd L
.48095 .16448 0 -2.5 Mabsadd L
.48095 .16448 -1.875 0 Mabsadd L closepath F
.48413 .16407 -1.875 0 Mabsadd m
.48413 .16407 0 2.5 Mabsadd L
.48413 .16407 1.875 0 Mabsadd L
.48413 .16407 0 -2.5 Mabsadd L
.48413 .16407 -1.875 0 Mabsadd L closepath F
.4873 .16367 -1.875 0 Mabsadd m
.4873 .16367 0 2.5 Mabsadd L
.4873 .16367 1.875 0 Mabsadd L
.4873 .16367 0 -2.5 Mabsadd L
.4873 .16367 -1.875 0 Mabsadd L closepath F
.49048 .16326 -1.875 0 Mabsadd m
.49048 .16326 0 2.5 Mabsadd L
.49048 .16326 1.875 0 Mabsadd L
.49048 .16326 0 -2.5 Mabsadd L
.49048 .16326 -1.875 0 Mabsadd L closepath F
.49365 .16284 -1.875 0 Mabsadd m
.49365 .16284 0 2.5 Mabsadd L
.49365 .16284 1.875 0 Mabsadd L
.49365 .16284 0 -2.5 Mabsadd L
.49365 .16284 -1.875 0 Mabsadd L closepath F
.49683 .16242 -1.875 0 Mabsadd m
.49683 .16242 0 2.5 Mabsadd L
.49683 .16242 1.875 0 Mabsadd L
.49683 .16242 0 -2.5 Mabsadd L
.49683 .16242 -1.875 0 Mabsadd L closepath F
.5 .162 -1.875 0 Mabsadd m
.5 .162 0 2.5 Mabsadd L
.5 .162 1.875 0 Mabsadd L
.5 .162 0 -2.5 Mabsadd L
.5 .162 -1.875 0 Mabsadd L closepath F
.50317 .16157 -1.875 0 Mabsadd m
.50317 .16157 0 2.5 Mabsadd L
.50317 .16157 1.875 0 Mabsadd L
.50317 .16157 0 -2.5 Mabsadd L
.50317 .16157 -1.875 0 Mabsadd L closepath F
.50635 .16114 -1.875 0 Mabsadd m
.50635 .16114 0 2.5 Mabsadd L
.50635 .16114 1.875 0 Mabsadd L
.50635 .16114 0 -2.5 Mabsadd L
.50635 .16114 -1.875 0 Mabsadd L closepath F
.50952 .16071 -1.875 0 Mabsadd m
.50952 .16071 0 2.5 Mabsadd L
.50952 .16071 1.875 0 Mabsadd L
.50952 .16071 0 -2.5 Mabsadd L
.50952 .16071 -1.875 0 Mabsadd L closepath F
.5127 .16027 -1.875 0 Mabsadd m
.5127 .16027 0 2.5 Mabsadd L
.5127 .16027 1.875 0 Mabsadd L
.5127 .16027 0 -2.5 Mabsadd L
.5127 .16027 -1.875 0 Mabsadd L closepath F
.51587 .15982 -1.875 0 Mabsadd m
.51587 .15982 0 2.5 Mabsadd L
.51587 .15982 1.875 0 Mabsadd L
.51587 .15982 0 -2.5 Mabsadd L
.51587 .15982 -1.875 0 Mabsadd L closepath F
.51905 .15937 -1.875 0 Mabsadd m
.51905 .15937 0 2.5 Mabsadd L
.51905 .15937 1.875 0 Mabsadd L
.51905 .15937 0 -2.5 Mabsadd L
.51905 .15937 -1.875 0 Mabsadd L closepath F
.52222 .15892 -1.875 0 Mabsadd m
.52222 .15892 0 2.5 Mabsadd L
.52222 .15892 1.875 0 Mabsadd L
.52222 .15892 0 -2.5 Mabsadd L
.52222 .15892 -1.875 0 Mabsadd L closepath F
.5254 .15846 -1.875 0 Mabsadd m
.5254 .15846 0 2.5 Mabsadd L
.5254 .15846 1.875 0 Mabsadd L
.5254 .15846 0 -2.5 Mabsadd L
.5254 .15846 -1.875 0 Mabsadd L closepath F
.52857 .158 -1.875 0 Mabsadd m
.52857 .158 0 2.5 Mabsadd L
.52857 .158 1.875 0 Mabsadd L
.52857 .158 0 -2.5 Mabsadd L
.52857 .158 -1.875 0 Mabsadd L closepath F
.53175 .15753 -1.875 0 Mabsadd m
.53175 .15753 0 2.5 Mabsadd L
.53175 .15753 1.875 0 Mabsadd L
.53175 .15753 0 -2.5 Mabsadd L
.53175 .15753 -1.875 0 Mabsadd L closepath F
.53492 .15706 -1.875 0 Mabsadd m
.53492 .15706 0 2.5 Mabsadd L
.53492 .15706 1.875 0 Mabsadd L
.53492 .15706 0 -2.5 Mabsadd L
.53492 .15706 -1.875 0 Mabsadd L closepath F
.5381 .15658 -1.875 0 Mabsadd m
.5381 .15658 0 2.5 Mabsadd L
.5381 .15658 1.875 0 Mabsadd L
.5381 .15658 0 -2.5 Mabsadd L
.5381 .15658 -1.875 0 Mabsadd L closepath F
.54127 .1561 -1.875 0 Mabsadd m
.54127 .1561 0 2.5 Mabsadd L
.54127 .1561 1.875 0 Mabsadd L
.54127 .1561 0 -2.5 Mabsadd L
.54127 .1561 -1.875 0 Mabsadd L closepath F
.54444 .15562 -1.875 0 Mabsadd m
.54444 .15562 0 2.5 Mabsadd L
.54444 .15562 1.875 0 Mabsadd L
.54444 .15562 0 -2.5 Mabsadd L
.54444 .15562 -1.875 0 Mabsadd L closepath F
.54762 .15513 -1.875 0 Mabsadd m
.54762 .15513 0 2.5 Mabsadd L
.54762 .15513 1.875 0 Mabsadd L
.54762 .15513 0 -2.5 Mabsadd L
.54762 .15513 -1.875 0 Mabsadd L closepath F
.55079 .15463 -1.875 0 Mabsadd m
.55079 .15463 0 2.5 Mabsadd L
.55079 .15463 1.875 0 Mabsadd L
.55079 .15463 0 -2.5 Mabsadd L
.55079 .15463 -1.875 0 Mabsadd L closepath F
.55397 .15413 -1.875 0 Mabsadd m
.55397 .15413 0 2.5 Mabsadd L
.55397 .15413 1.875 0 Mabsadd L
.55397 .15413 0 -2.5 Mabsadd L
.55397 .15413 -1.875 0 Mabsadd L closepath F
.55714 .15362 -1.875 0 Mabsadd m
.55714 .15362 0 2.5 Mabsadd L
.55714 .15362 1.875 0 Mabsadd L
.55714 .15362 0 -2.5 Mabsadd L
.55714 .15362 -1.875 0 Mabsadd L closepath F
.56032 .15311 -1.875 0 Mabsadd m
.56032 .15311 0 2.5 Mabsadd L
.56032 .15311 1.875 0 Mabsadd L
.56032 .15311 0 -2.5 Mabsadd L
.56032 .15311 -1.875 0 Mabsadd L closepath F
.56349 .1526 -1.875 0 Mabsadd m
.56349 .1526 0 2.5 Mabsadd L
.56349 .1526 1.875 0 Mabsadd L
.56349 .1526 0 -2.5 Mabsadd L
.56349 .1526 -1.875 0 Mabsadd L closepath F
.56667 .15208 -1.875 0 Mabsadd m
.56667 .15208 0 2.5 Mabsadd L
.56667 .15208 1.875 0 Mabsadd L
.56667 .15208 0 -2.5 Mabsadd L
.56667 .15208 -1.875 0 Mabsadd L closepath F
.56984 .15155 -1.875 0 Mabsadd m
.56984 .15155 0 2.5 Mabsadd L
.56984 .15155 1.875 0 Mabsadd L
.56984 .15155 0 -2.5 Mabsadd L
.56984 .15155 -1.875 0 Mabsadd L closepath F
.57302 .15102 -1.875 0 Mabsadd m
.57302 .15102 0 2.5 Mabsadd L
.57302 .15102 1.875 0 Mabsadd L
.57302 .15102 0 -2.5 Mabsadd L
.57302 .15102 -1.875 0 Mabsadd L closepath F
.57619 .15048 -1.875 0 Mabsadd m
.57619 .15048 0 2.5 Mabsadd L
.57619 .15048 1.875 0 Mabsadd L
.57619 .15048 0 -2.5 Mabsadd L
.57619 .15048 -1.875 0 Mabsadd L closepath F
.57937 .14994 -1.875 0 Mabsadd m
.57937 .14994 0 2.5 Mabsadd L
.57937 .14994 1.875 0 Mabsadd L
.57937 .14994 0 -2.5 Mabsadd L
.57937 .14994 -1.875 0 Mabsadd L closepath F
.58254 .14939 -1.875 0 Mabsadd m
.58254 .14939 0 2.5 Mabsadd L
.58254 .14939 1.875 0 Mabsadd L
.58254 .14939 0 -2.5 Mabsadd L
.58254 .14939 -1.875 0 Mabsadd L closepath F
.58571 .14884 -1.875 0 Mabsadd m
.58571 .14884 0 2.5 Mabsadd L
.58571 .14884 1.875 0 Mabsadd L
.58571 .14884 0 -2.5 Mabsadd L
.58571 .14884 -1.875 0 Mabsadd L closepath F
.58889 .14828 -1.875 0 Mabsadd m
.58889 .14828 0 2.5 Mabsadd L
.58889 .14828 1.875 0 Mabsadd L
.58889 .14828 0 -2.5 Mabsadd L
.58889 .14828 -1.875 0 Mabsadd L closepath F
.59206 .14771 -1.875 0 Mabsadd m
.59206 .14771 0 2.5 Mabsadd L
.59206 .14771 1.875 0 Mabsadd L
.59206 .14771 0 -2.5 Mabsadd L
.59206 .14771 -1.875 0 Mabsadd L closepath F
.59524 .14714 -1.875 0 Mabsadd m
.59524 .14714 0 2.5 Mabsadd L
.59524 .14714 1.875 0 Mabsadd L
.59524 .14714 0 -2.5 Mabsadd L
.59524 .14714 -1.875 0 Mabsadd L closepath F
.59841 .14657 -1.875 0 Mabsadd m
.59841 .14657 0 2.5 Mabsadd L
.59841 .14657 1.875 0 Mabsadd L
.59841 .14657 0 -2.5 Mabsadd L
.59841 .14657 -1.875 0 Mabsadd L closepath F
.60159 .14599 -1.875 0 Mabsadd m
.60159 .14599 0 2.5 Mabsadd L
.60159 .14599 1.875 0 Mabsadd L
.60159 .14599 0 -2.5 Mabsadd L
.60159 .14599 -1.875 0 Mabsadd L closepath F
.60476 .1454 -1.875 0 Mabsadd m
.60476 .1454 0 2.5 Mabsadd L
.60476 .1454 1.875 0 Mabsadd L
.60476 .1454 0 -2.5 Mabsadd L
.60476 .1454 -1.875 0 Mabsadd L closepath F
.60794 .14481 -1.875 0 Mabsadd m
.60794 .14481 0 2.5 Mabsadd L
.60794 .14481 1.875 0 Mabsadd L
.60794 .14481 0 -2.5 Mabsadd L
.60794 .14481 -1.875 0 Mabsadd L closepath F
.61111 .14421 -1.875 0 Mabsadd m
.61111 .14421 0 2.5 Mabsadd L
.61111 .14421 1.875 0 Mabsadd L
.61111 .14421 0 -2.5 Mabsadd L
.61111 .14421 -1.875 0 Mabsadd L closepath F
.61429 .1436 -1.875 0 Mabsadd m
.61429 .1436 0 2.5 Mabsadd L
.61429 .1436 1.875 0 Mabsadd L
.61429 .1436 0 -2.5 Mabsadd L
.61429 .1436 -1.875 0 Mabsadd L closepath F
.61746 .14299 -1.875 0 Mabsadd m
.61746 .14299 0 2.5 Mabsadd L
.61746 .14299 1.875 0 Mabsadd L
.61746 .14299 0 -2.5 Mabsadd L
.61746 .14299 -1.875 0 Mabsadd L closepath F
.62063 .14237 -1.875 0 Mabsadd m
.62063 .14237 0 2.5 Mabsadd L
.62063 .14237 1.875 0 Mabsadd L
.62063 .14237 0 -2.5 Mabsadd L
.62063 .14237 -1.875 0 Mabsadd L closepath F
.62381 .14175 -1.875 0 Mabsadd m
.62381 .14175 0 2.5 Mabsadd L
.62381 .14175 1.875 0 Mabsadd L
.62381 .14175 0 -2.5 Mabsadd L
.62381 .14175 -1.875 0 Mabsadd L closepath F
.62698 .14112 -1.875 0 Mabsadd m
.62698 .14112 0 2.5 Mabsadd L
.62698 .14112 1.875 0 Mabsadd L
.62698 .14112 0 -2.5 Mabsadd L
.62698 .14112 -1.875 0 Mabsadd L closepath F
.63016 .14049 -1.875 0 Mabsadd m
.63016 .14049 0 2.5 Mabsadd L
.63016 .14049 1.875 0 Mabsadd L
.63016 .14049 0 -2.5 Mabsadd L
.63016 .14049 -1.875 0 Mabsadd L closepath F
.63333 .13984 -1.875 0 Mabsadd m
.63333 .13984 0 2.5 Mabsadd L
.63333 .13984 1.875 0 Mabsadd L
.63333 .13984 0 -2.5 Mabsadd L
.63333 .13984 -1.875 0 Mabsadd L closepath F
.63651 .13919 -1.875 0 Mabsadd m
.63651 .13919 0 2.5 Mabsadd L
.63651 .13919 1.875 0 Mabsadd L
.63651 .13919 0 -2.5 Mabsadd L
.63651 .13919 -1.875 0 Mabsadd L closepath F
.63968 .13854 -1.875 0 Mabsadd m
.63968 .13854 0 2.5 Mabsadd L
.63968 .13854 1.875 0 Mabsadd L
.63968 .13854 0 -2.5 Mabsadd L
.63968 .13854 -1.875 0 Mabsadd L closepath F
.64286 .13788 -1.875 0 Mabsadd m
.64286 .13788 0 2.5 Mabsadd L
.64286 .13788 1.875 0 Mabsadd L
.64286 .13788 0 -2.5 Mabsadd L
.64286 .13788 -1.875 0 Mabsadd L closepath F
.64603 .13721 -1.875 0 Mabsadd m
.64603 .13721 0 2.5 Mabsadd L
.64603 .13721 1.875 0 Mabsadd L
.64603 .13721 0 -2.5 Mabsadd L
.64603 .13721 -1.875 0 Mabsadd L closepath F
.64921 .13653 -1.875 0 Mabsadd m
.64921 .13653 0 2.5 Mabsadd L
.64921 .13653 1.875 0 Mabsadd L
.64921 .13653 0 -2.5 Mabsadd L
.64921 .13653 -1.875 0 Mabsadd L closepath F
.65238 .13585 -1.875 0 Mabsadd m
.65238 .13585 0 2.5 Mabsadd L
.65238 .13585 1.875 0 Mabsadd L
.65238 .13585 0 -2.5 Mabsadd L
.65238 .13585 -1.875 0 Mabsadd L closepath F
.65556 .13516 -1.875 0 Mabsadd m
.65556 .13516 0 2.5 Mabsadd L
.65556 .13516 1.875 0 Mabsadd L
.65556 .13516 0 -2.5 Mabsadd L
.65556 .13516 -1.875 0 Mabsadd L closepath F
.65873 .13447 -1.875 0 Mabsadd m
.65873 .13447 0 2.5 Mabsadd L
.65873 .13447 1.875 0 Mabsadd L
.65873 .13447 0 -2.5 Mabsadd L
.65873 .13447 -1.875 0 Mabsadd L closepath F
.6619 .13377 -1.875 0 Mabsadd m
.6619 .13377 0 2.5 Mabsadd L
.6619 .13377 1.875 0 Mabsadd L
.6619 .13377 0 -2.5 Mabsadd L
.6619 .13377 -1.875 0 Mabsadd L closepath F
.66508 .13306 -1.875 0 Mabsadd m
.66508 .13306 0 2.5 Mabsadd L
.66508 .13306 1.875 0 Mabsadd L
.66508 .13306 0 -2.5 Mabsadd L
.66508 .13306 -1.875 0 Mabsadd L closepath F
.66825 .13234 -1.875 0 Mabsadd m
.66825 .13234 0 2.5 Mabsadd L
.66825 .13234 1.875 0 Mabsadd L
.66825 .13234 0 -2.5 Mabsadd L
.66825 .13234 -1.875 0 Mabsadd L closepath F
.67143 .13162 -1.875 0 Mabsadd m
.67143 .13162 0 2.5 Mabsadd L
.67143 .13162 1.875 0 Mabsadd L
.67143 .13162 0 -2.5 Mabsadd L
.67143 .13162 -1.875 0 Mabsadd L closepath F
.6746 .13089 -1.875 0 Mabsadd m
.6746 .13089 0 2.5 Mabsadd L
.6746 .13089 1.875 0 Mabsadd L
.6746 .13089 0 -2.5 Mabsadd L
.6746 .13089 -1.875 0 Mabsadd L closepath F
.67778 .13015 -1.875 0 Mabsadd m
.67778 .13015 0 2.5 Mabsadd L
.67778 .13015 1.875 0 Mabsadd L
.67778 .13015 0 -2.5 Mabsadd L
.67778 .13015 -1.875 0 Mabsadd L closepath F
.68095 .1294 -1.875 0 Mabsadd m
.68095 .1294 0 2.5 Mabsadd L
.68095 .1294 1.875 0 Mabsadd L
.68095 .1294 0 -2.5 Mabsadd L
.68095 .1294 -1.875 0 Mabsadd L closepath F
.68413 .12865 -1.875 0 Mabsadd m
.68413 .12865 0 2.5 Mabsadd L
.68413 .12865 1.875 0 Mabsadd L
.68413 .12865 0 -2.5 Mabsadd L
.68413 .12865 -1.875 0 Mabsadd L closepath F
.6873 .12789 -1.875 0 Mabsadd m
.6873 .12789 0 2.5 Mabsadd L
.6873 .12789 1.875 0 Mabsadd L
.6873 .12789 0 -2.5 Mabsadd L
.6873 .12789 -1.875 0 Mabsadd L closepath F
.69048 .12712 -1.875 0 Mabsadd m
.69048 .12712 0 2.5 Mabsadd L
.69048 .12712 1.875 0 Mabsadd L
.69048 .12712 0 -2.5 Mabsadd L
.69048 .12712 -1.875 0 Mabsadd L closepath F
.69365 .12634 -1.875 0 Mabsadd m
.69365 .12634 0 2.5 Mabsadd L
.69365 .12634 1.875 0 Mabsadd L
.69365 .12634 0 -2.5 Mabsadd L
.69365 .12634 -1.875 0 Mabsadd L closepath F
.69683 .12556 -1.875 0 Mabsadd m
.69683 .12556 0 2.5 Mabsadd L
.69683 .12556 1.875 0 Mabsadd L
.69683 .12556 0 -2.5 Mabsadd L
.69683 .12556 -1.875 0 Mabsadd L closepath F
.7 .12477 -1.875 0 Mabsadd m
.7 .12477 0 2.5 Mabsadd L
.7 .12477 1.875 0 Mabsadd L
.7 .12477 0 -2.5 Mabsadd L
.7 .12477 -1.875 0 Mabsadd L closepath F
.70317 .12397 -1.875 0 Mabsadd m
.70317 .12397 0 2.5 Mabsadd L
.70317 .12397 1.875 0 Mabsadd L
.70317 .12397 0 -2.5 Mabsadd L
.70317 .12397 -1.875 0 Mabsadd L closepath F
.70635 .12316 -1.875 0 Mabsadd m
.70635 .12316 0 2.5 Mabsadd L
.70635 .12316 1.875 0 Mabsadd L
.70635 .12316 0 -2.5 Mabsadd L
.70635 .12316 -1.875 0 Mabsadd L closepath F
.70952 .12235 -1.875 0 Mabsadd m
.70952 .12235 0 2.5 Mabsadd L
.70952 .12235 1.875 0 Mabsadd L
.70952 .12235 0 -2.5 Mabsadd L
.70952 .12235 -1.875 0 Mabsadd L closepath F
.7127 .12152 -1.875 0 Mabsadd m
.7127 .12152 0 2.5 Mabsadd L
.7127 .12152 1.875 0 Mabsadd L
.7127 .12152 0 -2.5 Mabsadd L
.7127 .12152 -1.875 0 Mabsadd L closepath F
.71587 .12069 -1.875 0 Mabsadd m
.71587 .12069 0 2.5 Mabsadd L
.71587 .12069 1.875 0 Mabsadd L
.71587 .12069 0 -2.5 Mabsadd L
.71587 .12069 -1.875 0 Mabsadd L closepath F
.71905 .11985 -1.875 0 Mabsadd m
.71905 .11985 0 2.5 Mabsadd L
.71905 .11985 1.875 0 Mabsadd L
.71905 .11985 0 -2.5 Mabsadd L
.71905 .11985 -1.875 0 Mabsadd L closepath F
.72222 .119 -1.875 0 Mabsadd m
.72222 .119 0 2.5 Mabsadd L
.72222 .119 1.875 0 Mabsadd L
.72222 .119 0 -2.5 Mabsadd L
.72222 .119 -1.875 0 Mabsadd L closepath F
.7254 .11814 -1.875 0 Mabsadd m
.7254 .11814 0 2.5 Mabsadd L
.7254 .11814 1.875 0 Mabsadd L
.7254 .11814 0 -2.5 Mabsadd L
.7254 .11814 -1.875 0 Mabsadd L closepath F
.72857 .11728 -1.875 0 Mabsadd m
.72857 .11728 0 2.5 Mabsadd L
.72857 .11728 1.875 0 Mabsadd L
.72857 .11728 0 -2.5 Mabsadd L
.72857 .11728 -1.875 0 Mabsadd L closepath F
.73175 .1164 -1.875 0 Mabsadd m
.73175 .1164 0 2.5 Mabsadd L
.73175 .1164 1.875 0 Mabsadd L
.73175 .1164 0 -2.5 Mabsadd L
.73175 .1164 -1.875 0 Mabsadd L closepath F
.73492 .11552 -1.875 0 Mabsadd m
.73492 .11552 0 2.5 Mabsadd L
.73492 .11552 1.875 0 Mabsadd L
.73492 .11552 0 -2.5 Mabsadd L
.73492 .11552 -1.875 0 Mabsadd L closepath F
.7381 .11463 -1.875 0 Mabsadd m
.7381 .11463 0 2.5 Mabsadd L
.7381 .11463 1.875 0 Mabsadd L
.7381 .11463 0 -2.5 Mabsadd L
.7381 .11463 -1.875 0 Mabsadd L closepath F
.74127 .11373 -1.875 0 Mabsadd m
.74127 .11373 0 2.5 Mabsadd L
.74127 .11373 1.875 0 Mabsadd L
.74127 .11373 0 -2.5 Mabsadd L
.74127 .11373 -1.875 0 Mabsadd L closepath F
.74444 .11282 -1.875 0 Mabsadd m
.74444 .11282 0 2.5 Mabsadd L
.74444 .11282 1.875 0 Mabsadd L
.74444 .11282 0 -2.5 Mabsadd L
.74444 .11282 -1.875 0 Mabsadd L closepath F
.74762 .1119 -1.875 0 Mabsadd m
.74762 .1119 0 2.5 Mabsadd L
.74762 .1119 1.875 0 Mabsadd L
.74762 .1119 0 -2.5 Mabsadd L
.74762 .1119 -1.875 0 Mabsadd L closepath F
.75079 .11097 -1.875 0 Mabsadd m
.75079 .11097 0 2.5 Mabsadd L
.75079 .11097 1.875 0 Mabsadd L
.75079 .11097 0 -2.5 Mabsadd L
.75079 .11097 -1.875 0 Mabsadd L closepath F
.75397 .11003 -1.875 0 Mabsadd m
.75397 .11003 0 2.5 Mabsadd L
.75397 .11003 1.875 0 Mabsadd L
.75397 .11003 0 -2.5 Mabsadd L
.75397 .11003 -1.875 0 Mabsadd L closepath F
.75714 .10909 -1.875 0 Mabsadd m
.75714 .10909 0 2.5 Mabsadd L
.75714 .10909 1.875 0 Mabsadd L
.75714 .10909 0 -2.5 Mabsadd L
.75714 .10909 -1.875 0 Mabsadd L closepath F
.76032 .10813 -1.875 0 Mabsadd m
.76032 .10813 0 2.5 Mabsadd L
.76032 .10813 1.875 0 Mabsadd L
.76032 .10813 0 -2.5 Mabsadd L
.76032 .10813 -1.875 0 Mabsadd L closepath F
.76349 .10717 -1.875 0 Mabsadd m
.76349 .10717 0 2.5 Mabsadd L
.76349 .10717 1.875 0 Mabsadd L
.76349 .10717 0 -2.5 Mabsadd L
.76349 .10717 -1.875 0 Mabsadd L closepath F
.76667 .10619 -1.875 0 Mabsadd m
.76667 .10619 0 2.5 Mabsadd L
.76667 .10619 1.875 0 Mabsadd L
.76667 .10619 0 -2.5 Mabsadd L
.76667 .10619 -1.875 0 Mabsadd L closepath F
.76984 .1052 -1.875 0 Mabsadd m
.76984 .1052 0 2.5 Mabsadd L
.76984 .1052 1.875 0 Mabsadd L
.76984 .1052 0 -2.5 Mabsadd L
.76984 .1052 -1.875 0 Mabsadd L closepath F
.77302 .10421 -1.875 0 Mabsadd m
.77302 .10421 0 2.5 Mabsadd L
.77302 .10421 1.875 0 Mabsadd L
.77302 .10421 0 -2.5 Mabsadd L
.77302 .10421 -1.875 0 Mabsadd L closepath F
.77619 .1032 -1.875 0 Mabsadd m
.77619 .1032 0 2.5 Mabsadd L
.77619 .1032 1.875 0 Mabsadd L
.77619 .1032 0 -2.5 Mabsadd L
.77619 .1032 -1.875 0 Mabsadd L closepath F
.77937 .10219 -1.875 0 Mabsadd m
.77937 .10219 0 2.5 Mabsadd L
.77937 .10219 1.875 0 Mabsadd L
.77937 .10219 0 -2.5 Mabsadd L
.77937 .10219 -1.875 0 Mabsadd L closepath F
.78254 .10116 -1.875 0 Mabsadd m
.78254 .10116 0 2.5 Mabsadd L
.78254 .10116 1.875 0 Mabsadd L
.78254 .10116 0 -2.5 Mabsadd L
.78254 .10116 -1.875 0 Mabsadd L closepath F
.78571 .10013 -1.875 0 Mabsadd m
.78571 .10013 0 2.5 Mabsadd L
.78571 .10013 1.875 0 Mabsadd L
.78571 .10013 0 -2.5 Mabsadd L
.78571 .10013 -1.875 0 Mabsadd L closepath F
.78889 .09908 -1.875 0 Mabsadd m
.78889 .09908 0 2.5 Mabsadd L
.78889 .09908 1.875 0 Mabsadd L
.78889 .09908 0 -2.5 Mabsadd L
.78889 .09908 -1.875 0 Mabsadd L closepath F
.79206 .09803 -1.875 0 Mabsadd m
.79206 .09803 0 2.5 Mabsadd L
.79206 .09803 1.875 0 Mabsadd L
.79206 .09803 0 -2.5 Mabsadd L
.79206 .09803 -1.875 0 Mabsadd L closepath F
.79524 .09696 -1.875 0 Mabsadd m
.79524 .09696 0 2.5 Mabsadd L
.79524 .09696 1.875 0 Mabsadd L
.79524 .09696 0 -2.5 Mabsadd L
.79524 .09696 -1.875 0 Mabsadd L closepath F
.79841 .09588 -1.875 0 Mabsadd m
.79841 .09588 0 2.5 Mabsadd L
.79841 .09588 1.875 0 Mabsadd L
.79841 .09588 0 -2.5 Mabsadd L
.79841 .09588 -1.875 0 Mabsadd L closepath F
.80159 .09479 -1.875 0 Mabsadd m
.80159 .09479 0 2.5 Mabsadd L
.80159 .09479 1.875 0 Mabsadd L
.80159 .09479 0 -2.5 Mabsadd L
.80159 .09479 -1.875 0 Mabsadd L closepath F
.80476 .09369 -1.875 0 Mabsadd m
.80476 .09369 0 2.5 Mabsadd L
.80476 .09369 1.875 0 Mabsadd L
.80476 .09369 0 -2.5 Mabsadd L
.80476 .09369 -1.875 0 Mabsadd L closepath F
.80794 .09258 -1.875 0 Mabsadd m
.80794 .09258 0 2.5 Mabsadd L
.80794 .09258 1.875 0 Mabsadd L
.80794 .09258 0 -2.5 Mabsadd L
.80794 .09258 -1.875 0 Mabsadd L closepath F
.81111 .09146 -1.875 0 Mabsadd m
.81111 .09146 0 2.5 Mabsadd L
.81111 .09146 1.875 0 Mabsadd L
.81111 .09146 0 -2.5 Mabsadd L
.81111 .09146 -1.875 0 Mabsadd L closepath F
.81429 .09033 -1.875 0 Mabsadd m
.81429 .09033 0 2.5 Mabsadd L
.81429 .09033 1.875 0 Mabsadd L
.81429 .09033 0 -2.5 Mabsadd L
.81429 .09033 -1.875 0 Mabsadd L closepath F
.81746 .08919 -1.875 0 Mabsadd m
.81746 .08919 0 2.5 Mabsadd L
.81746 .08919 1.875 0 Mabsadd L
.81746 .08919 0 -2.5 Mabsadd L
.81746 .08919 -1.875 0 Mabsadd L closepath F
.82063 .08803 -1.875 0 Mabsadd m
.82063 .08803 0 2.5 Mabsadd L
.82063 .08803 1.875 0 Mabsadd L
.82063 .08803 0 -2.5 Mabsadd L
.82063 .08803 -1.875 0 Mabsadd L closepath F
.82381 .08686 -1.875 0 Mabsadd m
.82381 .08686 0 2.5 Mabsadd L
.82381 .08686 1.875 0 Mabsadd L
.82381 .08686 0 -2.5 Mabsadd L
.82381 .08686 -1.875 0 Mabsadd L closepath F
.82698 .08569 -1.875 0 Mabsadd m
.82698 .08569 0 2.5 Mabsadd L
.82698 .08569 1.875 0 Mabsadd L
.82698 .08569 0 -2.5 Mabsadd L
.82698 .08569 -1.875 0 Mabsadd L closepath F
.83016 .0845 -1.875 0 Mabsadd m
.83016 .0845 0 2.5 Mabsadd L
.83016 .0845 1.875 0 Mabsadd L
.83016 .0845 0 -2.5 Mabsadd L
.83016 .0845 -1.875 0 Mabsadd L closepath F
.83333 .08329 -1.875 0 Mabsadd m
.83333 .08329 0 2.5 Mabsadd L
.83333 .08329 1.875 0 Mabsadd L
.83333 .08329 0 -2.5 Mabsadd L
.83333 .08329 -1.875 0 Mabsadd L closepath F
.83651 .08208 -1.875 0 Mabsadd m
.83651 .08208 0 2.5 Mabsadd L
.83651 .08208 1.875 0 Mabsadd L
.83651 .08208 0 -2.5 Mabsadd L
.83651 .08208 -1.875 0 Mabsadd L closepath F
.83968 .08085 -1.875 0 Mabsadd m
.83968 .08085 0 2.5 Mabsadd L
.83968 .08085 1.875 0 Mabsadd L
.83968 .08085 0 -2.5 Mabsadd L
.83968 .08085 -1.875 0 Mabsadd L closepath F
.84286 .07961 -1.875 0 Mabsadd m
.84286 .07961 0 2.5 Mabsadd L
.84286 .07961 1.875 0 Mabsadd L
.84286 .07961 0 -2.5 Mabsadd L
.84286 .07961 -1.875 0 Mabsadd L closepath F
.84603 .07836 -1.875 0 Mabsadd m
.84603 .07836 0 2.5 Mabsadd L
.84603 .07836 1.875 0 Mabsadd L
.84603 .07836 0 -2.5 Mabsadd L
.84603 .07836 -1.875 0 Mabsadd L closepath F
.84921 .0771 -1.875 0 Mabsadd m
.84921 .0771 0 2.5 Mabsadd L
.84921 .0771 1.875 0 Mabsadd L
.84921 .0771 0 -2.5 Mabsadd L
.84921 .0771 -1.875 0 Mabsadd L closepath F
.85238 .07582 -1.875 0 Mabsadd m
.85238 .07582 0 2.5 Mabsadd L
.85238 .07582 1.875 0 Mabsadd L
.85238 .07582 0 -2.5 Mabsadd L
.85238 .07582 -1.875 0 Mabsadd L closepath F
.85556 .07454 -1.875 0 Mabsadd m
.85556 .07454 0 2.5 Mabsadd L
.85556 .07454 1.875 0 Mabsadd L
.85556 .07454 0 -2.5 Mabsadd L
.85556 .07454 -1.875 0 Mabsadd L closepath F
.85873 .07323 -1.875 0 Mabsadd m
.85873 .07323 0 2.5 Mabsadd L
.85873 .07323 1.875 0 Mabsadd L
.85873 .07323 0 -2.5 Mabsadd L
.85873 .07323 -1.875 0 Mabsadd L closepath F
.8619 .07192 -1.875 0 Mabsadd m
.8619 .07192 0 2.5 Mabsadd L
.8619 .07192 1.875 0 Mabsadd L
.8619 .07192 0 -2.5 Mabsadd L
.8619 .07192 -1.875 0 Mabsadd L closepath F
.86508 .07059 -1.875 0 Mabsadd m
.86508 .07059 0 2.5 Mabsadd L
.86508 .07059 1.875 0 Mabsadd L
.86508 .07059 0 -2.5 Mabsadd L
.86508 .07059 -1.875 0 Mabsadd L closepath F
.86825 .06925 -1.875 0 Mabsadd m
.86825 .06925 0 2.5 Mabsadd L
.86825 .06925 1.875 0 Mabsadd L
.86825 .06925 0 -2.5 Mabsadd L
.86825 .06925 -1.875 0 Mabsadd L closepath F
.87143 .06789 -1.875 0 Mabsadd m
.87143 .06789 0 2.5 Mabsadd L
.87143 .06789 1.875 0 Mabsadd L
.87143 .06789 0 -2.5 Mabsadd L
.87143 .06789 -1.875 0 Mabsadd L closepath F
.8746 .06653 -1.875 0 Mabsadd m
.8746 .06653 0 2.5 Mabsadd L
.8746 .06653 1.875 0 Mabsadd L
.8746 .06653 0 -2.5 Mabsadd L
.8746 .06653 -1.875 0 Mabsadd L closepath F
.87778 .06514 -1.875 0 Mabsadd m
.87778 .06514 0 2.5 Mabsadd L
.87778 .06514 1.875 0 Mabsadd L
.87778 .06514 0 -2.5 Mabsadd L
.87778 .06514 -1.875 0 Mabsadd L closepath F
.88095 .06375 -1.875 0 Mabsadd m
.88095 .06375 0 2.5 Mabsadd L
.88095 .06375 1.875 0 Mabsadd L
.88095 .06375 0 -2.5 Mabsadd L
.88095 .06375 -1.875 0 Mabsadd L closepath F
.88413 .06234 -1.875 0 Mabsadd m
.88413 .06234 0 2.5 Mabsadd L
.88413 .06234 1.875 0 Mabsadd L
.88413 .06234 0 -2.5 Mabsadd L
.88413 .06234 -1.875 0 Mabsadd L closepath F
.8873 .06092 -1.875 0 Mabsadd m
.8873 .06092 0 2.5 Mabsadd L
.8873 .06092 1.875 0 Mabsadd L
.8873 .06092 0 -2.5 Mabsadd L
.8873 .06092 -1.875 0 Mabsadd L closepath F
.89048 .05948 -1.875 0 Mabsadd m
.89048 .05948 0 2.5 Mabsadd L
.89048 .05948 1.875 0 Mabsadd L
.89048 .05948 0 -2.5 Mabsadd L
.89048 .05948 -1.875 0 Mabsadd L closepath F
.89365 .05803 -1.875 0 Mabsadd m
.89365 .05803 0 2.5 Mabsadd L
.89365 .05803 1.875 0 Mabsadd L
.89365 .05803 0 -2.5 Mabsadd L
.89365 .05803 -1.875 0 Mabsadd L closepath F
.89683 .05656 -1.875 0 Mabsadd m
.89683 .05656 0 2.5 Mabsadd L
.89683 .05656 1.875 0 Mabsadd L
.89683 .05656 0 -2.5 Mabsadd L
.89683 .05656 -1.875 0 Mabsadd L closepath F
.9 .05508 -1.875 0 Mabsadd m
.9 .05508 0 2.5 Mabsadd L
.9 .05508 1.875 0 Mabsadd L
.9 .05508 0 -2.5 Mabsadd L
.9 .05508 -1.875 0 Mabsadd L closepath F
.90317 .05358 -1.875 0 Mabsadd m
.90317 .05358 0 2.5 Mabsadd L
.90317 .05358 1.875 0 Mabsadd L
.90317 .05358 0 -2.5 Mabsadd L
.90317 .05358 -1.875 0 Mabsadd L closepath F
.90635 .05207 -1.875 0 Mabsadd m
.90635 .05207 0 2.5 Mabsadd L
.90635 .05207 1.875 0 Mabsadd L
.90635 .05207 0 -2.5 Mabsadd L
.90635 .05207 -1.875 0 Mabsadd L closepath F
.90952 .05054 -1.875 0 Mabsadd m
.90952 .05054 0 2.5 Mabsadd L
.90952 .05054 1.875 0 Mabsadd L
.90952 .05054 0 -2.5 Mabsadd L
.90952 .05054 -1.875 0 Mabsadd L closepath F
.9127 .049 -1.875 0 Mabsadd m
.9127 .049 0 2.5 Mabsadd L
.9127 .049 1.875 0 Mabsadd L
.9127 .049 0 -2.5 Mabsadd L
.9127 .049 -1.875 0 Mabsadd L closepath F
.91587 .04744 -1.875 0 Mabsadd m
.91587 .04744 0 2.5 Mabsadd L
.91587 .04744 1.875 0 Mabsadd L
.91587 .04744 0 -2.5 Mabsadd L
.91587 .04744 -1.875 0 Mabsadd L closepath F
.91905 .04587 -1.875 0 Mabsadd m
.91905 .04587 0 2.5 Mabsadd L
.91905 .04587 1.875 0 Mabsadd L
.91905 .04587 0 -2.5 Mabsadd L
.91905 .04587 -1.875 0 Mabsadd L closepath F
.92222 .04428 -1.875 0 Mabsadd m
.92222 .04428 0 2.5 Mabsadd L
.92222 .04428 1.875 0 Mabsadd L
.92222 .04428 0 -2.5 Mabsadd L
.92222 .04428 -1.875 0 Mabsadd L closepath F
.9254 .04268 -1.875 0 Mabsadd m
.9254 .04268 0 2.5 Mabsadd L
.9254 .04268 1.875 0 Mabsadd L
.9254 .04268 0 -2.5 Mabsadd L
.9254 .04268 -1.875 0 Mabsadd L closepath F
.92857 .04106 -1.875 0 Mabsadd m
.92857 .04106 0 2.5 Mabsadd L
.92857 .04106 1.875 0 Mabsadd L
.92857 .04106 0 -2.5 Mabsadd L
.92857 .04106 -1.875 0 Mabsadd L closepath F
.93175 .03942 -1.875 0 Mabsadd m
.93175 .03942 0 2.5 Mabsadd L
.93175 .03942 1.875 0 Mabsadd L
.93175 .03942 0 -2.5 Mabsadd L
.93175 .03942 -1.875 0 Mabsadd L closepath F
.93492 .03777 -1.875 0 Mabsadd m
.93492 .03777 0 2.5 Mabsadd L
.93492 .03777 1.875 0 Mabsadd L
.93492 .03777 0 -2.5 Mabsadd L
.93492 .03777 -1.875 0 Mabsadd L closepath F
.9381 .0361 -1.875 0 Mabsadd m
.9381 .0361 0 2.5 Mabsadd L
.9381 .0361 1.875 0 Mabsadd L
.9381 .0361 0 -2.5 Mabsadd L
.9381 .0361 -1.875 0 Mabsadd L closepath F
.94127 .03441 -1.875 0 Mabsadd m
.94127 .03441 0 2.5 Mabsadd L
.94127 .03441 1.875 0 Mabsadd L
.94127 .03441 0 -2.5 Mabsadd L
.94127 .03441 -1.875 0 Mabsadd L closepath F
.94444 .03271 -1.875 0 Mabsadd m
.94444 .03271 0 2.5 Mabsadd L
.94444 .03271 1.875 0 Mabsadd L
.94444 .03271 0 -2.5 Mabsadd L
.94444 .03271 -1.875 0 Mabsadd L closepath F
.94762 .03099 -1.875 0 Mabsadd m
.94762 .03099 0 2.5 Mabsadd L
.94762 .03099 1.875 0 Mabsadd L
.94762 .03099 0 -2.5 Mabsadd L
.94762 .03099 -1.875 0 Mabsadd L closepath F
.95079 .02925 -1.875 0 Mabsadd m
.95079 .02925 0 2.5 Mabsadd L
.95079 .02925 1.875 0 Mabsadd L
.95079 .02925 0 -2.5 Mabsadd L
.95079 .02925 -1.875 0 Mabsadd L closepath F
.95397 .0275 -1.875 0 Mabsadd m
.95397 .0275 0 2.5 Mabsadd L
.95397 .0275 1.875 0 Mabsadd L
.95397 .0275 0 -2.5 Mabsadd L
.95397 .0275 -1.875 0 Mabsadd L closepath F
.95714 .02573 -1.875 0 Mabsadd m
.95714 .02573 0 2.5 Mabsadd L
.95714 .02573 1.875 0 Mabsadd L
.95714 .02573 0 -2.5 Mabsadd L
.95714 .02573 -1.875 0 Mabsadd L closepath F
.96032 .02394 -1.875 0 Mabsadd m
.96032 .02394 0 2.5 Mabsadd L
.96032 .02394 1.875 0 Mabsadd L
.96032 .02394 0 -2.5 Mabsadd L
.96032 .02394 -1.875 0 Mabsadd L closepath F
.96349 .02213 -1.875 0 Mabsadd m
.96349 .02213 0 2.5 Mabsadd L
.96349 .02213 1.875 0 Mabsadd L
.96349 .02213 0 -2.5 Mabsadd L
.96349 .02213 -1.875 0 Mabsadd L closepath F
.96667 .0203 -1.875 0 Mabsadd m
.96667 .0203 0 2.5 Mabsadd L
.96667 .0203 1.875 0 Mabsadd L
.96667 .0203 0 -2.5 Mabsadd L
.96667 .0203 -1.875 0 Mabsadd L closepath F
.96984 .01846 -1.875 0 Mabsadd m
.96984 .01846 0 2.5 Mabsadd L
.96984 .01846 1.875 0 Mabsadd L
.96984 .01846 0 -2.5 Mabsadd L
.96984 .01846 -1.875 0 Mabsadd L closepath F
.97302 .0166 -1.875 0 Mabsadd m
.97302 .0166 0 2.5 Mabsadd L
.97302 .0166 1.875 0 Mabsadd L
.97302 .0166 0 -2.5 Mabsadd L
.97302 .0166 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
.0075 w
.02698 .21441 m
.03016 .21451 L
.03333 .2146 L
.03651 .2147 L
.03968 .2148 L
.04286 .2149 L
.04603 .21501 L
.04921 .21511 L
.05238 .21521 L
.05556 .21532 L
.05873 .21542 L
.0619 .21553 L
.06508 .21564 L
.06825 .21575 L
.07143 .21586 L
.0746 .21597 L
.07778 .21608 L
.08095 .2162 L
.08413 .21631 L
.0873 .21643 L
.09048 .21655 L
.09365 .21666 L
.09683 .21678 L
.1 .2169 L
.10317 .21703 L
.10635 .21715 L
.10952 .21727 L
.1127 .2174 L
.11587 .21753 L
.11905 .21765 L
.12222 .21778 L
.1254 .21791 L
.12857 .21805 L
.13175 .21818 L
.13492 .21831 L
.1381 .21845 L
.14127 .21859 L
.14444 .21873 L
.14762 .21887 L
.15079 .21901 L
.15397 .21915 L
.15714 .2193 L
.16032 .21944 L
.16349 .21959 L
.16667 .21974 L
.16984 .21989 L
.17302 .22004 L
.17619 .22019 L
.17937 .22035 L
.18254 .2205 L
Mistroke
.18571 .22066 L
.18889 .22082 L
.19206 .22098 L
.19524 .22114 L
.19841 .22131 L
.20159 .22147 L
.20476 .22164 L
.20794 .22181 L
.21111 .22198 L
.21429 .22216 L
.21746 .22233 L
.22063 .22251 L
.22381 .22268 L
.22698 .22286 L
.23016 .22305 L
.23333 .22323 L
.23651 .22341 L
.23968 .2236 L
.24286 .22379 L
.24603 .22398 L
.24921 .22417 L
.25238 .22437 L
.25556 .22456 L
.25873 .22476 L
.2619 .22496 L
.26508 .22517 L
.26825 .22537 L
.27143 .22558 L
.2746 .22579 L
.27778 .226 L
.28095 .22621 L
.28413 .22642 L
.2873 .22664 L
.29048 .22686 L
.29365 .22708 L
.29683 .22731 L
.3 .22753 L
.30317 .22776 L
.30635 .22799 L
.30952 .22822 L
.3127 .22846 L
.31587 .2287 L
.31905 .22894 L
.32222 .22918 L
.3254 .22942 L
.32857 .22967 L
.33175 .22992 L
.33492 .23017 L
.3381 .23043 L
.34127 .23068 L
Mistroke
.34444 .23094 L
.34762 .2312 L
.35079 .23147 L
.35397 .23174 L
.35714 .23201 L
.36032 .23228 L
.36349 .23256 L
.36667 .23283 L
.36984 .23312 L
.37302 .2334 L
.37619 .23369 L
.37937 .23398 L
.38254 .23427 L
.38571 .23456 L
.38889 .23486 L
.39206 .23516 L
.39524 .23547 L
.39841 .23578 L
.40159 .23609 L
.40476 .2364 L
.40794 .23672 L
.41111 .23704 L
.41429 .23736 L
.41746 .23769 L
.42063 .23802 L
.42381 .23835 L
.42698 .23869 L
.43016 .23903 L
.43333 .23937 L
.43651 .23972 L
.43968 .24007 L
.44286 .24042 L
.44603 .24078 L
.44921 .24114 L
.45238 .2415 L
.45556 .24187 L
.45873 .24224 L
.4619 .24262 L
.46508 .243 L
.46825 .24338 L
.47143 .24377 L
.4746 .24416 L
.47778 .24455 L
.48095 .24495 L
.48413 .24535 L
.4873 .24576 L
.49048 .24617 L
.49365 .24658 L
.49683 .247 L
.5 .24742 L
Mistroke
.50317 .24785 L
.50635 .24828 L
.50952 .24872 L
.5127 .24916 L
.51587 .2496 L
.51905 .25005 L
.52222 .2505 L
.5254 .25096 L
.52857 .25143 L
.53175 .25189 L
.53492 .25236 L
.5381 .25284 L
.54127 .25332 L
.54444 .25381 L
.54762 .2543 L
.55079 .25479 L
.55397 .2553 L
.55714 .2558 L
.56032 .25631 L
.56349 .25683 L
.56667 .25735 L
.56984 .25788 L
.57302 .25841 L
.57619 .25894 L
.57937 .25949 L
.58254 .26003 L
.58571 .26059 L
.58889 .26115 L
.59206 .26171 L
.59524 .26228 L
.59841 .26286 L
.60159 .26344 L
.60476 .26403 L
.60794 .26462 L
.61111 .26522 L
.61429 .26582 L
.61746 .26643 L
.62063 .26705 L
.62381 .26767 L
.62698 .2683 L
.63016 .26894 L
.63333 .26958 L
.63651 .27023 L
.63968 .27089 L
.64286 .27155 L
.64603 .27222 L
.64921 .27289 L
.65238 .27357 L
.65556 .27426 L
.65873 .27496 L
Mistroke
.6619 .27566 L
.66508 .27637 L
.66825 .27709 L
.67143 .27781 L
.6746 .27854 L
.67778 .27928 L
.68095 .28002 L
.68413 .28078 L
.6873 .28154 L
.69048 .28231 L
.69365 .28308 L
.69683 .28387 L
.7 .28466 L
.70317 .28546 L
.70635 .28626 L
.70952 .28708 L
.7127 .2879 L
.71587 .28873 L
.71905 .28958 L
.72222 .29042 L
.7254 .29128 L
.72857 .29215 L
.73175 .29302 L
.73492 .2939 L
.7381 .2948 L
.74127 .2957 L
.74444 .29661 L
.74762 .29753 L
.75079 .29845 L
.75397 .29939 L
.75714 .30034 L
.76032 .30129 L
.76349 .30226 L
.76667 .30324 L
.76984 .30422 L
.77302 .30522 L
.77619 .30622 L
.77937 .30724 L
.78254 .30826 L
.78571 .3093 L
.78889 .31034 L
.79206 .3114 L
.79524 .31247 L
.79841 .31354 L
.80159 .31463 L
.80476 .31573 L
.80794 .31684 L
.81111 .31796 L
.81429 .31909 L
.81746 .32024 L
Mistroke
.82063 .32139 L
.82381 .32256 L
.82698 .32374 L
.83016 .32493 L
.83333 .32613 L
.83651 .32735 L
.83968 .32857 L
.84286 .32981 L
.84603 .33106 L
.84921 .33232 L
.85238 .3336 L
.85556 .33489 L
.85873 .33619 L
.8619 .33751 L
.86508 .33883 L
.86825 .34018 L
.87143 .34153 L
.8746 .3429 L
.87778 .34428 L
.88095 .34568 L
.88413 .34709 L
.8873 .34851 L
.89048 .34995 L
.89365 .3514 L
.89683 .35287 L
.9 .35435 L
.90317 .35584 L
.90635 .35736 L
.90952 .35888 L
.9127 .36042 L
.91587 .36198 L
.91905 .36355 L
.92222 .36514 L
.9254 .36675 L
.92857 .36837 L
.93175 .37 L
.93492 .37166 L
.9381 .37333 L
.94127 .37501 L
.94444 .37671 L
.94762 .37843 L
.95079 .38017 L
.95397 .38193 L
.95714 .3837 L
.96032 .38549 L
.96349 .3873 L
.96667 .38912 L
.96984 .39097 L
.97302 .39283 L
.97619 .39471 L
Mistroke
Mfstroke
.0001 w
.02698 .21441 0 2.5 Mabsadd m
.02698 .21441 -0.56518 .7779 Mabsadd L
.02698 .21441 -2.37764 .77254 Mabsadd L
.02698 .21441 -0.91448 -0.29713 Mabsadd L
.02698 .21441 -1.46946 -2.02254 Mabsadd L
.02698 .21441 0 -0.96154 Mabsadd L
.02698 .21441 1.46946 -2.02254 Mabsadd L
.02698 .21441 .91448 -0.29713 Mabsadd L
.02698 .21441 2.37764 .77254 Mabsadd L
.02698 .21441 .56518 .7779 Mabsadd L
.02698 .21441 0 2.5 Mabsadd L closepath F
.03016 .21451 0 2.5 Mabsadd m
.03016 .21451 -0.56518 .7779 Mabsadd L
.03016 .21451 -2.37764 .77254 Mabsadd L
.03016 .21451 -0.91448 -0.29713 Mabsadd L
.03016 .21451 -1.46946 -2.02254 Mabsadd L
.03016 .21451 0 -0.96154 Mabsadd L
.03016 .21451 1.46946 -2.02254 Mabsadd L
.03016 .21451 .91448 -0.29713 Mabsadd L
.03016 .21451 2.37764 .77254 Mabsadd L
.03016 .21451 .56518 .7779 Mabsadd L
.03016 .21451 0 2.5 Mabsadd L closepath F
.03333 .2146 0 2.5 Mabsadd m
.03333 .2146 -0.56518 .7779 Mabsadd L
.03333 .2146 -2.37764 .77254 Mabsadd L
.03333 .2146 -0.91448 -0.29713 Mabsadd L
.03333 .2146 -1.46946 -2.02254 Mabsadd L
.03333 .2146 0 -0.96154 Mabsadd L
.03333 .2146 1.46946 -2.02254 Mabsadd L
.03333 .2146 .91448 -0.29713 Mabsadd L
.03333 .2146 2.37764 .77254 Mabsadd L
.03333 .2146 .56518 .7779 Mabsadd L
.03333 .2146 0 2.5 Mabsadd L closepath F
.03651 .2147 0 2.5 Mabsadd m
.03651 .2147 -0.56518 .7779 Mabsadd L
.03651 .2147 -2.37764 .77254 Mabsadd L
.03651 .2147 -0.91448 -0.29713 Mabsadd L
.03651 .2147 -1.46946 -2.02254 Mabsadd L
.03651 .2147 0 -0.96154 Mabsadd L
.03651 .2147 1.46946 -2.02254 Mabsadd L
.03651 .2147 .91448 -0.29713 Mabsadd L
.03651 .2147 2.37764 .77254 Mabsadd L
.03651 .2147 .56518 .7779 Mabsadd L
.03651 .2147 0 2.5 Mabsadd L closepath F
.03968 .2148 0 2.5 Mabsadd m
.03968 .2148 -0.56518 .7779 Mabsadd L
.03968 .2148 -2.37764 .77254 Mabsadd L
.03968 .2148 -0.91448 -0.29713 Mabsadd L
.03968 .2148 -1.46946 -2.02254 Mabsadd L
.03968 .2148 0 -0.96154 Mabsadd L
.03968 .2148 1.46946 -2.02254 Mabsadd L
.03968 .2148 .91448 -0.29713 Mabsadd L
.03968 .2148 2.37764 .77254 Mabsadd L
.03968 .2148 .56518 .7779 Mabsadd L
.03968 .2148 0 2.5 Mabsadd L closepath F
.04286 .2149 0 2.5 Mabsadd m
.04286 .2149 -0.56518 .7779 Mabsadd L
.04286 .2149 -2.37764 .77254 Mabsadd L
.04286 .2149 -0.91448 -0.29713 Mabsadd L
.04286 .2149 -1.46946 -2.02254 Mabsadd L
.04286 .2149 0 -0.96154 Mabsadd L
.04286 .2149 1.46946 -2.02254 Mabsadd L
.04286 .2149 .91448 -0.29713 Mabsadd L
.04286 .2149 2.37764 .77254 Mabsadd L
.04286 .2149 .56518 .7779 Mabsadd L
.04286 .2149 0 2.5 Mabsadd L closepath F
.04603 .21501 0 2.5 Mabsadd m
.04603 .21501 -0.56518 .7779 Mabsadd L
.04603 .21501 -2.37764 .77254 Mabsadd L
.04603 .21501 -0.91448 -0.29713 Mabsadd L
.04603 .21501 -1.46946 -2.02254 Mabsadd L
.04603 .21501 0 -0.96154 Mabsadd L
.04603 .21501 1.46946 -2.02254 Mabsadd L
.04603 .21501 .91448 -0.29713 Mabsadd L
.04603 .21501 2.37764 .77254 Mabsadd L
.04603 .21501 .56518 .7779 Mabsadd L
.04603 .21501 0 2.5 Mabsadd L closepath F
.04921 .21511 0 2.5 Mabsadd m
.04921 .21511 -0.56518 .7779 Mabsadd L
.04921 .21511 -2.37764 .77254 Mabsadd L
.04921 .21511 -0.91448 -0.29713 Mabsadd L
.04921 .21511 -1.46946 -2.02254 Mabsadd L
.04921 .21511 0 -0.96154 Mabsadd L
.04921 .21511 1.46946 -2.02254 Mabsadd L
.04921 .21511 .91448 -0.29713 Mabsadd L
.04921 .21511 2.37764 .77254 Mabsadd L
.04921 .21511 .56518 .7779 Mabsadd L
.04921 .21511 0 2.5 Mabsadd L closepath F
.05238 .21521 0 2.5 Mabsadd m
.05238 .21521 -0.56518 .7779 Mabsadd L
.05238 .21521 -2.37764 .77254 Mabsadd L
.05238 .21521 -0.91448 -0.29713 Mabsadd L
.05238 .21521 -1.46946 -2.02254 Mabsadd L
.05238 .21521 0 -0.96154 Mabsadd L
.05238 .21521 1.46946 -2.02254 Mabsadd L
.05238 .21521 .91448 -0.29713 Mabsadd L
.05238 .21521 2.37764 .77254 Mabsadd L
.05238 .21521 .56518 .7779 Mabsadd L
.05238 .21521 0 2.5 Mabsadd L closepath F
.05556 .21532 0 2.5 Mabsadd m
.05556 .21532 -0.56518 .7779 Mabsadd L
.05556 .21532 -2.37764 .77254 Mabsadd L
.05556 .21532 -0.91448 -0.29713 Mabsadd L
.05556 .21532 -1.46946 -2.02254 Mabsadd L
.05556 .21532 0 -0.96154 Mabsadd L
.05556 .21532 1.46946 -2.02254 Mabsadd L
.05556 .21532 .91448 -0.29713 Mabsadd L
.05556 .21532 2.37764 .77254 Mabsadd L
.05556 .21532 .56518 .7779 Mabsadd L
.05556 .21532 0 2.5 Mabsadd L closepath F
.05873 .21542 0 2.5 Mabsadd m
.05873 .21542 -0.56518 .7779 Mabsadd L
.05873 .21542 -2.37764 .77254 Mabsadd L
.05873 .21542 -0.91448 -0.29713 Mabsadd L
.05873 .21542 -1.46946 -2.02254 Mabsadd L
.05873 .21542 0 -0.96154 Mabsadd L
.05873 .21542 1.46946 -2.02254 Mabsadd L
.05873 .21542 .91448 -0.29713 Mabsadd L
.05873 .21542 2.37764 .77254 Mabsadd L
.05873 .21542 .56518 .7779 Mabsadd L
.05873 .21542 0 2.5 Mabsadd L closepath F
.0619 .21553 0 2.5 Mabsadd m
.0619 .21553 -0.56518 .7779 Mabsadd L
.0619 .21553 -2.37764 .77254 Mabsadd L
.0619 .21553 -0.91448 -0.29713 Mabsadd L
.0619 .21553 -1.46946 -2.02254 Mabsadd L
.0619 .21553 0 -0.96154 Mabsadd L
.0619 .21553 1.46946 -2.02254 Mabsadd L
.0619 .21553 .91448 -0.29713 Mabsadd L
.0619 .21553 2.37764 .77254 Mabsadd L
.0619 .21553 .56518 .7779 Mabsadd L
.0619 .21553 0 2.5 Mabsadd L closepath F
.06508 .21564 0 2.5 Mabsadd m
.06508 .21564 -0.56518 .7779 Mabsadd L
.06508 .21564 -2.37764 .77254 Mabsadd L
.06508 .21564 -0.91448 -0.29713 Mabsadd L
.06508 .21564 -1.46946 -2.02254 Mabsadd L
.06508 .21564 0 -0.96154 Mabsadd L
.06508 .21564 1.46946 -2.02254 Mabsadd L
.06508 .21564 .91448 -0.29713 Mabsadd L
.06508 .21564 2.37764 .77254 Mabsadd L
.06508 .21564 .56518 .7779 Mabsadd L
.06508 .21564 0 2.5 Mabsadd L closepath F
.06825 .21575 0 2.5 Mabsadd m
.06825 .21575 -0.56518 .7779 Mabsadd L
.06825 .21575 -2.37764 .77254 Mabsadd L
.06825 .21575 -0.91448 -0.29713 Mabsadd L
.06825 .21575 -1.46946 -2.02254 Mabsadd L
.06825 .21575 0 -0.96154 Mabsadd L
.06825 .21575 1.46946 -2.02254 Mabsadd L
.06825 .21575 .91448 -0.29713 Mabsadd L
.06825 .21575 2.37764 .77254 Mabsadd L
.06825 .21575 .56518 .7779 Mabsadd L
.06825 .21575 0 2.5 Mabsadd L closepath F
.07143 .21586 0 2.5 Mabsadd m
.07143 .21586 -0.56518 .7779 Mabsadd L
.07143 .21586 -2.37764 .77254 Mabsadd L
.07143 .21586 -0.91448 -0.29713 Mabsadd L
.07143 .21586 -1.46946 -2.02254 Mabsadd L
.07143 .21586 0 -0.96154 Mabsadd L
.07143 .21586 1.46946 -2.02254 Mabsadd L
.07143 .21586 .91448 -0.29713 Mabsadd L
.07143 .21586 2.37764 .77254 Mabsadd L
.07143 .21586 .56518 .7779 Mabsadd L
.07143 .21586 0 2.5 Mabsadd L closepath F
.0746 .21597 0 2.5 Mabsadd m
.0746 .21597 -0.56518 .7779 Mabsadd L
.0746 .21597 -2.37764 .77254 Mabsadd L
.0746 .21597 -0.91448 -0.29713 Mabsadd L
.0746 .21597 -1.46946 -2.02254 Mabsadd L
.0746 .21597 0 -0.96154 Mabsadd L
.0746 .21597 1.46946 -2.02254 Mabsadd L
.0746 .21597 .91448 -0.29713 Mabsadd L
.0746 .21597 2.37764 .77254 Mabsadd L
.0746 .21597 .56518 .7779 Mabsadd L
.0746 .21597 0 2.5 Mabsadd L closepath F
.07778 .21608 0 2.5 Mabsadd m
.07778 .21608 -0.56518 .7779 Mabsadd L
.07778 .21608 -2.37764 .77254 Mabsadd L
.07778 .21608 -0.91448 -0.29713 Mabsadd L
.07778 .21608 -1.46946 -2.02254 Mabsadd L
.07778 .21608 0 -0.96154 Mabsadd L
.07778 .21608 1.46946 -2.02254 Mabsadd L
.07778 .21608 .91448 -0.29713 Mabsadd L
.07778 .21608 2.37764 .77254 Mabsadd L
.07778 .21608 .56518 .7779 Mabsadd L
.07778 .21608 0 2.5 Mabsadd L closepath F
.08095 .2162 0 2.5 Mabsadd m
.08095 .2162 -0.56518 .7779 Mabsadd L
.08095 .2162 -2.37764 .77254 Mabsadd L
.08095 .2162 -0.91448 -0.29713 Mabsadd L
.08095 .2162 -1.46946 -2.02254 Mabsadd L
.08095 .2162 0 -0.96154 Mabsadd L
.08095 .2162 1.46946 -2.02254 Mabsadd L
.08095 .2162 .91448 -0.29713 Mabsadd L
.08095 .2162 2.37764 .77254 Mabsadd L
.08095 .2162 .56518 .7779 Mabsadd L
.08095 .2162 0 2.5 Mabsadd L closepath F
.08413 .21631 0 2.5 Mabsadd m
.08413 .21631 -0.56518 .7779 Mabsadd L
.08413 .21631 -2.37764 .77254 Mabsadd L
.08413 .21631 -0.91448 -0.29713 Mabsadd L
.08413 .21631 -1.46946 -2.02254 Mabsadd L
.08413 .21631 0 -0.96154 Mabsadd L
.08413 .21631 1.46946 -2.02254 Mabsadd L
.08413 .21631 .91448 -0.29713 Mabsadd L
.08413 .21631 2.37764 .77254 Mabsadd L
.08413 .21631 .56518 .7779 Mabsadd L
.08413 .21631 0 2.5 Mabsadd L closepath F
.0873 .21643 0 2.5 Mabsadd m
.0873 .21643 -0.56518 .7779 Mabsadd L
.0873 .21643 -2.37764 .77254 Mabsadd L
.0873 .21643 -0.91448 -0.29713 Mabsadd L
.0873 .21643 -1.46946 -2.02254 Mabsadd L
.0873 .21643 0 -0.96154 Mabsadd L
.0873 .21643 1.46946 -2.02254 Mabsadd L
.0873 .21643 .91448 -0.29713 Mabsadd L
.0873 .21643 2.37764 .77254 Mabsadd L
.0873 .21643 .56518 .7779 Mabsadd L
.0873 .21643 0 2.5 Mabsadd L closepath F
.09048 .21655 0 2.5 Mabsadd m
.09048 .21655 -0.56518 .7779 Mabsadd L
.09048 .21655 -2.37764 .77254 Mabsadd L
.09048 .21655 -0.91448 -0.29713 Mabsadd L
.09048 .21655 -1.46946 -2.02254 Mabsadd L
.09048 .21655 0 -0.96154 Mabsadd L
.09048 .21655 1.46946 -2.02254 Mabsadd L
.09048 .21655 .91448 -0.29713 Mabsadd L
.09048 .21655 2.37764 .77254 Mabsadd L
.09048 .21655 .56518 .7779 Mabsadd L
.09048 .21655 0 2.5 Mabsadd L closepath F
.09365 .21666 0 2.5 Mabsadd m
.09365 .21666 -0.56518 .7779 Mabsadd L
.09365 .21666 -2.37764 .77254 Mabsadd L
.09365 .21666 -0.91448 -0.29713 Mabsadd L
.09365 .21666 -1.46946 -2.02254 Mabsadd L
.09365 .21666 0 -0.96154 Mabsadd L
.09365 .21666 1.46946 -2.02254 Mabsadd L
.09365 .21666 .91448 -0.29713 Mabsadd L
.09365 .21666 2.37764 .77254 Mabsadd L
.09365 .21666 .56518 .7779 Mabsadd L
.09365 .21666 0 2.5 Mabsadd L closepath F
.09683 .21678 0 2.5 Mabsadd m
.09683 .21678 -0.56518 .7779 Mabsadd L
.09683 .21678 -2.37764 .77254 Mabsadd L
.09683 .21678 -0.91448 -0.29713 Mabsadd L
.09683 .21678 -1.46946 -2.02254 Mabsadd L
.09683 .21678 0 -0.96154 Mabsadd L
.09683 .21678 1.46946 -2.02254 Mabsadd L
.09683 .21678 .91448 -0.29713 Mabsadd L
.09683 .21678 2.37764 .77254 Mabsadd L
.09683 .21678 .56518 .7779 Mabsadd L
.09683 .21678 0 2.5 Mabsadd L closepath F
.1 .2169 0 2.5 Mabsadd m
.1 .2169 -0.56518 .7779 Mabsadd L
.1 .2169 -2.37764 .77254 Mabsadd L
.1 .2169 -0.91448 -0.29713 Mabsadd L
.1 .2169 -1.46946 -2.02254 Mabsadd L
.1 .2169 0 -0.96154 Mabsadd L
.1 .2169 1.46946 -2.02254 Mabsadd L
.1 .2169 .91448 -0.29713 Mabsadd L
.1 .2169 2.37764 .77254 Mabsadd L
.1 .2169 .56518 .7779 Mabsadd L
.1 .2169 0 2.5 Mabsadd L closepath F
.10317 .21703 0 2.5 Mabsadd m
.10317 .21703 -0.56518 .7779 Mabsadd L
.10317 .21703 -2.37764 .77254 Mabsadd L
.10317 .21703 -0.91448 -0.29713 Mabsadd L
.10317 .21703 -1.46946 -2.02254 Mabsadd L
.10317 .21703 0 -0.96154 Mabsadd L
.10317 .21703 1.46946 -2.02254 Mabsadd L
.10317 .21703 .91448 -0.29713 Mabsadd L
.10317 .21703 2.37764 .77254 Mabsadd L
.10317 .21703 .56518 .7779 Mabsadd L
.10317 .21703 0 2.5 Mabsadd L closepath F
.10635 .21715 0 2.5 Mabsadd m
.10635 .21715 -0.56518 .7779 Mabsadd L
.10635 .21715 -2.37764 .77254 Mabsadd L
.10635 .21715 -0.91448 -0.29713 Mabsadd L
.10635 .21715 -1.46946 -2.02254 Mabsadd L
.10635 .21715 0 -0.96154 Mabsadd L
.10635 .21715 1.46946 -2.02254 Mabsadd L
.10635 .21715 .91448 -0.29713 Mabsadd L
.10635 .21715 2.37764 .77254 Mabsadd L
.10635 .21715 .56518 .7779 Mabsadd L
.10635 .21715 0 2.5 Mabsadd L closepath F
.10952 .21727 0 2.5 Mabsadd m
.10952 .21727 -0.56518 .7779 Mabsadd L
.10952 .21727 -2.37764 .77254 Mabsadd L
.10952 .21727 -0.91448 -0.29713 Mabsadd L
.10952 .21727 -1.46946 -2.02254 Mabsadd L
.10952 .21727 0 -0.96154 Mabsadd L
.10952 .21727 1.46946 -2.02254 Mabsadd L
.10952 .21727 .91448 -0.29713 Mabsadd L
.10952 .21727 2.37764 .77254 Mabsadd L
.10952 .21727 .56518 .7779 Mabsadd L
.10952 .21727 0 2.5 Mabsadd L closepath F
.1127 .2174 0 2.5 Mabsadd m
.1127 .2174 -0.56518 .7779 Mabsadd L
.1127 .2174 -2.37764 .77254 Mabsadd L
.1127 .2174 -0.91448 -0.29713 Mabsadd L
.1127 .2174 -1.46946 -2.02254 Mabsadd L
.1127 .2174 0 -0.96154 Mabsadd L
.1127 .2174 1.46946 -2.02254 Mabsadd L
.1127 .2174 .91448 -0.29713 Mabsadd L
.1127 .2174 2.37764 .77254 Mabsadd L
.1127 .2174 .56518 .7779 Mabsadd L
.1127 .2174 0 2.5 Mabsadd L closepath F
.11587 .21753 0 2.5 Mabsadd m
.11587 .21753 -0.56518 .7779 Mabsadd L
.11587 .21753 -2.37764 .77254 Mabsadd L
.11587 .21753 -0.91448 -0.29713 Mabsadd L
.11587 .21753 -1.46946 -2.02254 Mabsadd L
.11587 .21753 0 -0.96154 Mabsadd L
.11587 .21753 1.46946 -2.02254 Mabsadd L
.11587 .21753 .91448 -0.29713 Mabsadd L
.11587 .21753 2.37764 .77254 Mabsadd L
.11587 .21753 .56518 .7779 Mabsadd L
.11587 .21753 0 2.5 Mabsadd L closepath F
.11905 .21765 0 2.5 Mabsadd m
.11905 .21765 -0.56518 .7779 Mabsadd L
.11905 .21765 -2.37764 .77254 Mabsadd L
.11905 .21765 -0.91448 -0.29713 Mabsadd L
.11905 .21765 -1.46946 -2.02254 Mabsadd L
.11905 .21765 0 -0.96154 Mabsadd L
.11905 .21765 1.46946 -2.02254 Mabsadd L
.11905 .21765 .91448 -0.29713 Mabsadd L
.11905 .21765 2.37764 .77254 Mabsadd L
.11905 .21765 .56518 .7779 Mabsadd L
.11905 .21765 0 2.5 Mabsadd L closepath F
.12222 .21778 0 2.5 Mabsadd m
.12222 .21778 -0.56518 .7779 Mabsadd L
.12222 .21778 -2.37764 .77254 Mabsadd L
.12222 .21778 -0.91448 -0.29713 Mabsadd L
.12222 .21778 -1.46946 -2.02254 Mabsadd L
.12222 .21778 0 -0.96154 Mabsadd L
.12222 .21778 1.46946 -2.02254 Mabsadd L
.12222 .21778 .91448 -0.29713 Mabsadd L
.12222 .21778 2.37764 .77254 Mabsadd L
.12222 .21778 .56518 .7779 Mabsadd L
.12222 .21778 0 2.5 Mabsadd L closepath F
.1254 .21791 0 2.5 Mabsadd m
.1254 .21791 -0.56518 .7779 Mabsadd L
.1254 .21791 -2.37764 .77254 Mabsadd L
.1254 .21791 -0.91448 -0.29713 Mabsadd L
.1254 .21791 -1.46946 -2.02254 Mabsadd L
.1254 .21791 0 -0.96154 Mabsadd L
.1254 .21791 1.46946 -2.02254 Mabsadd L
.1254 .21791 .91448 -0.29713 Mabsadd L
.1254 .21791 2.37764 .77254 Mabsadd L
.1254 .21791 .56518 .7779 Mabsadd L
.1254 .21791 0 2.5 Mabsadd L closepath F
.12857 .21805 0 2.5 Mabsadd m
.12857 .21805 -0.56518 .7779 Mabsadd L
.12857 .21805 -2.37764 .77254 Mabsadd L
.12857 .21805 -0.91448 -0.29713 Mabsadd L
.12857 .21805 -1.46946 -2.02254 Mabsadd L
.12857 .21805 0 -0.96154 Mabsadd L
.12857 .21805 1.46946 -2.02254 Mabsadd L
.12857 .21805 .91448 -0.29713 Mabsadd L
.12857 .21805 2.37764 .77254 Mabsadd L
.12857 .21805 .56518 .7779 Mabsadd L
.12857 .21805 0 2.5 Mabsadd L closepath F
.13175 .21818 0 2.5 Mabsadd m
.13175 .21818 -0.56518 .7779 Mabsadd L
.13175 .21818 -2.37764 .77254 Mabsadd L
.13175 .21818 -0.91448 -0.29713 Mabsadd L
.13175 .21818 -1.46946 -2.02254 Mabsadd L
.13175 .21818 0 -0.96154 Mabsadd L
.13175 .21818 1.46946 -2.02254 Mabsadd L
.13175 .21818 .91448 -0.29713 Mabsadd L
.13175 .21818 2.37764 .77254 Mabsadd L
.13175 .21818 .56518 .7779 Mabsadd L
.13175 .21818 0 2.5 Mabsadd L closepath F
.13492 .21831 0 2.5 Mabsadd m
.13492 .21831 -0.56518 .7779 Mabsadd L
.13492 .21831 -2.37764 .77254 Mabsadd L
.13492 .21831 -0.91448 -0.29713 Mabsadd L
.13492 .21831 -1.46946 -2.02254 Mabsadd L
.13492 .21831 0 -0.96154 Mabsadd L
.13492 .21831 1.46946 -2.02254 Mabsadd L
.13492 .21831 .91448 -0.29713 Mabsadd L
.13492 .21831 2.37764 .77254 Mabsadd L
.13492 .21831 .56518 .7779 Mabsadd L
.13492 .21831 0 2.5 Mabsadd L closepath F
.1381 .21845 0 2.5 Mabsadd m
.1381 .21845 -0.56518 .7779 Mabsadd L
.1381 .21845 -2.37764 .77254 Mabsadd L
.1381 .21845 -0.91448 -0.29713 Mabsadd L
.1381 .21845 -1.46946 -2.02254 Mabsadd L
.1381 .21845 0 -0.96154 Mabsadd L
.1381 .21845 1.46946 -2.02254 Mabsadd L
.1381 .21845 .91448 -0.29713 Mabsadd L
.1381 .21845 2.37764 .77254 Mabsadd L
.1381 .21845 .56518 .7779 Mabsadd L
.1381 .21845 0 2.5 Mabsadd L closepath F
.14127 .21859 0 2.5 Mabsadd m
.14127 .21859 -0.56518 .7779 Mabsadd L
.14127 .21859 -2.37764 .77254 Mabsadd L
.14127 .21859 -0.91448 -0.29713 Mabsadd L
.14127 .21859 -1.46946 -2.02254 Mabsadd L
.14127 .21859 0 -0.96154 Mabsadd L
.14127 .21859 1.46946 -2.02254 Mabsadd L
.14127 .21859 .91448 -0.29713 Mabsadd L
.14127 .21859 2.37764 .77254 Mabsadd L
.14127 .21859 .56518 .7779 Mabsadd L
.14127 .21859 0 2.5 Mabsadd L closepath F
.14444 .21873 0 2.5 Mabsadd m
.14444 .21873 -0.56518 .7779 Mabsadd L
.14444 .21873 -2.37764 .77254 Mabsadd L
.14444 .21873 -0.91448 -0.29713 Mabsadd L
.14444 .21873 -1.46946 -2.02254 Mabsadd L
.14444 .21873 0 -0.96154 Mabsadd L
.14444 .21873 1.46946 -2.02254 Mabsadd L
.14444 .21873 .91448 -0.29713 Mabsadd L
.14444 .21873 2.37764 .77254 Mabsadd L
.14444 .21873 .56518 .7779 Mabsadd L
.14444 .21873 0 2.5 Mabsadd L closepath F
.14762 .21887 0 2.5 Mabsadd m
.14762 .21887 -0.56518 .7779 Mabsadd L
.14762 .21887 -2.37764 .77254 Mabsadd L
.14762 .21887 -0.91448 -0.29713 Mabsadd L
.14762 .21887 -1.46946 -2.02254 Mabsadd L
.14762 .21887 0 -0.96154 Mabsadd L
.14762 .21887 1.46946 -2.02254 Mabsadd L
.14762 .21887 .91448 -0.29713 Mabsadd L
.14762 .21887 2.37764 .77254 Mabsadd L
.14762 .21887 .56518 .7779 Mabsadd L
.14762 .21887 0 2.5 Mabsadd L closepath F
.15079 .21901 0 2.5 Mabsadd m
.15079 .21901 -0.56518 .7779 Mabsadd L
.15079 .21901 -2.37764 .77254 Mabsadd L
.15079 .21901 -0.91448 -0.29713 Mabsadd L
.15079 .21901 -1.46946 -2.02254 Mabsadd L
.15079 .21901 0 -0.96154 Mabsadd L
.15079 .21901 1.46946 -2.02254 Mabsadd L
.15079 .21901 .91448 -0.29713 Mabsadd L
.15079 .21901 2.37764 .77254 Mabsadd L
.15079 .21901 .56518 .7779 Mabsadd L
.15079 .21901 0 2.5 Mabsadd L closepath F
.15397 .21915 0 2.5 Mabsadd m
.15397 .21915 -0.56518 .7779 Mabsadd L
.15397 .21915 -2.37764 .77254 Mabsadd L
.15397 .21915 -0.91448 -0.29713 Mabsadd L
.15397 .21915 -1.46946 -2.02254 Mabsadd L
.15397 .21915 0 -0.96154 Mabsadd L
.15397 .21915 1.46946 -2.02254 Mabsadd L
.15397 .21915 .91448 -0.29713 Mabsadd L
.15397 .21915 2.37764 .77254 Mabsadd L
.15397 .21915 .56518 .7779 Mabsadd L
.15397 .21915 0 2.5 Mabsadd L closepath F
.15714 .2193 0 2.5 Mabsadd m
.15714 .2193 -0.56518 .7779 Mabsadd L
.15714 .2193 -2.37764 .77254 Mabsadd L
.15714 .2193 -0.91448 -0.29713 Mabsadd L
.15714 .2193 -1.46946 -2.02254 Mabsadd L
.15714 .2193 0 -0.96154 Mabsadd L
.15714 .2193 1.46946 -2.02254 Mabsadd L
.15714 .2193 .91448 -0.29713 Mabsadd L
.15714 .2193 2.37764 .77254 Mabsadd L
.15714 .2193 .56518 .7779 Mabsadd L
.15714 .2193 0 2.5 Mabsadd L closepath F
.16032 .21944 0 2.5 Mabsadd m
.16032 .21944 -0.56518 .7779 Mabsadd L
.16032 .21944 -2.37764 .77254 Mabsadd L
.16032 .21944 -0.91448 -0.29713 Mabsadd L
.16032 .21944 -1.46946 -2.02254 Mabsadd L
.16032 .21944 0 -0.96154 Mabsadd L
.16032 .21944 1.46946 -2.02254 Mabsadd L
.16032 .21944 .91448 -0.29713 Mabsadd L
.16032 .21944 2.37764 .77254 Mabsadd L
.16032 .21944 .56518 .7779 Mabsadd L
.16032 .21944 0 2.5 Mabsadd L closepath F
.16349 .21959 0 2.5 Mabsadd m
.16349 .21959 -0.56518 .7779 Mabsadd L
.16349 .21959 -2.37764 .77254 Mabsadd L
.16349 .21959 -0.91448 -0.29713 Mabsadd L
.16349 .21959 -1.46946 -2.02254 Mabsadd L
.16349 .21959 0 -0.96154 Mabsadd L
.16349 .21959 1.46946 -2.02254 Mabsadd L
.16349 .21959 .91448 -0.29713 Mabsadd L
.16349 .21959 2.37764 .77254 Mabsadd L
.16349 .21959 .56518 .7779 Mabsadd L
.16349 .21959 0 2.5 Mabsadd L closepath F
.16667 .21974 0 2.5 Mabsadd m
.16667 .21974 -0.56518 .7779 Mabsadd L
.16667 .21974 -2.37764 .77254 Mabsadd L
.16667 .21974 -0.91448 -0.29713 Mabsadd L
.16667 .21974 -1.46946 -2.02254 Mabsadd L
.16667 .21974 0 -0.96154 Mabsadd L
.16667 .21974 1.46946 -2.02254 Mabsadd L
.16667 .21974 .91448 -0.29713 Mabsadd L
.16667 .21974 2.37764 .77254 Mabsadd L
.16667 .21974 .56518 .7779 Mabsadd L
.16667 .21974 0 2.5 Mabsadd L closepath F
.16984 .21989 0 2.5 Mabsadd m
.16984 .21989 -0.56518 .7779 Mabsadd L
.16984 .21989 -2.37764 .77254 Mabsadd L
.16984 .21989 -0.91448 -0.29713 Mabsadd L
.16984 .21989 -1.46946 -2.02254 Mabsadd L
.16984 .21989 0 -0.96154 Mabsadd L
.16984 .21989 1.46946 -2.02254 Mabsadd L
.16984 .21989 .91448 -0.29713 Mabsadd L
.16984 .21989 2.37764 .77254 Mabsadd L
.16984 .21989 .56518 .7779 Mabsadd L
.16984 .21989 0 2.5 Mabsadd L closepath F
.17302 .22004 0 2.5 Mabsadd m
.17302 .22004 -0.56518 .7779 Mabsadd L
.17302 .22004 -2.37764 .77254 Mabsadd L
.17302 .22004 -0.91448 -0.29713 Mabsadd L
.17302 .22004 -1.46946 -2.02254 Mabsadd L
.17302 .22004 0 -0.96154 Mabsadd L
.17302 .22004 1.46946 -2.02254 Mabsadd L
.17302 .22004 .91448 -0.29713 Mabsadd L
.17302 .22004 2.37764 .77254 Mabsadd L
.17302 .22004 .56518 .7779 Mabsadd L
.17302 .22004 0 2.5 Mabsadd L closepath F
.17619 .22019 0 2.5 Mabsadd m
.17619 .22019 -0.56518 .7779 Mabsadd L
.17619 .22019 -2.37764 .77254 Mabsadd L
.17619 .22019 -0.91448 -0.29713 Mabsadd L
.17619 .22019 -1.46946 -2.02254 Mabsadd L
.17619 .22019 0 -0.96154 Mabsadd L
.17619 .22019 1.46946 -2.02254 Mabsadd L
.17619 .22019 .91448 -0.29713 Mabsadd L
.17619 .22019 2.37764 .77254 Mabsadd L
.17619 .22019 .56518 .7779 Mabsadd L
.17619 .22019 0 2.5 Mabsadd L closepath F
.17937 .22035 0 2.5 Mabsadd m
.17937 .22035 -0.56518 .7779 Mabsadd L
.17937 .22035 -2.37764 .77254 Mabsadd L
.17937 .22035 -0.91448 -0.29713 Mabsadd L
.17937 .22035 -1.46946 -2.02254 Mabsadd L
.17937 .22035 0 -0.96154 Mabsadd L
.17937 .22035 1.46946 -2.02254 Mabsadd L
.17937 .22035 .91448 -0.29713 Mabsadd L
.17937 .22035 2.37764 .77254 Mabsadd L
.17937 .22035 .56518 .7779 Mabsadd L
.17937 .22035 0 2.5 Mabsadd L closepath F
.18254 .2205 0 2.5 Mabsadd m
.18254 .2205 -0.56518 .7779 Mabsadd L
.18254 .2205 -2.37764 .77254 Mabsadd L
.18254 .2205 -0.91448 -0.29713 Mabsadd L
.18254 .2205 -1.46946 -2.02254 Mabsadd L
.18254 .2205 0 -0.96154 Mabsadd L
.18254 .2205 1.46946 -2.02254 Mabsadd L
.18254 .2205 .91448 -0.29713 Mabsadd L
.18254 .2205 2.37764 .77254 Mabsadd L
.18254 .2205 .56518 .7779 Mabsadd L
.18254 .2205 0 2.5 Mabsadd L closepath F
.18571 .22066 0 2.5 Mabsadd m
.18571 .22066 -0.56518 .7779 Mabsadd L
.18571 .22066 -2.37764 .77254 Mabsadd L
.18571 .22066 -0.91448 -0.29713 Mabsadd L
.18571 .22066 -1.46946 -2.02254 Mabsadd L
.18571 .22066 0 -0.96154 Mabsadd L
.18571 .22066 1.46946 -2.02254 Mabsadd L
.18571 .22066 .91448 -0.29713 Mabsadd L
.18571 .22066 2.37764 .77254 Mabsadd L
.18571 .22066 .56518 .7779 Mabsadd L
.18571 .22066 0 2.5 Mabsadd L closepath F
.18889 .22082 0 2.5 Mabsadd m
.18889 .22082 -0.56518 .7779 Mabsadd L
.18889 .22082 -2.37764 .77254 Mabsadd L
.18889 .22082 -0.91448 -0.29713 Mabsadd L
.18889 .22082 -1.46946 -2.02254 Mabsadd L
.18889 .22082 0 -0.96154 Mabsadd L
.18889 .22082 1.46946 -2.02254 Mabsadd L
.18889 .22082 .91448 -0.29713 Mabsadd L
.18889 .22082 2.37764 .77254 Mabsadd L
.18889 .22082 .56518 .7779 Mabsadd L
.18889 .22082 0 2.5 Mabsadd L closepath F
.19206 .22098 0 2.5 Mabsadd m
.19206 .22098 -0.56518 .7779 Mabsadd L
.19206 .22098 -2.37764 .77254 Mabsadd L
.19206 .22098 -0.91448 -0.29713 Mabsadd L
.19206 .22098 -1.46946 -2.02254 Mabsadd L
.19206 .22098 0 -0.96154 Mabsadd L
.19206 .22098 1.46946 -2.02254 Mabsadd L
.19206 .22098 .91448 -0.29713 Mabsadd L
.19206 .22098 2.37764 .77254 Mabsadd L
.19206 .22098 .56518 .7779 Mabsadd L
.19206 .22098 0 2.5 Mabsadd L closepath F
.19524 .22114 0 2.5 Mabsadd m
.19524 .22114 -0.56518 .7779 Mabsadd L
.19524 .22114 -2.37764 .77254 Mabsadd L
.19524 .22114 -0.91448 -0.29713 Mabsadd L
.19524 .22114 -1.46946 -2.02254 Mabsadd L
.19524 .22114 0 -0.96154 Mabsadd L
.19524 .22114 1.46946 -2.02254 Mabsadd L
.19524 .22114 .91448 -0.29713 Mabsadd L
.19524 .22114 2.37764 .77254 Mabsadd L
.19524 .22114 .56518 .7779 Mabsadd L
.19524 .22114 0 2.5 Mabsadd L closepath F
.19841 .22131 0 2.5 Mabsadd m
.19841 .22131 -0.56518 .7779 Mabsadd L
.19841 .22131 -2.37764 .77254 Mabsadd L
.19841 .22131 -0.91448 -0.29713 Mabsadd L
.19841 .22131 -1.46946 -2.02254 Mabsadd L
.19841 .22131 0 -0.96154 Mabsadd L
.19841 .22131 1.46946 -2.02254 Mabsadd L
.19841 .22131 .91448 -0.29713 Mabsadd L
.19841 .22131 2.37764 .77254 Mabsadd L
.19841 .22131 .56518 .7779 Mabsadd L
.19841 .22131 0 2.5 Mabsadd L closepath F
.20159 .22147 0 2.5 Mabsadd m
.20159 .22147 -0.56518 .7779 Mabsadd L
.20159 .22147 -2.37764 .77254 Mabsadd L
.20159 .22147 -0.91448 -0.29713 Mabsadd L
.20159 .22147 -1.46946 -2.02254 Mabsadd L
.20159 .22147 0 -0.96154 Mabsadd L
.20159 .22147 1.46946 -2.02254 Mabsadd L
.20159 .22147 .91448 -0.29713 Mabsadd L
.20159 .22147 2.37764 .77254 Mabsadd L
.20159 .22147 .56518 .7779 Mabsadd L
.20159 .22147 0 2.5 Mabsadd L closepath F
.20476 .22164 0 2.5 Mabsadd m
.20476 .22164 -0.56518 .7779 Mabsadd L
.20476 .22164 -2.37764 .77254 Mabsadd L
.20476 .22164 -0.91448 -0.29713 Mabsadd L
.20476 .22164 -1.46946 -2.02254 Mabsadd L
.20476 .22164 0 -0.96154 Mabsadd L
.20476 .22164 1.46946 -2.02254 Mabsadd L
.20476 .22164 .91448 -0.29713 Mabsadd L
.20476 .22164 2.37764 .77254 Mabsadd L
.20476 .22164 .56518 .7779 Mabsadd L
.20476 .22164 0 2.5 Mabsadd L closepath F
.20794 .22181 0 2.5 Mabsadd m
.20794 .22181 -0.56518 .7779 Mabsadd L
.20794 .22181 -2.37764 .77254 Mabsadd L
.20794 .22181 -0.91448 -0.29713 Mabsadd L
.20794 .22181 -1.46946 -2.02254 Mabsadd L
.20794 .22181 0 -0.96154 Mabsadd L
.20794 .22181 1.46946 -2.02254 Mabsadd L
.20794 .22181 .91448 -0.29713 Mabsadd L
.20794 .22181 2.37764 .77254 Mabsadd L
.20794 .22181 .56518 .7779 Mabsadd L
.20794 .22181 0 2.5 Mabsadd L closepath F
.21111 .22198 0 2.5 Mabsadd m
.21111 .22198 -0.56518 .7779 Mabsadd L
.21111 .22198 -2.37764 .77254 Mabsadd L
.21111 .22198 -0.91448 -0.29713 Mabsadd L
.21111 .22198 -1.46946 -2.02254 Mabsadd L
.21111 .22198 0 -0.96154 Mabsadd L
.21111 .22198 1.46946 -2.02254 Mabsadd L
.21111 .22198 .91448 -0.29713 Mabsadd L
.21111 .22198 2.37764 .77254 Mabsadd L
.21111 .22198 .56518 .7779 Mabsadd L
.21111 .22198 0 2.5 Mabsadd L closepath F
.21429 .22216 0 2.5 Mabsadd m
.21429 .22216 -0.56518 .7779 Mabsadd L
.21429 .22216 -2.37764 .77254 Mabsadd L
.21429 .22216 -0.91448 -0.29713 Mabsadd L
.21429 .22216 -1.46946 -2.02254 Mabsadd L
.21429 .22216 0 -0.96154 Mabsadd L
.21429 .22216 1.46946 -2.02254 Mabsadd L
.21429 .22216 .91448 -0.29713 Mabsadd L
.21429 .22216 2.37764 .77254 Mabsadd L
.21429 .22216 .56518 .7779 Mabsadd L
.21429 .22216 0 2.5 Mabsadd L closepath F
.21746 .22233 0 2.5 Mabsadd m
.21746 .22233 -0.56518 .7779 Mabsadd L
.21746 .22233 -2.37764 .77254 Mabsadd L
.21746 .22233 -0.91448 -0.29713 Mabsadd L
.21746 .22233 -1.46946 -2.02254 Mabsadd L
.21746 .22233 0 -0.96154 Mabsadd L
.21746 .22233 1.46946 -2.02254 Mabsadd L
.21746 .22233 .91448 -0.29713 Mabsadd L
.21746 .22233 2.37764 .77254 Mabsadd L
.21746 .22233 .56518 .7779 Mabsadd L
.21746 .22233 0 2.5 Mabsadd L closepath F
.22063 .22251 0 2.5 Mabsadd m
.22063 .22251 -0.56518 .7779 Mabsadd L
.22063 .22251 -2.37764 .77254 Mabsadd L
.22063 .22251 -0.91448 -0.29713 Mabsadd L
.22063 .22251 -1.46946 -2.02254 Mabsadd L
.22063 .22251 0 -0.96154 Mabsadd L
.22063 .22251 1.46946 -2.02254 Mabsadd L
.22063 .22251 .91448 -0.29713 Mabsadd L
.22063 .22251 2.37764 .77254 Mabsadd L
.22063 .22251 .56518 .7779 Mabsadd L
.22063 .22251 0 2.5 Mabsadd L closepath F
.22381 .22268 0 2.5 Mabsadd m
.22381 .22268 -0.56518 .7779 Mabsadd L
.22381 .22268 -2.37764 .77254 Mabsadd L
.22381 .22268 -0.91448 -0.29713 Mabsadd L
.22381 .22268 -1.46946 -2.02254 Mabsadd L
.22381 .22268 0 -0.96154 Mabsadd L
.22381 .22268 1.46946 -2.02254 Mabsadd L
.22381 .22268 .91448 -0.29713 Mabsadd L
.22381 .22268 2.37764 .77254 Mabsadd L
.22381 .22268 .56518 .7779 Mabsadd L
.22381 .22268 0 2.5 Mabsadd L closepath F
.22698 .22286 0 2.5 Mabsadd m
.22698 .22286 -0.56518 .7779 Mabsadd L
.22698 .22286 -2.37764 .77254 Mabsadd L
.22698 .22286 -0.91448 -0.29713 Mabsadd L
.22698 .22286 -1.46946 -2.02254 Mabsadd L
.22698 .22286 0 -0.96154 Mabsadd L
.22698 .22286 1.46946 -2.02254 Mabsadd L
.22698 .22286 .91448 -0.29713 Mabsadd L
.22698 .22286 2.37764 .77254 Mabsadd L
.22698 .22286 .56518 .7779 Mabsadd L
.22698 .22286 0 2.5 Mabsadd L closepath F
.23016 .22305 0 2.5 Mabsadd m
.23016 .22305 -0.56518 .7779 Mabsadd L
.23016 .22305 -2.37764 .77254 Mabsadd L
.23016 .22305 -0.91448 -0.29713 Mabsadd L
.23016 .22305 -1.46946 -2.02254 Mabsadd L
.23016 .22305 0 -0.96154 Mabsadd L
.23016 .22305 1.46946 -2.02254 Mabsadd L
.23016 .22305 .91448 -0.29713 Mabsadd L
.23016 .22305 2.37764 .77254 Mabsadd L
.23016 .22305 .56518 .7779 Mabsadd L
.23016 .22305 0 2.5 Mabsadd L closepath F
.23333 .22323 0 2.5 Mabsadd m
.23333 .22323 -0.56518 .7779 Mabsadd L
.23333 .22323 -2.37764 .77254 Mabsadd L
.23333 .22323 -0.91448 -0.29713 Mabsadd L
.23333 .22323 -1.46946 -2.02254 Mabsadd L
.23333 .22323 0 -0.96154 Mabsadd L
.23333 .22323 1.46946 -2.02254 Mabsadd L
.23333 .22323 .91448 -0.29713 Mabsadd L
.23333 .22323 2.37764 .77254 Mabsadd L
.23333 .22323 .56518 .7779 Mabsadd L
.23333 .22323 0 2.5 Mabsadd L closepath F
.23651 .22341 0 2.5 Mabsadd m
.23651 .22341 -0.56518 .7779 Mabsadd L
.23651 .22341 -2.37764 .77254 Mabsadd L
.23651 .22341 -0.91448 -0.29713 Mabsadd L
.23651 .22341 -1.46946 -2.02254 Mabsadd L
.23651 .22341 0 -0.96154 Mabsadd L
.23651 .22341 1.46946 -2.02254 Mabsadd L
.23651 .22341 .91448 -0.29713 Mabsadd L
.23651 .22341 2.37764 .77254 Mabsadd L
.23651 .22341 .56518 .7779 Mabsadd L
.23651 .22341 0 2.5 Mabsadd L closepath F
.23968 .2236 0 2.5 Mabsadd m
.23968 .2236 -0.56518 .7779 Mabsadd L
.23968 .2236 -2.37764 .77254 Mabsadd L
.23968 .2236 -0.91448 -0.29713 Mabsadd L
.23968 .2236 -1.46946 -2.02254 Mabsadd L
.23968 .2236 0 -0.96154 Mabsadd L
.23968 .2236 1.46946 -2.02254 Mabsadd L
.23968 .2236 .91448 -0.29713 Mabsadd L
.23968 .2236 2.37764 .77254 Mabsadd L
.23968 .2236 .56518 .7779 Mabsadd L
.23968 .2236 0 2.5 Mabsadd L closepath F
.24286 .22379 0 2.5 Mabsadd m
.24286 .22379 -0.56518 .7779 Mabsadd L
.24286 .22379 -2.37764 .77254 Mabsadd L
.24286 .22379 -0.91448 -0.29713 Mabsadd L
.24286 .22379 -1.46946 -2.02254 Mabsadd L
.24286 .22379 0 -0.96154 Mabsadd L
.24286 .22379 1.46946 -2.02254 Mabsadd L
.24286 .22379 .91448 -0.29713 Mabsadd L
.24286 .22379 2.37764 .77254 Mabsadd L
.24286 .22379 .56518 .7779 Mabsadd L
.24286 .22379 0 2.5 Mabsadd L closepath F
.24603 .22398 0 2.5 Mabsadd m
.24603 .22398 -0.56518 .7779 Mabsadd L
.24603 .22398 -2.37764 .77254 Mabsadd L
.24603 .22398 -0.91448 -0.29713 Mabsadd L
.24603 .22398 -1.46946 -2.02254 Mabsadd L
.24603 .22398 0 -0.96154 Mabsadd L
.24603 .22398 1.46946 -2.02254 Mabsadd L
.24603 .22398 .91448 -0.29713 Mabsadd L
.24603 .22398 2.37764 .77254 Mabsadd L
.24603 .22398 .56518 .7779 Mabsadd L
.24603 .22398 0 2.5 Mabsadd L closepath F
.24921 .22417 0 2.5 Mabsadd m
.24921 .22417 -0.56518 .7779 Mabsadd L
.24921 .22417 -2.37764 .77254 Mabsadd L
.24921 .22417 -0.91448 -0.29713 Mabsadd L
.24921 .22417 -1.46946 -2.02254 Mabsadd L
.24921 .22417 0 -0.96154 Mabsadd L
.24921 .22417 1.46946 -2.02254 Mabsadd L
.24921 .22417 .91448 -0.29713 Mabsadd L
.24921 .22417 2.37764 .77254 Mabsadd L
.24921 .22417 .56518 .7779 Mabsadd L
.24921 .22417 0 2.5 Mabsadd L closepath F
.25238 .22437 0 2.5 Mabsadd m
.25238 .22437 -0.56518 .7779 Mabsadd L
.25238 .22437 -2.37764 .77254 Mabsadd L
.25238 .22437 -0.91448 -0.29713 Mabsadd L
.25238 .22437 -1.46946 -2.02254 Mabsadd L
.25238 .22437 0 -0.96154 Mabsadd L
.25238 .22437 1.46946 -2.02254 Mabsadd L
.25238 .22437 .91448 -0.29713 Mabsadd L
.25238 .22437 2.37764 .77254 Mabsadd L
.25238 .22437 .56518 .7779 Mabsadd L
.25238 .22437 0 2.5 Mabsadd L closepath F
.25556 .22456 0 2.5 Mabsadd m
.25556 .22456 -0.56518 .7779 Mabsadd L
.25556 .22456 -2.37764 .77254 Mabsadd L
.25556 .22456 -0.91448 -0.29713 Mabsadd L
.25556 .22456 -1.46946 -2.02254 Mabsadd L
.25556 .22456 0 -0.96154 Mabsadd L
.25556 .22456 1.46946 -2.02254 Mabsadd L
.25556 .22456 .91448 -0.29713 Mabsadd L
.25556 .22456 2.37764 .77254 Mabsadd L
.25556 .22456 .56518 .7779 Mabsadd L
.25556 .22456 0 2.5 Mabsadd L closepath F
.25873 .22476 0 2.5 Mabsadd m
.25873 .22476 -0.56518 .7779 Mabsadd L
.25873 .22476 -2.37764 .77254 Mabsadd L
.25873 .22476 -0.91448 -0.29713 Mabsadd L
.25873 .22476 -1.46946 -2.02254 Mabsadd L
.25873 .22476 0 -0.96154 Mabsadd L
.25873 .22476 1.46946 -2.02254 Mabsadd L
.25873 .22476 .91448 -0.29713 Mabsadd L
.25873 .22476 2.37764 .77254 Mabsadd L
.25873 .22476 .56518 .7779 Mabsadd L
.25873 .22476 0 2.5 Mabsadd L closepath F
.2619 .22496 0 2.5 Mabsadd m
.2619 .22496 -0.56518 .7779 Mabsadd L
.2619 .22496 -2.37764 .77254 Mabsadd L
.2619 .22496 -0.91448 -0.29713 Mabsadd L
.2619 .22496 -1.46946 -2.02254 Mabsadd L
.2619 .22496 0 -0.96154 Mabsadd L
.2619 .22496 1.46946 -2.02254 Mabsadd L
.2619 .22496 .91448 -0.29713 Mabsadd L
.2619 .22496 2.37764 .77254 Mabsadd L
.2619 .22496 .56518 .7779 Mabsadd L
.2619 .22496 0 2.5 Mabsadd L closepath F
.26508 .22517 0 2.5 Mabsadd m
.26508 .22517 -0.56518 .7779 Mabsadd L
.26508 .22517 -2.37764 .77254 Mabsadd L
.26508 .22517 -0.91448 -0.29713 Mabsadd L
.26508 .22517 -1.46946 -2.02254 Mabsadd L
.26508 .22517 0 -0.96154 Mabsadd L
.26508 .22517 1.46946 -2.02254 Mabsadd L
.26508 .22517 .91448 -0.29713 Mabsadd L
.26508 .22517 2.37764 .77254 Mabsadd L
.26508 .22517 .56518 .7779 Mabsadd L
.26508 .22517 0 2.5 Mabsadd L closepath F
.26825 .22537 0 2.5 Mabsadd m
.26825 .22537 -0.56518 .7779 Mabsadd L
.26825 .22537 -2.37764 .77254 Mabsadd L
.26825 .22537 -0.91448 -0.29713 Mabsadd L
.26825 .22537 -1.46946 -2.02254 Mabsadd L
.26825 .22537 0 -0.96154 Mabsadd L
.26825 .22537 1.46946 -2.02254 Mabsadd L
.26825 .22537 .91448 -0.29713 Mabsadd L
.26825 .22537 2.37764 .77254 Mabsadd L
.26825 .22537 .56518 .7779 Mabsadd L
.26825 .22537 0 2.5 Mabsadd L closepath F
.27143 .22558 0 2.5 Mabsadd m
.27143 .22558 -0.56518 .7779 Mabsadd L
.27143 .22558 -2.37764 .77254 Mabsadd L
.27143 .22558 -0.91448 -0.29713 Mabsadd L
.27143 .22558 -1.46946 -2.02254 Mabsadd L
.27143 .22558 0 -0.96154 Mabsadd L
.27143 .22558 1.46946 -2.02254 Mabsadd L
.27143 .22558 .91448 -0.29713 Mabsadd L
.27143 .22558 2.37764 .77254 Mabsadd L
.27143 .22558 .56518 .7779 Mabsadd L
.27143 .22558 0 2.5 Mabsadd L closepath F
.2746 .22579 0 2.5 Mabsadd m
.2746 .22579 -0.56518 .7779 Mabsadd L
.2746 .22579 -2.37764 .77254 Mabsadd L
.2746 .22579 -0.91448 -0.29713 Mabsadd L
.2746 .22579 -1.46946 -2.02254 Mabsadd L
.2746 .22579 0 -0.96154 Mabsadd L
.2746 .22579 1.46946 -2.02254 Mabsadd L
.2746 .22579 .91448 -0.29713 Mabsadd L
.2746 .22579 2.37764 .77254 Mabsadd L
.2746 .22579 .56518 .7779 Mabsadd L
.2746 .22579 0 2.5 Mabsadd L closepath F
.27778 .226 0 2.5 Mabsadd m
.27778 .226 -0.56518 .7779 Mabsadd L
.27778 .226 -2.37764 .77254 Mabsadd L
.27778 .226 -0.91448 -0.29713 Mabsadd L
.27778 .226 -1.46946 -2.02254 Mabsadd L
.27778 .226 0 -0.96154 Mabsadd L
.27778 .226 1.46946 -2.02254 Mabsadd L
.27778 .226 .91448 -0.29713 Mabsadd L
.27778 .226 2.37764 .77254 Mabsadd L
.27778 .226 .56518 .7779 Mabsadd L
.27778 .226 0 2.5 Mabsadd L closepath F
.28095 .22621 0 2.5 Mabsadd m
.28095 .22621 -0.56518 .7779 Mabsadd L
.28095 .22621 -2.37764 .77254 Mabsadd L
.28095 .22621 -0.91448 -0.29713 Mabsadd L
.28095 .22621 -1.46946 -2.02254 Mabsadd L
.28095 .22621 0 -0.96154 Mabsadd L
.28095 .22621 1.46946 -2.02254 Mabsadd L
.28095 .22621 .91448 -0.29713 Mabsadd L
.28095 .22621 2.37764 .77254 Mabsadd L
.28095 .22621 .56518 .7779 Mabsadd L
.28095 .22621 0 2.5 Mabsadd L closepath F
.28413 .22642 0 2.5 Mabsadd m
.28413 .22642 -0.56518 .7779 Mabsadd L
.28413 .22642 -2.37764 .77254 Mabsadd L
.28413 .22642 -0.91448 -0.29713 Mabsadd L
.28413 .22642 -1.46946 -2.02254 Mabsadd L
.28413 .22642 0 -0.96154 Mabsadd L
.28413 .22642 1.46946 -2.02254 Mabsadd L
.28413 .22642 .91448 -0.29713 Mabsadd L
.28413 .22642 2.37764 .77254 Mabsadd L
.28413 .22642 .56518 .7779 Mabsadd L
.28413 .22642 0 2.5 Mabsadd L closepath F
.2873 .22664 0 2.5 Mabsadd m
.2873 .22664 -0.56518 .7779 Mabsadd L
.2873 .22664 -2.37764 .77254 Mabsadd L
.2873 .22664 -0.91448 -0.29713 Mabsadd L
.2873 .22664 -1.46946 -2.02254 Mabsadd L
.2873 .22664 0 -0.96154 Mabsadd L
.2873 .22664 1.46946 -2.02254 Mabsadd L
.2873 .22664 .91448 -0.29713 Mabsadd L
.2873 .22664 2.37764 .77254 Mabsadd L
.2873 .22664 .56518 .7779 Mabsadd L
.2873 .22664 0 2.5 Mabsadd L closepath F
.29048 .22686 0 2.5 Mabsadd m
.29048 .22686 -0.56518 .7779 Mabsadd L
.29048 .22686 -2.37764 .77254 Mabsadd L
.29048 .22686 -0.91448 -0.29713 Mabsadd L
.29048 .22686 -1.46946 -2.02254 Mabsadd L
.29048 .22686 0 -0.96154 Mabsadd L
.29048 .22686 1.46946 -2.02254 Mabsadd L
.29048 .22686 .91448 -0.29713 Mabsadd L
.29048 .22686 2.37764 .77254 Mabsadd L
.29048 .22686 .56518 .7779 Mabsadd L
.29048 .22686 0 2.5 Mabsadd L closepath F
.29365 .22708 0 2.5 Mabsadd m
.29365 .22708 -0.56518 .7779 Mabsadd L
.29365 .22708 -2.37764 .77254 Mabsadd L
.29365 .22708 -0.91448 -0.29713 Mabsadd L
.29365 .22708 -1.46946 -2.02254 Mabsadd L
.29365 .22708 0 -0.96154 Mabsadd L
.29365 .22708 1.46946 -2.02254 Mabsadd L
.29365 .22708 .91448 -0.29713 Mabsadd L
.29365 .22708 2.37764 .77254 Mabsadd L
.29365 .22708 .56518 .7779 Mabsadd L
.29365 .22708 0 2.5 Mabsadd L closepath F
.29683 .22731 0 2.5 Mabsadd m
.29683 .22731 -0.56518 .7779 Mabsadd L
.29683 .22731 -2.37764 .77254 Mabsadd L
.29683 .22731 -0.91448 -0.29713 Mabsadd L
.29683 .22731 -1.46946 -2.02254 Mabsadd L
.29683 .22731 0 -0.96154 Mabsadd L
.29683 .22731 1.46946 -2.02254 Mabsadd L
.29683 .22731 .91448 -0.29713 Mabsadd L
.29683 .22731 2.37764 .77254 Mabsadd L
.29683 .22731 .56518 .7779 Mabsadd L
.29683 .22731 0 2.5 Mabsadd L closepath F
.3 .22753 0 2.5 Mabsadd m
.3 .22753 -0.56518 .7779 Mabsadd L
.3 .22753 -2.37764 .77254 Mabsadd L
.3 .22753 -0.91448 -0.29713 Mabsadd L
.3 .22753 -1.46946 -2.02254 Mabsadd L
.3 .22753 0 -0.96154 Mabsadd L
.3 .22753 1.46946 -2.02254 Mabsadd L
.3 .22753 .91448 -0.29713 Mabsadd L
.3 .22753 2.37764 .77254 Mabsadd L
.3 .22753 .56518 .7779 Mabsadd L
.3 .22753 0 2.5 Mabsadd L closepath F
.30317 .22776 0 2.5 Mabsadd m
.30317 .22776 -0.56518 .7779 Mabsadd L
.30317 .22776 -2.37764 .77254 Mabsadd L
.30317 .22776 -0.91448 -0.29713 Mabsadd L
.30317 .22776 -1.46946 -2.02254 Mabsadd L
.30317 .22776 0 -0.96154 Mabsadd L
.30317 .22776 1.46946 -2.02254 Mabsadd L
.30317 .22776 .91448 -0.29713 Mabsadd L
.30317 .22776 2.37764 .77254 Mabsadd L
.30317 .22776 .56518 .7779 Mabsadd L
.30317 .22776 0 2.5 Mabsadd L closepath F
.30635 .22799 0 2.5 Mabsadd m
.30635 .22799 -0.56518 .7779 Mabsadd L
.30635 .22799 -2.37764 .77254 Mabsadd L
.30635 .22799 -0.91448 -0.29713 Mabsadd L
.30635 .22799 -1.46946 -2.02254 Mabsadd L
.30635 .22799 0 -0.96154 Mabsadd L
.30635 .22799 1.46946 -2.02254 Mabsadd L
.30635 .22799 .91448 -0.29713 Mabsadd L
.30635 .22799 2.37764 .77254 Mabsadd L
.30635 .22799 .56518 .7779 Mabsadd L
.30635 .22799 0 2.5 Mabsadd L closepath F
.30952 .22822 0 2.5 Mabsadd m
.30952 .22822 -0.56518 .7779 Mabsadd L
.30952 .22822 -2.37764 .77254 Mabsadd L
.30952 .22822 -0.91448 -0.29713 Mabsadd L
.30952 .22822 -1.46946 -2.02254 Mabsadd L
.30952 .22822 0 -0.96154 Mabsadd L
.30952 .22822 1.46946 -2.02254 Mabsadd L
.30952 .22822 .91448 -0.29713 Mabsadd L
.30952 .22822 2.37764 .77254 Mabsadd L
.30952 .22822 .56518 .7779 Mabsadd L
.30952 .22822 0 2.5 Mabsadd L closepath F
.3127 .22846 0 2.5 Mabsadd m
.3127 .22846 -0.56518 .7779 Mabsadd L
.3127 .22846 -2.37764 .77254 Mabsadd L
.3127 .22846 -0.91448 -0.29713 Mabsadd L
.3127 .22846 -1.46946 -2.02254 Mabsadd L
.3127 .22846 0 -0.96154 Mabsadd L
.3127 .22846 1.46946 -2.02254 Mabsadd L
.3127 .22846 .91448 -0.29713 Mabsadd L
.3127 .22846 2.37764 .77254 Mabsadd L
.3127 .22846 .56518 .7779 Mabsadd L
.3127 .22846 0 2.5 Mabsadd L closepath F
.31587 .2287 0 2.5 Mabsadd m
.31587 .2287 -0.56518 .7779 Mabsadd L
.31587 .2287 -2.37764 .77254 Mabsadd L
.31587 .2287 -0.91448 -0.29713 Mabsadd L
.31587 .2287 -1.46946 -2.02254 Mabsadd L
.31587 .2287 0 -0.96154 Mabsadd L
.31587 .2287 1.46946 -2.02254 Mabsadd L
.31587 .2287 .91448 -0.29713 Mabsadd L
.31587 .2287 2.37764 .77254 Mabsadd L
.31587 .2287 .56518 .7779 Mabsadd L
.31587 .2287 0 2.5 Mabsadd L closepath F
.31905 .22894 0 2.5 Mabsadd m
.31905 .22894 -0.56518 .7779 Mabsadd L
.31905 .22894 -2.37764 .77254 Mabsadd L
.31905 .22894 -0.91448 -0.29713 Mabsadd L
.31905 .22894 -1.46946 -2.02254 Mabsadd L
.31905 .22894 0 -0.96154 Mabsadd L
.31905 .22894 1.46946 -2.02254 Mabsadd L
.31905 .22894 .91448 -0.29713 Mabsadd L
.31905 .22894 2.37764 .77254 Mabsadd L
.31905 .22894 .56518 .7779 Mabsadd L
.31905 .22894 0 2.5 Mabsadd L closepath F
.32222 .22918 0 2.5 Mabsadd m
.32222 .22918 -0.56518 .7779 Mabsadd L
.32222 .22918 -2.37764 .77254 Mabsadd L
.32222 .22918 -0.91448 -0.29713 Mabsadd L
.32222 .22918 -1.46946 -2.02254 Mabsadd L
.32222 .22918 0 -0.96154 Mabsadd L
.32222 .22918 1.46946 -2.02254 Mabsadd L
.32222 .22918 .91448 -0.29713 Mabsadd L
.32222 .22918 2.37764 .77254 Mabsadd L
.32222 .22918 .56518 .7779 Mabsadd L
.32222 .22918 0 2.5 Mabsadd L closepath F
.3254 .22942 0 2.5 Mabsadd m
.3254 .22942 -0.56518 .7779 Mabsadd L
.3254 .22942 -2.37764 .77254 Mabsadd L
.3254 .22942 -0.91448 -0.29713 Mabsadd L
.3254 .22942 -1.46946 -2.02254 Mabsadd L
.3254 .22942 0 -0.96154 Mabsadd L
.3254 .22942 1.46946 -2.02254 Mabsadd L
.3254 .22942 .91448 -0.29713 Mabsadd L
.3254 .22942 2.37764 .77254 Mabsadd L
.3254 .22942 .56518 .7779 Mabsadd L
.3254 .22942 0 2.5 Mabsadd L closepath F
.32857 .22967 0 2.5 Mabsadd m
.32857 .22967 -0.56518 .7779 Mabsadd L
.32857 .22967 -2.37764 .77254 Mabsadd L
.32857 .22967 -0.91448 -0.29713 Mabsadd L
.32857 .22967 -1.46946 -2.02254 Mabsadd L
.32857 .22967 0 -0.96154 Mabsadd L
.32857 .22967 1.46946 -2.02254 Mabsadd L
.32857 .22967 .91448 -0.29713 Mabsadd L
.32857 .22967 2.37764 .77254 Mabsadd L
.32857 .22967 .56518 .7779 Mabsadd L
.32857 .22967 0 2.5 Mabsadd L closepath F
.33175 .22992 0 2.5 Mabsadd m
.33175 .22992 -0.56518 .7779 Mabsadd L
.33175 .22992 -2.37764 .77254 Mabsadd L
.33175 .22992 -0.91448 -0.29713 Mabsadd L
.33175 .22992 -1.46946 -2.02254 Mabsadd L
.33175 .22992 0 -0.96154 Mabsadd L
.33175 .22992 1.46946 -2.02254 Mabsadd L
.33175 .22992 .91448 -0.29713 Mabsadd L
.33175 .22992 2.37764 .77254 Mabsadd L
.33175 .22992 .56518 .7779 Mabsadd L
.33175 .22992 0 2.5 Mabsadd L closepath F
.33492 .23017 0 2.5 Mabsadd m
.33492 .23017 -0.56518 .7779 Mabsadd L
.33492 .23017 -2.37764 .77254 Mabsadd L
.33492 .23017 -0.91448 -0.29713 Mabsadd L
.33492 .23017 -1.46946 -2.02254 Mabsadd L
.33492 .23017 0 -0.96154 Mabsadd L
.33492 .23017 1.46946 -2.02254 Mabsadd L
.33492 .23017 .91448 -0.29713 Mabsadd L
.33492 .23017 2.37764 .77254 Mabsadd L
.33492 .23017 .56518 .7779 Mabsadd L
.33492 .23017 0 2.5 Mabsadd L closepath F
.3381 .23043 0 2.5 Mabsadd m
.3381 .23043 -0.56518 .7779 Mabsadd L
.3381 .23043 -2.37764 .77254 Mabsadd L
.3381 .23043 -0.91448 -0.29713 Mabsadd L
.3381 .23043 -1.46946 -2.02254 Mabsadd L
.3381 .23043 0 -0.96154 Mabsadd L
.3381 .23043 1.46946 -2.02254 Mabsadd L
.3381 .23043 .91448 -0.29713 Mabsadd L
.3381 .23043 2.37764 .77254 Mabsadd L
.3381 .23043 .56518 .7779 Mabsadd L
.3381 .23043 0 2.5 Mabsadd L closepath F
.34127 .23068 0 2.5 Mabsadd m
.34127 .23068 -0.56518 .7779 Mabsadd L
.34127 .23068 -2.37764 .77254 Mabsadd L
.34127 .23068 -0.91448 -0.29713 Mabsadd L
.34127 .23068 -1.46946 -2.02254 Mabsadd L
.34127 .23068 0 -0.96154 Mabsadd L
.34127 .23068 1.46946 -2.02254 Mabsadd L
.34127 .23068 .91448 -0.29713 Mabsadd L
.34127 .23068 2.37764 .77254 Mabsadd L
.34127 .23068 .56518 .7779 Mabsadd L
.34127 .23068 0 2.5 Mabsadd L closepath F
.34444 .23094 0 2.5 Mabsadd m
.34444 .23094 -0.56518 .7779 Mabsadd L
.34444 .23094 -2.37764 .77254 Mabsadd L
.34444 .23094 -0.91448 -0.29713 Mabsadd L
.34444 .23094 -1.46946 -2.02254 Mabsadd L
.34444 .23094 0 -0.96154 Mabsadd L
.34444 .23094 1.46946 -2.02254 Mabsadd L
.34444 .23094 .91448 -0.29713 Mabsadd L
.34444 .23094 2.37764 .77254 Mabsadd L
.34444 .23094 .56518 .7779 Mabsadd L
.34444 .23094 0 2.5 Mabsadd L closepath F
.34762 .2312 0 2.5 Mabsadd m
.34762 .2312 -0.56518 .7779 Mabsadd L
.34762 .2312 -2.37764 .77254 Mabsadd L
.34762 .2312 -0.91448 -0.29713 Mabsadd L
.34762 .2312 -1.46946 -2.02254 Mabsadd L
.34762 .2312 0 -0.96154 Mabsadd L
.34762 .2312 1.46946 -2.02254 Mabsadd L
.34762 .2312 .91448 -0.29713 Mabsadd L
.34762 .2312 2.37764 .77254 Mabsadd L
.34762 .2312 .56518 .7779 Mabsadd L
.34762 .2312 0 2.5 Mabsadd L closepath F
.35079 .23147 0 2.5 Mabsadd m
.35079 .23147 -0.56518 .7779 Mabsadd L
.35079 .23147 -2.37764 .77254 Mabsadd L
.35079 .23147 -0.91448 -0.29713 Mabsadd L
.35079 .23147 -1.46946 -2.02254 Mabsadd L
.35079 .23147 0 -0.96154 Mabsadd L
.35079 .23147 1.46946 -2.02254 Mabsadd L
.35079 .23147 .91448 -0.29713 Mabsadd L
.35079 .23147 2.37764 .77254 Mabsadd L
.35079 .23147 .56518 .7779 Mabsadd L
.35079 .23147 0 2.5 Mabsadd L closepath F
.35397 .23174 0 2.5 Mabsadd m
.35397 .23174 -0.56518 .7779 Mabsadd L
.35397 .23174 -2.37764 .77254 Mabsadd L
.35397 .23174 -0.91448 -0.29713 Mabsadd L
.35397 .23174 -1.46946 -2.02254 Mabsadd L
.35397 .23174 0 -0.96154 Mabsadd L
.35397 .23174 1.46946 -2.02254 Mabsadd L
.35397 .23174 .91448 -0.29713 Mabsadd L
.35397 .23174 2.37764 .77254 Mabsadd L
.35397 .23174 .56518 .7779 Mabsadd L
.35397 .23174 0 2.5 Mabsadd L closepath F
.35714 .23201 0 2.5 Mabsadd m
.35714 .23201 -0.56518 .7779 Mabsadd L
.35714 .23201 -2.37764 .77254 Mabsadd L
.35714 .23201 -0.91448 -0.29713 Mabsadd L
.35714 .23201 -1.46946 -2.02254 Mabsadd L
.35714 .23201 0 -0.96154 Mabsadd L
.35714 .23201 1.46946 -2.02254 Mabsadd L
.35714 .23201 .91448 -0.29713 Mabsadd L
.35714 .23201 2.37764 .77254 Mabsadd L
.35714 .23201 .56518 .7779 Mabsadd L
.35714 .23201 0 2.5 Mabsadd L closepath F
.36032 .23228 0 2.5 Mabsadd m
.36032 .23228 -0.56518 .7779 Mabsadd L
.36032 .23228 -2.37764 .77254 Mabsadd L
.36032 .23228 -0.91448 -0.29713 Mabsadd L
.36032 .23228 -1.46946 -2.02254 Mabsadd L
.36032 .23228 0 -0.96154 Mabsadd L
.36032 .23228 1.46946 -2.02254 Mabsadd L
.36032 .23228 .91448 -0.29713 Mabsadd L
.36032 .23228 2.37764 .77254 Mabsadd L
.36032 .23228 .56518 .7779 Mabsadd L
.36032 .23228 0 2.5 Mabsadd L closepath F
.36349 .23256 0 2.5 Mabsadd m
.36349 .23256 -0.56518 .7779 Mabsadd L
.36349 .23256 -2.37764 .77254 Mabsadd L
.36349 .23256 -0.91448 -0.29713 Mabsadd L
.36349 .23256 -1.46946 -2.02254 Mabsadd L
.36349 .23256 0 -0.96154 Mabsadd L
.36349 .23256 1.46946 -2.02254 Mabsadd L
.36349 .23256 .91448 -0.29713 Mabsadd L
.36349 .23256 2.37764 .77254 Mabsadd L
.36349 .23256 .56518 .7779 Mabsadd L
.36349 .23256 0 2.5 Mabsadd L closepath F
.36667 .23283 0 2.5 Mabsadd m
.36667 .23283 -0.56518 .7779 Mabsadd L
.36667 .23283 -2.37764 .77254 Mabsadd L
.36667 .23283 -0.91448 -0.29713 Mabsadd L
.36667 .23283 -1.46946 -2.02254 Mabsadd L
.36667 .23283 0 -0.96154 Mabsadd L
.36667 .23283 1.46946 -2.02254 Mabsadd L
.36667 .23283 .91448 -0.29713 Mabsadd L
.36667 .23283 2.37764 .77254 Mabsadd L
.36667 .23283 .56518 .7779 Mabsadd L
.36667 .23283 0 2.5 Mabsadd L closepath F
.36984 .23312 0 2.5 Mabsadd m
.36984 .23312 -0.56518 .7779 Mabsadd L
.36984 .23312 -2.37764 .77254 Mabsadd L
.36984 .23312 -0.91448 -0.29713 Mabsadd L
.36984 .23312 -1.46946 -2.02254 Mabsadd L
.36984 .23312 0 -0.96154 Mabsadd L
.36984 .23312 1.46946 -2.02254 Mabsadd L
.36984 .23312 .91448 -0.29713 Mabsadd L
.36984 .23312 2.37764 .77254 Mabsadd L
.36984 .23312 .56518 .7779 Mabsadd L
.36984 .23312 0 2.5 Mabsadd L closepath F
.37302 .2334 0 2.5 Mabsadd m
.37302 .2334 -0.56518 .7779 Mabsadd L
.37302 .2334 -2.37764 .77254 Mabsadd L
.37302 .2334 -0.91448 -0.29713 Mabsadd L
.37302 .2334 -1.46946 -2.02254 Mabsadd L
.37302 .2334 0 -0.96154 Mabsadd L
.37302 .2334 1.46946 -2.02254 Mabsadd L
.37302 .2334 .91448 -0.29713 Mabsadd L
.37302 .2334 2.37764 .77254 Mabsadd L
.37302 .2334 .56518 .7779 Mabsadd L
.37302 .2334 0 2.5 Mabsadd L closepath F
.37619 .23369 0 2.5 Mabsadd m
.37619 .23369 -0.56518 .7779 Mabsadd L
.37619 .23369 -2.37764 .77254 Mabsadd L
.37619 .23369 -0.91448 -0.29713 Mabsadd L
.37619 .23369 -1.46946 -2.02254 Mabsadd L
.37619 .23369 0 -0.96154 Mabsadd L
.37619 .23369 1.46946 -2.02254 Mabsadd L
.37619 .23369 .91448 -0.29713 Mabsadd L
.37619 .23369 2.37764 .77254 Mabsadd L
.37619 .23369 .56518 .7779 Mabsadd L
.37619 .23369 0 2.5 Mabsadd L closepath F
.37937 .23398 0 2.5 Mabsadd m
.37937 .23398 -0.56518 .7779 Mabsadd L
.37937 .23398 -2.37764 .77254 Mabsadd L
.37937 .23398 -0.91448 -0.29713 Mabsadd L
.37937 .23398 -1.46946 -2.02254 Mabsadd L
.37937 .23398 0 -0.96154 Mabsadd L
.37937 .23398 1.46946 -2.02254 Mabsadd L
.37937 .23398 .91448 -0.29713 Mabsadd L
.37937 .23398 2.37764 .77254 Mabsadd L
.37937 .23398 .56518 .7779 Mabsadd L
.37937 .23398 0 2.5 Mabsadd L closepath F
.38254 .23427 0 2.5 Mabsadd m
.38254 .23427 -0.56518 .7779 Mabsadd L
.38254 .23427 -2.37764 .77254 Mabsadd L
.38254 .23427 -0.91448 -0.29713 Mabsadd L
.38254 .23427 -1.46946 -2.02254 Mabsadd L
.38254 .23427 0 -0.96154 Mabsadd L
.38254 .23427 1.46946 -2.02254 Mabsadd L
.38254 .23427 .91448 -0.29713 Mabsadd L
.38254 .23427 2.37764 .77254 Mabsadd L
.38254 .23427 .56518 .7779 Mabsadd L
.38254 .23427 0 2.5 Mabsadd L closepath F
.38571 .23456 0 2.5 Mabsadd m
.38571 .23456 -0.56518 .7779 Mabsadd L
.38571 .23456 -2.37764 .77254 Mabsadd L
.38571 .23456 -0.91448 -0.29713 Mabsadd L
.38571 .23456 -1.46946 -2.02254 Mabsadd L
.38571 .23456 0 -0.96154 Mabsadd L
.38571 .23456 1.46946 -2.02254 Mabsadd L
.38571 .23456 .91448 -0.29713 Mabsadd L
.38571 .23456 2.37764 .77254 Mabsadd L
.38571 .23456 .56518 .7779 Mabsadd L
.38571 .23456 0 2.5 Mabsadd L closepath F
.38889 .23486 0 2.5 Mabsadd m
.38889 .23486 -0.56518 .7779 Mabsadd L
.38889 .23486 -2.37764 .77254 Mabsadd L
.38889 .23486 -0.91448 -0.29713 Mabsadd L
.38889 .23486 -1.46946 -2.02254 Mabsadd L
.38889 .23486 0 -0.96154 Mabsadd L
.38889 .23486 1.46946 -2.02254 Mabsadd L
.38889 .23486 .91448 -0.29713 Mabsadd L
.38889 .23486 2.37764 .77254 Mabsadd L
.38889 .23486 .56518 .7779 Mabsadd L
.38889 .23486 0 2.5 Mabsadd L closepath F
.39206 .23516 0 2.5 Mabsadd m
.39206 .23516 -0.56518 .7779 Mabsadd L
.39206 .23516 -2.37764 .77254 Mabsadd L
.39206 .23516 -0.91448 -0.29713 Mabsadd L
.39206 .23516 -1.46946 -2.02254 Mabsadd L
.39206 .23516 0 -0.96154 Mabsadd L
.39206 .23516 1.46946 -2.02254 Mabsadd L
.39206 .23516 .91448 -0.29713 Mabsadd L
.39206 .23516 2.37764 .77254 Mabsadd L
.39206 .23516 .56518 .7779 Mabsadd L
.39206 .23516 0 2.5 Mabsadd L closepath F
.39524 .23547 0 2.5 Mabsadd m
.39524 .23547 -0.56518 .7779 Mabsadd L
.39524 .23547 -2.37764 .77254 Mabsadd L
.39524 .23547 -0.91448 -0.29713 Mabsadd L
.39524 .23547 -1.46946 -2.02254 Mabsadd L
.39524 .23547 0 -0.96154 Mabsadd L
.39524 .23547 1.46946 -2.02254 Mabsadd L
.39524 .23547 .91448 -0.29713 Mabsadd L
.39524 .23547 2.37764 .77254 Mabsadd L
.39524 .23547 .56518 .7779 Mabsadd L
.39524 .23547 0 2.5 Mabsadd L closepath F
.39841 .23578 0 2.5 Mabsadd m
.39841 .23578 -0.56518 .7779 Mabsadd L
.39841 .23578 -2.37764 .77254 Mabsadd L
.39841 .23578 -0.91448 -0.29713 Mabsadd L
.39841 .23578 -1.46946 -2.02254 Mabsadd L
.39841 .23578 0 -0.96154 Mabsadd L
.39841 .23578 1.46946 -2.02254 Mabsadd L
.39841 .23578 .91448 -0.29713 Mabsadd L
.39841 .23578 2.37764 .77254 Mabsadd L
.39841 .23578 .56518 .7779 Mabsadd L
.39841 .23578 0 2.5 Mabsadd L closepath F
.40159 .23609 0 2.5 Mabsadd m
.40159 .23609 -0.56518 .7779 Mabsadd L
.40159 .23609 -2.37764 .77254 Mabsadd L
.40159 .23609 -0.91448 -0.29713 Mabsadd L
.40159 .23609 -1.46946 -2.02254 Mabsadd L
.40159 .23609 0 -0.96154 Mabsadd L
.40159 .23609 1.46946 -2.02254 Mabsadd L
.40159 .23609 .91448 -0.29713 Mabsadd L
.40159 .23609 2.37764 .77254 Mabsadd L
.40159 .23609 .56518 .7779 Mabsadd L
.40159 .23609 0 2.5 Mabsadd L closepath F
.40476 .2364 0 2.5 Mabsadd m
.40476 .2364 -0.56518 .7779 Mabsadd L
.40476 .2364 -2.37764 .77254 Mabsadd L
.40476 .2364 -0.91448 -0.29713 Mabsadd L
.40476 .2364 -1.46946 -2.02254 Mabsadd L
.40476 .2364 0 -0.96154 Mabsadd L
.40476 .2364 1.46946 -2.02254 Mabsadd L
.40476 .2364 .91448 -0.29713 Mabsadd L
.40476 .2364 2.37764 .77254 Mabsadd L
.40476 .2364 .56518 .7779 Mabsadd L
.40476 .2364 0 2.5 Mabsadd L closepath F
.40794 .23672 0 2.5 Mabsadd m
.40794 .23672 -0.56518 .7779 Mabsadd L
.40794 .23672 -2.37764 .77254 Mabsadd L
.40794 .23672 -0.91448 -0.29713 Mabsadd L
.40794 .23672 -1.46946 -2.02254 Mabsadd L
.40794 .23672 0 -0.96154 Mabsadd L
.40794 .23672 1.46946 -2.02254 Mabsadd L
.40794 .23672 .91448 -0.29713 Mabsadd L
.40794 .23672 2.37764 .77254 Mabsadd L
.40794 .23672 .56518 .7779 Mabsadd L
.40794 .23672 0 2.5 Mabsadd L closepath F
.41111 .23704 0 2.5 Mabsadd m
.41111 .23704 -0.56518 .7779 Mabsadd L
.41111 .23704 -2.37764 .77254 Mabsadd L
.41111 .23704 -0.91448 -0.29713 Mabsadd L
.41111 .23704 -1.46946 -2.02254 Mabsadd L
.41111 .23704 0 -0.96154 Mabsadd L
.41111 .23704 1.46946 -2.02254 Mabsadd L
.41111 .23704 .91448 -0.29713 Mabsadd L
.41111 .23704 2.37764 .77254 Mabsadd L
.41111 .23704 .56518 .7779 Mabsadd L
.41111 .23704 0 2.5 Mabsadd L closepath F
.41429 .23736 0 2.5 Mabsadd m
.41429 .23736 -0.56518 .7779 Mabsadd L
.41429 .23736 -2.37764 .77254 Mabsadd L
.41429 .23736 -0.91448 -0.29713 Mabsadd L
.41429 .23736 -1.46946 -2.02254 Mabsadd L
.41429 .23736 0 -0.96154 Mabsadd L
.41429 .23736 1.46946 -2.02254 Mabsadd L
.41429 .23736 .91448 -0.29713 Mabsadd L
.41429 .23736 2.37764 .77254 Mabsadd L
.41429 .23736 .56518 .7779 Mabsadd L
.41429 .23736 0 2.5 Mabsadd L closepath F
.41746 .23769 0 2.5 Mabsadd m
.41746 .23769 -0.56518 .7779 Mabsadd L
.41746 .23769 -2.37764 .77254 Mabsadd L
.41746 .23769 -0.91448 -0.29713 Mabsadd L
.41746 .23769 -1.46946 -2.02254 Mabsadd L
.41746 .23769 0 -0.96154 Mabsadd L
.41746 .23769 1.46946 -2.02254 Mabsadd L
.41746 .23769 .91448 -0.29713 Mabsadd L
.41746 .23769 2.37764 .77254 Mabsadd L
.41746 .23769 .56518 .7779 Mabsadd L
.41746 .23769 0 2.5 Mabsadd L closepath F
.42063 .23802 0 2.5 Mabsadd m
.42063 .23802 -0.56518 .7779 Mabsadd L
.42063 .23802 -2.37764 .77254 Mabsadd L
.42063 .23802 -0.91448 -0.29713 Mabsadd L
.42063 .23802 -1.46946 -2.02254 Mabsadd L
.42063 .23802 0 -0.96154 Mabsadd L
.42063 .23802 1.46946 -2.02254 Mabsadd L
.42063 .23802 .91448 -0.29713 Mabsadd L
.42063 .23802 2.37764 .77254 Mabsadd L
.42063 .23802 .56518 .7779 Mabsadd L
.42063 .23802 0 2.5 Mabsadd L closepath F
.42381 .23835 0 2.5 Mabsadd m
.42381 .23835 -0.56518 .7779 Mabsadd L
.42381 .23835 -2.37764 .77254 Mabsadd L
.42381 .23835 -0.91448 -0.29713 Mabsadd L
.42381 .23835 -1.46946 -2.02254 Mabsadd L
.42381 .23835 0 -0.96154 Mabsadd L
.42381 .23835 1.46946 -2.02254 Mabsadd L
.42381 .23835 .91448 -0.29713 Mabsadd L
.42381 .23835 2.37764 .77254 Mabsadd L
.42381 .23835 .56518 .7779 Mabsadd L
.42381 .23835 0 2.5 Mabsadd L closepath F
.42698 .23869 0 2.5 Mabsadd m
.42698 .23869 -0.56518 .7779 Mabsadd L
.42698 .23869 -2.37764 .77254 Mabsadd L
.42698 .23869 -0.91448 -0.29713 Mabsadd L
.42698 .23869 -1.46946 -2.02254 Mabsadd L
.42698 .23869 0 -0.96154 Mabsadd L
.42698 .23869 1.46946 -2.02254 Mabsadd L
.42698 .23869 .91448 -0.29713 Mabsadd L
.42698 .23869 2.37764 .77254 Mabsadd L
.42698 .23869 .56518 .7779 Mabsadd L
.42698 .23869 0 2.5 Mabsadd L closepath F
.43016 .23903 0 2.5 Mabsadd m
.43016 .23903 -0.56518 .7779 Mabsadd L
.43016 .23903 -2.37764 .77254 Mabsadd L
.43016 .23903 -0.91448 -0.29713 Mabsadd L
.43016 .23903 -1.46946 -2.02254 Mabsadd L
.43016 .23903 0 -0.96154 Mabsadd L
.43016 .23903 1.46946 -2.02254 Mabsadd L
.43016 .23903 .91448 -0.29713 Mabsadd L
.43016 .23903 2.37764 .77254 Mabsadd L
.43016 .23903 .56518 .7779 Mabsadd L
.43016 .23903 0 2.5 Mabsadd L closepath F
.43333 .23937 0 2.5 Mabsadd m
.43333 .23937 -0.56518 .7779 Mabsadd L
.43333 .23937 -2.37764 .77254 Mabsadd L
.43333 .23937 -0.91448 -0.29713 Mabsadd L
.43333 .23937 -1.46946 -2.02254 Mabsadd L
.43333 .23937 0 -0.96154 Mabsadd L
.43333 .23937 1.46946 -2.02254 Mabsadd L
.43333 .23937 .91448 -0.29713 Mabsadd L
.43333 .23937 2.37764 .77254 Mabsadd L
.43333 .23937 .56518 .7779 Mabsadd L
.43333 .23937 0 2.5 Mabsadd L closepath F
.43651 .23972 0 2.5 Mabsadd m
.43651 .23972 -0.56518 .7779 Mabsadd L
.43651 .23972 -2.37764 .77254 Mabsadd L
.43651 .23972 -0.91448 -0.29713 Mabsadd L
.43651 .23972 -1.46946 -2.02254 Mabsadd L
.43651 .23972 0 -0.96154 Mabsadd L
.43651 .23972 1.46946 -2.02254 Mabsadd L
.43651 .23972 .91448 -0.29713 Mabsadd L
.43651 .23972 2.37764 .77254 Mabsadd L
.43651 .23972 .56518 .7779 Mabsadd L
.43651 .23972 0 2.5 Mabsadd L closepath F
.43968 .24007 0 2.5 Mabsadd m
.43968 .24007 -0.56518 .7779 Mabsadd L
.43968 .24007 -2.37764 .77254 Mabsadd L
.43968 .24007 -0.91448 -0.29713 Mabsadd L
.43968 .24007 -1.46946 -2.02254 Mabsadd L
.43968 .24007 0 -0.96154 Mabsadd L
.43968 .24007 1.46946 -2.02254 Mabsadd L
.43968 .24007 .91448 -0.29713 Mabsadd L
.43968 .24007 2.37764 .77254 Mabsadd L
.43968 .24007 .56518 .7779 Mabsadd L
.43968 .24007 0 2.5 Mabsadd L closepath F
.44286 .24042 0 2.5 Mabsadd m
.44286 .24042 -0.56518 .7779 Mabsadd L
.44286 .24042 -2.37764 .77254 Mabsadd L
.44286 .24042 -0.91448 -0.29713 Mabsadd L
.44286 .24042 -1.46946 -2.02254 Mabsadd L
.44286 .24042 0 -0.96154 Mabsadd L
.44286 .24042 1.46946 -2.02254 Mabsadd L
.44286 .24042 .91448 -0.29713 Mabsadd L
.44286 .24042 2.37764 .77254 Mabsadd L
.44286 .24042 .56518 .7779 Mabsadd L
.44286 .24042 0 2.5 Mabsadd L closepath F
.44603 .24078 0 2.5 Mabsadd m
.44603 .24078 -0.56518 .7779 Mabsadd L
.44603 .24078 -2.37764 .77254 Mabsadd L
.44603 .24078 -0.91448 -0.29713 Mabsadd L
.44603 .24078 -1.46946 -2.02254 Mabsadd L
.44603 .24078 0 -0.96154 Mabsadd L
.44603 .24078 1.46946 -2.02254 Mabsadd L
.44603 .24078 .91448 -0.29713 Mabsadd L
.44603 .24078 2.37764 .77254 Mabsadd L
.44603 .24078 .56518 .7779 Mabsadd L
.44603 .24078 0 2.5 Mabsadd L closepath F
.44921 .24114 0 2.5 Mabsadd m
.44921 .24114 -0.56518 .7779 Mabsadd L
.44921 .24114 -2.37764 .77254 Mabsadd L
.44921 .24114 -0.91448 -0.29713 Mabsadd L
.44921 .24114 -1.46946 -2.02254 Mabsadd L
.44921 .24114 0 -0.96154 Mabsadd L
.44921 .24114 1.46946 -2.02254 Mabsadd L
.44921 .24114 .91448 -0.29713 Mabsadd L
.44921 .24114 2.37764 .77254 Mabsadd L
.44921 .24114 .56518 .7779 Mabsadd L
.44921 .24114 0 2.5 Mabsadd L closepath F
.45238 .2415 0 2.5 Mabsadd m
.45238 .2415 -0.56518 .7779 Mabsadd L
.45238 .2415 -2.37764 .77254 Mabsadd L
.45238 .2415 -0.91448 -0.29713 Mabsadd L
.45238 .2415 -1.46946 -2.02254 Mabsadd L
.45238 .2415 0 -0.96154 Mabsadd L
.45238 .2415 1.46946 -2.02254 Mabsadd L
.45238 .2415 .91448 -0.29713 Mabsadd L
.45238 .2415 2.37764 .77254 Mabsadd L
.45238 .2415 .56518 .7779 Mabsadd L
.45238 .2415 0 2.5 Mabsadd L closepath F
.45556 .24187 0 2.5 Mabsadd m
.45556 .24187 -0.56518 .7779 Mabsadd L
.45556 .24187 -2.37764 .77254 Mabsadd L
.45556 .24187 -0.91448 -0.29713 Mabsadd L
.45556 .24187 -1.46946 -2.02254 Mabsadd L
.45556 .24187 0 -0.96154 Mabsadd L
.45556 .24187 1.46946 -2.02254 Mabsadd L
.45556 .24187 .91448 -0.29713 Mabsadd L
.45556 .24187 2.37764 .77254 Mabsadd L
.45556 .24187 .56518 .7779 Mabsadd L
.45556 .24187 0 2.5 Mabsadd L closepath F
.45873 .24224 0 2.5 Mabsadd m
.45873 .24224 -0.56518 .7779 Mabsadd L
.45873 .24224 -2.37764 .77254 Mabsadd L
.45873 .24224 -0.91448 -0.29713 Mabsadd L
.45873 .24224 -1.46946 -2.02254 Mabsadd L
.45873 .24224 0 -0.96154 Mabsadd L
.45873 .24224 1.46946 -2.02254 Mabsadd L
.45873 .24224 .91448 -0.29713 Mabsadd L
.45873 .24224 2.37764 .77254 Mabsadd L
.45873 .24224 .56518 .7779 Mabsadd L
.45873 .24224 0 2.5 Mabsadd L closepath F
.4619 .24262 0 2.5 Mabsadd m
.4619 .24262 -0.56518 .7779 Mabsadd L
.4619 .24262 -2.37764 .77254 Mabsadd L
.4619 .24262 -0.91448 -0.29713 Mabsadd L
.4619 .24262 -1.46946 -2.02254 Mabsadd L
.4619 .24262 0 -0.96154 Mabsadd L
.4619 .24262 1.46946 -2.02254 Mabsadd L
.4619 .24262 .91448 -0.29713 Mabsadd L
.4619 .24262 2.37764 .77254 Mabsadd L
.4619 .24262 .56518 .7779 Mabsadd L
.4619 .24262 0 2.5 Mabsadd L closepath F
.46508 .243 0 2.5 Mabsadd m
.46508 .243 -0.56518 .7779 Mabsadd L
.46508 .243 -2.37764 .77254 Mabsadd L
.46508 .243 -0.91448 -0.29713 Mabsadd L
.46508 .243 -1.46946 -2.02254 Mabsadd L
.46508 .243 0 -0.96154 Mabsadd L
.46508 .243 1.46946 -2.02254 Mabsadd L
.46508 .243 .91448 -0.29713 Mabsadd L
.46508 .243 2.37764 .77254 Mabsadd L
.46508 .243 .56518 .7779 Mabsadd L
.46508 .243 0 2.5 Mabsadd L closepath F
.46825 .24338 0 2.5 Mabsadd m
.46825 .24338 -0.56518 .7779 Mabsadd L
.46825 .24338 -2.37764 .77254 Mabsadd L
.46825 .24338 -0.91448 -0.29713 Mabsadd L
.46825 .24338 -1.46946 -2.02254 Mabsadd L
.46825 .24338 0 -0.96154 Mabsadd L
.46825 .24338 1.46946 -2.02254 Mabsadd L
.46825 .24338 .91448 -0.29713 Mabsadd L
.46825 .24338 2.37764 .77254 Mabsadd L
.46825 .24338 .56518 .7779 Mabsadd L
.46825 .24338 0 2.5 Mabsadd L closepath F
.47143 .24377 0 2.5 Mabsadd m
.47143 .24377 -0.56518 .7779 Mabsadd L
.47143 .24377 -2.37764 .77254 Mabsadd L
.47143 .24377 -0.91448 -0.29713 Mabsadd L
.47143 .24377 -1.46946 -2.02254 Mabsadd L
.47143 .24377 0 -0.96154 Mabsadd L
.47143 .24377 1.46946 -2.02254 Mabsadd L
.47143 .24377 .91448 -0.29713 Mabsadd L
.47143 .24377 2.37764 .77254 Mabsadd L
.47143 .24377 .56518 .7779 Mabsadd L
.47143 .24377 0 2.5 Mabsadd L closepath F
.4746 .24416 0 2.5 Mabsadd m
.4746 .24416 -0.56518 .7779 Mabsadd L
.4746 .24416 -2.37764 .77254 Mabsadd L
.4746 .24416 -0.91448 -0.29713 Mabsadd L
.4746 .24416 -1.46946 -2.02254 Mabsadd L
.4746 .24416 0 -0.96154 Mabsadd L
.4746 .24416 1.46946 -2.02254 Mabsadd L
.4746 .24416 .91448 -0.29713 Mabsadd L
.4746 .24416 2.37764 .77254 Mabsadd L
.4746 .24416 .56518 .7779 Mabsadd L
.4746 .24416 0 2.5 Mabsadd L closepath F
.47778 .24455 0 2.5 Mabsadd m
.47778 .24455 -0.56518 .7779 Mabsadd L
.47778 .24455 -2.37764 .77254 Mabsadd L
.47778 .24455 -0.91448 -0.29713 Mabsadd L
.47778 .24455 -1.46946 -2.02254 Mabsadd L
.47778 .24455 0 -0.96154 Mabsadd L
.47778 .24455 1.46946 -2.02254 Mabsadd L
.47778 .24455 .91448 -0.29713 Mabsadd L
.47778 .24455 2.37764 .77254 Mabsadd L
.47778 .24455 .56518 .7779 Mabsadd L
.47778 .24455 0 2.5 Mabsadd L closepath F
.48095 .24495 0 2.5 Mabsadd m
.48095 .24495 -0.56518 .7779 Mabsadd L
.48095 .24495 -2.37764 .77254 Mabsadd L
.48095 .24495 -0.91448 -0.29713 Mabsadd L
.48095 .24495 -1.46946 -2.02254 Mabsadd L
.48095 .24495 0 -0.96154 Mabsadd L
.48095 .24495 1.46946 -2.02254 Mabsadd L
.48095 .24495 .91448 -0.29713 Mabsadd L
.48095 .24495 2.37764 .77254 Mabsadd L
.48095 .24495 .56518 .7779 Mabsadd L
.48095 .24495 0 2.5 Mabsadd L closepath F
.48413 .24535 0 2.5 Mabsadd m
.48413 .24535 -0.56518 .7779 Mabsadd L
.48413 .24535 -2.37764 .77254 Mabsadd L
.48413 .24535 -0.91448 -0.29713 Mabsadd L
.48413 .24535 -1.46946 -2.02254 Mabsadd L
.48413 .24535 0 -0.96154 Mabsadd L
.48413 .24535 1.46946 -2.02254 Mabsadd L
.48413 .24535 .91448 -0.29713 Mabsadd L
.48413 .24535 2.37764 .77254 Mabsadd L
.48413 .24535 .56518 .7779 Mabsadd L
.48413 .24535 0 2.5 Mabsadd L closepath F
.4873 .24576 0 2.5 Mabsadd m
.4873 .24576 -0.56518 .7779 Mabsadd L
.4873 .24576 -2.37764 .77254 Mabsadd L
.4873 .24576 -0.91448 -0.29713 Mabsadd L
.4873 .24576 -1.46946 -2.02254 Mabsadd L
.4873 .24576 0 -0.96154 Mabsadd L
.4873 .24576 1.46946 -2.02254 Mabsadd L
.4873 .24576 .91448 -0.29713 Mabsadd L
.4873 .24576 2.37764 .77254 Mabsadd L
.4873 .24576 .56518 .7779 Mabsadd L
.4873 .24576 0 2.5 Mabsadd L closepath F
.49048 .24617 0 2.5 Mabsadd m
.49048 .24617 -0.56518 .7779 Mabsadd L
.49048 .24617 -2.37764 .77254 Mabsadd L
.49048 .24617 -0.91448 -0.29713 Mabsadd L
.49048 .24617 -1.46946 -2.02254 Mabsadd L
.49048 .24617 0 -0.96154 Mabsadd L
.49048 .24617 1.46946 -2.02254 Mabsadd L
.49048 .24617 .91448 -0.29713 Mabsadd L
.49048 .24617 2.37764 .77254 Mabsadd L
.49048 .24617 .56518 .7779 Mabsadd L
.49048 .24617 0 2.5 Mabsadd L closepath F
.49365 .24658 0 2.5 Mabsadd m
.49365 .24658 -0.56518 .7779 Mabsadd L
.49365 .24658 -2.37764 .77254 Mabsadd L
.49365 .24658 -0.91448 -0.29713 Mabsadd L
.49365 .24658 -1.46946 -2.02254 Mabsadd L
.49365 .24658 0 -0.96154 Mabsadd L
.49365 .24658 1.46946 -2.02254 Mabsadd L
.49365 .24658 .91448 -0.29713 Mabsadd L
.49365 .24658 2.37764 .77254 Mabsadd L
.49365 .24658 .56518 .7779 Mabsadd L
.49365 .24658 0 2.5 Mabsadd L closepath F
.49683 .247 0 2.5 Mabsadd m
.49683 .247 -0.56518 .7779 Mabsadd L
.49683 .247 -2.37764 .77254 Mabsadd L
.49683 .247 -0.91448 -0.29713 Mabsadd L
.49683 .247 -1.46946 -2.02254 Mabsadd L
.49683 .247 0 -0.96154 Mabsadd L
.49683 .247 1.46946 -2.02254 Mabsadd L
.49683 .247 .91448 -0.29713 Mabsadd L
.49683 .247 2.37764 .77254 Mabsadd L
.49683 .247 .56518 .7779 Mabsadd L
.49683 .247 0 2.5 Mabsadd L closepath F
.5 .24742 0 2.5 Mabsadd m
.5 .24742 -0.56518 .7779 Mabsadd L
.5 .24742 -2.37764 .77254 Mabsadd L
.5 .24742 -0.91448 -0.29713 Mabsadd L
.5 .24742 -1.46946 -2.02254 Mabsadd L
.5 .24742 0 -0.96154 Mabsadd L
.5 .24742 1.46946 -2.02254 Mabsadd L
.5 .24742 .91448 -0.29713 Mabsadd L
.5 .24742 2.37764 .77254 Mabsadd L
.5 .24742 .56518 .7779 Mabsadd L
.5 .24742 0 2.5 Mabsadd L closepath F
.50317 .24785 0 2.5 Mabsadd m
.50317 .24785 -0.56518 .7779 Mabsadd L
.50317 .24785 -2.37764 .77254 Mabsadd L
.50317 .24785 -0.91448 -0.29713 Mabsadd L
.50317 .24785 -1.46946 -2.02254 Mabsadd L
.50317 .24785 0 -0.96154 Mabsadd L
.50317 .24785 1.46946 -2.02254 Mabsadd L
.50317 .24785 .91448 -0.29713 Mabsadd L
.50317 .24785 2.37764 .77254 Mabsadd L
.50317 .24785 .56518 .7779 Mabsadd L
.50317 .24785 0 2.5 Mabsadd L closepath F
.50635 .24828 0 2.5 Mabsadd m
.50635 .24828 -0.56518 .7779 Mabsadd L
.50635 .24828 -2.37764 .77254 Mabsadd L
.50635 .24828 -0.91448 -0.29713 Mabsadd L
.50635 .24828 -1.46946 -2.02254 Mabsadd L
.50635 .24828 0 -0.96154 Mabsadd L
.50635 .24828 1.46946 -2.02254 Mabsadd L
.50635 .24828 .91448 -0.29713 Mabsadd L
.50635 .24828 2.37764 .77254 Mabsadd L
.50635 .24828 .56518 .7779 Mabsadd L
.50635 .24828 0 2.5 Mabsadd L closepath F
.50952 .24872 0 2.5 Mabsadd m
.50952 .24872 -0.56518 .7779 Mabsadd L
.50952 .24872 -2.37764 .77254 Mabsadd L
.50952 .24872 -0.91448 -0.29713 Mabsadd L
.50952 .24872 -1.46946 -2.02254 Mabsadd L
.50952 .24872 0 -0.96154 Mabsadd L
.50952 .24872 1.46946 -2.02254 Mabsadd L
.50952 .24872 .91448 -0.29713 Mabsadd L
.50952 .24872 2.37764 .77254 Mabsadd L
.50952 .24872 .56518 .7779 Mabsadd L
.50952 .24872 0 2.5 Mabsadd L closepath F
.5127 .24916 0 2.5 Mabsadd m
.5127 .24916 -0.56518 .7779 Mabsadd L
.5127 .24916 -2.37764 .77254 Mabsadd L
.5127 .24916 -0.91448 -0.29713 Mabsadd L
.5127 .24916 -1.46946 -2.02254 Mabsadd L
.5127 .24916 0 -0.96154 Mabsadd L
.5127 .24916 1.46946 -2.02254 Mabsadd L
.5127 .24916 .91448 -0.29713 Mabsadd L
.5127 .24916 2.37764 .77254 Mabsadd L
.5127 .24916 .56518 .7779 Mabsadd L
.5127 .24916 0 2.5 Mabsadd L closepath F
.51587 .2496 0 2.5 Mabsadd m
.51587 .2496 -0.56518 .7779 Mabsadd L
.51587 .2496 -2.37764 .77254 Mabsadd L
.51587 .2496 -0.91448 -0.29713 Mabsadd L
.51587 .2496 -1.46946 -2.02254 Mabsadd L
.51587 .2496 0 -0.96154 Mabsadd L
.51587 .2496 1.46946 -2.02254 Mabsadd L
.51587 .2496 .91448 -0.29713 Mabsadd L
.51587 .2496 2.37764 .77254 Mabsadd L
.51587 .2496 .56518 .7779 Mabsadd L
.51587 .2496 0 2.5 Mabsadd L closepath F
.51905 .25005 0 2.5 Mabsadd m
.51905 .25005 -0.56518 .7779 Mabsadd L
.51905 .25005 -2.37764 .77254 Mabsadd L
.51905 .25005 -0.91448 -0.29713 Mabsadd L
.51905 .25005 -1.46946 -2.02254 Mabsadd L
.51905 .25005 0 -0.96154 Mabsadd L
.51905 .25005 1.46946 -2.02254 Mabsadd L
.51905 .25005 .91448 -0.29713 Mabsadd L
.51905 .25005 2.37764 .77254 Mabsadd L
.51905 .25005 .56518 .7779 Mabsadd L
.51905 .25005 0 2.5 Mabsadd L closepath F
.52222 .2505 0 2.5 Mabsadd m
.52222 .2505 -0.56518 .7779 Mabsadd L
.52222 .2505 -2.37764 .77254 Mabsadd L
.52222 .2505 -0.91448 -0.29713 Mabsadd L
.52222 .2505 -1.46946 -2.02254 Mabsadd L
.52222 .2505 0 -0.96154 Mabsadd L
.52222 .2505 1.46946 -2.02254 Mabsadd L
.52222 .2505 .91448 -0.29713 Mabsadd L
.52222 .2505 2.37764 .77254 Mabsadd L
.52222 .2505 .56518 .7779 Mabsadd L
.52222 .2505 0 2.5 Mabsadd L closepath F
.5254 .25096 0 2.5 Mabsadd m
.5254 .25096 -0.56518 .7779 Mabsadd L
.5254 .25096 -2.37764 .77254 Mabsadd L
.5254 .25096 -0.91448 -0.29713 Mabsadd L
.5254 .25096 -1.46946 -2.02254 Mabsadd L
.5254 .25096 0 -0.96154 Mabsadd L
.5254 .25096 1.46946 -2.02254 Mabsadd L
.5254 .25096 .91448 -0.29713 Mabsadd L
.5254 .25096 2.37764 .77254 Mabsadd L
.5254 .25096 .56518 .7779 Mabsadd L
.5254 .25096 0 2.5 Mabsadd L closepath F
.52857 .25143 0 2.5 Mabsadd m
.52857 .25143 -0.56518 .7779 Mabsadd L
.52857 .25143 -2.37764 .77254 Mabsadd L
.52857 .25143 -0.91448 -0.29713 Mabsadd L
.52857 .25143 -1.46946 -2.02254 Mabsadd L
.52857 .25143 0 -0.96154 Mabsadd L
.52857 .25143 1.46946 -2.02254 Mabsadd L
.52857 .25143 .91448 -0.29713 Mabsadd L
.52857 .25143 2.37764 .77254 Mabsadd L
.52857 .25143 .56518 .7779 Mabsadd L
.52857 .25143 0 2.5 Mabsadd L closepath F
.53175 .25189 0 2.5 Mabsadd m
.53175 .25189 -0.56518 .7779 Mabsadd L
.53175 .25189 -2.37764 .77254 Mabsadd L
.53175 .25189 -0.91448 -0.29713 Mabsadd L
.53175 .25189 -1.46946 -2.02254 Mabsadd L
.53175 .25189 0 -0.96154 Mabsadd L
.53175 .25189 1.46946 -2.02254 Mabsadd L
.53175 .25189 .91448 -0.29713 Mabsadd L
.53175 .25189 2.37764 .77254 Mabsadd L
.53175 .25189 .56518 .7779 Mabsadd L
.53175 .25189 0 2.5 Mabsadd L closepath F
.53492 .25236 0 2.5 Mabsadd m
.53492 .25236 -0.56518 .7779 Mabsadd L
.53492 .25236 -2.37764 .77254 Mabsadd L
.53492 .25236 -0.91448 -0.29713 Mabsadd L
.53492 .25236 -1.46946 -2.02254 Mabsadd L
.53492 .25236 0 -0.96154 Mabsadd L
.53492 .25236 1.46946 -2.02254 Mabsadd L
.53492 .25236 .91448 -0.29713 Mabsadd L
.53492 .25236 2.37764 .77254 Mabsadd L
.53492 .25236 .56518 .7779 Mabsadd L
.53492 .25236 0 2.5 Mabsadd L closepath F
.5381 .25284 0 2.5 Mabsadd m
.5381 .25284 -0.56518 .7779 Mabsadd L
.5381 .25284 -2.37764 .77254 Mabsadd L
.5381 .25284 -0.91448 -0.29713 Mabsadd L
.5381 .25284 -1.46946 -2.02254 Mabsadd L
.5381 .25284 0 -0.96154 Mabsadd L
.5381 .25284 1.46946 -2.02254 Mabsadd L
.5381 .25284 .91448 -0.29713 Mabsadd L
.5381 .25284 2.37764 .77254 Mabsadd L
.5381 .25284 .56518 .7779 Mabsadd L
.5381 .25284 0 2.5 Mabsadd L closepath F
.54127 .25332 0 2.5 Mabsadd m
.54127 .25332 -0.56518 .7779 Mabsadd L
.54127 .25332 -2.37764 .77254 Mabsadd L
.54127 .25332 -0.91448 -0.29713 Mabsadd L
.54127 .25332 -1.46946 -2.02254 Mabsadd L
.54127 .25332 0 -0.96154 Mabsadd L
.54127 .25332 1.46946 -2.02254 Mabsadd L
.54127 .25332 .91448 -0.29713 Mabsadd L
.54127 .25332 2.37764 .77254 Mabsadd L
.54127 .25332 .56518 .7779 Mabsadd L
.54127 .25332 0 2.5 Mabsadd L closepath F
.54444 .25381 0 2.5 Mabsadd m
.54444 .25381 -0.56518 .7779 Mabsadd L
.54444 .25381 -2.37764 .77254 Mabsadd L
.54444 .25381 -0.91448 -0.29713 Mabsadd L
.54444 .25381 -1.46946 -2.02254 Mabsadd L
.54444 .25381 0 -0.96154 Mabsadd L
.54444 .25381 1.46946 -2.02254 Mabsadd L
.54444 .25381 .91448 -0.29713 Mabsadd L
.54444 .25381 2.37764 .77254 Mabsadd L
.54444 .25381 .56518 .7779 Mabsadd L
.54444 .25381 0 2.5 Mabsadd L closepath F
.54762 .2543 0 2.5 Mabsadd m
.54762 .2543 -0.56518 .7779 Mabsadd L
.54762 .2543 -2.37764 .77254 Mabsadd L
.54762 .2543 -0.91448 -0.29713 Mabsadd L
.54762 .2543 -1.46946 -2.02254 Mabsadd L
.54762 .2543 0 -0.96154 Mabsadd L
.54762 .2543 1.46946 -2.02254 Mabsadd L
.54762 .2543 .91448 -0.29713 Mabsadd L
.54762 .2543 2.37764 .77254 Mabsadd L
.54762 .2543 .56518 .7779 Mabsadd L
.54762 .2543 0 2.5 Mabsadd L closepath F
.55079 .25479 0 2.5 Mabsadd m
.55079 .25479 -0.56518 .7779 Mabsadd L
.55079 .25479 -2.37764 .77254 Mabsadd L
.55079 .25479 -0.91448 -0.29713 Mabsadd L
.55079 .25479 -1.46946 -2.02254 Mabsadd L
.55079 .25479 0 -0.96154 Mabsadd L
.55079 .25479 1.46946 -2.02254 Mabsadd L
.55079 .25479 .91448 -0.29713 Mabsadd L
.55079 .25479 2.37764 .77254 Mabsadd L
.55079 .25479 .56518 .7779 Mabsadd L
.55079 .25479 0 2.5 Mabsadd L closepath F
.55397 .2553 0 2.5 Mabsadd m
.55397 .2553 -0.56518 .7779 Mabsadd L
.55397 .2553 -2.37764 .77254 Mabsadd L
.55397 .2553 -0.91448 -0.29713 Mabsadd L
.55397 .2553 -1.46946 -2.02254 Mabsadd L
.55397 .2553 0 -0.96154 Mabsadd L
.55397 .2553 1.46946 -2.02254 Mabsadd L
.55397 .2553 .91448 -0.29713 Mabsadd L
.55397 .2553 2.37764 .77254 Mabsadd L
.55397 .2553 .56518 .7779 Mabsadd L
.55397 .2553 0 2.5 Mabsadd L closepath F
.55714 .2558 0 2.5 Mabsadd m
.55714 .2558 -0.56518 .7779 Mabsadd L
.55714 .2558 -2.37764 .77254 Mabsadd L
.55714 .2558 -0.91448 -0.29713 Mabsadd L
.55714 .2558 -1.46946 -2.02254 Mabsadd L
.55714 .2558 0 -0.96154 Mabsadd L
.55714 .2558 1.46946 -2.02254 Mabsadd L
.55714 .2558 .91448 -0.29713 Mabsadd L
.55714 .2558 2.37764 .77254 Mabsadd L
.55714 .2558 .56518 .7779 Mabsadd L
.55714 .2558 0 2.5 Mabsadd L closepath F
.56032 .25631 0 2.5 Mabsadd m
.56032 .25631 -0.56518 .7779 Mabsadd L
.56032 .25631 -2.37764 .77254 Mabsadd L
.56032 .25631 -0.91448 -0.29713 Mabsadd L
.56032 .25631 -1.46946 -2.02254 Mabsadd L
.56032 .25631 0 -0.96154 Mabsadd L
.56032 .25631 1.46946 -2.02254 Mabsadd L
.56032 .25631 .91448 -0.29713 Mabsadd L
.56032 .25631 2.37764 .77254 Mabsadd L
.56032 .25631 .56518 .7779 Mabsadd L
.56032 .25631 0 2.5 Mabsadd L closepath F
.56349 .25683 0 2.5 Mabsadd m
.56349 .25683 -0.56518 .7779 Mabsadd L
.56349 .25683 -2.37764 .77254 Mabsadd L
.56349 .25683 -0.91448 -0.29713 Mabsadd L
.56349 .25683 -1.46946 -2.02254 Mabsadd L
.56349 .25683 0 -0.96154 Mabsadd L
.56349 .25683 1.46946 -2.02254 Mabsadd L
.56349 .25683 .91448 -0.29713 Mabsadd L
.56349 .25683 2.37764 .77254 Mabsadd L
.56349 .25683 .56518 .7779 Mabsadd L
.56349 .25683 0 2.5 Mabsadd L closepath F
.56667 .25735 0 2.5 Mabsadd m
.56667 .25735 -0.56518 .7779 Mabsadd L
.56667 .25735 -2.37764 .77254 Mabsadd L
.56667 .25735 -0.91448 -0.29713 Mabsadd L
.56667 .25735 -1.46946 -2.02254 Mabsadd L
.56667 .25735 0 -0.96154 Mabsadd L
.56667 .25735 1.46946 -2.02254 Mabsadd L
.56667 .25735 .91448 -0.29713 Mabsadd L
.56667 .25735 2.37764 .77254 Mabsadd L
.56667 .25735 .56518 .7779 Mabsadd L
.56667 .25735 0 2.5 Mabsadd L closepath F
.56984 .25788 0 2.5 Mabsadd m
.56984 .25788 -0.56518 .7779 Mabsadd L
.56984 .25788 -2.37764 .77254 Mabsadd L
.56984 .25788 -0.91448 -0.29713 Mabsadd L
.56984 .25788 -1.46946 -2.02254 Mabsadd L
.56984 .25788 0 -0.96154 Mabsadd L
.56984 .25788 1.46946 -2.02254 Mabsadd L
.56984 .25788 .91448 -0.29713 Mabsadd L
.56984 .25788 2.37764 .77254 Mabsadd L
.56984 .25788 .56518 .7779 Mabsadd L
.56984 .25788 0 2.5 Mabsadd L closepath F
.57302 .25841 0 2.5 Mabsadd m
.57302 .25841 -0.56518 .7779 Mabsadd L
.57302 .25841 -2.37764 .77254 Mabsadd L
.57302 .25841 -0.91448 -0.29713 Mabsadd L
.57302 .25841 -1.46946 -2.02254 Mabsadd L
.57302 .25841 0 -0.96154 Mabsadd L
.57302 .25841 1.46946 -2.02254 Mabsadd L
.57302 .25841 .91448 -0.29713 Mabsadd L
.57302 .25841 2.37764 .77254 Mabsadd L
.57302 .25841 .56518 .7779 Mabsadd L
.57302 .25841 0 2.5 Mabsadd L closepath F
.57619 .25894 0 2.5 Mabsadd m
.57619 .25894 -0.56518 .7779 Mabsadd L
.57619 .25894 -2.37764 .77254 Mabsadd L
.57619 .25894 -0.91448 -0.29713 Mabsadd L
.57619 .25894 -1.46946 -2.02254 Mabsadd L
.57619 .25894 0 -0.96154 Mabsadd L
.57619 .25894 1.46946 -2.02254 Mabsadd L
.57619 .25894 .91448 -0.29713 Mabsadd L
.57619 .25894 2.37764 .77254 Mabsadd L
.57619 .25894 .56518 .7779 Mabsadd L
.57619 .25894 0 2.5 Mabsadd L closepath F
.57937 .25949 0 2.5 Mabsadd m
.57937 .25949 -0.56518 .7779 Mabsadd L
.57937 .25949 -2.37764 .77254 Mabsadd L
.57937 .25949 -0.91448 -0.29713 Mabsadd L
.57937 .25949 -1.46946 -2.02254 Mabsadd L
.57937 .25949 0 -0.96154 Mabsadd L
.57937 .25949 1.46946 -2.02254 Mabsadd L
.57937 .25949 .91448 -0.29713 Mabsadd L
.57937 .25949 2.37764 .77254 Mabsadd L
.57937 .25949 .56518 .7779 Mabsadd L
.57937 .25949 0 2.5 Mabsadd L closepath F
.58254 .26003 0 2.5 Mabsadd m
.58254 .26003 -0.56518 .7779 Mabsadd L
.58254 .26003 -2.37764 .77254 Mabsadd L
.58254 .26003 -0.91448 -0.29713 Mabsadd L
.58254 .26003 -1.46946 -2.02254 Mabsadd L
.58254 .26003 0 -0.96154 Mabsadd L
.58254 .26003 1.46946 -2.02254 Mabsadd L
.58254 .26003 .91448 -0.29713 Mabsadd L
.58254 .26003 2.37764 .77254 Mabsadd L
.58254 .26003 .56518 .7779 Mabsadd L
.58254 .26003 0 2.5 Mabsadd L closepath F
.58571 .26059 0 2.5 Mabsadd m
.58571 .26059 -0.56518 .7779 Mabsadd L
.58571 .26059 -2.37764 .77254 Mabsadd L
.58571 .26059 -0.91448 -0.29713 Mabsadd L
.58571 .26059 -1.46946 -2.02254 Mabsadd L
.58571 .26059 0 -0.96154 Mabsadd L
.58571 .26059 1.46946 -2.02254 Mabsadd L
.58571 .26059 .91448 -0.29713 Mabsadd L
.58571 .26059 2.37764 .77254 Mabsadd L
.58571 .26059 .56518 .7779 Mabsadd L
.58571 .26059 0 2.5 Mabsadd L closepath F
.58889 .26115 0 2.5 Mabsadd m
.58889 .26115 -0.56518 .7779 Mabsadd L
.58889 .26115 -2.37764 .77254 Mabsadd L
.58889 .26115 -0.91448 -0.29713 Mabsadd L
.58889 .26115 -1.46946 -2.02254 Mabsadd L
.58889 .26115 0 -0.96154 Mabsadd L
.58889 .26115 1.46946 -2.02254 Mabsadd L
.58889 .26115 .91448 -0.29713 Mabsadd L
.58889 .26115 2.37764 .77254 Mabsadd L
.58889 .26115 .56518 .7779 Mabsadd L
.58889 .26115 0 2.5 Mabsadd L closepath F
.59206 .26171 0 2.5 Mabsadd m
.59206 .26171 -0.56518 .7779 Mabsadd L
.59206 .26171 -2.37764 .77254 Mabsadd L
.59206 .26171 -0.91448 -0.29713 Mabsadd L
.59206 .26171 -1.46946 -2.02254 Mabsadd L
.59206 .26171 0 -0.96154 Mabsadd L
.59206 .26171 1.46946 -2.02254 Mabsadd L
.59206 .26171 .91448 -0.29713 Mabsadd L
.59206 .26171 2.37764 .77254 Mabsadd L
.59206 .26171 .56518 .7779 Mabsadd L
.59206 .26171 0 2.5 Mabsadd L closepath F
.59524 .26228 0 2.5 Mabsadd m
.59524 .26228 -0.56518 .7779 Mabsadd L
.59524 .26228 -2.37764 .77254 Mabsadd L
.59524 .26228 -0.91448 -0.29713 Mabsadd L
.59524 .26228 -1.46946 -2.02254 Mabsadd L
.59524 .26228 0 -0.96154 Mabsadd L
.59524 .26228 1.46946 -2.02254 Mabsadd L
.59524 .26228 .91448 -0.29713 Mabsadd L
.59524 .26228 2.37764 .77254 Mabsadd L
.59524 .26228 .56518 .7779 Mabsadd L
.59524 .26228 0 2.5 Mabsadd L closepath F
.59841 .26286 0 2.5 Mabsadd m
.59841 .26286 -0.56518 .7779 Mabsadd L
.59841 .26286 -2.37764 .77254 Mabsadd L
.59841 .26286 -0.91448 -0.29713 Mabsadd L
.59841 .26286 -1.46946 -2.02254 Mabsadd L
.59841 .26286 0 -0.96154 Mabsadd L
.59841 .26286 1.46946 -2.02254 Mabsadd L
.59841 .26286 .91448 -0.29713 Mabsadd L
.59841 .26286 2.37764 .77254 Mabsadd L
.59841 .26286 .56518 .7779 Mabsadd L
.59841 .26286 0 2.5 Mabsadd L closepath F
.60159 .26344 0 2.5 Mabsadd m
.60159 .26344 -0.56518 .7779 Mabsadd L
.60159 .26344 -2.37764 .77254 Mabsadd L
.60159 .26344 -0.91448 -0.29713 Mabsadd L
.60159 .26344 -1.46946 -2.02254 Mabsadd L
.60159 .26344 0 -0.96154 Mabsadd L
.60159 .26344 1.46946 -2.02254 Mabsadd L
.60159 .26344 .91448 -0.29713 Mabsadd L
.60159 .26344 2.37764 .77254 Mabsadd L
.60159 .26344 .56518 .7779 Mabsadd L
.60159 .26344 0 2.5 Mabsadd L closepath F
.60476 .26403 0 2.5 Mabsadd m
.60476 .26403 -0.56518 .7779 Mabsadd L
.60476 .26403 -2.37764 .77254 Mabsadd L
.60476 .26403 -0.91448 -0.29713 Mabsadd L
.60476 .26403 -1.46946 -2.02254 Mabsadd L
.60476 .26403 0 -0.96154 Mabsadd L
.60476 .26403 1.46946 -2.02254 Mabsadd L
.60476 .26403 .91448 -0.29713 Mabsadd L
.60476 .26403 2.37764 .77254 Mabsadd L
.60476 .26403 .56518 .7779 Mabsadd L
.60476 .26403 0 2.5 Mabsadd L closepath F
.60794 .26462 0 2.5 Mabsadd m
.60794 .26462 -0.56518 .7779 Mabsadd L
.60794 .26462 -2.37764 .77254 Mabsadd L
.60794 .26462 -0.91448 -0.29713 Mabsadd L
.60794 .26462 -1.46946 -2.02254 Mabsadd L
.60794 .26462 0 -0.96154 Mabsadd L
.60794 .26462 1.46946 -2.02254 Mabsadd L
.60794 .26462 .91448 -0.29713 Mabsadd L
.60794 .26462 2.37764 .77254 Mabsadd L
.60794 .26462 .56518 .7779 Mabsadd L
.60794 .26462 0 2.5 Mabsadd L closepath F
.61111 .26522 0 2.5 Mabsadd m
.61111 .26522 -0.56518 .7779 Mabsadd L
.61111 .26522 -2.37764 .77254 Mabsadd L
.61111 .26522 -0.91448 -0.29713 Mabsadd L
.61111 .26522 -1.46946 -2.02254 Mabsadd L
.61111 .26522 0 -0.96154 Mabsadd L
.61111 .26522 1.46946 -2.02254 Mabsadd L
.61111 .26522 .91448 -0.29713 Mabsadd L
.61111 .26522 2.37764 .77254 Mabsadd L
.61111 .26522 .56518 .7779 Mabsadd L
.61111 .26522 0 2.5 Mabsadd L closepath F
.61429 .26582 0 2.5 Mabsadd m
.61429 .26582 -0.56518 .7779 Mabsadd L
.61429 .26582 -2.37764 .77254 Mabsadd L
.61429 .26582 -0.91448 -0.29713 Mabsadd L
.61429 .26582 -1.46946 -2.02254 Mabsadd L
.61429 .26582 0 -0.96154 Mabsadd L
.61429 .26582 1.46946 -2.02254 Mabsadd L
.61429 .26582 .91448 -0.29713 Mabsadd L
.61429 .26582 2.37764 .77254 Mabsadd L
.61429 .26582 .56518 .7779 Mabsadd L
.61429 .26582 0 2.5 Mabsadd L closepath F
.61746 .26643 0 2.5 Mabsadd m
.61746 .26643 -0.56518 .7779 Mabsadd L
.61746 .26643 -2.37764 .77254 Mabsadd L
.61746 .26643 -0.91448 -0.29713 Mabsadd L
.61746 .26643 -1.46946 -2.02254 Mabsadd L
.61746 .26643 0 -0.96154 Mabsadd L
.61746 .26643 1.46946 -2.02254 Mabsadd L
.61746 .26643 .91448 -0.29713 Mabsadd L
.61746 .26643 2.37764 .77254 Mabsadd L
.61746 .26643 .56518 .7779 Mabsadd L
.61746 .26643 0 2.5 Mabsadd L closepath F
.62063 .26705 0 2.5 Mabsadd m
.62063 .26705 -0.56518 .7779 Mabsadd L
.62063 .26705 -2.37764 .77254 Mabsadd L
.62063 .26705 -0.91448 -0.29713 Mabsadd L
.62063 .26705 -1.46946 -2.02254 Mabsadd L
.62063 .26705 0 -0.96154 Mabsadd L
.62063 .26705 1.46946 -2.02254 Mabsadd L
.62063 .26705 .91448 -0.29713 Mabsadd L
.62063 .26705 2.37764 .77254 Mabsadd L
.62063 .26705 .56518 .7779 Mabsadd L
.62063 .26705 0 2.5 Mabsadd L closepath F
.62381 .26767 0 2.5 Mabsadd m
.62381 .26767 -0.56518 .7779 Mabsadd L
.62381 .26767 -2.37764 .77254 Mabsadd L
.62381 .26767 -0.91448 -0.29713 Mabsadd L
.62381 .26767 -1.46946 -2.02254 Mabsadd L
.62381 .26767 0 -0.96154 Mabsadd L
.62381 .26767 1.46946 -2.02254 Mabsadd L
.62381 .26767 .91448 -0.29713 Mabsadd L
.62381 .26767 2.37764 .77254 Mabsadd L
.62381 .26767 .56518 .7779 Mabsadd L
.62381 .26767 0 2.5 Mabsadd L closepath F
.62698 .2683 0 2.5 Mabsadd m
.62698 .2683 -0.56518 .7779 Mabsadd L
.62698 .2683 -2.37764 .77254 Mabsadd L
.62698 .2683 -0.91448 -0.29713 Mabsadd L
.62698 .2683 -1.46946 -2.02254 Mabsadd L
.62698 .2683 0 -0.96154 Mabsadd L
.62698 .2683 1.46946 -2.02254 Mabsadd L
.62698 .2683 .91448 -0.29713 Mabsadd L
.62698 .2683 2.37764 .77254 Mabsadd L
.62698 .2683 .56518 .7779 Mabsadd L
.62698 .2683 0 2.5 Mabsadd L closepath F
.63016 .26894 0 2.5 Mabsadd m
.63016 .26894 -0.56518 .7779 Mabsadd L
.63016 .26894 -2.37764 .77254 Mabsadd L
.63016 .26894 -0.91448 -0.29713 Mabsadd L
.63016 .26894 -1.46946 -2.02254 Mabsadd L
.63016 .26894 0 -0.96154 Mabsadd L
.63016 .26894 1.46946 -2.02254 Mabsadd L
.63016 .26894 .91448 -0.29713 Mabsadd L
.63016 .26894 2.37764 .77254 Mabsadd L
.63016 .26894 .56518 .7779 Mabsadd L
.63016 .26894 0 2.5 Mabsadd L closepath F
.63333 .26958 0 2.5 Mabsadd m
.63333 .26958 -0.56518 .7779 Mabsadd L
.63333 .26958 -2.37764 .77254 Mabsadd L
.63333 .26958 -0.91448 -0.29713 Mabsadd L
.63333 .26958 -1.46946 -2.02254 Mabsadd L
.63333 .26958 0 -0.96154 Mabsadd L
.63333 .26958 1.46946 -2.02254 Mabsadd L
.63333 .26958 .91448 -0.29713 Mabsadd L
.63333 .26958 2.37764 .77254 Mabsadd L
.63333 .26958 .56518 .7779 Mabsadd L
.63333 .26958 0 2.5 Mabsadd L closepath F
.63651 .27023 0 2.5 Mabsadd m
.63651 .27023 -0.56518 .7779 Mabsadd L
.63651 .27023 -2.37764 .77254 Mabsadd L
.63651 .27023 -0.91448 -0.29713 Mabsadd L
.63651 .27023 -1.46946 -2.02254 Mabsadd L
.63651 .27023 0 -0.96154 Mabsadd L
.63651 .27023 1.46946 -2.02254 Mabsadd L
.63651 .27023 .91448 -0.29713 Mabsadd L
.63651 .27023 2.37764 .77254 Mabsadd L
.63651 .27023 .56518 .7779 Mabsadd L
.63651 .27023 0 2.5 Mabsadd L closepath F
.63968 .27089 0 2.5 Mabsadd m
.63968 .27089 -0.56518 .7779 Mabsadd L
.63968 .27089 -2.37764 .77254 Mabsadd L
.63968 .27089 -0.91448 -0.29713 Mabsadd L
.63968 .27089 -1.46946 -2.02254 Mabsadd L
.63968 .27089 0 -0.96154 Mabsadd L
.63968 .27089 1.46946 -2.02254 Mabsadd L
.63968 .27089 .91448 -0.29713 Mabsadd L
.63968 .27089 2.37764 .77254 Mabsadd L
.63968 .27089 .56518 .7779 Mabsadd L
.63968 .27089 0 2.5 Mabsadd L closepath F
.64286 .27155 0 2.5 Mabsadd m
.64286 .27155 -0.56518 .7779 Mabsadd L
.64286 .27155 -2.37764 .77254 Mabsadd L
.64286 .27155 -0.91448 -0.29713 Mabsadd L
.64286 .27155 -1.46946 -2.02254 Mabsadd L
.64286 .27155 0 -0.96154 Mabsadd L
.64286 .27155 1.46946 -2.02254 Mabsadd L
.64286 .27155 .91448 -0.29713 Mabsadd L
.64286 .27155 2.37764 .77254 Mabsadd L
.64286 .27155 .56518 .7779 Mabsadd L
.64286 .27155 0 2.5 Mabsadd L closepath F
.64603 .27222 0 2.5 Mabsadd m
.64603 .27222 -0.56518 .7779 Mabsadd L
.64603 .27222 -2.37764 .77254 Mabsadd L
.64603 .27222 -0.91448 -0.29713 Mabsadd L
.64603 .27222 -1.46946 -2.02254 Mabsadd L
.64603 .27222 0 -0.96154 Mabsadd L
.64603 .27222 1.46946 -2.02254 Mabsadd L
.64603 .27222 .91448 -0.29713 Mabsadd L
.64603 .27222 2.37764 .77254 Mabsadd L
.64603 .27222 .56518 .7779 Mabsadd L
.64603 .27222 0 2.5 Mabsadd L closepath F
.64921 .27289 0 2.5 Mabsadd m
.64921 .27289 -0.56518 .7779 Mabsadd L
.64921 .27289 -2.37764 .77254 Mabsadd L
.64921 .27289 -0.91448 -0.29713 Mabsadd L
.64921 .27289 -1.46946 -2.02254 Mabsadd L
.64921 .27289 0 -0.96154 Mabsadd L
.64921 .27289 1.46946 -2.02254 Mabsadd L
.64921 .27289 .91448 -0.29713 Mabsadd L
.64921 .27289 2.37764 .77254 Mabsadd L
.64921 .27289 .56518 .7779 Mabsadd L
.64921 .27289 0 2.5 Mabsadd L closepath F
.65238 .27357 0 2.5 Mabsadd m
.65238 .27357 -0.56518 .7779 Mabsadd L
.65238 .27357 -2.37764 .77254 Mabsadd L
.65238 .27357 -0.91448 -0.29713 Mabsadd L
.65238 .27357 -1.46946 -2.02254 Mabsadd L
.65238 .27357 0 -0.96154 Mabsadd L
.65238 .27357 1.46946 -2.02254 Mabsadd L
.65238 .27357 .91448 -0.29713 Mabsadd L
.65238 .27357 2.37764 .77254 Mabsadd L
.65238 .27357 .56518 .7779 Mabsadd L
.65238 .27357 0 2.5 Mabsadd L closepath F
.65556 .27426 0 2.5 Mabsadd m
.65556 .27426 -0.56518 .7779 Mabsadd L
.65556 .27426 -2.37764 .77254 Mabsadd L
.65556 .27426 -0.91448 -0.29713 Mabsadd L
.65556 .27426 -1.46946 -2.02254 Mabsadd L
.65556 .27426 0 -0.96154 Mabsadd L
.65556 .27426 1.46946 -2.02254 Mabsadd L
.65556 .27426 .91448 -0.29713 Mabsadd L
.65556 .27426 2.37764 .77254 Mabsadd L
.65556 .27426 .56518 .7779 Mabsadd L
.65556 .27426 0 2.5 Mabsadd L closepath F
.65873 .27496 0 2.5 Mabsadd m
.65873 .27496 -0.56518 .7779 Mabsadd L
.65873 .27496 -2.37764 .77254 Mabsadd L
.65873 .27496 -0.91448 -0.29713 Mabsadd L
.65873 .27496 -1.46946 -2.02254 Mabsadd L
.65873 .27496 0 -0.96154 Mabsadd L
.65873 .27496 1.46946 -2.02254 Mabsadd L
.65873 .27496 .91448 -0.29713 Mabsadd L
.65873 .27496 2.37764 .77254 Mabsadd L
.65873 .27496 .56518 .7779 Mabsadd L
.65873 .27496 0 2.5 Mabsadd L closepath F
.6619 .27566 0 2.5 Mabsadd m
.6619 .27566 -0.56518 .7779 Mabsadd L
.6619 .27566 -2.37764 .77254 Mabsadd L
.6619 .27566 -0.91448 -0.29713 Mabsadd L
.6619 .27566 -1.46946 -2.02254 Mabsadd L
.6619 .27566 0 -0.96154 Mabsadd L
.6619 .27566 1.46946 -2.02254 Mabsadd L
.6619 .27566 .91448 -0.29713 Mabsadd L
.6619 .27566 2.37764 .77254 Mabsadd L
.6619 .27566 .56518 .7779 Mabsadd L
.6619 .27566 0 2.5 Mabsadd L closepath F
.66508 .27637 0 2.5 Mabsadd m
.66508 .27637 -0.56518 .7779 Mabsadd L
.66508 .27637 -2.37764 .77254 Mabsadd L
.66508 .27637 -0.91448 -0.29713 Mabsadd L
.66508 .27637 -1.46946 -2.02254 Mabsadd L
.66508 .27637 0 -0.96154 Mabsadd L
.66508 .27637 1.46946 -2.02254 Mabsadd L
.66508 .27637 .91448 -0.29713 Mabsadd L
.66508 .27637 2.37764 .77254 Mabsadd L
.66508 .27637 .56518 .7779 Mabsadd L
.66508 .27637 0 2.5 Mabsadd L closepath F
.66825 .27709 0 2.5 Mabsadd m
.66825 .27709 -0.56518 .7779 Mabsadd L
.66825 .27709 -2.37764 .77254 Mabsadd L
.66825 .27709 -0.91448 -0.29713 Mabsadd L
.66825 .27709 -1.46946 -2.02254 Mabsadd L
.66825 .27709 0 -0.96154 Mabsadd L
.66825 .27709 1.46946 -2.02254 Mabsadd L
.66825 .27709 .91448 -0.29713 Mabsadd L
.66825 .27709 2.37764 .77254 Mabsadd L
.66825 .27709 .56518 .7779 Mabsadd L
.66825 .27709 0 2.5 Mabsadd L closepath F
.67143 .27781 0 2.5 Mabsadd m
.67143 .27781 -0.56518 .7779 Mabsadd L
.67143 .27781 -2.37764 .77254 Mabsadd L
.67143 .27781 -0.91448 -0.29713 Mabsadd L
.67143 .27781 -1.46946 -2.02254 Mabsadd L
.67143 .27781 0 -0.96154 Mabsadd L
.67143 .27781 1.46946 -2.02254 Mabsadd L
.67143 .27781 .91448 -0.29713 Mabsadd L
.67143 .27781 2.37764 .77254 Mabsadd L
.67143 .27781 .56518 .7779 Mabsadd L
.67143 .27781 0 2.5 Mabsadd L closepath F
.6746 .27854 0 2.5 Mabsadd m
.6746 .27854 -0.56518 .7779 Mabsadd L
.6746 .27854 -2.37764 .77254 Mabsadd L
.6746 .27854 -0.91448 -0.29713 Mabsadd L
.6746 .27854 -1.46946 -2.02254 Mabsadd L
.6746 .27854 0 -0.96154 Mabsadd L
.6746 .27854 1.46946 -2.02254 Mabsadd L
.6746 .27854 .91448 -0.29713 Mabsadd L
.6746 .27854 2.37764 .77254 Mabsadd L
.6746 .27854 .56518 .7779 Mabsadd L
.6746 .27854 0 2.5 Mabsadd L closepath F
.67778 .27928 0 2.5 Mabsadd m
.67778 .27928 -0.56518 .7779 Mabsadd L
.67778 .27928 -2.37764 .77254 Mabsadd L
.67778 .27928 -0.91448 -0.29713 Mabsadd L
.67778 .27928 -1.46946 -2.02254 Mabsadd L
.67778 .27928 0 -0.96154 Mabsadd L
.67778 .27928 1.46946 -2.02254 Mabsadd L
.67778 .27928 .91448 -0.29713 Mabsadd L
.67778 .27928 2.37764 .77254 Mabsadd L
.67778 .27928 .56518 .7779 Mabsadd L
.67778 .27928 0 2.5 Mabsadd L closepath F
.68095 .28002 0 2.5 Mabsadd m
.68095 .28002 -0.56518 .7779 Mabsadd L
.68095 .28002 -2.37764 .77254 Mabsadd L
.68095 .28002 -0.91448 -0.29713 Mabsadd L
.68095 .28002 -1.46946 -2.02254 Mabsadd L
.68095 .28002 0 -0.96154 Mabsadd L
.68095 .28002 1.46946 -2.02254 Mabsadd L
.68095 .28002 .91448 -0.29713 Mabsadd L
.68095 .28002 2.37764 .77254 Mabsadd L
.68095 .28002 .56518 .7779 Mabsadd L
.68095 .28002 0 2.5 Mabsadd L closepath F
.68413 .28078 0 2.5 Mabsadd m
.68413 .28078 -0.56518 .7779 Mabsadd L
.68413 .28078 -2.37764 .77254 Mabsadd L
.68413 .28078 -0.91448 -0.29713 Mabsadd L
.68413 .28078 -1.46946 -2.02254 Mabsadd L
.68413 .28078 0 -0.96154 Mabsadd L
.68413 .28078 1.46946 -2.02254 Mabsadd L
.68413 .28078 .91448 -0.29713 Mabsadd L
.68413 .28078 2.37764 .77254 Mabsadd L
.68413 .28078 .56518 .7779 Mabsadd L
.68413 .28078 0 2.5 Mabsadd L closepath F
.6873 .28154 0 2.5 Mabsadd m
.6873 .28154 -0.56518 .7779 Mabsadd L
.6873 .28154 -2.37764 .77254 Mabsadd L
.6873 .28154 -0.91448 -0.29713 Mabsadd L
.6873 .28154 -1.46946 -2.02254 Mabsadd L
.6873 .28154 0 -0.96154 Mabsadd L
.6873 .28154 1.46946 -2.02254 Mabsadd L
.6873 .28154 .91448 -0.29713 Mabsadd L
.6873 .28154 2.37764 .77254 Mabsadd L
.6873 .28154 .56518 .7779 Mabsadd L
.6873 .28154 0 2.5 Mabsadd L closepath F
.69048 .28231 0 2.5 Mabsadd m
.69048 .28231 -0.56518 .7779 Mabsadd L
.69048 .28231 -2.37764 .77254 Mabsadd L
.69048 .28231 -0.91448 -0.29713 Mabsadd L
.69048 .28231 -1.46946 -2.02254 Mabsadd L
.69048 .28231 0 -0.96154 Mabsadd L
.69048 .28231 1.46946 -2.02254 Mabsadd L
.69048 .28231 .91448 -0.29713 Mabsadd L
.69048 .28231 2.37764 .77254 Mabsadd L
.69048 .28231 .56518 .7779 Mabsadd L
.69048 .28231 0 2.5 Mabsadd L closepath F
.69365 .28308 0 2.5 Mabsadd m
.69365 .28308 -0.56518 .7779 Mabsadd L
.69365 .28308 -2.37764 .77254 Mabsadd L
.69365 .28308 -0.91448 -0.29713 Mabsadd L
.69365 .28308 -1.46946 -2.02254 Mabsadd L
.69365 .28308 0 -0.96154 Mabsadd L
.69365 .28308 1.46946 -2.02254 Mabsadd L
.69365 .28308 .91448 -0.29713 Mabsadd L
.69365 .28308 2.37764 .77254 Mabsadd L
.69365 .28308 .56518 .7779 Mabsadd L
.69365 .28308 0 2.5 Mabsadd L closepath F
.69683 .28387 0 2.5 Mabsadd m
.69683 .28387 -0.56518 .7779 Mabsadd L
.69683 .28387 -2.37764 .77254 Mabsadd L
.69683 .28387 -0.91448 -0.29713 Mabsadd L
.69683 .28387 -1.46946 -2.02254 Mabsadd L
.69683 .28387 0 -0.96154 Mabsadd L
.69683 .28387 1.46946 -2.02254 Mabsadd L
.69683 .28387 .91448 -0.29713 Mabsadd L
.69683 .28387 2.37764 .77254 Mabsadd L
.69683 .28387 .56518 .7779 Mabsadd L
.69683 .28387 0 2.5 Mabsadd L closepath F
.7 .28466 0 2.5 Mabsadd m
.7 .28466 -0.56518 .7779 Mabsadd L
.7 .28466 -2.37764 .77254 Mabsadd L
.7 .28466 -0.91448 -0.29713 Mabsadd L
.7 .28466 -1.46946 -2.02254 Mabsadd L
.7 .28466 0 -0.96154 Mabsadd L
.7 .28466 1.46946 -2.02254 Mabsadd L
.7 .28466 .91448 -0.29713 Mabsadd L
.7 .28466 2.37764 .77254 Mabsadd L
.7 .28466 .56518 .7779 Mabsadd L
.7 .28466 0 2.5 Mabsadd L closepath F
.70317 .28546 0 2.5 Mabsadd m
.70317 .28546 -0.56518 .7779 Mabsadd L
.70317 .28546 -2.37764 .77254 Mabsadd L
.70317 .28546 -0.91448 -0.29713 Mabsadd L
.70317 .28546 -1.46946 -2.02254 Mabsadd L
.70317 .28546 0 -0.96154 Mabsadd L
.70317 .28546 1.46946 -2.02254 Mabsadd L
.70317 .28546 .91448 -0.29713 Mabsadd L
.70317 .28546 2.37764 .77254 Mabsadd L
.70317 .28546 .56518 .7779 Mabsadd L
.70317 .28546 0 2.5 Mabsadd L closepath F
.70635 .28626 0 2.5 Mabsadd m
.70635 .28626 -0.56518 .7779 Mabsadd L
.70635 .28626 -2.37764 .77254 Mabsadd L
.70635 .28626 -0.91448 -0.29713 Mabsadd L
.70635 .28626 -1.46946 -2.02254 Mabsadd L
.70635 .28626 0 -0.96154 Mabsadd L
.70635 .28626 1.46946 -2.02254 Mabsadd L
.70635 .28626 .91448 -0.29713 Mabsadd L
.70635 .28626 2.37764 .77254 Mabsadd L
.70635 .28626 .56518 .7779 Mabsadd L
.70635 .28626 0 2.5 Mabsadd L closepath F
.70952 .28708 0 2.5 Mabsadd m
.70952 .28708 -0.56518 .7779 Mabsadd L
.70952 .28708 -2.37764 .77254 Mabsadd L
.70952 .28708 -0.91448 -0.29713 Mabsadd L
.70952 .28708 -1.46946 -2.02254 Mabsadd L
.70952 .28708 0 -0.96154 Mabsadd L
.70952 .28708 1.46946 -2.02254 Mabsadd L
.70952 .28708 .91448 -0.29713 Mabsadd L
.70952 .28708 2.37764 .77254 Mabsadd L
.70952 .28708 .56518 .7779 Mabsadd L
.70952 .28708 0 2.5 Mabsadd L closepath F
.7127 .2879 0 2.5 Mabsadd m
.7127 .2879 -0.56518 .7779 Mabsadd L
.7127 .2879 -2.37764 .77254 Mabsadd L
.7127 .2879 -0.91448 -0.29713 Mabsadd L
.7127 .2879 -1.46946 -2.02254 Mabsadd L
.7127 .2879 0 -0.96154 Mabsadd L
.7127 .2879 1.46946 -2.02254 Mabsadd L
.7127 .2879 .91448 -0.29713 Mabsadd L
.7127 .2879 2.37764 .77254 Mabsadd L
.7127 .2879 .56518 .7779 Mabsadd L
.7127 .2879 0 2.5 Mabsadd L closepath F
.71587 .28873 0 2.5 Mabsadd m
.71587 .28873 -0.56518 .7779 Mabsadd L
.71587 .28873 -2.37764 .77254 Mabsadd L
.71587 .28873 -0.91448 -0.29713 Mabsadd L
.71587 .28873 -1.46946 -2.02254 Mabsadd L
.71587 .28873 0 -0.96154 Mabsadd L
.71587 .28873 1.46946 -2.02254 Mabsadd L
.71587 .28873 .91448 -0.29713 Mabsadd L
.71587 .28873 2.37764 .77254 Mabsadd L
.71587 .28873 .56518 .7779 Mabsadd L
.71587 .28873 0 2.5 Mabsadd L closepath F
.71905 .28958 0 2.5 Mabsadd m
.71905 .28958 -0.56518 .7779 Mabsadd L
.71905 .28958 -2.37764 .77254 Mabsadd L
.71905 .28958 -0.91448 -0.29713 Mabsadd L
.71905 .28958 -1.46946 -2.02254 Mabsadd L
.71905 .28958 0 -0.96154 Mabsadd L
.71905 .28958 1.46946 -2.02254 Mabsadd L
.71905 .28958 .91448 -0.29713 Mabsadd L
.71905 .28958 2.37764 .77254 Mabsadd L
.71905 .28958 .56518 .7779 Mabsadd L
.71905 .28958 0 2.5 Mabsadd L closepath F
.72222 .29042 0 2.5 Mabsadd m
.72222 .29042 -0.56518 .7779 Mabsadd L
.72222 .29042 -2.37764 .77254 Mabsadd L
.72222 .29042 -0.91448 -0.29713 Mabsadd L
.72222 .29042 -1.46946 -2.02254 Mabsadd L
.72222 .29042 0 -0.96154 Mabsadd L
.72222 .29042 1.46946 -2.02254 Mabsadd L
.72222 .29042 .91448 -0.29713 Mabsadd L
.72222 .29042 2.37764 .77254 Mabsadd L
.72222 .29042 .56518 .7779 Mabsadd L
.72222 .29042 0 2.5 Mabsadd L closepath F
.7254 .29128 0 2.5 Mabsadd m
.7254 .29128 -0.56518 .7779 Mabsadd L
.7254 .29128 -2.37764 .77254 Mabsadd L
.7254 .29128 -0.91448 -0.29713 Mabsadd L
.7254 .29128 -1.46946 -2.02254 Mabsadd L
.7254 .29128 0 -0.96154 Mabsadd L
.7254 .29128 1.46946 -2.02254 Mabsadd L
.7254 .29128 .91448 -0.29713 Mabsadd L
.7254 .29128 2.37764 .77254 Mabsadd L
.7254 .29128 .56518 .7779 Mabsadd L
.7254 .29128 0 2.5 Mabsadd L closepath F
.72857 .29215 0 2.5 Mabsadd m
.72857 .29215 -0.56518 .7779 Mabsadd L
.72857 .29215 -2.37764 .77254 Mabsadd L
.72857 .29215 -0.91448 -0.29713 Mabsadd L
.72857 .29215 -1.46946 -2.02254 Mabsadd L
.72857 .29215 0 -0.96154 Mabsadd L
.72857 .29215 1.46946 -2.02254 Mabsadd L
.72857 .29215 .91448 -0.29713 Mabsadd L
.72857 .29215 2.37764 .77254 Mabsadd L
.72857 .29215 .56518 .7779 Mabsadd L
.72857 .29215 0 2.5 Mabsadd L closepath F
.73175 .29302 0 2.5 Mabsadd m
.73175 .29302 -0.56518 .7779 Mabsadd L
.73175 .29302 -2.37764 .77254 Mabsadd L
.73175 .29302 -0.91448 -0.29713 Mabsadd L
.73175 .29302 -1.46946 -2.02254 Mabsadd L
.73175 .29302 0 -0.96154 Mabsadd L
.73175 .29302 1.46946 -2.02254 Mabsadd L
.73175 .29302 .91448 -0.29713 Mabsadd L
.73175 .29302 2.37764 .77254 Mabsadd L
.73175 .29302 .56518 .7779 Mabsadd L
.73175 .29302 0 2.5 Mabsadd L closepath F
.73492 .2939 0 2.5 Mabsadd m
.73492 .2939 -0.56518 .7779 Mabsadd L
.73492 .2939 -2.37764 .77254 Mabsadd L
.73492 .2939 -0.91448 -0.29713 Mabsadd L
.73492 .2939 -1.46946 -2.02254 Mabsadd L
.73492 .2939 0 -0.96154 Mabsadd L
.73492 .2939 1.46946 -2.02254 Mabsadd L
.73492 .2939 .91448 -0.29713 Mabsadd L
.73492 .2939 2.37764 .77254 Mabsadd L
.73492 .2939 .56518 .7779 Mabsadd L
.73492 .2939 0 2.5 Mabsadd L closepath F
.7381 .2948 0 2.5 Mabsadd m
.7381 .2948 -0.56518 .7779 Mabsadd L
.7381 .2948 -2.37764 .77254 Mabsadd L
.7381 .2948 -0.91448 -0.29713 Mabsadd L
.7381 .2948 -1.46946 -2.02254 Mabsadd L
.7381 .2948 0 -0.96154 Mabsadd L
.7381 .2948 1.46946 -2.02254 Mabsadd L
.7381 .2948 .91448 -0.29713 Mabsadd L
.7381 .2948 2.37764 .77254 Mabsadd L
.7381 .2948 .56518 .7779 Mabsadd L
.7381 .2948 0 2.5 Mabsadd L closepath F
.74127 .2957 0 2.5 Mabsadd m
.74127 .2957 -0.56518 .7779 Mabsadd L
.74127 .2957 -2.37764 .77254 Mabsadd L
.74127 .2957 -0.91448 -0.29713 Mabsadd L
.74127 .2957 -1.46946 -2.02254 Mabsadd L
.74127 .2957 0 -0.96154 Mabsadd L
.74127 .2957 1.46946 -2.02254 Mabsadd L
.74127 .2957 .91448 -0.29713 Mabsadd L
.74127 .2957 2.37764 .77254 Mabsadd L
.74127 .2957 .56518 .7779 Mabsadd L
.74127 .2957 0 2.5 Mabsadd L closepath F
.74444 .29661 0 2.5 Mabsadd m
.74444 .29661 -0.56518 .7779 Mabsadd L
.74444 .29661 -2.37764 .77254 Mabsadd L
.74444 .29661 -0.91448 -0.29713 Mabsadd L
.74444 .29661 -1.46946 -2.02254 Mabsadd L
.74444 .29661 0 -0.96154 Mabsadd L
.74444 .29661 1.46946 -2.02254 Mabsadd L
.74444 .29661 .91448 -0.29713 Mabsadd L
.74444 .29661 2.37764 .77254 Mabsadd L
.74444 .29661 .56518 .7779 Mabsadd L
.74444 .29661 0 2.5 Mabsadd L closepath F
.74762 .29753 0 2.5 Mabsadd m
.74762 .29753 -0.56518 .7779 Mabsadd L
.74762 .29753 -2.37764 .77254 Mabsadd L
.74762 .29753 -0.91448 -0.29713 Mabsadd L
.74762 .29753 -1.46946 -2.02254 Mabsadd L
.74762 .29753 0 -0.96154 Mabsadd L
.74762 .29753 1.46946 -2.02254 Mabsadd L
.74762 .29753 .91448 -0.29713 Mabsadd L
.74762 .29753 2.37764 .77254 Mabsadd L
.74762 .29753 .56518 .7779 Mabsadd L
.74762 .29753 0 2.5 Mabsadd L closepath F
.75079 .29845 0 2.5 Mabsadd m
.75079 .29845 -0.56518 .7779 Mabsadd L
.75079 .29845 -2.37764 .77254 Mabsadd L
.75079 .29845 -0.91448 -0.29713 Mabsadd L
.75079 .29845 -1.46946 -2.02254 Mabsadd L
.75079 .29845 0 -0.96154 Mabsadd L
.75079 .29845 1.46946 -2.02254 Mabsadd L
.75079 .29845 .91448 -0.29713 Mabsadd L
.75079 .29845 2.37764 .77254 Mabsadd L
.75079 .29845 .56518 .7779 Mabsadd L
.75079 .29845 0 2.5 Mabsadd L closepath F
.75397 .29939 0 2.5 Mabsadd m
.75397 .29939 -0.56518 .7779 Mabsadd L
.75397 .29939 -2.37764 .77254 Mabsadd L
.75397 .29939 -0.91448 -0.29713 Mabsadd L
.75397 .29939 -1.46946 -2.02254 Mabsadd L
.75397 .29939 0 -0.96154 Mabsadd L
.75397 .29939 1.46946 -2.02254 Mabsadd L
.75397 .29939 .91448 -0.29713 Mabsadd L
.75397 .29939 2.37764 .77254 Mabsadd L
.75397 .29939 .56518 .7779 Mabsadd L
.75397 .29939 0 2.5 Mabsadd L closepath F
.75714 .30034 0 2.5 Mabsadd m
.75714 .30034 -0.56518 .7779 Mabsadd L
.75714 .30034 -2.37764 .77254 Mabsadd L
.75714 .30034 -0.91448 -0.29713 Mabsadd L
.75714 .30034 -1.46946 -2.02254 Mabsadd L
.75714 .30034 0 -0.96154 Mabsadd L
.75714 .30034 1.46946 -2.02254 Mabsadd L
.75714 .30034 .91448 -0.29713 Mabsadd L
.75714 .30034 2.37764 .77254 Mabsadd L
.75714 .30034 .56518 .7779 Mabsadd L
.75714 .30034 0 2.5 Mabsadd L closepath F
.76032 .30129 0 2.5 Mabsadd m
.76032 .30129 -0.56518 .7779 Mabsadd L
.76032 .30129 -2.37764 .77254 Mabsadd L
.76032 .30129 -0.91448 -0.29713 Mabsadd L
.76032 .30129 -1.46946 -2.02254 Mabsadd L
.76032 .30129 0 -0.96154 Mabsadd L
.76032 .30129 1.46946 -2.02254 Mabsadd L
.76032 .30129 .91448 -0.29713 Mabsadd L
.76032 .30129 2.37764 .77254 Mabsadd L
.76032 .30129 .56518 .7779 Mabsadd L
.76032 .30129 0 2.5 Mabsadd L closepath F
.76349 .30226 0 2.5 Mabsadd m
.76349 .30226 -0.56518 .7779 Mabsadd L
.76349 .30226 -2.37764 .77254 Mabsadd L
.76349 .30226 -0.91448 -0.29713 Mabsadd L
.76349 .30226 -1.46946 -2.02254 Mabsadd L
.76349 .30226 0 -0.96154 Mabsadd L
.76349 .30226 1.46946 -2.02254 Mabsadd L
.76349 .30226 .91448 -0.29713 Mabsadd L
.76349 .30226 2.37764 .77254 Mabsadd L
.76349 .30226 .56518 .7779 Mabsadd L
.76349 .30226 0 2.5 Mabsadd L closepath F
.76667 .30324 0 2.5 Mabsadd m
.76667 .30324 -0.56518 .7779 Mabsadd L
.76667 .30324 -2.37764 .77254 Mabsadd L
.76667 .30324 -0.91448 -0.29713 Mabsadd L
.76667 .30324 -1.46946 -2.02254 Mabsadd L
.76667 .30324 0 -0.96154 Mabsadd L
.76667 .30324 1.46946 -2.02254 Mabsadd L
.76667 .30324 .91448 -0.29713 Mabsadd L
.76667 .30324 2.37764 .77254 Mabsadd L
.76667 .30324 .56518 .7779 Mabsadd L
.76667 .30324 0 2.5 Mabsadd L closepath F
.76984 .30422 0 2.5 Mabsadd m
.76984 .30422 -0.56518 .7779 Mabsadd L
.76984 .30422 -2.37764 .77254 Mabsadd L
.76984 .30422 -0.91448 -0.29713 Mabsadd L
.76984 .30422 -1.46946 -2.02254 Mabsadd L
.76984 .30422 0 -0.96154 Mabsadd L
.76984 .30422 1.46946 -2.02254 Mabsadd L
.76984 .30422 .91448 -0.29713 Mabsadd L
.76984 .30422 2.37764 .77254 Mabsadd L
.76984 .30422 .56518 .7779 Mabsadd L
.76984 .30422 0 2.5 Mabsadd L closepath F
.77302 .30522 0 2.5 Mabsadd m
.77302 .30522 -0.56518 .7779 Mabsadd L
.77302 .30522 -2.37764 .77254 Mabsadd L
.77302 .30522 -0.91448 -0.29713 Mabsadd L
.77302 .30522 -1.46946 -2.02254 Mabsadd L
.77302 .30522 0 -0.96154 Mabsadd L
.77302 .30522 1.46946 -2.02254 Mabsadd L
.77302 .30522 .91448 -0.29713 Mabsadd L
.77302 .30522 2.37764 .77254 Mabsadd L
.77302 .30522 .56518 .7779 Mabsadd L
.77302 .30522 0 2.5 Mabsadd L closepath F
.77619 .30622 0 2.5 Mabsadd m
.77619 .30622 -0.56518 .7779 Mabsadd L
.77619 .30622 -2.37764 .77254 Mabsadd L
.77619 .30622 -0.91448 -0.29713 Mabsadd L
.77619 .30622 -1.46946 -2.02254 Mabsadd L
.77619 .30622 0 -0.96154 Mabsadd L
.77619 .30622 1.46946 -2.02254 Mabsadd L
.77619 .30622 .91448 -0.29713 Mabsadd L
.77619 .30622 2.37764 .77254 Mabsadd L
.77619 .30622 .56518 .7779 Mabsadd L
.77619 .30622 0 2.5 Mabsadd L closepath F
.77937 .30724 0 2.5 Mabsadd m
.77937 .30724 -0.56518 .7779 Mabsadd L
.77937 .30724 -2.37764 .77254 Mabsadd L
.77937 .30724 -0.91448 -0.29713 Mabsadd L
.77937 .30724 -1.46946 -2.02254 Mabsadd L
.77937 .30724 0 -0.96154 Mabsadd L
.77937 .30724 1.46946 -2.02254 Mabsadd L
.77937 .30724 .91448 -0.29713 Mabsadd L
.77937 .30724 2.37764 .77254 Mabsadd L
.77937 .30724 .56518 .7779 Mabsadd L
.77937 .30724 0 2.5 Mabsadd L closepath F
.78254 .30826 0 2.5 Mabsadd m
.78254 .30826 -0.56518 .7779 Mabsadd L
.78254 .30826 -2.37764 .77254 Mabsadd L
.78254 .30826 -0.91448 -0.29713 Mabsadd L
.78254 .30826 -1.46946 -2.02254 Mabsadd L
.78254 .30826 0 -0.96154 Mabsadd L
.78254 .30826 1.46946 -2.02254 Mabsadd L
.78254 .30826 .91448 -0.29713 Mabsadd L
.78254 .30826 2.37764 .77254 Mabsadd L
.78254 .30826 .56518 .7779 Mabsadd L
.78254 .30826 0 2.5 Mabsadd L closepath F
.78571 .3093 0 2.5 Mabsadd m
.78571 .3093 -0.56518 .7779 Mabsadd L
.78571 .3093 -2.37764 .77254 Mabsadd L
.78571 .3093 -0.91448 -0.29713 Mabsadd L
.78571 .3093 -1.46946 -2.02254 Mabsadd L
.78571 .3093 0 -0.96154 Mabsadd L
.78571 .3093 1.46946 -2.02254 Mabsadd L
.78571 .3093 .91448 -0.29713 Mabsadd L
.78571 .3093 2.37764 .77254 Mabsadd L
.78571 .3093 .56518 .7779 Mabsadd L
.78571 .3093 0 2.5 Mabsadd L closepath F
.78889 .31034 0 2.5 Mabsadd m
.78889 .31034 -0.56518 .7779 Mabsadd L
.78889 .31034 -2.37764 .77254 Mabsadd L
.78889 .31034 -0.91448 -0.29713 Mabsadd L
.78889 .31034 -1.46946 -2.02254 Mabsadd L
.78889 .31034 0 -0.96154 Mabsadd L
.78889 .31034 1.46946 -2.02254 Mabsadd L
.78889 .31034 .91448 -0.29713 Mabsadd L
.78889 .31034 2.37764 .77254 Mabsadd L
.78889 .31034 .56518 .7779 Mabsadd L
.78889 .31034 0 2.5 Mabsadd L closepath F
.79206 .3114 0 2.5 Mabsadd m
.79206 .3114 -0.56518 .7779 Mabsadd L
.79206 .3114 -2.37764 .77254 Mabsadd L
.79206 .3114 -0.91448 -0.29713 Mabsadd L
.79206 .3114 -1.46946 -2.02254 Mabsadd L
.79206 .3114 0 -0.96154 Mabsadd L
.79206 .3114 1.46946 -2.02254 Mabsadd L
.79206 .3114 .91448 -0.29713 Mabsadd L
.79206 .3114 2.37764 .77254 Mabsadd L
.79206 .3114 .56518 .7779 Mabsadd L
.79206 .3114 0 2.5 Mabsadd L closepath F
.79524 .31247 0 2.5 Mabsadd m
.79524 .31247 -0.56518 .7779 Mabsadd L
.79524 .31247 -2.37764 .77254 Mabsadd L
.79524 .31247 -0.91448 -0.29713 Mabsadd L
.79524 .31247 -1.46946 -2.02254 Mabsadd L
.79524 .31247 0 -0.96154 Mabsadd L
.79524 .31247 1.46946 -2.02254 Mabsadd L
.79524 .31247 .91448 -0.29713 Mabsadd L
.79524 .31247 2.37764 .77254 Mabsadd L
.79524 .31247 .56518 .7779 Mabsadd L
.79524 .31247 0 2.5 Mabsadd L closepath F
.79841 .31354 0 2.5 Mabsadd m
.79841 .31354 -0.56518 .7779 Mabsadd L
.79841 .31354 -2.37764 .77254 Mabsadd L
.79841 .31354 -0.91448 -0.29713 Mabsadd L
.79841 .31354 -1.46946 -2.02254 Mabsadd L
.79841 .31354 0 -0.96154 Mabsadd L
.79841 .31354 1.46946 -2.02254 Mabsadd L
.79841 .31354 .91448 -0.29713 Mabsadd L
.79841 .31354 2.37764 .77254 Mabsadd L
.79841 .31354 .56518 .7779 Mabsadd L
.79841 .31354 0 2.5 Mabsadd L closepath F
.80159 .31463 0 2.5 Mabsadd m
.80159 .31463 -0.56518 .7779 Mabsadd L
.80159 .31463 -2.37764 .77254 Mabsadd L
.80159 .31463 -0.91448 -0.29713 Mabsadd L
.80159 .31463 -1.46946 -2.02254 Mabsadd L
.80159 .31463 0 -0.96154 Mabsadd L
.80159 .31463 1.46946 -2.02254 Mabsadd L
.80159 .31463 .91448 -0.29713 Mabsadd L
.80159 .31463 2.37764 .77254 Mabsadd L
.80159 .31463 .56518 .7779 Mabsadd L
.80159 .31463 0 2.5 Mabsadd L closepath F
.80476 .31573 0 2.5 Mabsadd m
.80476 .31573 -0.56518 .7779 Mabsadd L
.80476 .31573 -2.37764 .77254 Mabsadd L
.80476 .31573 -0.91448 -0.29713 Mabsadd L
.80476 .31573 -1.46946 -2.02254 Mabsadd L
.80476 .31573 0 -0.96154 Mabsadd L
.80476 .31573 1.46946 -2.02254 Mabsadd L
.80476 .31573 .91448 -0.29713 Mabsadd L
.80476 .31573 2.37764 .77254 Mabsadd L
.80476 .31573 .56518 .7779 Mabsadd L
.80476 .31573 0 2.5 Mabsadd L closepath F
.80794 .31684 0 2.5 Mabsadd m
.80794 .31684 -0.56518 .7779 Mabsadd L
.80794 .31684 -2.37764 .77254 Mabsadd L
.80794 .31684 -0.91448 -0.29713 Mabsadd L
.80794 .31684 -1.46946 -2.02254 Mabsadd L
.80794 .31684 0 -0.96154 Mabsadd L
.80794 .31684 1.46946 -2.02254 Mabsadd L
.80794 .31684 .91448 -0.29713 Mabsadd L
.80794 .31684 2.37764 .77254 Mabsadd L
.80794 .31684 .56518 .7779 Mabsadd L
.80794 .31684 0 2.5 Mabsadd L closepath F
.81111 .31796 0 2.5 Mabsadd m
.81111 .31796 -0.56518 .7779 Mabsadd L
.81111 .31796 -2.37764 .77254 Mabsadd L
.81111 .31796 -0.91448 -0.29713 Mabsadd L
.81111 .31796 -1.46946 -2.02254 Mabsadd L
.81111 .31796 0 -0.96154 Mabsadd L
.81111 .31796 1.46946 -2.02254 Mabsadd L
.81111 .31796 .91448 -0.29713 Mabsadd L
.81111 .31796 2.37764 .77254 Mabsadd L
.81111 .31796 .56518 .7779 Mabsadd L
.81111 .31796 0 2.5 Mabsadd L closepath F
.81429 .31909 0 2.5 Mabsadd m
.81429 .31909 -0.56518 .7779 Mabsadd L
.81429 .31909 -2.37764 .77254 Mabsadd L
.81429 .31909 -0.91448 -0.29713 Mabsadd L
.81429 .31909 -1.46946 -2.02254 Mabsadd L
.81429 .31909 0 -0.96154 Mabsadd L
.81429 .31909 1.46946 -2.02254 Mabsadd L
.81429 .31909 .91448 -0.29713 Mabsadd L
.81429 .31909 2.37764 .77254 Mabsadd L
.81429 .31909 .56518 .7779 Mabsadd L
.81429 .31909 0 2.5 Mabsadd L closepath F
.81746 .32024 0 2.5 Mabsadd m
.81746 .32024 -0.56518 .7779 Mabsadd L
.81746 .32024 -2.37764 .77254 Mabsadd L
.81746 .32024 -0.91448 -0.29713 Mabsadd L
.81746 .32024 -1.46946 -2.02254 Mabsadd L
.81746 .32024 0 -0.96154 Mabsadd L
.81746 .32024 1.46946 -2.02254 Mabsadd L
.81746 .32024 .91448 -0.29713 Mabsadd L
.81746 .32024 2.37764 .77254 Mabsadd L
.81746 .32024 .56518 .7779 Mabsadd L
.81746 .32024 0 2.5 Mabsadd L closepath F
.82063 .32139 0 2.5 Mabsadd m
.82063 .32139 -0.56518 .7779 Mabsadd L
.82063 .32139 -2.37764 .77254 Mabsadd L
.82063 .32139 -0.91448 -0.29713 Mabsadd L
.82063 .32139 -1.46946 -2.02254 Mabsadd L
.82063 .32139 0 -0.96154 Mabsadd L
.82063 .32139 1.46946 -2.02254 Mabsadd L
.82063 .32139 .91448 -0.29713 Mabsadd L
.82063 .32139 2.37764 .77254 Mabsadd L
.82063 .32139 .56518 .7779 Mabsadd L
.82063 .32139 0 2.5 Mabsadd L closepath F
.82381 .32256 0 2.5 Mabsadd m
.82381 .32256 -0.56518 .7779 Mabsadd L
.82381 .32256 -2.37764 .77254 Mabsadd L
.82381 .32256 -0.91448 -0.29713 Mabsadd L
.82381 .32256 -1.46946 -2.02254 Mabsadd L
.82381 .32256 0 -0.96154 Mabsadd L
.82381 .32256 1.46946 -2.02254 Mabsadd L
.82381 .32256 .91448 -0.29713 Mabsadd L
.82381 .32256 2.37764 .77254 Mabsadd L
.82381 .32256 .56518 .7779 Mabsadd L
.82381 .32256 0 2.5 Mabsadd L closepath F
.82698 .32374 0 2.5 Mabsadd m
.82698 .32374 -0.56518 .7779 Mabsadd L
.82698 .32374 -2.37764 .77254 Mabsadd L
.82698 .32374 -0.91448 -0.29713 Mabsadd L
.82698 .32374 -1.46946 -2.02254 Mabsadd L
.82698 .32374 0 -0.96154 Mabsadd L
.82698 .32374 1.46946 -2.02254 Mabsadd L
.82698 .32374 .91448 -0.29713 Mabsadd L
.82698 .32374 2.37764 .77254 Mabsadd L
.82698 .32374 .56518 .7779 Mabsadd L
.82698 .32374 0 2.5 Mabsadd L closepath F
.83016 .32493 0 2.5 Mabsadd m
.83016 .32493 -0.56518 .7779 Mabsadd L
.83016 .32493 -2.37764 .77254 Mabsadd L
.83016 .32493 -0.91448 -0.29713 Mabsadd L
.83016 .32493 -1.46946 -2.02254 Mabsadd L
.83016 .32493 0 -0.96154 Mabsadd L
.83016 .32493 1.46946 -2.02254 Mabsadd L
.83016 .32493 .91448 -0.29713 Mabsadd L
.83016 .32493 2.37764 .77254 Mabsadd L
.83016 .32493 .56518 .7779 Mabsadd L
.83016 .32493 0 2.5 Mabsadd L closepath F
.83333 .32613 0 2.5 Mabsadd m
.83333 .32613 -0.56518 .7779 Mabsadd L
.83333 .32613 -2.37764 .77254 Mabsadd L
.83333 .32613 -0.91448 -0.29713 Mabsadd L
.83333 .32613 -1.46946 -2.02254 Mabsadd L
.83333 .32613 0 -0.96154 Mabsadd L
.83333 .32613 1.46946 -2.02254 Mabsadd L
.83333 .32613 .91448 -0.29713 Mabsadd L
.83333 .32613 2.37764 .77254 Mabsadd L
.83333 .32613 .56518 .7779 Mabsadd L
.83333 .32613 0 2.5 Mabsadd L closepath F
.83651 .32735 0 2.5 Mabsadd m
.83651 .32735 -0.56518 .7779 Mabsadd L
.83651 .32735 -2.37764 .77254 Mabsadd L
.83651 .32735 -0.91448 -0.29713 Mabsadd L
.83651 .32735 -1.46946 -2.02254 Mabsadd L
.83651 .32735 0 -0.96154 Mabsadd L
.83651 .32735 1.46946 -2.02254 Mabsadd L
.83651 .32735 .91448 -0.29713 Mabsadd L
.83651 .32735 2.37764 .77254 Mabsadd L
.83651 .32735 .56518 .7779 Mabsadd L
.83651 .32735 0 2.5 Mabsadd L closepath F
.83968 .32857 0 2.5 Mabsadd m
.83968 .32857 -0.56518 .7779 Mabsadd L
.83968 .32857 -2.37764 .77254 Mabsadd L
.83968 .32857 -0.91448 -0.29713 Mabsadd L
.83968 .32857 -1.46946 -2.02254 Mabsadd L
.83968 .32857 0 -0.96154 Mabsadd L
.83968 .32857 1.46946 -2.02254 Mabsadd L
.83968 .32857 .91448 -0.29713 Mabsadd L
.83968 .32857 2.37764 .77254 Mabsadd L
.83968 .32857 .56518 .7779 Mabsadd L
.83968 .32857 0 2.5 Mabsadd L closepath F
.84286 .32981 0 2.5 Mabsadd m
.84286 .32981 -0.56518 .7779 Mabsadd L
.84286 .32981 -2.37764 .77254 Mabsadd L
.84286 .32981 -0.91448 -0.29713 Mabsadd L
.84286 .32981 -1.46946 -2.02254 Mabsadd L
.84286 .32981 0 -0.96154 Mabsadd L
.84286 .32981 1.46946 -2.02254 Mabsadd L
.84286 .32981 .91448 -0.29713 Mabsadd L
.84286 .32981 2.37764 .77254 Mabsadd L
.84286 .32981 .56518 .7779 Mabsadd L
.84286 .32981 0 2.5 Mabsadd L closepath F
.84603 .33106 0 2.5 Mabsadd m
.84603 .33106 -0.56518 .7779 Mabsadd L
.84603 .33106 -2.37764 .77254 Mabsadd L
.84603 .33106 -0.91448 -0.29713 Mabsadd L
.84603 .33106 -1.46946 -2.02254 Mabsadd L
.84603 .33106 0 -0.96154 Mabsadd L
.84603 .33106 1.46946 -2.02254 Mabsadd L
.84603 .33106 .91448 -0.29713 Mabsadd L
.84603 .33106 2.37764 .77254 Mabsadd L
.84603 .33106 .56518 .7779 Mabsadd L
.84603 .33106 0 2.5 Mabsadd L closepath F
.84921 .33232 0 2.5 Mabsadd m
.84921 .33232 -0.56518 .7779 Mabsadd L
.84921 .33232 -2.37764 .77254 Mabsadd L
.84921 .33232 -0.91448 -0.29713 Mabsadd L
.84921 .33232 -1.46946 -2.02254 Mabsadd L
.84921 .33232 0 -0.96154 Mabsadd L
.84921 .33232 1.46946 -2.02254 Mabsadd L
.84921 .33232 .91448 -0.29713 Mabsadd L
.84921 .33232 2.37764 .77254 Mabsadd L
.84921 .33232 .56518 .7779 Mabsadd L
.84921 .33232 0 2.5 Mabsadd L closepath F
.85238 .3336 0 2.5 Mabsadd m
.85238 .3336 -0.56518 .7779 Mabsadd L
.85238 .3336 -2.37764 .77254 Mabsadd L
.85238 .3336 -0.91448 -0.29713 Mabsadd L
.85238 .3336 -1.46946 -2.02254 Mabsadd L
.85238 .3336 0 -0.96154 Mabsadd L
.85238 .3336 1.46946 -2.02254 Mabsadd L
.85238 .3336 .91448 -0.29713 Mabsadd L
.85238 .3336 2.37764 .77254 Mabsadd L
.85238 .3336 .56518 .7779 Mabsadd L
.85238 .3336 0 2.5 Mabsadd L closepath F
.85556 .33489 0 2.5 Mabsadd m
.85556 .33489 -0.56518 .7779 Mabsadd L
.85556 .33489 -2.37764 .77254 Mabsadd L
.85556 .33489 -0.91448 -0.29713 Mabsadd L
.85556 .33489 -1.46946 -2.02254 Mabsadd L
.85556 .33489 0 -0.96154 Mabsadd L
.85556 .33489 1.46946 -2.02254 Mabsadd L
.85556 .33489 .91448 -0.29713 Mabsadd L
.85556 .33489 2.37764 .77254 Mabsadd L
.85556 .33489 .56518 .7779 Mabsadd L
.85556 .33489 0 2.5 Mabsadd L closepath F
.85873 .33619 0 2.5 Mabsadd m
.85873 .33619 -0.56518 .7779 Mabsadd L
.85873 .33619 -2.37764 .77254 Mabsadd L
.85873 .33619 -0.91448 -0.29713 Mabsadd L
.85873 .33619 -1.46946 -2.02254 Mabsadd L
.85873 .33619 0 -0.96154 Mabsadd L
.85873 .33619 1.46946 -2.02254 Mabsadd L
.85873 .33619 .91448 -0.29713 Mabsadd L
.85873 .33619 2.37764 .77254 Mabsadd L
.85873 .33619 .56518 .7779 Mabsadd L
.85873 .33619 0 2.5 Mabsadd L closepath F
.8619 .33751 0 2.5 Mabsadd m
.8619 .33751 -0.56518 .7779 Mabsadd L
.8619 .33751 -2.37764 .77254 Mabsadd L
.8619 .33751 -0.91448 -0.29713 Mabsadd L
.8619 .33751 -1.46946 -2.02254 Mabsadd L
.8619 .33751 0 -0.96154 Mabsadd L
.8619 .33751 1.46946 -2.02254 Mabsadd L
.8619 .33751 .91448 -0.29713 Mabsadd L
.8619 .33751 2.37764 .77254 Mabsadd L
.8619 .33751 .56518 .7779 Mabsadd L
.8619 .33751 0 2.5 Mabsadd L closepath F
.86508 .33883 0 2.5 Mabsadd m
.86508 .33883 -0.56518 .7779 Mabsadd L
.86508 .33883 -2.37764 .77254 Mabsadd L
.86508 .33883 -0.91448 -0.29713 Mabsadd L
.86508 .33883 -1.46946 -2.02254 Mabsadd L
.86508 .33883 0 -0.96154 Mabsadd L
.86508 .33883 1.46946 -2.02254 Mabsadd L
.86508 .33883 .91448 -0.29713 Mabsadd L
.86508 .33883 2.37764 .77254 Mabsadd L
.86508 .33883 .56518 .7779 Mabsadd L
.86508 .33883 0 2.5 Mabsadd L closepath F
.86825 .34018 0 2.5 Mabsadd m
.86825 .34018 -0.56518 .7779 Mabsadd L
.86825 .34018 -2.37764 .77254 Mabsadd L
.86825 .34018 -0.91448 -0.29713 Mabsadd L
.86825 .34018 -1.46946 -2.02254 Mabsadd L
.86825 .34018 0 -0.96154 Mabsadd L
.86825 .34018 1.46946 -2.02254 Mabsadd L
.86825 .34018 .91448 -0.29713 Mabsadd L
.86825 .34018 2.37764 .77254 Mabsadd L
.86825 .34018 .56518 .7779 Mabsadd L
.86825 .34018 0 2.5 Mabsadd L closepath F
.87143 .34153 0 2.5 Mabsadd m
.87143 .34153 -0.56518 .7779 Mabsadd L
.87143 .34153 -2.37764 .77254 Mabsadd L
.87143 .34153 -0.91448 -0.29713 Mabsadd L
.87143 .34153 -1.46946 -2.02254 Mabsadd L
.87143 .34153 0 -0.96154 Mabsadd L
.87143 .34153 1.46946 -2.02254 Mabsadd L
.87143 .34153 .91448 -0.29713 Mabsadd L
.87143 .34153 2.37764 .77254 Mabsadd L
.87143 .34153 .56518 .7779 Mabsadd L
.87143 .34153 0 2.5 Mabsadd L closepath F
.8746 .3429 0 2.5 Mabsadd m
.8746 .3429 -0.56518 .7779 Mabsadd L
.8746 .3429 -2.37764 .77254 Mabsadd L
.8746 .3429 -0.91448 -0.29713 Mabsadd L
.8746 .3429 -1.46946 -2.02254 Mabsadd L
.8746 .3429 0 -0.96154 Mabsadd L
.8746 .3429 1.46946 -2.02254 Mabsadd L
.8746 .3429 .91448 -0.29713 Mabsadd L
.8746 .3429 2.37764 .77254 Mabsadd L
.8746 .3429 .56518 .7779 Mabsadd L
.8746 .3429 0 2.5 Mabsadd L closepath F
.87778 .34428 0 2.5 Mabsadd m
.87778 .34428 -0.56518 .7779 Mabsadd L
.87778 .34428 -2.37764 .77254 Mabsadd L
.87778 .34428 -0.91448 -0.29713 Mabsadd L
.87778 .34428 -1.46946 -2.02254 Mabsadd L
.87778 .34428 0 -0.96154 Mabsadd L
.87778 .34428 1.46946 -2.02254 Mabsadd L
.87778 .34428 .91448 -0.29713 Mabsadd L
.87778 .34428 2.37764 .77254 Mabsadd L
.87778 .34428 .56518 .7779 Mabsadd L
.87778 .34428 0 2.5 Mabsadd L closepath F
.88095 .34568 0 2.5 Mabsadd m
.88095 .34568 -0.56518 .7779 Mabsadd L
.88095 .34568 -2.37764 .77254 Mabsadd L
.88095 .34568 -0.91448 -0.29713 Mabsadd L
.88095 .34568 -1.46946 -2.02254 Mabsadd L
.88095 .34568 0 -0.96154 Mabsadd L
.88095 .34568 1.46946 -2.02254 Mabsadd L
.88095 .34568 .91448 -0.29713 Mabsadd L
.88095 .34568 2.37764 .77254 Mabsadd L
.88095 .34568 .56518 .7779 Mabsadd L
.88095 .34568 0 2.5 Mabsadd L closepath F
.88413 .34709 0 2.5 Mabsadd m
.88413 .34709 -0.56518 .7779 Mabsadd L
.88413 .34709 -2.37764 .77254 Mabsadd L
.88413 .34709 -0.91448 -0.29713 Mabsadd L
.88413 .34709 -1.46946 -2.02254 Mabsadd L
.88413 .34709 0 -0.96154 Mabsadd L
.88413 .34709 1.46946 -2.02254 Mabsadd L
.88413 .34709 .91448 -0.29713 Mabsadd L
.88413 .34709 2.37764 .77254 Mabsadd L
.88413 .34709 .56518 .7779 Mabsadd L
.88413 .34709 0 2.5 Mabsadd L closepath F
.8873 .34851 0 2.5 Mabsadd m
.8873 .34851 -0.56518 .7779 Mabsadd L
.8873 .34851 -2.37764 .77254 Mabsadd L
.8873 .34851 -0.91448 -0.29713 Mabsadd L
.8873 .34851 -1.46946 -2.02254 Mabsadd L
.8873 .34851 0 -0.96154 Mabsadd L
.8873 .34851 1.46946 -2.02254 Mabsadd L
.8873 .34851 .91448 -0.29713 Mabsadd L
.8873 .34851 2.37764 .77254 Mabsadd L
.8873 .34851 .56518 .7779 Mabsadd L
.8873 .34851 0 2.5 Mabsadd L closepath F
.89048 .34995 0 2.5 Mabsadd m
.89048 .34995 -0.56518 .7779 Mabsadd L
.89048 .34995 -2.37764 .77254 Mabsadd L
.89048 .34995 -0.91448 -0.29713 Mabsadd L
.89048 .34995 -1.46946 -2.02254 Mabsadd L
.89048 .34995 0 -0.96154 Mabsadd L
.89048 .34995 1.46946 -2.02254 Mabsadd L
.89048 .34995 .91448 -0.29713 Mabsadd L
.89048 .34995 2.37764 .77254 Mabsadd L
.89048 .34995 .56518 .7779 Mabsadd L
.89048 .34995 0 2.5 Mabsadd L closepath F
.89365 .3514 0 2.5 Mabsadd m
.89365 .3514 -0.56518 .7779 Mabsadd L
.89365 .3514 -2.37764 .77254 Mabsadd L
.89365 .3514 -0.91448 -0.29713 Mabsadd L
.89365 .3514 -1.46946 -2.02254 Mabsadd L
.89365 .3514 0 -0.96154 Mabsadd L
.89365 .3514 1.46946 -2.02254 Mabsadd L
.89365 .3514 .91448 -0.29713 Mabsadd L
.89365 .3514 2.37764 .77254 Mabsadd L
.89365 .3514 .56518 .7779 Mabsadd L
.89365 .3514 0 2.5 Mabsadd L closepath F
.89683 .35287 0 2.5 Mabsadd m
.89683 .35287 -0.56518 .7779 Mabsadd L
.89683 .35287 -2.37764 .77254 Mabsadd L
.89683 .35287 -0.91448 -0.29713 Mabsadd L
.89683 .35287 -1.46946 -2.02254 Mabsadd L
.89683 .35287 0 -0.96154 Mabsadd L
.89683 .35287 1.46946 -2.02254 Mabsadd L
.89683 .35287 .91448 -0.29713 Mabsadd L
.89683 .35287 2.37764 .77254 Mabsadd L
.89683 .35287 .56518 .7779 Mabsadd L
.89683 .35287 0 2.5 Mabsadd L closepath F
.9 .35435 0 2.5 Mabsadd m
.9 .35435 -0.56518 .7779 Mabsadd L
.9 .35435 -2.37764 .77254 Mabsadd L
.9 .35435 -0.91448 -0.29713 Mabsadd L
.9 .35435 -1.46946 -2.02254 Mabsadd L
.9 .35435 0 -0.96154 Mabsadd L
.9 .35435 1.46946 -2.02254 Mabsadd L
.9 .35435 .91448 -0.29713 Mabsadd L
.9 .35435 2.37764 .77254 Mabsadd L
.9 .35435 .56518 .7779 Mabsadd L
.9 .35435 0 2.5 Mabsadd L closepath F
.90317 .35584 0 2.5 Mabsadd m
.90317 .35584 -0.56518 .7779 Mabsadd L
.90317 .35584 -2.37764 .77254 Mabsadd L
.90317 .35584 -0.91448 -0.29713 Mabsadd L
.90317 .35584 -1.46946 -2.02254 Mabsadd L
.90317 .35584 0 -0.96154 Mabsadd L
.90317 .35584 1.46946 -2.02254 Mabsadd L
.90317 .35584 .91448 -0.29713 Mabsadd L
.90317 .35584 2.37764 .77254 Mabsadd L
.90317 .35584 .56518 .7779 Mabsadd L
.90317 .35584 0 2.5 Mabsadd L closepath F
.90635 .35736 0 2.5 Mabsadd m
.90635 .35736 -0.56518 .7779 Mabsadd L
.90635 .35736 -2.37764 .77254 Mabsadd L
.90635 .35736 -0.91448 -0.29713 Mabsadd L
.90635 .35736 -1.46946 -2.02254 Mabsadd L
.90635 .35736 0 -0.96154 Mabsadd L
.90635 .35736 1.46946 -2.02254 Mabsadd L
.90635 .35736 .91448 -0.29713 Mabsadd L
.90635 .35736 2.37764 .77254 Mabsadd L
.90635 .35736 .56518 .7779 Mabsadd L
.90635 .35736 0 2.5 Mabsadd L closepath F
.90952 .35888 0 2.5 Mabsadd m
.90952 .35888 -0.56518 .7779 Mabsadd L
.90952 .35888 -2.37764 .77254 Mabsadd L
.90952 .35888 -0.91448 -0.29713 Mabsadd L
.90952 .35888 -1.46946 -2.02254 Mabsadd L
.90952 .35888 0 -0.96154 Mabsadd L
.90952 .35888 1.46946 -2.02254 Mabsadd L
.90952 .35888 .91448 -0.29713 Mabsadd L
.90952 .35888 2.37764 .77254 Mabsadd L
.90952 .35888 .56518 .7779 Mabsadd L
.90952 .35888 0 2.5 Mabsadd L closepath F
.9127 .36042 0 2.5 Mabsadd m
.9127 .36042 -0.56518 .7779 Mabsadd L
.9127 .36042 -2.37764 .77254 Mabsadd L
.9127 .36042 -0.91448 -0.29713 Mabsadd L
.9127 .36042 -1.46946 -2.02254 Mabsadd L
.9127 .36042 0 -0.96154 Mabsadd L
.9127 .36042 1.46946 -2.02254 Mabsadd L
.9127 .36042 .91448 -0.29713 Mabsadd L
.9127 .36042 2.37764 .77254 Mabsadd L
.9127 .36042 .56518 .7779 Mabsadd L
.9127 .36042 0 2.5 Mabsadd L closepath F
.91587 .36198 0 2.5 Mabsadd m
.91587 .36198 -0.56518 .7779 Mabsadd L
.91587 .36198 -2.37764 .77254 Mabsadd L
.91587 .36198 -0.91448 -0.29713 Mabsadd L
.91587 .36198 -1.46946 -2.02254 Mabsadd L
.91587 .36198 0 -0.96154 Mabsadd L
.91587 .36198 1.46946 -2.02254 Mabsadd L
.91587 .36198 .91448 -0.29713 Mabsadd L
.91587 .36198 2.37764 .77254 Mabsadd L
.91587 .36198 .56518 .7779 Mabsadd L
.91587 .36198 0 2.5 Mabsadd L closepath F
.91905 .36355 0 2.5 Mabsadd m
.91905 .36355 -0.56518 .7779 Mabsadd L
.91905 .36355 -2.37764 .77254 Mabsadd L
.91905 .36355 -0.91448 -0.29713 Mabsadd L
.91905 .36355 -1.46946 -2.02254 Mabsadd L
.91905 .36355 0 -0.96154 Mabsadd L
.91905 .36355 1.46946 -2.02254 Mabsadd L
.91905 .36355 .91448 -0.29713 Mabsadd L
.91905 .36355 2.37764 .77254 Mabsadd L
.91905 .36355 .56518 .7779 Mabsadd L
.91905 .36355 0 2.5 Mabsadd L closepath F
.92222 .36514 0 2.5 Mabsadd m
.92222 .36514 -0.56518 .7779 Mabsadd L
.92222 .36514 -2.37764 .77254 Mabsadd L
.92222 .36514 -0.91448 -0.29713 Mabsadd L
.92222 .36514 -1.46946 -2.02254 Mabsadd L
.92222 .36514 0 -0.96154 Mabsadd L
.92222 .36514 1.46946 -2.02254 Mabsadd L
.92222 .36514 .91448 -0.29713 Mabsadd L
.92222 .36514 2.37764 .77254 Mabsadd L
.92222 .36514 .56518 .7779 Mabsadd L
.92222 .36514 0 2.5 Mabsadd L closepath F
.9254 .36675 0 2.5 Mabsadd m
.9254 .36675 -0.56518 .7779 Mabsadd L
.9254 .36675 -2.37764 .77254 Mabsadd L
.9254 .36675 -0.91448 -0.29713 Mabsadd L
.9254 .36675 -1.46946 -2.02254 Mabsadd L
.9254 .36675 0 -0.96154 Mabsadd L
.9254 .36675 1.46946 -2.02254 Mabsadd L
.9254 .36675 .91448 -0.29713 Mabsadd L
.9254 .36675 2.37764 .77254 Mabsadd L
.9254 .36675 .56518 .7779 Mabsadd L
.9254 .36675 0 2.5 Mabsadd L closepath F
.92857 .36837 0 2.5 Mabsadd m
.92857 .36837 -0.56518 .7779 Mabsadd L
.92857 .36837 -2.37764 .77254 Mabsadd L
.92857 .36837 -0.91448 -0.29713 Mabsadd L
.92857 .36837 -1.46946 -2.02254 Mabsadd L
.92857 .36837 0 -0.96154 Mabsadd L
.92857 .36837 1.46946 -2.02254 Mabsadd L
.92857 .36837 .91448 -0.29713 Mabsadd L
.92857 .36837 2.37764 .77254 Mabsadd L
.92857 .36837 .56518 .7779 Mabsadd L
.92857 .36837 0 2.5 Mabsadd L closepath F
.93175 .37 0 2.5 Mabsadd m
.93175 .37 -0.56518 .7779 Mabsadd L
.93175 .37 -2.37764 .77254 Mabsadd L
.93175 .37 -0.91448 -0.29713 Mabsadd L
.93175 .37 -1.46946 -2.02254 Mabsadd L
.93175 .37 0 -0.96154 Mabsadd L
.93175 .37 1.46946 -2.02254 Mabsadd L
.93175 .37 .91448 -0.29713 Mabsadd L
.93175 .37 2.37764 .77254 Mabsadd L
.93175 .37 .56518 .7779 Mabsadd L
.93175 .37 0 2.5 Mabsadd L closepath F
.93492 .37166 0 2.5 Mabsadd m
.93492 .37166 -0.56518 .7779 Mabsadd L
.93492 .37166 -2.37764 .77254 Mabsadd L
.93492 .37166 -0.91448 -0.29713 Mabsadd L
.93492 .37166 -1.46946 -2.02254 Mabsadd L
.93492 .37166 0 -0.96154 Mabsadd L
.93492 .37166 1.46946 -2.02254 Mabsadd L
.93492 .37166 .91448 -0.29713 Mabsadd L
.93492 .37166 2.37764 .77254 Mabsadd L
.93492 .37166 .56518 .7779 Mabsadd L
.93492 .37166 0 2.5 Mabsadd L closepath F
.9381 .37333 0 2.5 Mabsadd m
.9381 .37333 -0.56518 .7779 Mabsadd L
.9381 .37333 -2.37764 .77254 Mabsadd L
.9381 .37333 -0.91448 -0.29713 Mabsadd L
.9381 .37333 -1.46946 -2.02254 Mabsadd L
.9381 .37333 0 -0.96154 Mabsadd L
.9381 .37333 1.46946 -2.02254 Mabsadd L
.9381 .37333 .91448 -0.29713 Mabsadd L
.9381 .37333 2.37764 .77254 Mabsadd L
.9381 .37333 .56518 .7779 Mabsadd L
.9381 .37333 0 2.5 Mabsadd L closepath F
.94127 .37501 0 2.5 Mabsadd m
.94127 .37501 -0.56518 .7779 Mabsadd L
.94127 .37501 -2.37764 .77254 Mabsadd L
.94127 .37501 -0.91448 -0.29713 Mabsadd L
.94127 .37501 -1.46946 -2.02254 Mabsadd L
.94127 .37501 0 -0.96154 Mabsadd L
.94127 .37501 1.46946 -2.02254 Mabsadd L
.94127 .37501 .91448 -0.29713 Mabsadd L
.94127 .37501 2.37764 .77254 Mabsadd L
.94127 .37501 .56518 .7779 Mabsadd L
.94127 .37501 0 2.5 Mabsadd L closepath F
.94444 .37671 0 2.5 Mabsadd m
.94444 .37671 -0.56518 .7779 Mabsadd L
.94444 .37671 -2.37764 .77254 Mabsadd L
.94444 .37671 -0.91448 -0.29713 Mabsadd L
.94444 .37671 -1.46946 -2.02254 Mabsadd L
.94444 .37671 0 -0.96154 Mabsadd L
.94444 .37671 1.46946 -2.02254 Mabsadd L
.94444 .37671 .91448 -0.29713 Mabsadd L
.94444 .37671 2.37764 .77254 Mabsadd L
.94444 .37671 .56518 .7779 Mabsadd L
.94444 .37671 0 2.5 Mabsadd L closepath F
.94762 .37843 0 2.5 Mabsadd m
.94762 .37843 -0.56518 .7779 Mabsadd L
.94762 .37843 -2.37764 .77254 Mabsadd L
.94762 .37843 -0.91448 -0.29713 Mabsadd L
.94762 .37843 -1.46946 -2.02254 Mabsadd L
.94762 .37843 0 -0.96154 Mabsadd L
.94762 .37843 1.46946 -2.02254 Mabsadd L
.94762 .37843 .91448 -0.29713 Mabsadd L
.94762 .37843 2.37764 .77254 Mabsadd L
.94762 .37843 .56518 .7779 Mabsadd L
.94762 .37843 0 2.5 Mabsadd L closepath F
.95079 .38017 0 2.5 Mabsadd m
.95079 .38017 -0.56518 .7779 Mabsadd L
.95079 .38017 -2.37764 .77254 Mabsadd L
.95079 .38017 -0.91448 -0.29713 Mabsadd L
.95079 .38017 -1.46946 -2.02254 Mabsadd L
.95079 .38017 0 -0.96154 Mabsadd L
.95079 .38017 1.46946 -2.02254 Mabsadd L
.95079 .38017 .91448 -0.29713 Mabsadd L
.95079 .38017 2.37764 .77254 Mabsadd L
.95079 .38017 .56518 .7779 Mabsadd L
.95079 .38017 0 2.5 Mabsadd L closepath F
.95397 .38193 0 2.5 Mabsadd m
.95397 .38193 -0.56518 .7779 Mabsadd L
.95397 .38193 -2.37764 .77254 Mabsadd L
.95397 .38193 -0.91448 -0.29713 Mabsadd L
.95397 .38193 -1.46946 -2.02254 Mabsadd L
.95397 .38193 0 -0.96154 Mabsadd L
.95397 .38193 1.46946 -2.02254 Mabsadd L
.95397 .38193 .91448 -0.29713 Mabsadd L
.95397 .38193 2.37764 .77254 Mabsadd L
.95397 .38193 .56518 .7779 Mabsadd L
.95397 .38193 0 2.5 Mabsadd L closepath F
.95714 .3837 0 2.5 Mabsadd m
.95714 .3837 -0.56518 .7779 Mabsadd L
.95714 .3837 -2.37764 .77254 Mabsadd L
.95714 .3837 -0.91448 -0.29713 Mabsadd L
.95714 .3837 -1.46946 -2.02254 Mabsadd L
.95714 .3837 0 -0.96154 Mabsadd L
.95714 .3837 1.46946 -2.02254 Mabsadd L
.95714 .3837 .91448 -0.29713 Mabsadd L
.95714 .3837 2.37764 .77254 Mabsadd L
.95714 .3837 .56518 .7779 Mabsadd L
.95714 .3837 0 2.5 Mabsadd L closepath F
.96032 .38549 0 2.5 Mabsadd m
.96032 .38549 -0.56518 .7779 Mabsadd L
.96032 .38549 -2.37764 .77254 Mabsadd L
.96032 .38549 -0.91448 -0.29713 Mabsadd L
.96032 .38549 -1.46946 -2.02254 Mabsadd L
.96032 .38549 0 -0.96154 Mabsadd L
.96032 .38549 1.46946 -2.02254 Mabsadd L
.96032 .38549 .91448 -0.29713 Mabsadd L
.96032 .38549 2.37764 .77254 Mabsadd L
.96032 .38549 .56518 .7779 Mabsadd L
.96032 .38549 0 2.5 Mabsadd L closepath F
.96349 .3873 0 2.5 Mabsadd m
.96349 .3873 -0.56518 .7779 Mabsadd L
.96349 .3873 -2.37764 .77254 Mabsadd L
.96349 .3873 -0.91448 -0.29713 Mabsadd L
.96349 .3873 -1.46946 -2.02254 Mabsadd L
.96349 .3873 0 -0.96154 Mabsadd L
.96349 .3873 1.46946 -2.02254 Mabsadd L
.96349 .3873 .91448 -0.29713 Mabsadd L
.96349 .3873 2.37764 .77254 Mabsadd L
.96349 .3873 .56518 .7779 Mabsadd L
.96349 .3873 0 2.5 Mabsadd L closepath F
.96667 .38912 0 2.5 Mabsadd m
.96667 .38912 -0.56518 .7779 Mabsadd L
.96667 .38912 -2.37764 .77254 Mabsadd L
.96667 .38912 -0.91448 -0.29713 Mabsadd L
.96667 .38912 -1.46946 -2.02254 Mabsadd L
.96667 .38912 0 -0.96154 Mabsadd L
.96667 .38912 1.46946 -2.02254 Mabsadd L
.96667 .38912 .91448 -0.29713 Mabsadd L
.96667 .38912 2.37764 .77254 Mabsadd L
.96667 .38912 .56518 .7779 Mabsadd L
.96667 .38912 0 2.5 Mabsadd L closepath F
.96984 .39097 0 2.5 Mabsadd m
.96984 .39097 -0.56518 .7779 Mabsadd L
.96984 .39097 -2.37764 .77254 Mabsadd L
.96984 .39097 -0.91448 -0.29713 Mabsadd L
.96984 .39097 -1.46946 -2.02254 Mabsadd L
.96984 .39097 0 -0.96154 Mabsadd L
.96984 .39097 1.46946 -2.02254 Mabsadd L
.96984 .39097 .91448 -0.29713 Mabsadd L
.96984 .39097 2.37764 .77254 Mabsadd L
.96984 .39097 .56518 .7779 Mabsadd L
.96984 .39097 0 2.5 Mabsadd L closepath F
.97302 .39283 0 2.5 Mabsadd m
.97302 .39283 -0.56518 .7779 Mabsadd L
.97302 .39283 -2.37764 .77254 Mabsadd L
.97302 .39283 -0.91448 -0.29713 Mabsadd L
.97302 .39283 -1.46946 -2.02254 Mabsadd L
.97302 .39283 0 -0.96154 Mabsadd L
.97302 .39283 1.46946 -2.02254 Mabsadd L
.97302 .39283 .91448 -0.29713 Mabsadd L
.97302 .39283 2.37764 .77254 Mabsadd L
.97302 .39283 .56518 .7779 Mabsadd L
.97302 .39283 0 2.5 Mabsadd L closepath F
.97619 .39471 0 2.5 Mabsadd m
.97619 .39471 -0.56518 .7779 Mabsadd L
.97619 .39471 -2.37764 .77254 Mabsadd L
.97619 .39471 -0.91448 -0.29713 Mabsadd L
.97619 .39471 -1.46946 -2.02254 Mabsadd L
.97619 .39471 0 -0.96154 Mabsadd L
.97619 .39471 1.46946 -2.02254 Mabsadd L
.97619 .39471 .91448 -0.29713 Mabsadd L
.97619 .39471 2.37764 .77254 Mabsadd L
.97619 .39471 .56518 .7779 Mabsadd L
.97619 .39471 0 2.5 Mabsadd L closepath F
.0075 w
.02698 .22411 m
.03016 .2243 L
.03333 .2245 L
.03651 .2247 L
.03968 .22489 L
.04286 .2251 L
.04603 .2253 L
.04921 .22551 L
.05238 .22571 L
.05556 .22592 L
.05873 .22614 L
.0619 .22635 L
.06508 .22657 L
.06825 .22679 L
.07143 .22701 L
.0746 .22723 L
.07778 .22745 L
.08095 .22768 L
.08413 .22791 L
.0873 .22814 L
.09048 .22838 L
.09365 .22861 L
.09683 .22885 L
.1 .2291 L
.10317 .22934 L
.10635 .22959 L
.10952 .22983 L
.1127 .23009 L
.11587 .23034 L
.11905 .2306 L
.12222 .23085 L
.1254 .23112 L
.12857 .23138 L
.13175 .23165 L
.13492 .23192 L
.1381 .23219 L
.14127 .23246 L
.14444 .23274 L
.14762 .23302 L
.15079 .2333 L
.15397 .23359 L
.15714 .23388 L
.16032 .23417 L
.16349 .23446 L
.16667 .23476 L
.16984 .23506 L
.17302 .23537 L
.17619 .23567 L
.17937 .23598 L
.18254 .23629 L
Mistroke
.18571 .23661 L
.18889 .23693 L
.19206 .23725 L
.19524 .23758 L
.19841 .23791 L
.20159 .23824 L
.20476 .23857 L
.20794 .23891 L
.21111 .23925 L
.21429 .2396 L
.21746 .23995 L
.22063 .2403 L
.22381 .24066 L
.22698 .24101 L
.23016 .24138 L
.23333 .24174 L
.23651 .24211 L
.23968 .24249 L
.24286 .24287 L
.24603 .24325 L
.24921 .24363 L
.25238 .24402 L
.25556 .24442 L
.25873 .24481 L
.2619 .24521 L
.26508 .24562 L
.26825 .24603 L
.27143 .24644 L
.2746 .24686 L
.27778 .24728 L
.28095 .24771 L
.28413 .24814 L
.2873 .24857 L
.29048 .24901 L
.29365 .24945 L
.29683 .2499 L
.3 .25035 L
.30317 .25081 L
.30635 .25127 L
.30952 .25173 L
.3127 .2522 L
.31587 .25268 L
.31905 .25316 L
.32222 .25364 L
.3254 .25413 L
.32857 .25463 L
.33175 .25513 L
.33492 .25563 L
.3381 .25614 L
.34127 .25665 L
Mistroke
.34444 .25717 L
.34762 .2577 L
.35079 .25823 L
.35397 .25876 L
.35714 .2593 L
.36032 .25985 L
.36349 .2604 L
.36667 .26096 L
.36984 .26152 L
.37302 .26209 L
.37619 .26266 L
.37937 .26324 L
.38254 .26383 L
.38571 .26442 L
.38889 .26501 L
.39206 .26562 L
.39524 .26623 L
.39841 .26684 L
.40159 .26746 L
.40476 .26809 L
.40794 .26872 L
.41111 .26936 L
.41429 .27001 L
.41746 .27066 L
.42063 .27132 L
.42381 .27199 L
.42698 .27266 L
.43016 .27334 L
.43333 .27403 L
.43651 .27472 L
.43968 .27542 L
.44286 .27613 L
.44603 .27684 L
.44921 .27756 L
.45238 .27829 L
.45556 .27903 L
.45873 .27977 L
.4619 .28052 L
.46508 .28128 L
.46825 .28204 L
.47143 .28282 L
.4746 .2836 L
.47778 .28439 L
.48095 .28518 L
.48413 .28599 L
.4873 .2868 L
.49048 .28762 L
.49365 .28845 L
.49683 .28929 L
.5 .29013 L
Mistroke
.50317 .29099 L
.50635 .29185 L
.50952 .29272 L
.5127 .2936 L
.51587 .29449 L
.51905 .29539 L
.52222 .2963 L
.5254 .29721 L
.52857 .29814 L
.53175 .29907 L
.53492 .30002 L
.5381 .30097 L
.54127 .30193 L
.54444 .3029 L
.54762 .30389 L
.55079 .30488 L
.55397 .30588 L
.55714 .30689 L
.56032 .30791 L
.56349 .30894 L
.56667 .30999 L
.56984 .31104 L
.57302 .3121 L
.57619 .31318 L
.57937 .31426 L
.58254 .31536 L
.58571 .31646 L
.58889 .31758 L
.59206 .31871 L
.59524 .31985 L
.59841 .321 L
.60159 .32216 L
.60476 .32334 L
.60794 .32452 L
.61111 .32572 L
.61429 .32693 L
.61746 .32815 L
.62063 .32939 L
.62381 .33064 L
.62698 .33189 L
.63016 .33317 L
.63333 .33445 L
.63651 .33575 L
.63968 .33706 L
.64286 .33838 L
.64603 .33972 L
.64921 .34107 L
.65238 .34243 L
.65556 .34381 L
.65873 .3452 L
Mistroke
.6619 .34661 L
.66508 .34802 L
.66825 .34946 L
.67143 .35091 L
.6746 .35237 L
.67778 .35384 L
.68095 .35534 L
.68413 .35684 L
.6873 .35836 L
.69048 .3599 L
.69365 .36145 L
.69683 .36302 L
.7 .3646 L
.70317 .3662 L
.70635 .36782 L
.70952 .36945 L
.7127 .37109 L
.71587 .37276 L
.71905 .37444 L
.72222 .37614 L
.7254 .37785 L
.72857 .37958 L
.73175 .38133 L
.73492 .3831 L
.7381 .38488 L
.74127 .38668 L
.74444 .3885 L
.74762 .39034 L
.75079 .39219 L
.75397 .39407 L
.75714 .39596 L
.76032 .39788 L
.76349 .39981 L
.76667 .40176 L
.76984 .40373 L
.77302 .40572 L
.77619 .40773 L
.77937 .40976 L
.78254 .41181 L
.78571 .41388 L
.78889 .41597 L
.79206 .41808 L
.79524 .42022 L
.79841 .42237 L
.80159 .42455 L
.80476 .42675 L
.80794 .42897 L
.81111 .43121 L
.81429 .43348 L
.81746 .43576 L
Mistroke
.82063 .43807 L
.82381 .44041 L
.82698 .44277 L
.83016 .44515 L
.83333 .44755 L
.83651 .44998 L
.83968 .45243 L
.84286 .45491 L
.84603 .45741 L
.84921 .45994 L
.85238 .46249 L
.85556 .46507 L
.85873 .46767 L
.8619 .4703 L
.86508 .47296 L
.86825 .47564 L
.87143 .47835 L
.8746 .48108 L
.87778 .48385 L
.88095 .48664 L
.88413 .48946 L
.8873 .49231 L
.89048 .49518 L
.89365 .49809 L
.89683 .50102 L
.9 .50398 L
.90317 .50698 L
.90635 .51 L
.90952 .51305 L
.9127 .51614 L
.91587 .51925 L
.91905 .52239 L
.92222 .52557 L
.9254 .52878 L
.92857 .53202 L
.93175 .53529 L
.93492 .5386 L
.9381 .54194 L
.94127 .54531 L
.94444 .54872 L
.94762 .55216 L
.95079 .55563 L
.95397 .55914 L
.95714 .56268 L
.96032 .56626 L
.96349 .56988 L
.96667 .57353 L
.96984 .57722 L
.97302 .58095 L
.97619 .58471 L
Mistroke
Mfstroke
.0001 w
.02698 .22411 -2.5 2.5 Mabsadd m
.02698 .22411 2.5 2.5 Mabsadd L
.02698 .22411 2.5 -2.5 Mabsadd L
.02698 .22411 -2.5 -2.5 Mabsadd L
.02698 .22411 -2.5 2.5 Mabsadd L closepath F
.03016 .2243 -2.5 2.5 Mabsadd m
.03016 .2243 2.5 2.5 Mabsadd L
.03016 .2243 2.5 -2.5 Mabsadd L
.03016 .2243 -2.5 -2.5 Mabsadd L
.03016 .2243 -2.5 2.5 Mabsadd L closepath F
.03333 .2245 -2.5 2.5 Mabsadd m
.03333 .2245 2.5 2.5 Mabsadd L
.03333 .2245 2.5 -2.5 Mabsadd L
.03333 .2245 -2.5 -2.5 Mabsadd L
.03333 .2245 -2.5 2.5 Mabsadd L closepath F
.03651 .2247 -2.5 2.5 Mabsadd m
.03651 .2247 2.5 2.5 Mabsadd L
.03651 .2247 2.5 -2.5 Mabsadd L
.03651 .2247 -2.5 -2.5 Mabsadd L
.03651 .2247 -2.5 2.5 Mabsadd L closepath F
.03968 .22489 -2.5 2.5 Mabsadd m
.03968 .22489 2.5 2.5 Mabsadd L
.03968 .22489 2.5 -2.5 Mabsadd L
.03968 .22489 -2.5 -2.5 Mabsadd L
.03968 .22489 -2.5 2.5 Mabsadd L closepath F
.04286 .2251 -2.5 2.5 Mabsadd m
.04286 .2251 2.5 2.5 Mabsadd L
.04286 .2251 2.5 -2.5 Mabsadd L
.04286 .2251 -2.5 -2.5 Mabsadd L
.04286 .2251 -2.5 2.5 Mabsadd L closepath F
.04603 .2253 -2.5 2.5 Mabsadd m
.04603 .2253 2.5 2.5 Mabsadd L
.04603 .2253 2.5 -2.5 Mabsadd L
.04603 .2253 -2.5 -2.5 Mabsadd L
.04603 .2253 -2.5 2.5 Mabsadd L closepath F
.04921 .22551 -2.5 2.5 Mabsadd m
.04921 .22551 2.5 2.5 Mabsadd L
.04921 .22551 2.5 -2.5 Mabsadd L
.04921 .22551 -2.5 -2.5 Mabsadd L
.04921 .22551 -2.5 2.5 Mabsadd L closepath F
.05238 .22571 -2.5 2.5 Mabsadd m
.05238 .22571 2.5 2.5 Mabsadd L
.05238 .22571 2.5 -2.5 Mabsadd L
.05238 .22571 -2.5 -2.5 Mabsadd L
.05238 .22571 -2.5 2.5 Mabsadd L closepath F
.05556 .22592 -2.5 2.5 Mabsadd m
.05556 .22592 2.5 2.5 Mabsadd L
.05556 .22592 2.5 -2.5 Mabsadd L
.05556 .22592 -2.5 -2.5 Mabsadd L
.05556 .22592 -2.5 2.5 Mabsadd L closepath F
.05873 .22614 -2.5 2.5 Mabsadd m
.05873 .22614 2.5 2.5 Mabsadd L
.05873 .22614 2.5 -2.5 Mabsadd L
.05873 .22614 -2.5 -2.5 Mabsadd L
.05873 .22614 -2.5 2.5 Mabsadd L closepath F
.0619 .22635 -2.5 2.5 Mabsadd m
.0619 .22635 2.5 2.5 Mabsadd L
.0619 .22635 2.5 -2.5 Mabsadd L
.0619 .22635 -2.5 -2.5 Mabsadd L
.0619 .22635 -2.5 2.5 Mabsadd L closepath F
.06508 .22657 -2.5 2.5 Mabsadd m
.06508 .22657 2.5 2.5 Mabsadd L
.06508 .22657 2.5 -2.5 Mabsadd L
.06508 .22657 -2.5 -2.5 Mabsadd L
.06508 .22657 -2.5 2.5 Mabsadd L closepath F
.06825 .22679 -2.5 2.5 Mabsadd m
.06825 .22679 2.5 2.5 Mabsadd L
.06825 .22679 2.5 -2.5 Mabsadd L
.06825 .22679 -2.5 -2.5 Mabsadd L
.06825 .22679 -2.5 2.5 Mabsadd L closepath F
.07143 .22701 -2.5 2.5 Mabsadd m
.07143 .22701 2.5 2.5 Mabsadd L
.07143 .22701 2.5 -2.5 Mabsadd L
.07143 .22701 -2.5 -2.5 Mabsadd L
.07143 .22701 -2.5 2.5 Mabsadd L closepath F
.0746 .22723 -2.5 2.5 Mabsadd m
.0746 .22723 2.5 2.5 Mabsadd L
.0746 .22723 2.5 -2.5 Mabsadd L
.0746 .22723 -2.5 -2.5 Mabsadd L
.0746 .22723 -2.5 2.5 Mabsadd L closepath F
.07778 .22745 -2.5 2.5 Mabsadd m
.07778 .22745 2.5 2.5 Mabsadd L
.07778 .22745 2.5 -2.5 Mabsadd L
.07778 .22745 -2.5 -2.5 Mabsadd L
.07778 .22745 -2.5 2.5 Mabsadd L closepath F
.08095 .22768 -2.5 2.5 Mabsadd m
.08095 .22768 2.5 2.5 Mabsadd L
.08095 .22768 2.5 -2.5 Mabsadd L
.08095 .22768 -2.5 -2.5 Mabsadd L
.08095 .22768 -2.5 2.5 Mabsadd L closepath F
.08413 .22791 -2.5 2.5 Mabsadd m
.08413 .22791 2.5 2.5 Mabsadd L
.08413 .22791 2.5 -2.5 Mabsadd L
.08413 .22791 -2.5 -2.5 Mabsadd L
.08413 .22791 -2.5 2.5 Mabsadd L closepath F
.0873 .22814 -2.5 2.5 Mabsadd m
.0873 .22814 2.5 2.5 Mabsadd L
.0873 .22814 2.5 -2.5 Mabsadd L
.0873 .22814 -2.5 -2.5 Mabsadd L
.0873 .22814 -2.5 2.5 Mabsadd L closepath F
.09048 .22838 -2.5 2.5 Mabsadd m
.09048 .22838 2.5 2.5 Mabsadd L
.09048 .22838 2.5 -2.5 Mabsadd L
.09048 .22838 -2.5 -2.5 Mabsadd L
.09048 .22838 -2.5 2.5 Mabsadd L closepath F
.09365 .22861 -2.5 2.5 Mabsadd m
.09365 .22861 2.5 2.5 Mabsadd L
.09365 .22861 2.5 -2.5 Mabsadd L
.09365 .22861 -2.5 -2.5 Mabsadd L
.09365 .22861 -2.5 2.5 Mabsadd L closepath F
.09683 .22885 -2.5 2.5 Mabsadd m
.09683 .22885 2.5 2.5 Mabsadd L
.09683 .22885 2.5 -2.5 Mabsadd L
.09683 .22885 -2.5 -2.5 Mabsadd L
.09683 .22885 -2.5 2.5 Mabsadd L closepath F
.1 .2291 -2.5 2.5 Mabsadd m
.1 .2291 2.5 2.5 Mabsadd L
.1 .2291 2.5 -2.5 Mabsadd L
.1 .2291 -2.5 -2.5 Mabsadd L
.1 .2291 -2.5 2.5 Mabsadd L closepath F
.10317 .22934 -2.5 2.5 Mabsadd m
.10317 .22934 2.5 2.5 Mabsadd L
.10317 .22934 2.5 -2.5 Mabsadd L
.10317 .22934 -2.5 -2.5 Mabsadd L
.10317 .22934 -2.5 2.5 Mabsadd L closepath F
.10635 .22959 -2.5 2.5 Mabsadd m
.10635 .22959 2.5 2.5 Mabsadd L
.10635 .22959 2.5 -2.5 Mabsadd L
.10635 .22959 -2.5 -2.5 Mabsadd L
.10635 .22959 -2.5 2.5 Mabsadd L closepath F
.10952 .22983 -2.5 2.5 Mabsadd m
.10952 .22983 2.5 2.5 Mabsadd L
.10952 .22983 2.5 -2.5 Mabsadd L
.10952 .22983 -2.5 -2.5 Mabsadd L
.10952 .22983 -2.5 2.5 Mabsadd L closepath F
.1127 .23009 -2.5 2.5 Mabsadd m
.1127 .23009 2.5 2.5 Mabsadd L
.1127 .23009 2.5 -2.5 Mabsadd L
.1127 .23009 -2.5 -2.5 Mabsadd L
.1127 .23009 -2.5 2.5 Mabsadd L closepath F
.11587 .23034 -2.5 2.5 Mabsadd m
.11587 .23034 2.5 2.5 Mabsadd L
.11587 .23034 2.5 -2.5 Mabsadd L
.11587 .23034 -2.5 -2.5 Mabsadd L
.11587 .23034 -2.5 2.5 Mabsadd L closepath F
.11905 .2306 -2.5 2.5 Mabsadd m
.11905 .2306 2.5 2.5 Mabsadd L
.11905 .2306 2.5 -2.5 Mabsadd L
.11905 .2306 -2.5 -2.5 Mabsadd L
.11905 .2306 -2.5 2.5 Mabsadd L closepath F
.12222 .23085 -2.5 2.5 Mabsadd m
.12222 .23085 2.5 2.5 Mabsadd L
.12222 .23085 2.5 -2.5 Mabsadd L
.12222 .23085 -2.5 -2.5 Mabsadd L
.12222 .23085 -2.5 2.5 Mabsadd L closepath F
.1254 .23112 -2.5 2.5 Mabsadd m
.1254 .23112 2.5 2.5 Mabsadd L
.1254 .23112 2.5 -2.5 Mabsadd L
.1254 .23112 -2.5 -2.5 Mabsadd L
.1254 .23112 -2.5 2.5 Mabsadd L closepath F
.12857 .23138 -2.5 2.5 Mabsadd m
.12857 .23138 2.5 2.5 Mabsadd L
.12857 .23138 2.5 -2.5 Mabsadd L
.12857 .23138 -2.5 -2.5 Mabsadd L
.12857 .23138 -2.5 2.5 Mabsadd L closepath F
.13175 .23165 -2.5 2.5 Mabsadd m
.13175 .23165 2.5 2.5 Mabsadd L
.13175 .23165 2.5 -2.5 Mabsadd L
.13175 .23165 -2.5 -2.5 Mabsadd L
.13175 .23165 -2.5 2.5 Mabsadd L closepath F
.13492 .23192 -2.5 2.5 Mabsadd m
.13492 .23192 2.5 2.5 Mabsadd L
.13492 .23192 2.5 -2.5 Mabsadd L
.13492 .23192 -2.5 -2.5 Mabsadd L
.13492 .23192 -2.5 2.5 Mabsadd L closepath F
.1381 .23219 -2.5 2.5 Mabsadd m
.1381 .23219 2.5 2.5 Mabsadd L
.1381 .23219 2.5 -2.5 Mabsadd L
.1381 .23219 -2.5 -2.5 Mabsadd L
.1381 .23219 -2.5 2.5 Mabsadd L closepath F
.14127 .23246 -2.5 2.5 Mabsadd m
.14127 .23246 2.5 2.5 Mabsadd L
.14127 .23246 2.5 -2.5 Mabsadd L
.14127 .23246 -2.5 -2.5 Mabsadd L
.14127 .23246 -2.5 2.5 Mabsadd L closepath F
.14444 .23274 -2.5 2.5 Mabsadd m
.14444 .23274 2.5 2.5 Mabsadd L
.14444 .23274 2.5 -2.5 Mabsadd L
.14444 .23274 -2.5 -2.5 Mabsadd L
.14444 .23274 -2.5 2.5 Mabsadd L closepath F
.14762 .23302 -2.5 2.5 Mabsadd m
.14762 .23302 2.5 2.5 Mabsadd L
.14762 .23302 2.5 -2.5 Mabsadd L
.14762 .23302 -2.5 -2.5 Mabsadd L
.14762 .23302 -2.5 2.5 Mabsadd L closepath F
.15079 .2333 -2.5 2.5 Mabsadd m
.15079 .2333 2.5 2.5 Mabsadd L
.15079 .2333 2.5 -2.5 Mabsadd L
.15079 .2333 -2.5 -2.5 Mabsadd L
.15079 .2333 -2.5 2.5 Mabsadd L closepath F
.15397 .23359 -2.5 2.5 Mabsadd m
.15397 .23359 2.5 2.5 Mabsadd L
.15397 .23359 2.5 -2.5 Mabsadd L
.15397 .23359 -2.5 -2.5 Mabsadd L
.15397 .23359 -2.5 2.5 Mabsadd L closepath F
.15714 .23388 -2.5 2.5 Mabsadd m
.15714 .23388 2.5 2.5 Mabsadd L
.15714 .23388 2.5 -2.5 Mabsadd L
.15714 .23388 -2.5 -2.5 Mabsadd L
.15714 .23388 -2.5 2.5 Mabsadd L closepath F
.16032 .23417 -2.5 2.5 Mabsadd m
.16032 .23417 2.5 2.5 Mabsadd L
.16032 .23417 2.5 -2.5 Mabsadd L
.16032 .23417 -2.5 -2.5 Mabsadd L
.16032 .23417 -2.5 2.5 Mabsadd L closepath F
.16349 .23446 -2.5 2.5 Mabsadd m
.16349 .23446 2.5 2.5 Mabsadd L
.16349 .23446 2.5 -2.5 Mabsadd L
.16349 .23446 -2.5 -2.5 Mabsadd L
.16349 .23446 -2.5 2.5 Mabsadd L closepath F
.16667 .23476 -2.5 2.5 Mabsadd m
.16667 .23476 2.5 2.5 Mabsadd L
.16667 .23476 2.5 -2.5 Mabsadd L
.16667 .23476 -2.5 -2.5 Mabsadd L
.16667 .23476 -2.5 2.5 Mabsadd L closepath F
.16984 .23506 -2.5 2.5 Mabsadd m
.16984 .23506 2.5 2.5 Mabsadd L
.16984 .23506 2.5 -2.5 Mabsadd L
.16984 .23506 -2.5 -2.5 Mabsadd L
.16984 .23506 -2.5 2.5 Mabsadd L closepath F
.17302 .23537 -2.5 2.5 Mabsadd m
.17302 .23537 2.5 2.5 Mabsadd L
.17302 .23537 2.5 -2.5 Mabsadd L
.17302 .23537 -2.5 -2.5 Mabsadd L
.17302 .23537 -2.5 2.5 Mabsadd L closepath F
.17619 .23567 -2.5 2.5 Mabsadd m
.17619 .23567 2.5 2.5 Mabsadd L
.17619 .23567 2.5 -2.5 Mabsadd L
.17619 .23567 -2.5 -2.5 Mabsadd L
.17619 .23567 -2.5 2.5 Mabsadd L closepath F
.17937 .23598 -2.5 2.5 Mabsadd m
.17937 .23598 2.5 2.5 Mabsadd L
.17937 .23598 2.5 -2.5 Mabsadd L
.17937 .23598 -2.5 -2.5 Mabsadd L
.17937 .23598 -2.5 2.5 Mabsadd L closepath F
.18254 .23629 -2.5 2.5 Mabsadd m
.18254 .23629 2.5 2.5 Mabsadd L
.18254 .23629 2.5 -2.5 Mabsadd L
.18254 .23629 -2.5 -2.5 Mabsadd L
.18254 .23629 -2.5 2.5 Mabsadd L closepath F
.18571 .23661 -2.5 2.5 Mabsadd m
.18571 .23661 2.5 2.5 Mabsadd L
.18571 .23661 2.5 -2.5 Mabsadd L
.18571 .23661 -2.5 -2.5 Mabsadd L
.18571 .23661 -2.5 2.5 Mabsadd L closepath F
.18889 .23693 -2.5 2.5 Mabsadd m
.18889 .23693 2.5 2.5 Mabsadd L
.18889 .23693 2.5 -2.5 Mabsadd L
.18889 .23693 -2.5 -2.5 Mabsadd L
.18889 .23693 -2.5 2.5 Mabsadd L closepath F
.19206 .23725 -2.5 2.5 Mabsadd m
.19206 .23725 2.5 2.5 Mabsadd L
.19206 .23725 2.5 -2.5 Mabsadd L
.19206 .23725 -2.5 -2.5 Mabsadd L
.19206 .23725 -2.5 2.5 Mabsadd L closepath F
.19524 .23758 -2.5 2.5 Mabsadd m
.19524 .23758 2.5 2.5 Mabsadd L
.19524 .23758 2.5 -2.5 Mabsadd L
.19524 .23758 -2.5 -2.5 Mabsadd L
.19524 .23758 -2.5 2.5 Mabsadd L closepath F
.19841 .23791 -2.5 2.5 Mabsadd m
.19841 .23791 2.5 2.5 Mabsadd L
.19841 .23791 2.5 -2.5 Mabsadd L
.19841 .23791 -2.5 -2.5 Mabsadd L
.19841 .23791 -2.5 2.5 Mabsadd L closepath F
.20159 .23824 -2.5 2.5 Mabsadd m
.20159 .23824 2.5 2.5 Mabsadd L
.20159 .23824 2.5 -2.5 Mabsadd L
.20159 .23824 -2.5 -2.5 Mabsadd L
.20159 .23824 -2.5 2.5 Mabsadd L closepath F
.20476 .23857 -2.5 2.5 Mabsadd m
.20476 .23857 2.5 2.5 Mabsadd L
.20476 .23857 2.5 -2.5 Mabsadd L
.20476 .23857 -2.5 -2.5 Mabsadd L
.20476 .23857 -2.5 2.5 Mabsadd L closepath F
.20794 .23891 -2.5 2.5 Mabsadd m
.20794 .23891 2.5 2.5 Mabsadd L
.20794 .23891 2.5 -2.5 Mabsadd L
.20794 .23891 -2.5 -2.5 Mabsadd L
.20794 .23891 -2.5 2.5 Mabsadd L closepath F
.21111 .23925 -2.5 2.5 Mabsadd m
.21111 .23925 2.5 2.5 Mabsadd L
.21111 .23925 2.5 -2.5 Mabsadd L
.21111 .23925 -2.5 -2.5 Mabsadd L
.21111 .23925 -2.5 2.5 Mabsadd L closepath F
.21429 .2396 -2.5 2.5 Mabsadd m
.21429 .2396 2.5 2.5 Mabsadd L
.21429 .2396 2.5 -2.5 Mabsadd L
.21429 .2396 -2.5 -2.5 Mabsadd L
.21429 .2396 -2.5 2.5 Mabsadd L closepath F
.21746 .23995 -2.5 2.5 Mabsadd m
.21746 .23995 2.5 2.5 Mabsadd L
.21746 .23995 2.5 -2.5 Mabsadd L
.21746 .23995 -2.5 -2.5 Mabsadd L
.21746 .23995 -2.5 2.5 Mabsadd L closepath F
.22063 .2403 -2.5 2.5 Mabsadd m
.22063 .2403 2.5 2.5 Mabsadd L
.22063 .2403 2.5 -2.5 Mabsadd L
.22063 .2403 -2.5 -2.5 Mabsadd L
.22063 .2403 -2.5 2.5 Mabsadd L closepath F
.22381 .24066 -2.5 2.5 Mabsadd m
.22381 .24066 2.5 2.5 Mabsadd L
.22381 .24066 2.5 -2.5 Mabsadd L
.22381 .24066 -2.5 -2.5 Mabsadd L
.22381 .24066 -2.5 2.5 Mabsadd L closepath F
.22698 .24101 -2.5 2.5 Mabsadd m
.22698 .24101 2.5 2.5 Mabsadd L
.22698 .24101 2.5 -2.5 Mabsadd L
.22698 .24101 -2.5 -2.5 Mabsadd L
.22698 .24101 -2.5 2.5 Mabsadd L closepath F
.23016 .24138 -2.5 2.5 Mabsadd m
.23016 .24138 2.5 2.5 Mabsadd L
.23016 .24138 2.5 -2.5 Mabsadd L
.23016 .24138 -2.5 -2.5 Mabsadd L
.23016 .24138 -2.5 2.5 Mabsadd L closepath F
.23333 .24174 -2.5 2.5 Mabsadd m
.23333 .24174 2.5 2.5 Mabsadd L
.23333 .24174 2.5 -2.5 Mabsadd L
.23333 .24174 -2.5 -2.5 Mabsadd L
.23333 .24174 -2.5 2.5 Mabsadd L closepath F
.23651 .24211 -2.5 2.5 Mabsadd m
.23651 .24211 2.5 2.5 Mabsadd L
.23651 .24211 2.5 -2.5 Mabsadd L
.23651 .24211 -2.5 -2.5 Mabsadd L
.23651 .24211 -2.5 2.5 Mabsadd L closepath F
.23968 .24249 -2.5 2.5 Mabsadd m
.23968 .24249 2.5 2.5 Mabsadd L
.23968 .24249 2.5 -2.5 Mabsadd L
.23968 .24249 -2.5 -2.5 Mabsadd L
.23968 .24249 -2.5 2.5 Mabsadd L closepath F
.24286 .24287 -2.5 2.5 Mabsadd m
.24286 .24287 2.5 2.5 Mabsadd L
.24286 .24287 2.5 -2.5 Mabsadd L
.24286 .24287 -2.5 -2.5 Mabsadd L
.24286 .24287 -2.5 2.5 Mabsadd L closepath F
.24603 .24325 -2.5 2.5 Mabsadd m
.24603 .24325 2.5 2.5 Mabsadd L
.24603 .24325 2.5 -2.5 Mabsadd L
.24603 .24325 -2.5 -2.5 Mabsadd L
.24603 .24325 -2.5 2.5 Mabsadd L closepath F
.24921 .24363 -2.5 2.5 Mabsadd m
.24921 .24363 2.5 2.5 Mabsadd L
.24921 .24363 2.5 -2.5 Mabsadd L
.24921 .24363 -2.5 -2.5 Mabsadd L
.24921 .24363 -2.5 2.5 Mabsadd L closepath F
.25238 .24402 -2.5 2.5 Mabsadd m
.25238 .24402 2.5 2.5 Mabsadd L
.25238 .24402 2.5 -2.5 Mabsadd L
.25238 .24402 -2.5 -2.5 Mabsadd L
.25238 .24402 -2.5 2.5 Mabsadd L closepath F
.25556 .24442 -2.5 2.5 Mabsadd m
.25556 .24442 2.5 2.5 Mabsadd L
.25556 .24442 2.5 -2.5 Mabsadd L
.25556 .24442 -2.5 -2.5 Mabsadd L
.25556 .24442 -2.5 2.5 Mabsadd L closepath F
.25873 .24481 -2.5 2.5 Mabsadd m
.25873 .24481 2.5 2.5 Mabsadd L
.25873 .24481 2.5 -2.5 Mabsadd L
.25873 .24481 -2.5 -2.5 Mabsadd L
.25873 .24481 -2.5 2.5 Mabsadd L closepath F
.2619 .24521 -2.5 2.5 Mabsadd m
.2619 .24521 2.5 2.5 Mabsadd L
.2619 .24521 2.5 -2.5 Mabsadd L
.2619 .24521 -2.5 -2.5 Mabsadd L
.2619 .24521 -2.5 2.5 Mabsadd L closepath F
.26508 .24562 -2.5 2.5 Mabsadd m
.26508 .24562 2.5 2.5 Mabsadd L
.26508 .24562 2.5 -2.5 Mabsadd L
.26508 .24562 -2.5 -2.5 Mabsadd L
.26508 .24562 -2.5 2.5 Mabsadd L closepath F
.26825 .24603 -2.5 2.5 Mabsadd m
.26825 .24603 2.5 2.5 Mabsadd L
.26825 .24603 2.5 -2.5 Mabsadd L
.26825 .24603 -2.5 -2.5 Mabsadd L
.26825 .24603 -2.5 2.5 Mabsadd L closepath F
.27143 .24644 -2.5 2.5 Mabsadd m
.27143 .24644 2.5 2.5 Mabsadd L
.27143 .24644 2.5 -2.5 Mabsadd L
.27143 .24644 -2.5 -2.5 Mabsadd L
.27143 .24644 -2.5 2.5 Mabsadd L closepath F
.2746 .24686 -2.5 2.5 Mabsadd m
.2746 .24686 2.5 2.5 Mabsadd L
.2746 .24686 2.5 -2.5 Mabsadd L
.2746 .24686 -2.5 -2.5 Mabsadd L
.2746 .24686 -2.5 2.5 Mabsadd L closepath F
.27778 .24728 -2.5 2.5 Mabsadd m
.27778 .24728 2.5 2.5 Mabsadd L
.27778 .24728 2.5 -2.5 Mabsadd L
.27778 .24728 -2.5 -2.5 Mabsadd L
.27778 .24728 -2.5 2.5 Mabsadd L closepath F
.28095 .24771 -2.5 2.5 Mabsadd m
.28095 .24771 2.5 2.5 Mabsadd L
.28095 .24771 2.5 -2.5 Mabsadd L
.28095 .24771 -2.5 -2.5 Mabsadd L
.28095 .24771 -2.5 2.5 Mabsadd L closepath F
.28413 .24814 -2.5 2.5 Mabsadd m
.28413 .24814 2.5 2.5 Mabsadd L
.28413 .24814 2.5 -2.5 Mabsadd L
.28413 .24814 -2.5 -2.5 Mabsadd L
.28413 .24814 -2.5 2.5 Mabsadd L closepath F
.2873 .24857 -2.5 2.5 Mabsadd m
.2873 .24857 2.5 2.5 Mabsadd L
.2873 .24857 2.5 -2.5 Mabsadd L
.2873 .24857 -2.5 -2.5 Mabsadd L
.2873 .24857 -2.5 2.5 Mabsadd L closepath F
.29048 .24901 -2.5 2.5 Mabsadd m
.29048 .24901 2.5 2.5 Mabsadd L
.29048 .24901 2.5 -2.5 Mabsadd L
.29048 .24901 -2.5 -2.5 Mabsadd L
.29048 .24901 -2.5 2.5 Mabsadd L closepath F
.29365 .24945 -2.5 2.5 Mabsadd m
.29365 .24945 2.5 2.5 Mabsadd L
.29365 .24945 2.5 -2.5 Mabsadd L
.29365 .24945 -2.5 -2.5 Mabsadd L
.29365 .24945 -2.5 2.5 Mabsadd L closepath F
.29683 .2499 -2.5 2.5 Mabsadd m
.29683 .2499 2.5 2.5 Mabsadd L
.29683 .2499 2.5 -2.5 Mabsadd L
.29683 .2499 -2.5 -2.5 Mabsadd L
.29683 .2499 -2.5 2.5 Mabsadd L closepath F
.3 .25035 -2.5 2.5 Mabsadd m
.3 .25035 2.5 2.5 Mabsadd L
.3 .25035 2.5 -2.5 Mabsadd L
.3 .25035 -2.5 -2.5 Mabsadd L
.3 .25035 -2.5 2.5 Mabsadd L closepath F
.30317 .25081 -2.5 2.5 Mabsadd m
.30317 .25081 2.5 2.5 Mabsadd L
.30317 .25081 2.5 -2.5 Mabsadd L
.30317 .25081 -2.5 -2.5 Mabsadd L
.30317 .25081 -2.5 2.5 Mabsadd L closepath F
.30635 .25127 -2.5 2.5 Mabsadd m
.30635 .25127 2.5 2.5 Mabsadd L
.30635 .25127 2.5 -2.5 Mabsadd L
.30635 .25127 -2.5 -2.5 Mabsadd L
.30635 .25127 -2.5 2.5 Mabsadd L closepath F
.30952 .25173 -2.5 2.5 Mabsadd m
.30952 .25173 2.5 2.5 Mabsadd L
.30952 .25173 2.5 -2.5 Mabsadd L
.30952 .25173 -2.5 -2.5 Mabsadd L
.30952 .25173 -2.5 2.5 Mabsadd L closepath F
.3127 .2522 -2.5 2.5 Mabsadd m
.3127 .2522 2.5 2.5 Mabsadd L
.3127 .2522 2.5 -2.5 Mabsadd L
.3127 .2522 -2.5 -2.5 Mabsadd L
.3127 .2522 -2.5 2.5 Mabsadd L closepath F
.31587 .25268 -2.5 2.5 Mabsadd m
.31587 .25268 2.5 2.5 Mabsadd L
.31587 .25268 2.5 -2.5 Mabsadd L
.31587 .25268 -2.5 -2.5 Mabsadd L
.31587 .25268 -2.5 2.5 Mabsadd L closepath F
.31905 .25316 -2.5 2.5 Mabsadd m
.31905 .25316 2.5 2.5 Mabsadd L
.31905 .25316 2.5 -2.5 Mabsadd L
.31905 .25316 -2.5 -2.5 Mabsadd L
.31905 .25316 -2.5 2.5 Mabsadd L closepath F
.32222 .25364 -2.5 2.5 Mabsadd m
.32222 .25364 2.5 2.5 Mabsadd L
.32222 .25364 2.5 -2.5 Mabsadd L
.32222 .25364 -2.5 -2.5 Mabsadd L
.32222 .25364 -2.5 2.5 Mabsadd L closepath F
.3254 .25413 -2.5 2.5 Mabsadd m
.3254 .25413 2.5 2.5 Mabsadd L
.3254 .25413 2.5 -2.5 Mabsadd L
.3254 .25413 -2.5 -2.5 Mabsadd L
.3254 .25413 -2.5 2.5 Mabsadd L closepath F
.32857 .25463 -2.5 2.5 Mabsadd m
.32857 .25463 2.5 2.5 Mabsadd L
.32857 .25463 2.5 -2.5 Mabsadd L
.32857 .25463 -2.5 -2.5 Mabsadd L
.32857 .25463 -2.5 2.5 Mabsadd L closepath F
.33175 .25513 -2.5 2.5 Mabsadd m
.33175 .25513 2.5 2.5 Mabsadd L
.33175 .25513 2.5 -2.5 Mabsadd L
.33175 .25513 -2.5 -2.5 Mabsadd L
.33175 .25513 -2.5 2.5 Mabsadd L closepath F
.33492 .25563 -2.5 2.5 Mabsadd m
.33492 .25563 2.5 2.5 Mabsadd L
.33492 .25563 2.5 -2.5 Mabsadd L
.33492 .25563 -2.5 -2.5 Mabsadd L
.33492 .25563 -2.5 2.5 Mabsadd L closepath F
.3381 .25614 -2.5 2.5 Mabsadd m
.3381 .25614 2.5 2.5 Mabsadd L
.3381 .25614 2.5 -2.5 Mabsadd L
.3381 .25614 -2.5 -2.5 Mabsadd L
.3381 .25614 -2.5 2.5 Mabsadd L closepath F
.34127 .25665 -2.5 2.5 Mabsadd m
.34127 .25665 2.5 2.5 Mabsadd L
.34127 .25665 2.5 -2.5 Mabsadd L
.34127 .25665 -2.5 -2.5 Mabsadd L
.34127 .25665 -2.5 2.5 Mabsadd L closepath F
.34444 .25717 -2.5 2.5 Mabsadd m
.34444 .25717 2.5 2.5 Mabsadd L
.34444 .25717 2.5 -2.5 Mabsadd L
.34444 .25717 -2.5 -2.5 Mabsadd L
.34444 .25717 -2.5 2.5 Mabsadd L closepath F
.34762 .2577 -2.5 2.5 Mabsadd m
.34762 .2577 2.5 2.5 Mabsadd L
.34762 .2577 2.5 -2.5 Mabsadd L
.34762 .2577 -2.5 -2.5 Mabsadd L
.34762 .2577 -2.5 2.5 Mabsadd L closepath F
.35079 .25823 -2.5 2.5 Mabsadd m
.35079 .25823 2.5 2.5 Mabsadd L
.35079 .25823 2.5 -2.5 Mabsadd L
.35079 .25823 -2.5 -2.5 Mabsadd L
.35079 .25823 -2.5 2.5 Mabsadd L closepath F
.35397 .25876 -2.5 2.5 Mabsadd m
.35397 .25876 2.5 2.5 Mabsadd L
.35397 .25876 2.5 -2.5 Mabsadd L
.35397 .25876 -2.5 -2.5 Mabsadd L
.35397 .25876 -2.5 2.5 Mabsadd L closepath F
.35714 .2593 -2.5 2.5 Mabsadd m
.35714 .2593 2.5 2.5 Mabsadd L
.35714 .2593 2.5 -2.5 Mabsadd L
.35714 .2593 -2.5 -2.5 Mabsadd L
.35714 .2593 -2.5 2.5 Mabsadd L closepath F
.36032 .25985 -2.5 2.5 Mabsadd m
.36032 .25985 2.5 2.5 Mabsadd L
.36032 .25985 2.5 -2.5 Mabsadd L
.36032 .25985 -2.5 -2.5 Mabsadd L
.36032 .25985 -2.5 2.5 Mabsadd L closepath F
.36349 .2604 -2.5 2.5 Mabsadd m
.36349 .2604 2.5 2.5 Mabsadd L
.36349 .2604 2.5 -2.5 Mabsadd L
.36349 .2604 -2.5 -2.5 Mabsadd L
.36349 .2604 -2.5 2.5 Mabsadd L closepath F
.36667 .26096 -2.5 2.5 Mabsadd m
.36667 .26096 2.5 2.5 Mabsadd L
.36667 .26096 2.5 -2.5 Mabsadd L
.36667 .26096 -2.5 -2.5 Mabsadd L
.36667 .26096 -2.5 2.5 Mabsadd L closepath F
.36984 .26152 -2.5 2.5 Mabsadd m
.36984 .26152 2.5 2.5 Mabsadd L
.36984 .26152 2.5 -2.5 Mabsadd L
.36984 .26152 -2.5 -2.5 Mabsadd L
.36984 .26152 -2.5 2.5 Mabsadd L closepath F
.37302 .26209 -2.5 2.5 Mabsadd m
.37302 .26209 2.5 2.5 Mabsadd L
.37302 .26209 2.5 -2.5 Mabsadd L
.37302 .26209 -2.5 -2.5 Mabsadd L
.37302 .26209 -2.5 2.5 Mabsadd L closepath F
.37619 .26266 -2.5 2.5 Mabsadd m
.37619 .26266 2.5 2.5 Mabsadd L
.37619 .26266 2.5 -2.5 Mabsadd L
.37619 .26266 -2.5 -2.5 Mabsadd L
.37619 .26266 -2.5 2.5 Mabsadd L closepath F
.37937 .26324 -2.5 2.5 Mabsadd m
.37937 .26324 2.5 2.5 Mabsadd L
.37937 .26324 2.5 -2.5 Mabsadd L
.37937 .26324 -2.5 -2.5 Mabsadd L
.37937 .26324 -2.5 2.5 Mabsadd L closepath F
.38254 .26383 -2.5 2.5 Mabsadd m
.38254 .26383 2.5 2.5 Mabsadd L
.38254 .26383 2.5 -2.5 Mabsadd L
.38254 .26383 -2.5 -2.5 Mabsadd L
.38254 .26383 -2.5 2.5 Mabsadd L closepath F
.38571 .26442 -2.5 2.5 Mabsadd m
.38571 .26442 2.5 2.5 Mabsadd L
.38571 .26442 2.5 -2.5 Mabsadd L
.38571 .26442 -2.5 -2.5 Mabsadd L
.38571 .26442 -2.5 2.5 Mabsadd L closepath F
.38889 .26501 -2.5 2.5 Mabsadd m
.38889 .26501 2.5 2.5 Mabsadd L
.38889 .26501 2.5 -2.5 Mabsadd L
.38889 .26501 -2.5 -2.5 Mabsadd L
.38889 .26501 -2.5 2.5 Mabsadd L closepath F
.39206 .26562 -2.5 2.5 Mabsadd m
.39206 .26562 2.5 2.5 Mabsadd L
.39206 .26562 2.5 -2.5 Mabsadd L
.39206 .26562 -2.5 -2.5 Mabsadd L
.39206 .26562 -2.5 2.5 Mabsadd L closepath F
.39524 .26623 -2.5 2.5 Mabsadd m
.39524 .26623 2.5 2.5 Mabsadd L
.39524 .26623 2.5 -2.5 Mabsadd L
.39524 .26623 -2.5 -2.5 Mabsadd L
.39524 .26623 -2.5 2.5 Mabsadd L closepath F
.39841 .26684 -2.5 2.5 Mabsadd m
.39841 .26684 2.5 2.5 Mabsadd L
.39841 .26684 2.5 -2.5 Mabsadd L
.39841 .26684 -2.5 -2.5 Mabsadd L
.39841 .26684 -2.5 2.5 Mabsadd L closepath F
.40159 .26746 -2.5 2.5 Mabsadd m
.40159 .26746 2.5 2.5 Mabsadd L
.40159 .26746 2.5 -2.5 Mabsadd L
.40159 .26746 -2.5 -2.5 Mabsadd L
.40159 .26746 -2.5 2.5 Mabsadd L closepath F
.40476 .26809 -2.5 2.5 Mabsadd m
.40476 .26809 2.5 2.5 Mabsadd L
.40476 .26809 2.5 -2.5 Mabsadd L
.40476 .26809 -2.5 -2.5 Mabsadd L
.40476 .26809 -2.5 2.5 Mabsadd L closepath F
.40794 .26872 -2.5 2.5 Mabsadd m
.40794 .26872 2.5 2.5 Mabsadd L
.40794 .26872 2.5 -2.5 Mabsadd L
.40794 .26872 -2.5 -2.5 Mabsadd L
.40794 .26872 -2.5 2.5 Mabsadd L closepath F
.41111 .26936 -2.5 2.5 Mabsadd m
.41111 .26936 2.5 2.5 Mabsadd L
.41111 .26936 2.5 -2.5 Mabsadd L
.41111 .26936 -2.5 -2.5 Mabsadd L
.41111 .26936 -2.5 2.5 Mabsadd L closepath F
.41429 .27001 -2.5 2.5 Mabsadd m
.41429 .27001 2.5 2.5 Mabsadd L
.41429 .27001 2.5 -2.5 Mabsadd L
.41429 .27001 -2.5 -2.5 Mabsadd L
.41429 .27001 -2.5 2.5 Mabsadd L closepath F
.41746 .27066 -2.5 2.5 Mabsadd m
.41746 .27066 2.5 2.5 Mabsadd L
.41746 .27066 2.5 -2.5 Mabsadd L
.41746 .27066 -2.5 -2.5 Mabsadd L
.41746 .27066 -2.5 2.5 Mabsadd L closepath F
.42063 .27132 -2.5 2.5 Mabsadd m
.42063 .27132 2.5 2.5 Mabsadd L
.42063 .27132 2.5 -2.5 Mabsadd L
.42063 .27132 -2.5 -2.5 Mabsadd L
.42063 .27132 -2.5 2.5 Mabsadd L closepath F
.42381 .27199 -2.5 2.5 Mabsadd m
.42381 .27199 2.5 2.5 Mabsadd L
.42381 .27199 2.5 -2.5 Mabsadd L
.42381 .27199 -2.5 -2.5 Mabsadd L
.42381 .27199 -2.5 2.5 Mabsadd L closepath F
.42698 .27266 -2.5 2.5 Mabsadd m
.42698 .27266 2.5 2.5 Mabsadd L
.42698 .27266 2.5 -2.5 Mabsadd L
.42698 .27266 -2.5 -2.5 Mabsadd L
.42698 .27266 -2.5 2.5 Mabsadd L closepath F
.43016 .27334 -2.5 2.5 Mabsadd m
.43016 .27334 2.5 2.5 Mabsadd L
.43016 .27334 2.5 -2.5 Mabsadd L
.43016 .27334 -2.5 -2.5 Mabsadd L
.43016 .27334 -2.5 2.5 Mabsadd L closepath F
.43333 .27403 -2.5 2.5 Mabsadd m
.43333 .27403 2.5 2.5 Mabsadd L
.43333 .27403 2.5 -2.5 Mabsadd L
.43333 .27403 -2.5 -2.5 Mabsadd L
.43333 .27403 -2.5 2.5 Mabsadd L closepath F
.43651 .27472 -2.5 2.5 Mabsadd m
.43651 .27472 2.5 2.5 Mabsadd L
.43651 .27472 2.5 -2.5 Mabsadd L
.43651 .27472 -2.5 -2.5 Mabsadd L
.43651 .27472 -2.5 2.5 Mabsadd L closepath F
.43968 .27542 -2.5 2.5 Mabsadd m
.43968 .27542 2.5 2.5 Mabsadd L
.43968 .27542 2.5 -2.5 Mabsadd L
.43968 .27542 -2.5 -2.5 Mabsadd L
.43968 .27542 -2.5 2.5 Mabsadd L closepath F
.44286 .27613 -2.5 2.5 Mabsadd m
.44286 .27613 2.5 2.5 Mabsadd L
.44286 .27613 2.5 -2.5 Mabsadd L
.44286 .27613 -2.5 -2.5 Mabsadd L
.44286 .27613 -2.5 2.5 Mabsadd L closepath F
.44603 .27684 -2.5 2.5 Mabsadd m
.44603 .27684 2.5 2.5 Mabsadd L
.44603 .27684 2.5 -2.5 Mabsadd L
.44603 .27684 -2.5 -2.5 Mabsadd L
.44603 .27684 -2.5 2.5 Mabsadd L closepath F
.44921 .27756 -2.5 2.5 Mabsadd m
.44921 .27756 2.5 2.5 Mabsadd L
.44921 .27756 2.5 -2.5 Mabsadd L
.44921 .27756 -2.5 -2.5 Mabsadd L
.44921 .27756 -2.5 2.5 Mabsadd L closepath F
.45238 .27829 -2.5 2.5 Mabsadd m
.45238 .27829 2.5 2.5 Mabsadd L
.45238 .27829 2.5 -2.5 Mabsadd L
.45238 .27829 -2.5 -2.5 Mabsadd L
.45238 .27829 -2.5 2.5 Mabsadd L closepath F
.45556 .27903 -2.5 2.5 Mabsadd m
.45556 .27903 2.5 2.5 Mabsadd L
.45556 .27903 2.5 -2.5 Mabsadd L
.45556 .27903 -2.5 -2.5 Mabsadd L
.45556 .27903 -2.5 2.5 Mabsadd L closepath F
.45873 .27977 -2.5 2.5 Mabsadd m
.45873 .27977 2.5 2.5 Mabsadd L
.45873 .27977 2.5 -2.5 Mabsadd L
.45873 .27977 -2.5 -2.5 Mabsadd L
.45873 .27977 -2.5 2.5 Mabsadd L closepath F
.4619 .28052 -2.5 2.5 Mabsadd m
.4619 .28052 2.5 2.5 Mabsadd L
.4619 .28052 2.5 -2.5 Mabsadd L
.4619 .28052 -2.5 -2.5 Mabsadd L
.4619 .28052 -2.5 2.5 Mabsadd L closepath F
.46508 .28128 -2.5 2.5 Mabsadd m
.46508 .28128 2.5 2.5 Mabsadd L
.46508 .28128 2.5 -2.5 Mabsadd L
.46508 .28128 -2.5 -2.5 Mabsadd L
.46508 .28128 -2.5 2.5 Mabsadd L closepath F
.46825 .28204 -2.5 2.5 Mabsadd m
.46825 .28204 2.5 2.5 Mabsadd L
.46825 .28204 2.5 -2.5 Mabsadd L
.46825 .28204 -2.5 -2.5 Mabsadd L
.46825 .28204 -2.5 2.5 Mabsadd L closepath F
.47143 .28282 -2.5 2.5 Mabsadd m
.47143 .28282 2.5 2.5 Mabsadd L
.47143 .28282 2.5 -2.5 Mabsadd L
.47143 .28282 -2.5 -2.5 Mabsadd L
.47143 .28282 -2.5 2.5 Mabsadd L closepath F
.4746 .2836 -2.5 2.5 Mabsadd m
.4746 .2836 2.5 2.5 Mabsadd L
.4746 .2836 2.5 -2.5 Mabsadd L
.4746 .2836 -2.5 -2.5 Mabsadd L
.4746 .2836 -2.5 2.5 Mabsadd L closepath F
.47778 .28439 -2.5 2.5 Mabsadd m
.47778 .28439 2.5 2.5 Mabsadd L
.47778 .28439 2.5 -2.5 Mabsadd L
.47778 .28439 -2.5 -2.5 Mabsadd L
.47778 .28439 -2.5 2.5 Mabsadd L closepath F
.48095 .28518 -2.5 2.5 Mabsadd m
.48095 .28518 2.5 2.5 Mabsadd L
.48095 .28518 2.5 -2.5 Mabsadd L
.48095 .28518 -2.5 -2.5 Mabsadd L
.48095 .28518 -2.5 2.5 Mabsadd L closepath F
.48413 .28599 -2.5 2.5 Mabsadd m
.48413 .28599 2.5 2.5 Mabsadd L
.48413 .28599 2.5 -2.5 Mabsadd L
.48413 .28599 -2.5 -2.5 Mabsadd L
.48413 .28599 -2.5 2.5 Mabsadd L closepath F
.4873 .2868 -2.5 2.5 Mabsadd m
.4873 .2868 2.5 2.5 Mabsadd L
.4873 .2868 2.5 -2.5 Mabsadd L
.4873 .2868 -2.5 -2.5 Mabsadd L
.4873 .2868 -2.5 2.5 Mabsadd L closepath F
.49048 .28762 -2.5 2.5 Mabsadd m
.49048 .28762 2.5 2.5 Mabsadd L
.49048 .28762 2.5 -2.5 Mabsadd L
.49048 .28762 -2.5 -2.5 Mabsadd L
.49048 .28762 -2.5 2.5 Mabsadd L closepath F
.49365 .28845 -2.5 2.5 Mabsadd m
.49365 .28845 2.5 2.5 Mabsadd L
.49365 .28845 2.5 -2.5 Mabsadd L
.49365 .28845 -2.5 -2.5 Mabsadd L
.49365 .28845 -2.5 2.5 Mabsadd L closepath F
.49683 .28929 -2.5 2.5 Mabsadd m
.49683 .28929 2.5 2.5 Mabsadd L
.49683 .28929 2.5 -2.5 Mabsadd L
.49683 .28929 -2.5 -2.5 Mabsadd L
.49683 .28929 -2.5 2.5 Mabsadd L closepath F
.5 .29013 -2.5 2.5 Mabsadd m
.5 .29013 2.5 2.5 Mabsadd L
.5 .29013 2.5 -2.5 Mabsadd L
.5 .29013 -2.5 -2.5 Mabsadd L
.5 .29013 -2.5 2.5 Mabsadd L closepath F
.50317 .29099 -2.5 2.5 Mabsadd m
.50317 .29099 2.5 2.5 Mabsadd L
.50317 .29099 2.5 -2.5 Mabsadd L
.50317 .29099 -2.5 -2.5 Mabsadd L
.50317 .29099 -2.5 2.5 Mabsadd L closepath F
.50635 .29185 -2.5 2.5 Mabsadd m
.50635 .29185 2.5 2.5 Mabsadd L
.50635 .29185 2.5 -2.5 Mabsadd L
.50635 .29185 -2.5 -2.5 Mabsadd L
.50635 .29185 -2.5 2.5 Mabsadd L closepath F
.50952 .29272 -2.5 2.5 Mabsadd m
.50952 .29272 2.5 2.5 Mabsadd L
.50952 .29272 2.5 -2.5 Mabsadd L
.50952 .29272 -2.5 -2.5 Mabsadd L
.50952 .29272 -2.5 2.5 Mabsadd L closepath F
.5127 .2936 -2.5 2.5 Mabsadd m
.5127 .2936 2.5 2.5 Mabsadd L
.5127 .2936 2.5 -2.5 Mabsadd L
.5127 .2936 -2.5 -2.5 Mabsadd L
.5127 .2936 -2.5 2.5 Mabsadd L closepath F
.51587 .29449 -2.5 2.5 Mabsadd m
.51587 .29449 2.5 2.5 Mabsadd L
.51587 .29449 2.5 -2.5 Mabsadd L
.51587 .29449 -2.5 -2.5 Mabsadd L
.51587 .29449 -2.5 2.5 Mabsadd L closepath F
.51905 .29539 -2.5 2.5 Mabsadd m
.51905 .29539 2.5 2.5 Mabsadd L
.51905 .29539 2.5 -2.5 Mabsadd L
.51905 .29539 -2.5 -2.5 Mabsadd L
.51905 .29539 -2.5 2.5 Mabsadd L closepath F
.52222 .2963 -2.5 2.5 Mabsadd m
.52222 .2963 2.5 2.5 Mabsadd L
.52222 .2963 2.5 -2.5 Mabsadd L
.52222 .2963 -2.5 -2.5 Mabsadd L
.52222 .2963 -2.5 2.5 Mabsadd L closepath F
.5254 .29721 -2.5 2.5 Mabsadd m
.5254 .29721 2.5 2.5 Mabsadd L
.5254 .29721 2.5 -2.5 Mabsadd L
.5254 .29721 -2.5 -2.5 Mabsadd L
.5254 .29721 -2.5 2.5 Mabsadd L closepath F
.52857 .29814 -2.5 2.5 Mabsadd m
.52857 .29814 2.5 2.5 Mabsadd L
.52857 .29814 2.5 -2.5 Mabsadd L
.52857 .29814 -2.5 -2.5 Mabsadd L
.52857 .29814 -2.5 2.5 Mabsadd L closepath F
.53175 .29907 -2.5 2.5 Mabsadd m
.53175 .29907 2.5 2.5 Mabsadd L
.53175 .29907 2.5 -2.5 Mabsadd L
.53175 .29907 -2.5 -2.5 Mabsadd L
.53175 .29907 -2.5 2.5 Mabsadd L closepath F
.53492 .30002 -2.5 2.5 Mabsadd m
.53492 .30002 2.5 2.5 Mabsadd L
.53492 .30002 2.5 -2.5 Mabsadd L
.53492 .30002 -2.5 -2.5 Mabsadd L
.53492 .30002 -2.5 2.5 Mabsadd L closepath F
.5381 .30097 -2.5 2.5 Mabsadd m
.5381 .30097 2.5 2.5 Mabsadd L
.5381 .30097 2.5 -2.5 Mabsadd L
.5381 .30097 -2.5 -2.5 Mabsadd L
.5381 .30097 -2.5 2.5 Mabsadd L closepath F
.54127 .30193 -2.5 2.5 Mabsadd m
.54127 .30193 2.5 2.5 Mabsadd L
.54127 .30193 2.5 -2.5 Mabsadd L
.54127 .30193 -2.5 -2.5 Mabsadd L
.54127 .30193 -2.5 2.5 Mabsadd L closepath F
.54444 .3029 -2.5 2.5 Mabsadd m
.54444 .3029 2.5 2.5 Mabsadd L
.54444 .3029 2.5 -2.5 Mabsadd L
.54444 .3029 -2.5 -2.5 Mabsadd L
.54444 .3029 -2.5 2.5 Mabsadd L closepath F
.54762 .30389 -2.5 2.5 Mabsadd m
.54762 .30389 2.5 2.5 Mabsadd L
.54762 .30389 2.5 -2.5 Mabsadd L
.54762 .30389 -2.5 -2.5 Mabsadd L
.54762 .30389 -2.5 2.5 Mabsadd L closepath F
.55079 .30488 -2.5 2.5 Mabsadd m
.55079 .30488 2.5 2.5 Mabsadd L
.55079 .30488 2.5 -2.5 Mabsadd L
.55079 .30488 -2.5 -2.5 Mabsadd L
.55079 .30488 -2.5 2.5 Mabsadd L closepath F
.55397 .30588 -2.5 2.5 Mabsadd m
.55397 .30588 2.5 2.5 Mabsadd L
.55397 .30588 2.5 -2.5 Mabsadd L
.55397 .30588 -2.5 -2.5 Mabsadd L
.55397 .30588 -2.5 2.5 Mabsadd L closepath F
.55714 .30689 -2.5 2.5 Mabsadd m
.55714 .30689 2.5 2.5 Mabsadd L
.55714 .30689 2.5 -2.5 Mabsadd L
.55714 .30689 -2.5 -2.5 Mabsadd L
.55714 .30689 -2.5 2.5 Mabsadd L closepath F
.56032 .30791 -2.5 2.5 Mabsadd m
.56032 .30791 2.5 2.5 Mabsadd L
.56032 .30791 2.5 -2.5 Mabsadd L
.56032 .30791 -2.5 -2.5 Mabsadd L
.56032 .30791 -2.5 2.5 Mabsadd L closepath F
.56349 .30894 -2.5 2.5 Mabsadd m
.56349 .30894 2.5 2.5 Mabsadd L
.56349 .30894 2.5 -2.5 Mabsadd L
.56349 .30894 -2.5 -2.5 Mabsadd L
.56349 .30894 -2.5 2.5 Mabsadd L closepath F
.56667 .30999 -2.5 2.5 Mabsadd m
.56667 .30999 2.5 2.5 Mabsadd L
.56667 .30999 2.5 -2.5 Mabsadd L
.56667 .30999 -2.5 -2.5 Mabsadd L
.56667 .30999 -2.5 2.5 Mabsadd L closepath F
.56984 .31104 -2.5 2.5 Mabsadd m
.56984 .31104 2.5 2.5 Mabsadd L
.56984 .31104 2.5 -2.5 Mabsadd L
.56984 .31104 -2.5 -2.5 Mabsadd L
.56984 .31104 -2.5 2.5 Mabsadd L closepath F
.57302 .3121 -2.5 2.5 Mabsadd m
.57302 .3121 2.5 2.5 Mabsadd L
.57302 .3121 2.5 -2.5 Mabsadd L
.57302 .3121 -2.5 -2.5 Mabsadd L
.57302 .3121 -2.5 2.5 Mabsadd L closepath F
.57619 .31318 -2.5 2.5 Mabsadd m
.57619 .31318 2.5 2.5 Mabsadd L
.57619 .31318 2.5 -2.5 Mabsadd L
.57619 .31318 -2.5 -2.5 Mabsadd L
.57619 .31318 -2.5 2.5 Mabsadd L closepath F
.57937 .31426 -2.5 2.5 Mabsadd m
.57937 .31426 2.5 2.5 Mabsadd L
.57937 .31426 2.5 -2.5 Mabsadd L
.57937 .31426 -2.5 -2.5 Mabsadd L
.57937 .31426 -2.5 2.5 Mabsadd L closepath F
.58254 .31536 -2.5 2.5 Mabsadd m
.58254 .31536 2.5 2.5 Mabsadd L
.58254 .31536 2.5 -2.5 Mabsadd L
.58254 .31536 -2.5 -2.5 Mabsadd L
.58254 .31536 -2.5 2.5 Mabsadd L closepath F
.58571 .31646 -2.5 2.5 Mabsadd m
.58571 .31646 2.5 2.5 Mabsadd L
.58571 .31646 2.5 -2.5 Mabsadd L
.58571 .31646 -2.5 -2.5 Mabsadd L
.58571 .31646 -2.5 2.5 Mabsadd L closepath F
.58889 .31758 -2.5 2.5 Mabsadd m
.58889 .31758 2.5 2.5 Mabsadd L
.58889 .31758 2.5 -2.5 Mabsadd L
.58889 .31758 -2.5 -2.5 Mabsadd L
.58889 .31758 -2.5 2.5 Mabsadd L closepath F
.59206 .31871 -2.5 2.5 Mabsadd m
.59206 .31871 2.5 2.5 Mabsadd L
.59206 .31871 2.5 -2.5 Mabsadd L
.59206 .31871 -2.5 -2.5 Mabsadd L
.59206 .31871 -2.5 2.5 Mabsadd L closepath F
.59524 .31985 -2.5 2.5 Mabsadd m
.59524 .31985 2.5 2.5 Mabsadd L
.59524 .31985 2.5 -2.5 Mabsadd L
.59524 .31985 -2.5 -2.5 Mabsadd L
.59524 .31985 -2.5 2.5 Mabsadd L closepath F
.59841 .321 -2.5 2.5 Mabsadd m
.59841 .321 2.5 2.5 Mabsadd L
.59841 .321 2.5 -2.5 Mabsadd L
.59841 .321 -2.5 -2.5 Mabsadd L
.59841 .321 -2.5 2.5 Mabsadd L closepath F
.60159 .32216 -2.5 2.5 Mabsadd m
.60159 .32216 2.5 2.5 Mabsadd L
.60159 .32216 2.5 -2.5 Mabsadd L
.60159 .32216 -2.5 -2.5 Mabsadd L
.60159 .32216 -2.5 2.5 Mabsadd L closepath F
.60476 .32334 -2.5 2.5 Mabsadd m
.60476 .32334 2.5 2.5 Mabsadd L
.60476 .32334 2.5 -2.5 Mabsadd L
.60476 .32334 -2.5 -2.5 Mabsadd L
.60476 .32334 -2.5 2.5 Mabsadd L closepath F
.60794 .32452 -2.5 2.5 Mabsadd m
.60794 .32452 2.5 2.5 Mabsadd L
.60794 .32452 2.5 -2.5 Mabsadd L
.60794 .32452 -2.5 -2.5 Mabsadd L
.60794 .32452 -2.5 2.5 Mabsadd L closepath F
.61111 .32572 -2.5 2.5 Mabsadd m
.61111 .32572 2.5 2.5 Mabsadd L
.61111 .32572 2.5 -2.5 Mabsadd L
.61111 .32572 -2.5 -2.5 Mabsadd L
.61111 .32572 -2.5 2.5 Mabsadd L closepath F
.61429 .32693 -2.5 2.5 Mabsadd m
.61429 .32693 2.5 2.5 Mabsadd L
.61429 .32693 2.5 -2.5 Mabsadd L
.61429 .32693 -2.5 -2.5 Mabsadd L
.61429 .32693 -2.5 2.5 Mabsadd L closepath F
.61746 .32815 -2.5 2.5 Mabsadd m
.61746 .32815 2.5 2.5 Mabsadd L
.61746 .32815 2.5 -2.5 Mabsadd L
.61746 .32815 -2.5 -2.5 Mabsadd L
.61746 .32815 -2.5 2.5 Mabsadd L closepath F
.62063 .32939 -2.5 2.5 Mabsadd m
.62063 .32939 2.5 2.5 Mabsadd L
.62063 .32939 2.5 -2.5 Mabsadd L
.62063 .32939 -2.5 -2.5 Mabsadd L
.62063 .32939 -2.5 2.5 Mabsadd L closepath F
.62381 .33064 -2.5 2.5 Mabsadd m
.62381 .33064 2.5 2.5 Mabsadd L
.62381 .33064 2.5 -2.5 Mabsadd L
.62381 .33064 -2.5 -2.5 Mabsadd L
.62381 .33064 -2.5 2.5 Mabsadd L closepath F
.62698 .33189 -2.5 2.5 Mabsadd m
.62698 .33189 2.5 2.5 Mabsadd L
.62698 .33189 2.5 -2.5 Mabsadd L
.62698 .33189 -2.5 -2.5 Mabsadd L
.62698 .33189 -2.5 2.5 Mabsadd L closepath F
.63016 .33317 -2.5 2.5 Mabsadd m
.63016 .33317 2.5 2.5 Mabsadd L
.63016 .33317 2.5 -2.5 Mabsadd L
.63016 .33317 -2.5 -2.5 Mabsadd L
.63016 .33317 -2.5 2.5 Mabsadd L closepath F
.63333 .33445 -2.5 2.5 Mabsadd m
.63333 .33445 2.5 2.5 Mabsadd L
.63333 .33445 2.5 -2.5 Mabsadd L
.63333 .33445 -2.5 -2.5 Mabsadd L
.63333 .33445 -2.5 2.5 Mabsadd L closepath F
.63651 .33575 -2.5 2.5 Mabsadd m
.63651 .33575 2.5 2.5 Mabsadd L
.63651 .33575 2.5 -2.5 Mabsadd L
.63651 .33575 -2.5 -2.5 Mabsadd L
.63651 .33575 -2.5 2.5 Mabsadd L closepath F
.63968 .33706 -2.5 2.5 Mabsadd m
.63968 .33706 2.5 2.5 Mabsadd L
.63968 .33706 2.5 -2.5 Mabsadd L
.63968 .33706 -2.5 -2.5 Mabsadd L
.63968 .33706 -2.5 2.5 Mabsadd L closepath F
.64286 .33838 -2.5 2.5 Mabsadd m
.64286 .33838 2.5 2.5 Mabsadd L
.64286 .33838 2.5 -2.5 Mabsadd L
.64286 .33838 -2.5 -2.5 Mabsadd L
.64286 .33838 -2.5 2.5 Mabsadd L closepath F
.64603 .33972 -2.5 2.5 Mabsadd m
.64603 .33972 2.5 2.5 Mabsadd L
.64603 .33972 2.5 -2.5 Mabsadd L
.64603 .33972 -2.5 -2.5 Mabsadd L
.64603 .33972 -2.5 2.5 Mabsadd L closepath F
.64921 .34107 -2.5 2.5 Mabsadd m
.64921 .34107 2.5 2.5 Mabsadd L
.64921 .34107 2.5 -2.5 Mabsadd L
.64921 .34107 -2.5 -2.5 Mabsadd L
.64921 .34107 -2.5 2.5 Mabsadd L closepath F
.65238 .34243 -2.5 2.5 Mabsadd m
.65238 .34243 2.5 2.5 Mabsadd L
.65238 .34243 2.5 -2.5 Mabsadd L
.65238 .34243 -2.5 -2.5 Mabsadd L
.65238 .34243 -2.5 2.5 Mabsadd L closepath F
.65556 .34381 -2.5 2.5 Mabsadd m
.65556 .34381 2.5 2.5 Mabsadd L
.65556 .34381 2.5 -2.5 Mabsadd L
.65556 .34381 -2.5 -2.5 Mabsadd L
.65556 .34381 -2.5 2.5 Mabsadd L closepath F
.65873 .3452 -2.5 2.5 Mabsadd m
.65873 .3452 2.5 2.5 Mabsadd L
.65873 .3452 2.5 -2.5 Mabsadd L
.65873 .3452 -2.5 -2.5 Mabsadd L
.65873 .3452 -2.5 2.5 Mabsadd L closepath F
.6619 .34661 -2.5 2.5 Mabsadd m
.6619 .34661 2.5 2.5 Mabsadd L
.6619 .34661 2.5 -2.5 Mabsadd L
.6619 .34661 -2.5 -2.5 Mabsadd L
.6619 .34661 -2.5 2.5 Mabsadd L closepath F
.66508 .34802 -2.5 2.5 Mabsadd m
.66508 .34802 2.5 2.5 Mabsadd L
.66508 .34802 2.5 -2.5 Mabsadd L
.66508 .34802 -2.5 -2.5 Mabsadd L
.66508 .34802 -2.5 2.5 Mabsadd L closepath F
.66825 .34946 -2.5 2.5 Mabsadd m
.66825 .34946 2.5 2.5 Mabsadd L
.66825 .34946 2.5 -2.5 Mabsadd L
.66825 .34946 -2.5 -2.5 Mabsadd L
.66825 .34946 -2.5 2.5 Mabsadd L closepath F
.67143 .35091 -2.5 2.5 Mabsadd m
.67143 .35091 2.5 2.5 Mabsadd L
.67143 .35091 2.5 -2.5 Mabsadd L
.67143 .35091 -2.5 -2.5 Mabsadd L
.67143 .35091 -2.5 2.5 Mabsadd L closepath F
.6746 .35237 -2.5 2.5 Mabsadd m
.6746 .35237 2.5 2.5 Mabsadd L
.6746 .35237 2.5 -2.5 Mabsadd L
.6746 .35237 -2.5 -2.5 Mabsadd L
.6746 .35237 -2.5 2.5 Mabsadd L closepath F
.67778 .35384 -2.5 2.5 Mabsadd m
.67778 .35384 2.5 2.5 Mabsadd L
.67778 .35384 2.5 -2.5 Mabsadd L
.67778 .35384 -2.5 -2.5 Mabsadd L
.67778 .35384 -2.5 2.5 Mabsadd L closepath F
.68095 .35534 -2.5 2.5 Mabsadd m
.68095 .35534 2.5 2.5 Mabsadd L
.68095 .35534 2.5 -2.5 Mabsadd L
.68095 .35534 -2.5 -2.5 Mabsadd L
.68095 .35534 -2.5 2.5 Mabsadd L closepath F
.68413 .35684 -2.5 2.5 Mabsadd m
.68413 .35684 2.5 2.5 Mabsadd L
.68413 .35684 2.5 -2.5 Mabsadd L
.68413 .35684 -2.5 -2.5 Mabsadd L
.68413 .35684 -2.5 2.5 Mabsadd L closepath F
.6873 .35836 -2.5 2.5 Mabsadd m
.6873 .35836 2.5 2.5 Mabsadd L
.6873 .35836 2.5 -2.5 Mabsadd L
.6873 .35836 -2.5 -2.5 Mabsadd L
.6873 .35836 -2.5 2.5 Mabsadd L closepath F
.69048 .3599 -2.5 2.5 Mabsadd m
.69048 .3599 2.5 2.5 Mabsadd L
.69048 .3599 2.5 -2.5 Mabsadd L
.69048 .3599 -2.5 -2.5 Mabsadd L
.69048 .3599 -2.5 2.5 Mabsadd L closepath F
.69365 .36145 -2.5 2.5 Mabsadd m
.69365 .36145 2.5 2.5 Mabsadd L
.69365 .36145 2.5 -2.5 Mabsadd L
.69365 .36145 -2.5 -2.5 Mabsadd L
.69365 .36145 -2.5 2.5 Mabsadd L closepath F
.69683 .36302 -2.5 2.5 Mabsadd m
.69683 .36302 2.5 2.5 Mabsadd L
.69683 .36302 2.5 -2.5 Mabsadd L
.69683 .36302 -2.5 -2.5 Mabsadd L
.69683 .36302 -2.5 2.5 Mabsadd L closepath F
.7 .3646 -2.5 2.5 Mabsadd m
.7 .3646 2.5 2.5 Mabsadd L
.7 .3646 2.5 -2.5 Mabsadd L
.7 .3646 -2.5 -2.5 Mabsadd L
.7 .3646 -2.5 2.5 Mabsadd L closepath F
.70317 .3662 -2.5 2.5 Mabsadd m
.70317 .3662 2.5 2.5 Mabsadd L
.70317 .3662 2.5 -2.5 Mabsadd L
.70317 .3662 -2.5 -2.5 Mabsadd L
.70317 .3662 -2.5 2.5 Mabsadd L closepath F
.70635 .36782 -2.5 2.5 Mabsadd m
.70635 .36782 2.5 2.5 Mabsadd L
.70635 .36782 2.5 -2.5 Mabsadd L
.70635 .36782 -2.5 -2.5 Mabsadd L
.70635 .36782 -2.5 2.5 Mabsadd L closepath F
.70952 .36945 -2.5 2.5 Mabsadd m
.70952 .36945 2.5 2.5 Mabsadd L
.70952 .36945 2.5 -2.5 Mabsadd L
.70952 .36945 -2.5 -2.5 Mabsadd L
.70952 .36945 -2.5 2.5 Mabsadd L closepath F
.7127 .37109 -2.5 2.5 Mabsadd m
.7127 .37109 2.5 2.5 Mabsadd L
.7127 .37109 2.5 -2.5 Mabsadd L
.7127 .37109 -2.5 -2.5 Mabsadd L
.7127 .37109 -2.5 2.5 Mabsadd L closepath F
.71587 .37276 -2.5 2.5 Mabsadd m
.71587 .37276 2.5 2.5 Mabsadd L
.71587 .37276 2.5 -2.5 Mabsadd L
.71587 .37276 -2.5 -2.5 Mabsadd L
.71587 .37276 -2.5 2.5 Mabsadd L closepath F
.71905 .37444 -2.5 2.5 Mabsadd m
.71905 .37444 2.5 2.5 Mabsadd L
.71905 .37444 2.5 -2.5 Mabsadd L
.71905 .37444 -2.5 -2.5 Mabsadd L
.71905 .37444 -2.5 2.5 Mabsadd L closepath F
.72222 .37614 -2.5 2.5 Mabsadd m
.72222 .37614 2.5 2.5 Mabsadd L
.72222 .37614 2.5 -2.5 Mabsadd L
.72222 .37614 -2.5 -2.5 Mabsadd L
.72222 .37614 -2.5 2.5 Mabsadd L closepath F
.7254 .37785 -2.5 2.5 Mabsadd m
.7254 .37785 2.5 2.5 Mabsadd L
.7254 .37785 2.5 -2.5 Mabsadd L
.7254 .37785 -2.5 -2.5 Mabsadd L
.7254 .37785 -2.5 2.5 Mabsadd L closepath F
.72857 .37958 -2.5 2.5 Mabsadd m
.72857 .37958 2.5 2.5 Mabsadd L
.72857 .37958 2.5 -2.5 Mabsadd L
.72857 .37958 -2.5 -2.5 Mabsadd L
.72857 .37958 -2.5 2.5 Mabsadd L closepath F
.73175 .38133 -2.5 2.5 Mabsadd m
.73175 .38133 2.5 2.5 Mabsadd L
.73175 .38133 2.5 -2.5 Mabsadd L
.73175 .38133 -2.5 -2.5 Mabsadd L
.73175 .38133 -2.5 2.5 Mabsadd L closepath F
.73492 .3831 -2.5 2.5 Mabsadd m
.73492 .3831 2.5 2.5 Mabsadd L
.73492 .3831 2.5 -2.5 Mabsadd L
.73492 .3831 -2.5 -2.5 Mabsadd L
.73492 .3831 -2.5 2.5 Mabsadd L closepath F
.7381 .38488 -2.5 2.5 Mabsadd m
.7381 .38488 2.5 2.5 Mabsadd L
.7381 .38488 2.5 -2.5 Mabsadd L
.7381 .38488 -2.5 -2.5 Mabsadd L
.7381 .38488 -2.5 2.5 Mabsadd L closepath F
.74127 .38668 -2.5 2.5 Mabsadd m
.74127 .38668 2.5 2.5 Mabsadd L
.74127 .38668 2.5 -2.5 Mabsadd L
.74127 .38668 -2.5 -2.5 Mabsadd L
.74127 .38668 -2.5 2.5 Mabsadd L closepath F
.74444 .3885 -2.5 2.5 Mabsadd m
.74444 .3885 2.5 2.5 Mabsadd L
.74444 .3885 2.5 -2.5 Mabsadd L
.74444 .3885 -2.5 -2.5 Mabsadd L
.74444 .3885 -2.5 2.5 Mabsadd L closepath F
.74762 .39034 -2.5 2.5 Mabsadd m
.74762 .39034 2.5 2.5 Mabsadd L
.74762 .39034 2.5 -2.5 Mabsadd L
.74762 .39034 -2.5 -2.5 Mabsadd L
.74762 .39034 -2.5 2.5 Mabsadd L closepath F
.75079 .39219 -2.5 2.5 Mabsadd m
.75079 .39219 2.5 2.5 Mabsadd L
.75079 .39219 2.5 -2.5 Mabsadd L
.75079 .39219 -2.5 -2.5 Mabsadd L
.75079 .39219 -2.5 2.5 Mabsadd L closepath F
.75397 .39407 -2.5 2.5 Mabsadd m
.75397 .39407 2.5 2.5 Mabsadd L
.75397 .39407 2.5 -2.5 Mabsadd L
.75397 .39407 -2.5 -2.5 Mabsadd L
.75397 .39407 -2.5 2.5 Mabsadd L closepath F
.75714 .39596 -2.5 2.5 Mabsadd m
.75714 .39596 2.5 2.5 Mabsadd L
.75714 .39596 2.5 -2.5 Mabsadd L
.75714 .39596 -2.5 -2.5 Mabsadd L
.75714 .39596 -2.5 2.5 Mabsadd L closepath F
.76032 .39788 -2.5 2.5 Mabsadd m
.76032 .39788 2.5 2.5 Mabsadd L
.76032 .39788 2.5 -2.5 Mabsadd L
.76032 .39788 -2.5 -2.5 Mabsadd L
.76032 .39788 -2.5 2.5 Mabsadd L closepath F
.76349 .39981 -2.5 2.5 Mabsadd m
.76349 .39981 2.5 2.5 Mabsadd L
.76349 .39981 2.5 -2.5 Mabsadd L
.76349 .39981 -2.5 -2.5 Mabsadd L
.76349 .39981 -2.5 2.5 Mabsadd L closepath F
.76667 .40176 -2.5 2.5 Mabsadd m
.76667 .40176 2.5 2.5 Mabsadd L
.76667 .40176 2.5 -2.5 Mabsadd L
.76667 .40176 -2.5 -2.5 Mabsadd L
.76667 .40176 -2.5 2.5 Mabsadd L closepath F
.76984 .40373 -2.5 2.5 Mabsadd m
.76984 .40373 2.5 2.5 Mabsadd L
.76984 .40373 2.5 -2.5 Mabsadd L
.76984 .40373 -2.5 -2.5 Mabsadd L
.76984 .40373 -2.5 2.5 Mabsadd L closepath F
.77302 .40572 -2.5 2.5 Mabsadd m
.77302 .40572 2.5 2.5 Mabsadd L
.77302 .40572 2.5 -2.5 Mabsadd L
.77302 .40572 -2.5 -2.5 Mabsadd L
.77302 .40572 -2.5 2.5 Mabsadd L closepath F
.77619 .40773 -2.5 2.5 Mabsadd m
.77619 .40773 2.5 2.5 Mabsadd L
.77619 .40773 2.5 -2.5 Mabsadd L
.77619 .40773 -2.5 -2.5 Mabsadd L
.77619 .40773 -2.5 2.5 Mabsadd L closepath F
.77937 .40976 -2.5 2.5 Mabsadd m
.77937 .40976 2.5 2.5 Mabsadd L
.77937 .40976 2.5 -2.5 Mabsadd L
.77937 .40976 -2.5 -2.5 Mabsadd L
.77937 .40976 -2.5 2.5 Mabsadd L closepath F
.78254 .41181 -2.5 2.5 Mabsadd m
.78254 .41181 2.5 2.5 Mabsadd L
.78254 .41181 2.5 -2.5 Mabsadd L
.78254 .41181 -2.5 -2.5 Mabsadd L
.78254 .41181 -2.5 2.5 Mabsadd L closepath F
.78571 .41388 -2.5 2.5 Mabsadd m
.78571 .41388 2.5 2.5 Mabsadd L
.78571 .41388 2.5 -2.5 Mabsadd L
.78571 .41388 -2.5 -2.5 Mabsadd L
.78571 .41388 -2.5 2.5 Mabsadd L closepath F
.78889 .41597 -2.5 2.5 Mabsadd m
.78889 .41597 2.5 2.5 Mabsadd L
.78889 .41597 2.5 -2.5 Mabsadd L
.78889 .41597 -2.5 -2.5 Mabsadd L
.78889 .41597 -2.5 2.5 Mabsadd L closepath F
.79206 .41808 -2.5 2.5 Mabsadd m
.79206 .41808 2.5 2.5 Mabsadd L
.79206 .41808 2.5 -2.5 Mabsadd L
.79206 .41808 -2.5 -2.5 Mabsadd L
.79206 .41808 -2.5 2.5 Mabsadd L closepath F
.79524 .42022 -2.5 2.5 Mabsadd m
.79524 .42022 2.5 2.5 Mabsadd L
.79524 .42022 2.5 -2.5 Mabsadd L
.79524 .42022 -2.5 -2.5 Mabsadd L
.79524 .42022 -2.5 2.5 Mabsadd L closepath F
.79841 .42237 -2.5 2.5 Mabsadd m
.79841 .42237 2.5 2.5 Mabsadd L
.79841 .42237 2.5 -2.5 Mabsadd L
.79841 .42237 -2.5 -2.5 Mabsadd L
.79841 .42237 -2.5 2.5 Mabsadd L closepath F
.80159 .42455 -2.5 2.5 Mabsadd m
.80159 .42455 2.5 2.5 Mabsadd L
.80159 .42455 2.5 -2.5 Mabsadd L
.80159 .42455 -2.5 -2.5 Mabsadd L
.80159 .42455 -2.5 2.5 Mabsadd L closepath F
.80476 .42675 -2.5 2.5 Mabsadd m
.80476 .42675 2.5 2.5 Mabsadd L
.80476 .42675 2.5 -2.5 Mabsadd L
.80476 .42675 -2.5 -2.5 Mabsadd L
.80476 .42675 -2.5 2.5 Mabsadd L closepath F
.80794 .42897 -2.5 2.5 Mabsadd m
.80794 .42897 2.5 2.5 Mabsadd L
.80794 .42897 2.5 -2.5 Mabsadd L
.80794 .42897 -2.5 -2.5 Mabsadd L
.80794 .42897 -2.5 2.5 Mabsadd L closepath F
.81111 .43121 -2.5 2.5 Mabsadd m
.81111 .43121 2.5 2.5 Mabsadd L
.81111 .43121 2.5 -2.5 Mabsadd L
.81111 .43121 -2.5 -2.5 Mabsadd L
.81111 .43121 -2.5 2.5 Mabsadd L closepath F
.81429 .43348 -2.5 2.5 Mabsadd m
.81429 .43348 2.5 2.5 Mabsadd L
.81429 .43348 2.5 -2.5 Mabsadd L
.81429 .43348 -2.5 -2.5 Mabsadd L
.81429 .43348 -2.5 2.5 Mabsadd L closepath F
.81746 .43576 -2.5 2.5 Mabsadd m
.81746 .43576 2.5 2.5 Mabsadd L
.81746 .43576 2.5 -2.5 Mabsadd L
.81746 .43576 -2.5 -2.5 Mabsadd L
.81746 .43576 -2.5 2.5 Mabsadd L closepath F
.82063 .43807 -2.5 2.5 Mabsadd m
.82063 .43807 2.5 2.5 Mabsadd L
.82063 .43807 2.5 -2.5 Mabsadd L
.82063 .43807 -2.5 -2.5 Mabsadd L
.82063 .43807 -2.5 2.5 Mabsadd L closepath F
.82381 .44041 -2.5 2.5 Mabsadd m
.82381 .44041 2.5 2.5 Mabsadd L
.82381 .44041 2.5 -2.5 Mabsadd L
.82381 .44041 -2.5 -2.5 Mabsadd L
.82381 .44041 -2.5 2.5 Mabsadd L closepath F
.82698 .44277 -2.5 2.5 Mabsadd m
.82698 .44277 2.5 2.5 Mabsadd L
.82698 .44277 2.5 -2.5 Mabsadd L
.82698 .44277 -2.5 -2.5 Mabsadd L
.82698 .44277 -2.5 2.5 Mabsadd L closepath F
.83016 .44515 -2.5 2.5 Mabsadd m
.83016 .44515 2.5 2.5 Mabsadd L
.83016 .44515 2.5 -2.5 Mabsadd L
.83016 .44515 -2.5 -2.5 Mabsadd L
.83016 .44515 -2.5 2.5 Mabsadd L closepath F
.83333 .44755 -2.5 2.5 Mabsadd m
.83333 .44755 2.5 2.5 Mabsadd L
.83333 .44755 2.5 -2.5 Mabsadd L
.83333 .44755 -2.5 -2.5 Mabsadd L
.83333 .44755 -2.5 2.5 Mabsadd L closepath F
.83651 .44998 -2.5 2.5 Mabsadd m
.83651 .44998 2.5 2.5 Mabsadd L
.83651 .44998 2.5 -2.5 Mabsadd L
.83651 .44998 -2.5 -2.5 Mabsadd L
.83651 .44998 -2.5 2.5 Mabsadd L closepath F
.83968 .45243 -2.5 2.5 Mabsadd m
.83968 .45243 2.5 2.5 Mabsadd L
.83968 .45243 2.5 -2.5 Mabsadd L
.83968 .45243 -2.5 -2.5 Mabsadd L
.83968 .45243 -2.5 2.5 Mabsadd L closepath F
.84286 .45491 -2.5 2.5 Mabsadd m
.84286 .45491 2.5 2.5 Mabsadd L
.84286 .45491 2.5 -2.5 Mabsadd L
.84286 .45491 -2.5 -2.5 Mabsadd L
.84286 .45491 -2.5 2.5 Mabsadd L closepath F
.84603 .45741 -2.5 2.5 Mabsadd m
.84603 .45741 2.5 2.5 Mabsadd L
.84603 .45741 2.5 -2.5 Mabsadd L
.84603 .45741 -2.5 -2.5 Mabsadd L
.84603 .45741 -2.5 2.5 Mabsadd L closepath F
.84921 .45994 -2.5 2.5 Mabsadd m
.84921 .45994 2.5 2.5 Mabsadd L
.84921 .45994 2.5 -2.5 Mabsadd L
.84921 .45994 -2.5 -2.5 Mabsadd L
.84921 .45994 -2.5 2.5 Mabsadd L closepath F
.85238 .46249 -2.5 2.5 Mabsadd m
.85238 .46249 2.5 2.5 Mabsadd L
.85238 .46249 2.5 -2.5 Mabsadd L
.85238 .46249 -2.5 -2.5 Mabsadd L
.85238 .46249 -2.5 2.5 Mabsadd L closepath F
.85556 .46507 -2.5 2.5 Mabsadd m
.85556 .46507 2.5 2.5 Mabsadd L
.85556 .46507 2.5 -2.5 Mabsadd L
.85556 .46507 -2.5 -2.5 Mabsadd L
.85556 .46507 -2.5 2.5 Mabsadd L closepath F
.85873 .46767 -2.5 2.5 Mabsadd m
.85873 .46767 2.5 2.5 Mabsadd L
.85873 .46767 2.5 -2.5 Mabsadd L
.85873 .46767 -2.5 -2.5 Mabsadd L
.85873 .46767 -2.5 2.5 Mabsadd L closepath F
.8619 .4703 -2.5 2.5 Mabsadd m
.8619 .4703 2.5 2.5 Mabsadd L
.8619 .4703 2.5 -2.5 Mabsadd L
.8619 .4703 -2.5 -2.5 Mabsadd L
.8619 .4703 -2.5 2.5 Mabsadd L closepath F
.86508 .47296 -2.5 2.5 Mabsadd m
.86508 .47296 2.5 2.5 Mabsadd L
.86508 .47296 2.5 -2.5 Mabsadd L
.86508 .47296 -2.5 -2.5 Mabsadd L
.86508 .47296 -2.5 2.5 Mabsadd L closepath F
.86825 .47564 -2.5 2.5 Mabsadd m
.86825 .47564 2.5 2.5 Mabsadd L
.86825 .47564 2.5 -2.5 Mabsadd L
.86825 .47564 -2.5 -2.5 Mabsadd L
.86825 .47564 -2.5 2.5 Mabsadd L closepath F
.87143 .47835 -2.5 2.5 Mabsadd m
.87143 .47835 2.5 2.5 Mabsadd L
.87143 .47835 2.5 -2.5 Mabsadd L
.87143 .47835 -2.5 -2.5 Mabsadd L
.87143 .47835 -2.5 2.5 Mabsadd L closepath F
.8746 .48108 -2.5 2.5 Mabsadd m
.8746 .48108 2.5 2.5 Mabsadd L
.8746 .48108 2.5 -2.5 Mabsadd L
.8746 .48108 -2.5 -2.5 Mabsadd L
.8746 .48108 -2.5 2.5 Mabsadd L closepath F
.87778 .48385 -2.5 2.5 Mabsadd m
.87778 .48385 2.5 2.5 Mabsadd L
.87778 .48385 2.5 -2.5 Mabsadd L
.87778 .48385 -2.5 -2.5 Mabsadd L
.87778 .48385 -2.5 2.5 Mabsadd L closepath F
.88095 .48664 -2.5 2.5 Mabsadd m
.88095 .48664 2.5 2.5 Mabsadd L
.88095 .48664 2.5 -2.5 Mabsadd L
.88095 .48664 -2.5 -2.5 Mabsadd L
.88095 .48664 -2.5 2.5 Mabsadd L closepath F
.88413 .48946 -2.5 2.5 Mabsadd m
.88413 .48946 2.5 2.5 Mabsadd L
.88413 .48946 2.5 -2.5 Mabsadd L
.88413 .48946 -2.5 -2.5 Mabsadd L
.88413 .48946 -2.5 2.5 Mabsadd L closepath F
.8873 .49231 -2.5 2.5 Mabsadd m
.8873 .49231 2.5 2.5 Mabsadd L
.8873 .49231 2.5 -2.5 Mabsadd L
.8873 .49231 -2.5 -2.5 Mabsadd L
.8873 .49231 -2.5 2.5 Mabsadd L closepath F
.89048 .49518 -2.5 2.5 Mabsadd m
.89048 .49518 2.5 2.5 Mabsadd L
.89048 .49518 2.5 -2.5 Mabsadd L
.89048 .49518 -2.5 -2.5 Mabsadd L
.89048 .49518 -2.5 2.5 Mabsadd L closepath F
.89365 .49809 -2.5 2.5 Mabsadd m
.89365 .49809 2.5 2.5 Mabsadd L
.89365 .49809 2.5 -2.5 Mabsadd L
.89365 .49809 -2.5 -2.5 Mabsadd L
.89365 .49809 -2.5 2.5 Mabsadd L closepath F
.89683 .50102 -2.5 2.5 Mabsadd m
.89683 .50102 2.5 2.5 Mabsadd L
.89683 .50102 2.5 -2.5 Mabsadd L
.89683 .50102 -2.5 -2.5 Mabsadd L
.89683 .50102 -2.5 2.5 Mabsadd L closepath F
.9 .50398 -2.5 2.5 Mabsadd m
.9 .50398 2.5 2.5 Mabsadd L
.9 .50398 2.5 -2.5 Mabsadd L
.9 .50398 -2.5 -2.5 Mabsadd L
.9 .50398 -2.5 2.5 Mabsadd L closepath F
.90317 .50698 -2.5 2.5 Mabsadd m
.90317 .50698 2.5 2.5 Mabsadd L
.90317 .50698 2.5 -2.5 Mabsadd L
.90317 .50698 -2.5 -2.5 Mabsadd L
.90317 .50698 -2.5 2.5 Mabsadd L closepath F
.90635 .51 -2.5 2.5 Mabsadd m
.90635 .51 2.5 2.5 Mabsadd L
.90635 .51 2.5 -2.5 Mabsadd L
.90635 .51 -2.5 -2.5 Mabsadd L
.90635 .51 -2.5 2.5 Mabsadd L closepath F
.90952 .51305 -2.5 2.5 Mabsadd m
.90952 .51305 2.5 2.5 Mabsadd L
.90952 .51305 2.5 -2.5 Mabsadd L
.90952 .51305 -2.5 -2.5 Mabsadd L
.90952 .51305 -2.5 2.5 Mabsadd L closepath F
.9127 .51614 -2.5 2.5 Mabsadd m
.9127 .51614 2.5 2.5 Mabsadd L
.9127 .51614 2.5 -2.5 Mabsadd L
.9127 .51614 -2.5 -2.5 Mabsadd L
.9127 .51614 -2.5 2.5 Mabsadd L closepath F
.91587 .51925 -2.5 2.5 Mabsadd m
.91587 .51925 2.5 2.5 Mabsadd L
.91587 .51925 2.5 -2.5 Mabsadd L
.91587 .51925 -2.5 -2.5 Mabsadd L
.91587 .51925 -2.5 2.5 Mabsadd L closepath F
.91905 .52239 -2.5 2.5 Mabsadd m
.91905 .52239 2.5 2.5 Mabsadd L
.91905 .52239 2.5 -2.5 Mabsadd L
.91905 .52239 -2.5 -2.5 Mabsadd L
.91905 .52239 -2.5 2.5 Mabsadd L closepath F
.92222 .52557 -2.5 2.5 Mabsadd m
.92222 .52557 2.5 2.5 Mabsadd L
.92222 .52557 2.5 -2.5 Mabsadd L
.92222 .52557 -2.5 -2.5 Mabsadd L
.92222 .52557 -2.5 2.5 Mabsadd L closepath F
.9254 .52878 -2.5 2.5 Mabsadd m
.9254 .52878 2.5 2.5 Mabsadd L
.9254 .52878 2.5 -2.5 Mabsadd L
.9254 .52878 -2.5 -2.5 Mabsadd L
.9254 .52878 -2.5 2.5 Mabsadd L closepath F
.92857 .53202 -2.5 2.5 Mabsadd m
.92857 .53202 2.5 2.5 Mabsadd L
.92857 .53202 2.5 -2.5 Mabsadd L
.92857 .53202 -2.5 -2.5 Mabsadd L
.92857 .53202 -2.5 2.5 Mabsadd L closepath F
.93175 .53529 -2.5 2.5 Mabsadd m
.93175 .53529 2.5 2.5 Mabsadd L
.93175 .53529 2.5 -2.5 Mabsadd L
.93175 .53529 -2.5 -2.5 Mabsadd L
.93175 .53529 -2.5 2.5 Mabsadd L closepath F
.93492 .5386 -2.5 2.5 Mabsadd m
.93492 .5386 2.5 2.5 Mabsadd L
.93492 .5386 2.5 -2.5 Mabsadd L
.93492 .5386 -2.5 -2.5 Mabsadd L
.93492 .5386 -2.5 2.5 Mabsadd L closepath F
.9381 .54194 -2.5 2.5 Mabsadd m
.9381 .54194 2.5 2.5 Mabsadd L
.9381 .54194 2.5 -2.5 Mabsadd L
.9381 .54194 -2.5 -2.5 Mabsadd L
.9381 .54194 -2.5 2.5 Mabsadd L closepath F
.94127 .54531 -2.5 2.5 Mabsadd m
.94127 .54531 2.5 2.5 Mabsadd L
.94127 .54531 2.5 -2.5 Mabsadd L
.94127 .54531 -2.5 -2.5 Mabsadd L
.94127 .54531 -2.5 2.5 Mabsadd L closepath F
.94444 .54872 -2.5 2.5 Mabsadd m
.94444 .54872 2.5 2.5 Mabsadd L
.94444 .54872 2.5 -2.5 Mabsadd L
.94444 .54872 -2.5 -2.5 Mabsadd L
.94444 .54872 -2.5 2.5 Mabsadd L closepath F
.94762 .55216 -2.5 2.5 Mabsadd m
.94762 .55216 2.5 2.5 Mabsadd L
.94762 .55216 2.5 -2.5 Mabsadd L
.94762 .55216 -2.5 -2.5 Mabsadd L
.94762 .55216 -2.5 2.5 Mabsadd L closepath F
.95079 .55563 -2.5 2.5 Mabsadd m
.95079 .55563 2.5 2.5 Mabsadd L
.95079 .55563 2.5 -2.5 Mabsadd L
.95079 .55563 -2.5 -2.5 Mabsadd L
.95079 .55563 -2.5 2.5 Mabsadd L closepath F
.95397 .55914 -2.5 2.5 Mabsadd m
.95397 .55914 2.5 2.5 Mabsadd L
.95397 .55914 2.5 -2.5 Mabsadd L
.95397 .55914 -2.5 -2.5 Mabsadd L
.95397 .55914 -2.5 2.5 Mabsadd L closepath F
.95714 .56268 -2.5 2.5 Mabsadd m
.95714 .56268 2.5 2.5 Mabsadd L
.95714 .56268 2.5 -2.5 Mabsadd L
.95714 .56268 -2.5 -2.5 Mabsadd L
.95714 .56268 -2.5 2.5 Mabsadd L closepath F
.96032 .56626 -2.5 2.5 Mabsadd m
.96032 .56626 2.5 2.5 Mabsadd L
.96032 .56626 2.5 -2.5 Mabsadd L
.96032 .56626 -2.5 -2.5 Mabsadd L
.96032 .56626 -2.5 2.5 Mabsadd L closepath F
.96349 .56988 -2.5 2.5 Mabsadd m
.96349 .56988 2.5 2.5 Mabsadd L
.96349 .56988 2.5 -2.5 Mabsadd L
.96349 .56988 -2.5 -2.5 Mabsadd L
.96349 .56988 -2.5 2.5 Mabsadd L closepath F
.96667 .57353 -2.5 2.5 Mabsadd m
.96667 .57353 2.5 2.5 Mabsadd L
.96667 .57353 2.5 -2.5 Mabsadd L
.96667 .57353 -2.5 -2.5 Mabsadd L
.96667 .57353 -2.5 2.5 Mabsadd L closepath F
.96984 .57722 -2.5 2.5 Mabsadd m
.96984 .57722 2.5 2.5 Mabsadd L
.96984 .57722 2.5 -2.5 Mabsadd L
.96984 .57722 -2.5 -2.5 Mabsadd L
.96984 .57722 -2.5 2.5 Mabsadd L closepath F
.97302 .58095 -2.5 2.5 Mabsadd m
.97302 .58095 2.5 2.5 Mabsadd L
.97302 .58095 2.5 -2.5 Mabsadd L
.97302 .58095 -2.5 -2.5 Mabsadd L
.97302 .58095 -2.5 2.5 Mabsadd L closepath F
.97619 .58471 -2.5 2.5 Mabsadd m
.97619 .58471 2.5 2.5 Mabsadd L
.97619 .58471 2.5 -2.5 Mabsadd L
.97619 .58471 -2.5 -2.5 Mabsadd L
.97619 .58471 -2.5 2.5 Mabsadd L closepath F
.0075 w
.02698 .2338 m
.03016 .2341 L
.03333 .23439 L
.03651 .23469 L
.03968 .23499 L
.04286 .23529 L
.04603 .23559 L
.04921 .2359 L
.05238 .23622 L
.05556 .23653 L
.05873 .23685 L
.0619 .23717 L
.06508 .23749 L
.06825 .23782 L
.07143 .23815 L
.0746 .23849 L
.07778 .23883 L
.08095 .23917 L
.08413 .23951 L
.0873 .23986 L
.09048 .24021 L
.09365 .24057 L
.09683 .24092 L
.1 .24129 L
.10317 .24165 L
.10635 .24202 L
.10952 .24239 L
.1127 .24277 L
.11587 .24315 L
.11905 .24354 L
.12222 .24392 L
.1254 .24432 L
.12857 .24471 L
.13175 .24511 L
.13492 .24552 L
.1381 .24592 L
.14127 .24634 L
.14444 .24675 L
.14762 .24717 L
.15079 .2476 L
.15397 .24803 L
.15714 .24846 L
.16032 .2489 L
.16349 .24934 L
.16667 .24979 L
.16984 .25024 L
.17302 .25069 L
.17619 .25115 L
.17937 .25162 L
.18254 .25208 L
Mistroke
.18571 .25256 L
.18889 .25304 L
.19206 .25352 L
.19524 .25401 L
.19841 .2545 L
.20159 .255 L
.20476 .2555 L
.20794 .25601 L
.21111 .25652 L
.21429 .25704 L
.21746 .25756 L
.22063 .25809 L
.22381 .25863 L
.22698 .25917 L
.23016 .25971 L
.23333 .26026 L
.23651 .26082 L
.23968 .26138 L
.24286 .26194 L
.24603 .26252 L
.24921 .26309 L
.25238 .26368 L
.25556 .26427 L
.25873 .26486 L
.2619 .26546 L
.26508 .26607 L
.26825 .26669 L
.27143 .26731 L
.2746 .26793 L
.27778 .26856 L
.28095 .2692 L
.28413 .26985 L
.2873 .2705 L
.29048 .27116 L
.29365 .27182 L
.29683 .27249 L
.3 .27317 L
.30317 .27385 L
.30635 .27455 L
.30952 .27524 L
.3127 .27595 L
.31587 .27666 L
.31905 .27738 L
.32222 .27811 L
.3254 .27884 L
.32857 .27958 L
.33175 .28033 L
.33492 .28109 L
.3381 .28185 L
.34127 .28262 L
Mistroke
.34444 .2834 L
.34762 .28419 L
.35079 .28498 L
.35397 .28579 L
.35714 .2866 L
.36032 .28742 L
.36349 .28824 L
.36667 .28908 L
.36984 .28992 L
.37302 .29077 L
.37619 .29163 L
.37937 .2925 L
.38254 .29338 L
.38571 .29427 L
.38889 .29516 L
.39206 .29607 L
.39524 .29698 L
.39841 .2979 L
.40159 .29884 L
.40476 .29978 L
.40794 .30073 L
.41111 .30169 L
.41429 .30266 L
.41746 .30364 L
.42063 .30463 L
.42381 .30563 L
.42698 .30664 L
.43016 .30765 L
.43333 .30868 L
.43651 .30972 L
.43968 .31077 L
.44286 .31183 L
.44603 .31291 L
.44921 .31399 L
.45238 .31508 L
.45556 .31618 L
.45873 .3173 L
.4619 .31842 L
.46508 .31956 L
.46825 .32071 L
.47143 .32187 L
.4746 .32304 L
.47778 .32423 L
.48095 .32542 L
.48413 .32663 L
.4873 .32785 L
.49048 .32908 L
.49365 .33032 L
.49683 .33158 L
.5 .33285 L
Mistroke
.50317 .33413 L
.50635 .33542 L
.50952 .33673 L
.5127 .33805 L
.51587 .33938 L
.51905 .34073 L
.52222 .34209 L
.5254 .34346 L
.52857 .34485 L
.53175 .34625 L
.53492 .34767 L
.5381 .3491 L
.54127 .35054 L
.54444 .352 L
.54762 .35347 L
.55079 .35496 L
.55397 .35646 L
.55714 .35798 L
.56032 .35951 L
.56349 .36106 L
.56667 .36262 L
.56984 .3642 L
.57302 .3658 L
.57619 .36741 L
.57937 .36904 L
.58254 .37068 L
.58571 .37234 L
.58889 .37401 L
.59206 .37571 L
.59524 .37742 L
.59841 .37914 L
.60159 .38089 L
.60476 .38265 L
.60794 .38443 L
.61111 .38623 L
.61429 .38804 L
.61746 .38988 L
.62063 .39173 L
.62381 .3936 L
.62698 .39549 L
.63016 .39739 L
.63333 .39932 L
.63651 .40127 L
.63968 .40323 L
.64286 .40522 L
.64603 .40722 L
.64921 .40925 L
.65238 .41129 L
.65556 .41336 L
.65873 .41545 L
Mistroke
.6619 .41755 L
.66508 .41968 L
.66825 .42183 L
.67143 .424 L
.6746 .42619 L
.67778 .42841 L
.68095 .43065 L
.68413 .43291 L
.6873 .43519 L
.69048 .43749 L
.69365 .43982 L
.69683 .44217 L
.7 .44455 L
.70317 .44694 L
.70635 .44937 L
.70952 .45181 L
.7127 .45428 L
.71587 .45678 L
.71905 .4593 L
.72222 .46185 L
.7254 .46442 L
.72857 .46701 L
.73175 .46964 L
.73492 .47229 L
.7381 .47496 L
.74127 .47767 L
.74444 .48039 L
.74762 .48315 L
.75079 .48594 L
.75397 .48875 L
.75714 .49159 L
.76032 .49446 L
.76349 .49735 L
.76667 .50028 L
.76984 .50324 L
.77302 .50622 L
.77619 .50924 L
.77937 .51228 L
.78254 .51536 L
.78571 .51846 L
.78889 .5216 L
.79206 .52477 L
.79524 .52797 L
.79841 .5312 L
.80159 .53447 L
.80476 .53777 L
.80794 .5411 L
.81111 .54446 L
.81429 .54786 L
.81746 .55129 L
Mistroke
.82063 .55476 L
.82381 .55826 L
.82698 .56179 L
.83016 .56536 L
.83333 .56897 L
.83651 .57261 L
.83968 .57629 L
.84286 .58001 L
.84603 .58376 L
.84921 .58755 L
.85238 .59138 L
.85556 .59524 L
.85873 .59915 L
.8619 .60309 L
.86508 .60708 L
.86825 .6111 L
.87143 .61517 L
Mfstroke
.87143 .61517 m
.87365 .61803 L
s
.0001 w
.02698 .2338 0 2.5 Mabsadd m
.02698 .2338 -2.165 -1.25 Mabsadd L
.02698 .2338 2.165 -1.25 Mabsadd L
.02698 .2338 0 2.5 Mabsadd L closepath F
.03016 .2341 0 2.5 Mabsadd m
.03016 .2341 -2.165 -1.25 Mabsadd L
.03016 .2341 2.165 -1.25 Mabsadd L
.03016 .2341 0 2.5 Mabsadd L closepath F
.03333 .23439 0 2.5 Mabsadd m
.03333 .23439 -2.165 -1.25 Mabsadd L
.03333 .23439 2.165 -1.25 Mabsadd L
.03333 .23439 0 2.5 Mabsadd L closepath F
.03651 .23469 0 2.5 Mabsadd m
.03651 .23469 -2.165 -1.25 Mabsadd L
.03651 .23469 2.165 -1.25 Mabsadd L
.03651 .23469 0 2.5 Mabsadd L closepath F
.03968 .23499 0 2.5 Mabsadd m
.03968 .23499 -2.165 -1.25 Mabsadd L
.03968 .23499 2.165 -1.25 Mabsadd L
.03968 .23499 0 2.5 Mabsadd L closepath F
.04286 .23529 0 2.5 Mabsadd m
.04286 .23529 -2.165 -1.25 Mabsadd L
.04286 .23529 2.165 -1.25 Mabsadd L
.04286 .23529 0 2.5 Mabsadd L closepath F
.04603 .23559 0 2.5 Mabsadd m
.04603 .23559 -2.165 -1.25 Mabsadd L
.04603 .23559 2.165 -1.25 Mabsadd L
.04603 .23559 0 2.5 Mabsadd L closepath F
.04921 .2359 0 2.5 Mabsadd m
.04921 .2359 -2.165 -1.25 Mabsadd L
.04921 .2359 2.165 -1.25 Mabsadd L
.04921 .2359 0 2.5 Mabsadd L closepath F
.05238 .23622 0 2.5 Mabsadd m
.05238 .23622 -2.165 -1.25 Mabsadd L
.05238 .23622 2.165 -1.25 Mabsadd L
.05238 .23622 0 2.5 Mabsadd L closepath F
.05556 .23653 0 2.5 Mabsadd m
.05556 .23653 -2.165 -1.25 Mabsadd L
.05556 .23653 2.165 -1.25 Mabsadd L
.05556 .23653 0 2.5 Mabsadd L closepath F
.05873 .23685 0 2.5 Mabsadd m
.05873 .23685 -2.165 -1.25 Mabsadd L
.05873 .23685 2.165 -1.25 Mabsadd L
.05873 .23685 0 2.5 Mabsadd L closepath F
.0619 .23717 0 2.5 Mabsadd m
.0619 .23717 -2.165 -1.25 Mabsadd L
.0619 .23717 2.165 -1.25 Mabsadd L
.0619 .23717 0 2.5 Mabsadd L closepath F
.06508 .23749 0 2.5 Mabsadd m
.06508 .23749 -2.165 -1.25 Mabsadd L
.06508 .23749 2.165 -1.25 Mabsadd L
.06508 .23749 0 2.5 Mabsadd L closepath F
.06825 .23782 0 2.5 Mabsadd m
.06825 .23782 -2.165 -1.25 Mabsadd L
.06825 .23782 2.165 -1.25 Mabsadd L
.06825 .23782 0 2.5 Mabsadd L closepath F
.07143 .23815 0 2.5 Mabsadd m
.07143 .23815 -2.165 -1.25 Mabsadd L
.07143 .23815 2.165 -1.25 Mabsadd L
.07143 .23815 0 2.5 Mabsadd L closepath F
.0746 .23849 0 2.5 Mabsadd m
.0746 .23849 -2.165 -1.25 Mabsadd L
.0746 .23849 2.165 -1.25 Mabsadd L
.0746 .23849 0 2.5 Mabsadd L closepath F
.07778 .23883 0 2.5 Mabsadd m
.07778 .23883 -2.165 -1.25 Mabsadd L
.07778 .23883 2.165 -1.25 Mabsadd L
.07778 .23883 0 2.5 Mabsadd L closepath F
.08095 .23917 0 2.5 Mabsadd m
.08095 .23917 -2.165 -1.25 Mabsadd L
.08095 .23917 2.165 -1.25 Mabsadd L
.08095 .23917 0 2.5 Mabsadd L closepath F
.08413 .23951 0 2.5 Mabsadd m
.08413 .23951 -2.165 -1.25 Mabsadd L
.08413 .23951 2.165 -1.25 Mabsadd L
.08413 .23951 0 2.5 Mabsadd L closepath F
.0873 .23986 0 2.5 Mabsadd m
.0873 .23986 -2.165 -1.25 Mabsadd L
.0873 .23986 2.165 -1.25 Mabsadd L
.0873 .23986 0 2.5 Mabsadd L closepath F
.09048 .24021 0 2.5 Mabsadd m
.09048 .24021 -2.165 -1.25 Mabsadd L
.09048 .24021 2.165 -1.25 Mabsadd L
.09048 .24021 0 2.5 Mabsadd L closepath F
.09365 .24057 0 2.5 Mabsadd m
.09365 .24057 -2.165 -1.25 Mabsadd L
.09365 .24057 2.165 -1.25 Mabsadd L
.09365 .24057 0 2.5 Mabsadd L closepath F
.09683 .24092 0 2.5 Mabsadd m
.09683 .24092 -2.165 -1.25 Mabsadd L
.09683 .24092 2.165 -1.25 Mabsadd L
.09683 .24092 0 2.5 Mabsadd L closepath F
.1 .24129 0 2.5 Mabsadd m
.1 .24129 -2.165 -1.25 Mabsadd L
.1 .24129 2.165 -1.25 Mabsadd L
.1 .24129 0 2.5 Mabsadd L closepath F
.10317 .24165 0 2.5 Mabsadd m
.10317 .24165 -2.165 -1.25 Mabsadd L
.10317 .24165 2.165 -1.25 Mabsadd L
.10317 .24165 0 2.5 Mabsadd L closepath F
.10635 .24202 0 2.5 Mabsadd m
.10635 .24202 -2.165 -1.25 Mabsadd L
.10635 .24202 2.165 -1.25 Mabsadd L
.10635 .24202 0 2.5 Mabsadd L closepath F
.10952 .24239 0 2.5 Mabsadd m
.10952 .24239 -2.165 -1.25 Mabsadd L
.10952 .24239 2.165 -1.25 Mabsadd L
.10952 .24239 0 2.5 Mabsadd L closepath F
.1127 .24277 0 2.5 Mabsadd m
.1127 .24277 -2.165 -1.25 Mabsadd L
.1127 .24277 2.165 -1.25 Mabsadd L
.1127 .24277 0 2.5 Mabsadd L closepath F
.11587 .24315 0 2.5 Mabsadd m
.11587 .24315 -2.165 -1.25 Mabsadd L
.11587 .24315 2.165 -1.25 Mabsadd L
.11587 .24315 0 2.5 Mabsadd L closepath F
.11905 .24354 0 2.5 Mabsadd m
.11905 .24354 -2.165 -1.25 Mabsadd L
.11905 .24354 2.165 -1.25 Mabsadd L
.11905 .24354 0 2.5 Mabsadd L closepath F
.12222 .24392 0 2.5 Mabsadd m
.12222 .24392 -2.165 -1.25 Mabsadd L
.12222 .24392 2.165 -1.25 Mabsadd L
.12222 .24392 0 2.5 Mabsadd L closepath F
.1254 .24432 0 2.5 Mabsadd m
.1254 .24432 -2.165 -1.25 Mabsadd L
.1254 .24432 2.165 -1.25 Mabsadd L
.1254 .24432 0 2.5 Mabsadd L closepath F
.12857 .24471 0 2.5 Mabsadd m
.12857 .24471 -2.165 -1.25 Mabsadd L
.12857 .24471 2.165 -1.25 Mabsadd L
.12857 .24471 0 2.5 Mabsadd L closepath F
.13175 .24511 0 2.5 Mabsadd m
.13175 .24511 -2.165 -1.25 Mabsadd L
.13175 .24511 2.165 -1.25 Mabsadd L
.13175 .24511 0 2.5 Mabsadd L closepath F
.13492 .24552 0 2.5 Mabsadd m
.13492 .24552 -2.165 -1.25 Mabsadd L
.13492 .24552 2.165 -1.25 Mabsadd L
.13492 .24552 0 2.5 Mabsadd L closepath F
.1381 .24592 0 2.5 Mabsadd m
.1381 .24592 -2.165 -1.25 Mabsadd L
.1381 .24592 2.165 -1.25 Mabsadd L
.1381 .24592 0 2.5 Mabsadd L closepath F
.14127 .24634 0 2.5 Mabsadd m
.14127 .24634 -2.165 -1.25 Mabsadd L
.14127 .24634 2.165 -1.25 Mabsadd L
.14127 .24634 0 2.5 Mabsadd L closepath F
.14444 .24675 0 2.5 Mabsadd m
.14444 .24675 -2.165 -1.25 Mabsadd L
.14444 .24675 2.165 -1.25 Mabsadd L
.14444 .24675 0 2.5 Mabsadd L closepath F
.14762 .24717 0 2.5 Mabsadd m
.14762 .24717 -2.165 -1.25 Mabsadd L
.14762 .24717 2.165 -1.25 Mabsadd L
.14762 .24717 0 2.5 Mabsadd L closepath F
.15079 .2476 0 2.5 Mabsadd m
.15079 .2476 -2.165 -1.25 Mabsadd L
.15079 .2476 2.165 -1.25 Mabsadd L
.15079 .2476 0 2.5 Mabsadd L closepath F
.15397 .24803 0 2.5 Mabsadd m
.15397 .24803 -2.165 -1.25 Mabsadd L
.15397 .24803 2.165 -1.25 Mabsadd L
.15397 .24803 0 2.5 Mabsadd L closepath F
.15714 .24846 0 2.5 Mabsadd m
.15714 .24846 -2.165 -1.25 Mabsadd L
.15714 .24846 2.165 -1.25 Mabsadd L
.15714 .24846 0 2.5 Mabsadd L closepath F
.16032 .2489 0 2.5 Mabsadd m
.16032 .2489 -2.165 -1.25 Mabsadd L
.16032 .2489 2.165 -1.25 Mabsadd L
.16032 .2489 0 2.5 Mabsadd L closepath F
.16349 .24934 0 2.5 Mabsadd m
.16349 .24934 -2.165 -1.25 Mabsadd L
.16349 .24934 2.165 -1.25 Mabsadd L
.16349 .24934 0 2.5 Mabsadd L closepath F
.16667 .24979 0 2.5 Mabsadd m
.16667 .24979 -2.165 -1.25 Mabsadd L
.16667 .24979 2.165 -1.25 Mabsadd L
.16667 .24979 0 2.5 Mabsadd L closepath F
.16984 .25024 0 2.5 Mabsadd m
.16984 .25024 -2.165 -1.25 Mabsadd L
.16984 .25024 2.165 -1.25 Mabsadd L
.16984 .25024 0 2.5 Mabsadd L closepath F
.17302 .25069 0 2.5 Mabsadd m
.17302 .25069 -2.165 -1.25 Mabsadd L
.17302 .25069 2.165 -1.25 Mabsadd L
.17302 .25069 0 2.5 Mabsadd L closepath F
.17619 .25115 0 2.5 Mabsadd m
.17619 .25115 -2.165 -1.25 Mabsadd L
.17619 .25115 2.165 -1.25 Mabsadd L
.17619 .25115 0 2.5 Mabsadd L closepath F
.17937 .25162 0 2.5 Mabsadd m
.17937 .25162 -2.165 -1.25 Mabsadd L
.17937 .25162 2.165 -1.25 Mabsadd L
.17937 .25162 0 2.5 Mabsadd L closepath F
.18254 .25208 0 2.5 Mabsadd m
.18254 .25208 -2.165 -1.25 Mabsadd L
.18254 .25208 2.165 -1.25 Mabsadd L
.18254 .25208 0 2.5 Mabsadd L closepath F
.18571 .25256 0 2.5 Mabsadd m
.18571 .25256 -2.165 -1.25 Mabsadd L
.18571 .25256 2.165 -1.25 Mabsadd L
.18571 .25256 0 2.5 Mabsadd L closepath F
.18889 .25304 0 2.5 Mabsadd m
.18889 .25304 -2.165 -1.25 Mabsadd L
.18889 .25304 2.165 -1.25 Mabsadd L
.18889 .25304 0 2.5 Mabsadd L closepath F
.19206 .25352 0 2.5 Mabsadd m
.19206 .25352 -2.165 -1.25 Mabsadd L
.19206 .25352 2.165 -1.25 Mabsadd L
.19206 .25352 0 2.5 Mabsadd L closepath F
.19524 .25401 0 2.5 Mabsadd m
.19524 .25401 -2.165 -1.25 Mabsadd L
.19524 .25401 2.165 -1.25 Mabsadd L
.19524 .25401 0 2.5 Mabsadd L closepath F
.19841 .2545 0 2.5 Mabsadd m
.19841 .2545 -2.165 -1.25 Mabsadd L
.19841 .2545 2.165 -1.25 Mabsadd L
.19841 .2545 0 2.5 Mabsadd L closepath F
.20159 .255 0 2.5 Mabsadd m
.20159 .255 -2.165 -1.25 Mabsadd L
.20159 .255 2.165 -1.25 Mabsadd L
.20159 .255 0 2.5 Mabsadd L closepath F
.20476 .2555 0 2.5 Mabsadd m
.20476 .2555 -2.165 -1.25 Mabsadd L
.20476 .2555 2.165 -1.25 Mabsadd L
.20476 .2555 0 2.5 Mabsadd L closepath F
.20794 .25601 0 2.5 Mabsadd m
.20794 .25601 -2.165 -1.25 Mabsadd L
.20794 .25601 2.165 -1.25 Mabsadd L
.20794 .25601 0 2.5 Mabsadd L closepath F
.21111 .25652 0 2.5 Mabsadd m
.21111 .25652 -2.165 -1.25 Mabsadd L
.21111 .25652 2.165 -1.25 Mabsadd L
.21111 .25652 0 2.5 Mabsadd L closepath F
.21429 .25704 0 2.5 Mabsadd m
.21429 .25704 -2.165 -1.25 Mabsadd L
.21429 .25704 2.165 -1.25 Mabsadd L
.21429 .25704 0 2.5 Mabsadd L closepath F
.21746 .25756 0 2.5 Mabsadd m
.21746 .25756 -2.165 -1.25 Mabsadd L
.21746 .25756 2.165 -1.25 Mabsadd L
.21746 .25756 0 2.5 Mabsadd L closepath F
.22063 .25809 0 2.5 Mabsadd m
.22063 .25809 -2.165 -1.25 Mabsadd L
.22063 .25809 2.165 -1.25 Mabsadd L
.22063 .25809 0 2.5 Mabsadd L closepath F
.22381 .25863 0 2.5 Mabsadd m
.22381 .25863 -2.165 -1.25 Mabsadd L
.22381 .25863 2.165 -1.25 Mabsadd L
.22381 .25863 0 2.5 Mabsadd L closepath F
.22698 .25917 0 2.5 Mabsadd m
.22698 .25917 -2.165 -1.25 Mabsadd L
.22698 .25917 2.165 -1.25 Mabsadd L
.22698 .25917 0 2.5 Mabsadd L closepath F
.23016 .25971 0 2.5 Mabsadd m
.23016 .25971 -2.165 -1.25 Mabsadd L
.23016 .25971 2.165 -1.25 Mabsadd L
.23016 .25971 0 2.5 Mabsadd L closepath F
.23333 .26026 0 2.5 Mabsadd m
.23333 .26026 -2.165 -1.25 Mabsadd L
.23333 .26026 2.165 -1.25 Mabsadd L
.23333 .26026 0 2.5 Mabsadd L closepath F
.23651 .26082 0 2.5 Mabsadd m
.23651 .26082 -2.165 -1.25 Mabsadd L
.23651 .26082 2.165 -1.25 Mabsadd L
.23651 .26082 0 2.5 Mabsadd L closepath F
.23968 .26138 0 2.5 Mabsadd m
.23968 .26138 -2.165 -1.25 Mabsadd L
.23968 .26138 2.165 -1.25 Mabsadd L
.23968 .26138 0 2.5 Mabsadd L closepath F
.24286 .26194 0 2.5 Mabsadd m
.24286 .26194 -2.165 -1.25 Mabsadd L
.24286 .26194 2.165 -1.25 Mabsadd L
.24286 .26194 0 2.5 Mabsadd L closepath F
.24603 .26252 0 2.5 Mabsadd m
.24603 .26252 -2.165 -1.25 Mabsadd L
.24603 .26252 2.165 -1.25 Mabsadd L
.24603 .26252 0 2.5 Mabsadd L closepath F
.24921 .26309 0 2.5 Mabsadd m
.24921 .26309 -2.165 -1.25 Mabsadd L
.24921 .26309 2.165 -1.25 Mabsadd L
.24921 .26309 0 2.5 Mabsadd L closepath F
.25238 .26368 0 2.5 Mabsadd m
.25238 .26368 -2.165 -1.25 Mabsadd L
.25238 .26368 2.165 -1.25 Mabsadd L
.25238 .26368 0 2.5 Mabsadd L closepath F
.25556 .26427 0 2.5 Mabsadd m
.25556 .26427 -2.165 -1.25 Mabsadd L
.25556 .26427 2.165 -1.25 Mabsadd L
.25556 .26427 0 2.5 Mabsadd L closepath F
.25873 .26486 0 2.5 Mabsadd m
.25873 .26486 -2.165 -1.25 Mabsadd L
.25873 .26486 2.165 -1.25 Mabsadd L
.25873 .26486 0 2.5 Mabsadd L closepath F
.2619 .26546 0 2.5 Mabsadd m
.2619 .26546 -2.165 -1.25 Mabsadd L
.2619 .26546 2.165 -1.25 Mabsadd L
.2619 .26546 0 2.5 Mabsadd L closepath F
.26508 .26607 0 2.5 Mabsadd m
.26508 .26607 -2.165 -1.25 Mabsadd L
.26508 .26607 2.165 -1.25 Mabsadd L
.26508 .26607 0 2.5 Mabsadd L closepath F
.26825 .26669 0 2.5 Mabsadd m
.26825 .26669 -2.165 -1.25 Mabsadd L
.26825 .26669 2.165 -1.25 Mabsadd L
.26825 .26669 0 2.5 Mabsadd L closepath F
.27143 .26731 0 2.5 Mabsadd m
.27143 .26731 -2.165 -1.25 Mabsadd L
.27143 .26731 2.165 -1.25 Mabsadd L
.27143 .26731 0 2.5 Mabsadd L closepath F
.2746 .26793 0 2.5 Mabsadd m
.2746 .26793 -2.165 -1.25 Mabsadd L
.2746 .26793 2.165 -1.25 Mabsadd L
.2746 .26793 0 2.5 Mabsadd L closepath F
.27778 .26856 0 2.5 Mabsadd m
.27778 .26856 -2.165 -1.25 Mabsadd L
.27778 .26856 2.165 -1.25 Mabsadd L
.27778 .26856 0 2.5 Mabsadd L closepath F
.28095 .2692 0 2.5 Mabsadd m
.28095 .2692 -2.165 -1.25 Mabsadd L
.28095 .2692 2.165 -1.25 Mabsadd L
.28095 .2692 0 2.5 Mabsadd L closepath F
.28413 .26985 0 2.5 Mabsadd m
.28413 .26985 -2.165 -1.25 Mabsadd L
.28413 .26985 2.165 -1.25 Mabsadd L
.28413 .26985 0 2.5 Mabsadd L closepath F
.2873 .2705 0 2.5 Mabsadd m
.2873 .2705 -2.165 -1.25 Mabsadd L
.2873 .2705 2.165 -1.25 Mabsadd L
.2873 .2705 0 2.5 Mabsadd L closepath F
.29048 .27116 0 2.5 Mabsadd m
.29048 .27116 -2.165 -1.25 Mabsadd L
.29048 .27116 2.165 -1.25 Mabsadd L
.29048 .27116 0 2.5 Mabsadd L closepath F
.29365 .27182 0 2.5 Mabsadd m
.29365 .27182 -2.165 -1.25 Mabsadd L
.29365 .27182 2.165 -1.25 Mabsadd L
.29365 .27182 0 2.5 Mabsadd L closepath F
.29683 .27249 0 2.5 Mabsadd m
.29683 .27249 -2.165 -1.25 Mabsadd L
.29683 .27249 2.165 -1.25 Mabsadd L
.29683 .27249 0 2.5 Mabsadd L closepath F
.3 .27317 0 2.5 Mabsadd m
.3 .27317 -2.165 -1.25 Mabsadd L
.3 .27317 2.165 -1.25 Mabsadd L
.3 .27317 0 2.5 Mabsadd L closepath F
.30317 .27385 0 2.5 Mabsadd m
.30317 .27385 -2.165 -1.25 Mabsadd L
.30317 .27385 2.165 -1.25 Mabsadd L
.30317 .27385 0 2.5 Mabsadd L closepath F
.30635 .27455 0 2.5 Mabsadd m
.30635 .27455 -2.165 -1.25 Mabsadd L
.30635 .27455 2.165 -1.25 Mabsadd L
.30635 .27455 0 2.5 Mabsadd L closepath F
.30952 .27524 0 2.5 Mabsadd m
.30952 .27524 -2.165 -1.25 Mabsadd L
.30952 .27524 2.165 -1.25 Mabsadd L
.30952 .27524 0 2.5 Mabsadd L closepath F
.3127 .27595 0 2.5 Mabsadd m
.3127 .27595 -2.165 -1.25 Mabsadd L
.3127 .27595 2.165 -1.25 Mabsadd L
.3127 .27595 0 2.5 Mabsadd L closepath F
.31587 .27666 0 2.5 Mabsadd m
.31587 .27666 -2.165 -1.25 Mabsadd L
.31587 .27666 2.165 -1.25 Mabsadd L
.31587 .27666 0 2.5 Mabsadd L closepath F
.31905 .27738 0 2.5 Mabsadd m
.31905 .27738 -2.165 -1.25 Mabsadd L
.31905 .27738 2.165 -1.25 Mabsadd L
.31905 .27738 0 2.5 Mabsadd L closepath F
.32222 .27811 0 2.5 Mabsadd m
.32222 .27811 -2.165 -1.25 Mabsadd L
.32222 .27811 2.165 -1.25 Mabsadd L
.32222 .27811 0 2.5 Mabsadd L closepath F
.3254 .27884 0 2.5 Mabsadd m
.3254 .27884 -2.165 -1.25 Mabsadd L
.3254 .27884 2.165 -1.25 Mabsadd L
.3254 .27884 0 2.5 Mabsadd L closepath F
.32857 .27958 0 2.5 Mabsadd m
.32857 .27958 -2.165 -1.25 Mabsadd L
.32857 .27958 2.165 -1.25 Mabsadd L
.32857 .27958 0 2.5 Mabsadd L closepath F
.33175 .28033 0 2.5 Mabsadd m
.33175 .28033 -2.165 -1.25 Mabsadd L
.33175 .28033 2.165 -1.25 Mabsadd L
.33175 .28033 0 2.5 Mabsadd L closepath F
.33492 .28109 0 2.5 Mabsadd m
.33492 .28109 -2.165 -1.25 Mabsadd L
.33492 .28109 2.165 -1.25 Mabsadd L
.33492 .28109 0 2.5 Mabsadd L closepath F
.3381 .28185 0 2.5 Mabsadd m
.3381 .28185 -2.165 -1.25 Mabsadd L
.3381 .28185 2.165 -1.25 Mabsadd L
.3381 .28185 0 2.5 Mabsadd L closepath F
.34127 .28262 0 2.5 Mabsadd m
.34127 .28262 -2.165 -1.25 Mabsadd L
.34127 .28262 2.165 -1.25 Mabsadd L
.34127 .28262 0 2.5 Mabsadd L closepath F
.34444 .2834 0 2.5 Mabsadd m
.34444 .2834 -2.165 -1.25 Mabsadd L
.34444 .2834 2.165 -1.25 Mabsadd L
.34444 .2834 0 2.5 Mabsadd L closepath F
.34762 .28419 0 2.5 Mabsadd m
.34762 .28419 -2.165 -1.25 Mabsadd L
.34762 .28419 2.165 -1.25 Mabsadd L
.34762 .28419 0 2.5 Mabsadd L closepath F
.35079 .28498 0 2.5 Mabsadd m
.35079 .28498 -2.165 -1.25 Mabsadd L
.35079 .28498 2.165 -1.25 Mabsadd L
.35079 .28498 0 2.5 Mabsadd L closepath F
.35397 .28579 0 2.5 Mabsadd m
.35397 .28579 -2.165 -1.25 Mabsadd L
.35397 .28579 2.165 -1.25 Mabsadd L
.35397 .28579 0 2.5 Mabsadd L closepath F
.35714 .2866 0 2.5 Mabsadd m
.35714 .2866 -2.165 -1.25 Mabsadd L
.35714 .2866 2.165 -1.25 Mabsadd L
.35714 .2866 0 2.5 Mabsadd L closepath F
.36032 .28742 0 2.5 Mabsadd m
.36032 .28742 -2.165 -1.25 Mabsadd L
.36032 .28742 2.165 -1.25 Mabsadd L
.36032 .28742 0 2.5 Mabsadd L closepath F
.36349 .28824 0 2.5 Mabsadd m
.36349 .28824 -2.165 -1.25 Mabsadd L
.36349 .28824 2.165 -1.25 Mabsadd L
.36349 .28824 0 2.5 Mabsadd L closepath F
.36667 .28908 0 2.5 Mabsadd m
.36667 .28908 -2.165 -1.25 Mabsadd L
.36667 .28908 2.165 -1.25 Mabsadd L
.36667 .28908 0 2.5 Mabsadd L closepath F
.36984 .28992 0 2.5 Mabsadd m
.36984 .28992 -2.165 -1.25 Mabsadd L
.36984 .28992 2.165 -1.25 Mabsadd L
.36984 .28992 0 2.5 Mabsadd L closepath F
.37302 .29077 0 2.5 Mabsadd m
.37302 .29077 -2.165 -1.25 Mabsadd L
.37302 .29077 2.165 -1.25 Mabsadd L
.37302 .29077 0 2.5 Mabsadd L closepath F
.37619 .29163 0 2.5 Mabsadd m
.37619 .29163 -2.165 -1.25 Mabsadd L
.37619 .29163 2.165 -1.25 Mabsadd L
.37619 .29163 0 2.5 Mabsadd L closepath F
.37937 .2925 0 2.5 Mabsadd m
.37937 .2925 -2.165 -1.25 Mabsadd L
.37937 .2925 2.165 -1.25 Mabsadd L
.37937 .2925 0 2.5 Mabsadd L closepath F
.38254 .29338 0 2.5 Mabsadd m
.38254 .29338 -2.165 -1.25 Mabsadd L
.38254 .29338 2.165 -1.25 Mabsadd L
.38254 .29338 0 2.5 Mabsadd L closepath F
.38571 .29427 0 2.5 Mabsadd m
.38571 .29427 -2.165 -1.25 Mabsadd L
.38571 .29427 2.165 -1.25 Mabsadd L
.38571 .29427 0 2.5 Mabsadd L closepath F
.38889 .29516 0 2.5 Mabsadd m
.38889 .29516 -2.165 -1.25 Mabsadd L
.38889 .29516 2.165 -1.25 Mabsadd L
.38889 .29516 0 2.5 Mabsadd L closepath F
.39206 .29607 0 2.5 Mabsadd m
.39206 .29607 -2.165 -1.25 Mabsadd L
.39206 .29607 2.165 -1.25 Mabsadd L
.39206 .29607 0 2.5 Mabsadd L closepath F
.39524 .29698 0 2.5 Mabsadd m
.39524 .29698 -2.165 -1.25 Mabsadd L
.39524 .29698 2.165 -1.25 Mabsadd L
.39524 .29698 0 2.5 Mabsadd L closepath F
.39841 .2979 0 2.5 Mabsadd m
.39841 .2979 -2.165 -1.25 Mabsadd L
.39841 .2979 2.165 -1.25 Mabsadd L
.39841 .2979 0 2.5 Mabsadd L closepath F
.40159 .29884 0 2.5 Mabsadd m
.40159 .29884 -2.165 -1.25 Mabsadd L
.40159 .29884 2.165 -1.25 Mabsadd L
.40159 .29884 0 2.5 Mabsadd L closepath F
.40476 .29978 0 2.5 Mabsadd m
.40476 .29978 -2.165 -1.25 Mabsadd L
.40476 .29978 2.165 -1.25 Mabsadd L
.40476 .29978 0 2.5 Mabsadd L closepath F
.40794 .30073 0 2.5 Mabsadd m
.40794 .30073 -2.165 -1.25 Mabsadd L
.40794 .30073 2.165 -1.25 Mabsadd L
.40794 .30073 0 2.5 Mabsadd L closepath F
.41111 .30169 0 2.5 Mabsadd m
.41111 .30169 -2.165 -1.25 Mabsadd L
.41111 .30169 2.165 -1.25 Mabsadd L
.41111 .30169 0 2.5 Mabsadd L closepath F
.41429 .30266 0 2.5 Mabsadd m
.41429 .30266 -2.165 -1.25 Mabsadd L
.41429 .30266 2.165 -1.25 Mabsadd L
.41429 .30266 0 2.5 Mabsadd L closepath F
.41746 .30364 0 2.5 Mabsadd m
.41746 .30364 -2.165 -1.25 Mabsadd L
.41746 .30364 2.165 -1.25 Mabsadd L
.41746 .30364 0 2.5 Mabsadd L closepath F
.42063 .30463 0 2.5 Mabsadd m
.42063 .30463 -2.165 -1.25 Mabsadd L
.42063 .30463 2.165 -1.25 Mabsadd L
.42063 .30463 0 2.5 Mabsadd L closepath F
.42381 .30563 0 2.5 Mabsadd m
.42381 .30563 -2.165 -1.25 Mabsadd L
.42381 .30563 2.165 -1.25 Mabsadd L
.42381 .30563 0 2.5 Mabsadd L closepath F
.42698 .30664 0 2.5 Mabsadd m
.42698 .30664 -2.165 -1.25 Mabsadd L
.42698 .30664 2.165 -1.25 Mabsadd L
.42698 .30664 0 2.5 Mabsadd L closepath F
.43016 .30765 0 2.5 Mabsadd m
.43016 .30765 -2.165 -1.25 Mabsadd L
.43016 .30765 2.165 -1.25 Mabsadd L
.43016 .30765 0 2.5 Mabsadd L closepath F
.43333 .30868 0 2.5 Mabsadd m
.43333 .30868 -2.165 -1.25 Mabsadd L
.43333 .30868 2.165 -1.25 Mabsadd L
.43333 .30868 0 2.5 Mabsadd L closepath F
.43651 .30972 0 2.5 Mabsadd m
.43651 .30972 -2.165 -1.25 Mabsadd L
.43651 .30972 2.165 -1.25 Mabsadd L
.43651 .30972 0 2.5 Mabsadd L closepath F
.43968 .31077 0 2.5 Mabsadd m
.43968 .31077 -2.165 -1.25 Mabsadd L
.43968 .31077 2.165 -1.25 Mabsadd L
.43968 .31077 0 2.5 Mabsadd L closepath F
.44286 .31183 0 2.5 Mabsadd m
.44286 .31183 -2.165 -1.25 Mabsadd L
.44286 .31183 2.165 -1.25 Mabsadd L
.44286 .31183 0 2.5 Mabsadd L closepath F
.44603 .31291 0 2.5 Mabsadd m
.44603 .31291 -2.165 -1.25 Mabsadd L
.44603 .31291 2.165 -1.25 Mabsadd L
.44603 .31291 0 2.5 Mabsadd L closepath F
.44921 .31399 0 2.5 Mabsadd m
.44921 .31399 -2.165 -1.25 Mabsadd L
.44921 .31399 2.165 -1.25 Mabsadd L
.44921 .31399 0 2.5 Mabsadd L closepath F
.45238 .31508 0 2.5 Mabsadd m
.45238 .31508 -2.165 -1.25 Mabsadd L
.45238 .31508 2.165 -1.25 Mabsadd L
.45238 .31508 0 2.5 Mabsadd L closepath F
.45556 .31618 0 2.5 Mabsadd m
.45556 .31618 -2.165 -1.25 Mabsadd L
.45556 .31618 2.165 -1.25 Mabsadd L
.45556 .31618 0 2.5 Mabsadd L closepath F
.45873 .3173 0 2.5 Mabsadd m
.45873 .3173 -2.165 -1.25 Mabsadd L
.45873 .3173 2.165 -1.25 Mabsadd L
.45873 .3173 0 2.5 Mabsadd L closepath F
.4619 .31842 0 2.5 Mabsadd m
.4619 .31842 -2.165 -1.25 Mabsadd L
.4619 .31842 2.165 -1.25 Mabsadd L
.4619 .31842 0 2.5 Mabsadd L closepath F
.46508 .31956 0 2.5 Mabsadd m
.46508 .31956 -2.165 -1.25 Mabsadd L
.46508 .31956 2.165 -1.25 Mabsadd L
.46508 .31956 0 2.5 Mabsadd L closepath F
.46825 .32071 0 2.5 Mabsadd m
.46825 .32071 -2.165 -1.25 Mabsadd L
.46825 .32071 2.165 -1.25 Mabsadd L
.46825 .32071 0 2.5 Mabsadd L closepath F
.47143 .32187 0 2.5 Mabsadd m
.47143 .32187 -2.165 -1.25 Mabsadd L
.47143 .32187 2.165 -1.25 Mabsadd L
.47143 .32187 0 2.5 Mabsadd L closepath F
.4746 .32304 0 2.5 Mabsadd m
.4746 .32304 -2.165 -1.25 Mabsadd L
.4746 .32304 2.165 -1.25 Mabsadd L
.4746 .32304 0 2.5 Mabsadd L closepath F
.47778 .32423 0 2.5 Mabsadd m
.47778 .32423 -2.165 -1.25 Mabsadd L
.47778 .32423 2.165 -1.25 Mabsadd L
.47778 .32423 0 2.5 Mabsadd L closepath F
.48095 .32542 0 2.5 Mabsadd m
.48095 .32542 -2.165 -1.25 Mabsadd L
.48095 .32542 2.165 -1.25 Mabsadd L
.48095 .32542 0 2.5 Mabsadd L closepath F
.48413 .32663 0 2.5 Mabsadd m
.48413 .32663 -2.165 -1.25 Mabsadd L
.48413 .32663 2.165 -1.25 Mabsadd L
.48413 .32663 0 2.5 Mabsadd L closepath F
.4873 .32785 0 2.5 Mabsadd m
.4873 .32785 -2.165 -1.25 Mabsadd L
.4873 .32785 2.165 -1.25 Mabsadd L
.4873 .32785 0 2.5 Mabsadd L closepath F
.49048 .32908 0 2.5 Mabsadd m
.49048 .32908 -2.165 -1.25 Mabsadd L
.49048 .32908 2.165 -1.25 Mabsadd L
.49048 .32908 0 2.5 Mabsadd L closepath F
.49365 .33032 0 2.5 Mabsadd m
.49365 .33032 -2.165 -1.25 Mabsadd L
.49365 .33032 2.165 -1.25 Mabsadd L
.49365 .33032 0 2.5 Mabsadd L closepath F
.49683 .33158 0 2.5 Mabsadd m
.49683 .33158 -2.165 -1.25 Mabsadd L
.49683 .33158 2.165 -1.25 Mabsadd L
.49683 .33158 0 2.5 Mabsadd L closepath F
.5 .33285 0 2.5 Mabsadd m
.5 .33285 -2.165 -1.25 Mabsadd L
.5 .33285 2.165 -1.25 Mabsadd L
.5 .33285 0 2.5 Mabsadd L closepath F
.50317 .33413 0 2.5 Mabsadd m
.50317 .33413 -2.165 -1.25 Mabsadd L
.50317 .33413 2.165 -1.25 Mabsadd L
.50317 .33413 0 2.5 Mabsadd L closepath F
.50635 .33542 0 2.5 Mabsadd m
.50635 .33542 -2.165 -1.25 Mabsadd L
.50635 .33542 2.165 -1.25 Mabsadd L
.50635 .33542 0 2.5 Mabsadd L closepath F
.50952 .33673 0 2.5 Mabsadd m
.50952 .33673 -2.165 -1.25 Mabsadd L
.50952 .33673 2.165 -1.25 Mabsadd L
.50952 .33673 0 2.5 Mabsadd L closepath F
.5127 .33805 0 2.5 Mabsadd m
.5127 .33805 -2.165 -1.25 Mabsadd L
.5127 .33805 2.165 -1.25 Mabsadd L
.5127 .33805 0 2.5 Mabsadd L closepath F
.51587 .33938 0 2.5 Mabsadd m
.51587 .33938 -2.165 -1.25 Mabsadd L
.51587 .33938 2.165 -1.25 Mabsadd L
.51587 .33938 0 2.5 Mabsadd L closepath F
.51905 .34073 0 2.5 Mabsadd m
.51905 .34073 -2.165 -1.25 Mabsadd L
.51905 .34073 2.165 -1.25 Mabsadd L
.51905 .34073 0 2.5 Mabsadd L closepath F
.52222 .34209 0 2.5 Mabsadd m
.52222 .34209 -2.165 -1.25 Mabsadd L
.52222 .34209 2.165 -1.25 Mabsadd L
.52222 .34209 0 2.5 Mabsadd L closepath F
.5254 .34346 0 2.5 Mabsadd m
.5254 .34346 -2.165 -1.25 Mabsadd L
.5254 .34346 2.165 -1.25 Mabsadd L
.5254 .34346 0 2.5 Mabsadd L closepath F
.52857 .34485 0 2.5 Mabsadd m
.52857 .34485 -2.165 -1.25 Mabsadd L
.52857 .34485 2.165 -1.25 Mabsadd L
.52857 .34485 0 2.5 Mabsadd L closepath F
.53175 .34625 0 2.5 Mabsadd m
.53175 .34625 -2.165 -1.25 Mabsadd L
.53175 .34625 2.165 -1.25 Mabsadd L
.53175 .34625 0 2.5 Mabsadd L closepath F
.53492 .34767 0 2.5 Mabsadd m
.53492 .34767 -2.165 -1.25 Mabsadd L
.53492 .34767 2.165 -1.25 Mabsadd L
.53492 .34767 0 2.5 Mabsadd L closepath F
.5381 .3491 0 2.5 Mabsadd m
.5381 .3491 -2.165 -1.25 Mabsadd L
.5381 .3491 2.165 -1.25 Mabsadd L
.5381 .3491 0 2.5 Mabsadd L closepath F
.54127 .35054 0 2.5 Mabsadd m
.54127 .35054 -2.165 -1.25 Mabsadd L
.54127 .35054 2.165 -1.25 Mabsadd L
.54127 .35054 0 2.5 Mabsadd L closepath F
.54444 .352 0 2.5 Mabsadd m
.54444 .352 -2.165 -1.25 Mabsadd L
.54444 .352 2.165 -1.25 Mabsadd L
.54444 .352 0 2.5 Mabsadd L closepath F
.54762 .35347 0 2.5 Mabsadd m
.54762 .35347 -2.165 -1.25 Mabsadd L
.54762 .35347 2.165 -1.25 Mabsadd L
.54762 .35347 0 2.5 Mabsadd L closepath F
.55079 .35496 0 2.5 Mabsadd m
.55079 .35496 -2.165 -1.25 Mabsadd L
.55079 .35496 2.165 -1.25 Mabsadd L
.55079 .35496 0 2.5 Mabsadd L closepath F
.55397 .35646 0 2.5 Mabsadd m
.55397 .35646 -2.165 -1.25 Mabsadd L
.55397 .35646 2.165 -1.25 Mabsadd L
.55397 .35646 0 2.5 Mabsadd L closepath F
.55714 .35798 0 2.5 Mabsadd m
.55714 .35798 -2.165 -1.25 Mabsadd L
.55714 .35798 2.165 -1.25 Mabsadd L
.55714 .35798 0 2.5 Mabsadd L closepath F
.56032 .35951 0 2.5 Mabsadd m
.56032 .35951 -2.165 -1.25 Mabsadd L
.56032 .35951 2.165 -1.25 Mabsadd L
.56032 .35951 0 2.5 Mabsadd L closepath F
.56349 .36106 0 2.5 Mabsadd m
.56349 .36106 -2.165 -1.25 Mabsadd L
.56349 .36106 2.165 -1.25 Mabsadd L
.56349 .36106 0 2.5 Mabsadd L closepath F
.56667 .36262 0 2.5 Mabsadd m
.56667 .36262 -2.165 -1.25 Mabsadd L
.56667 .36262 2.165 -1.25 Mabsadd L
.56667 .36262 0 2.5 Mabsadd L closepath F
.56984 .3642 0 2.5 Mabsadd m
.56984 .3642 -2.165 -1.25 Mabsadd L
.56984 .3642 2.165 -1.25 Mabsadd L
.56984 .3642 0 2.5 Mabsadd L closepath F
.57302 .3658 0 2.5 Mabsadd m
.57302 .3658 -2.165 -1.25 Mabsadd L
.57302 .3658 2.165 -1.25 Mabsadd L
.57302 .3658 0 2.5 Mabsadd L closepath F
.57619 .36741 0 2.5 Mabsadd m
.57619 .36741 -2.165 -1.25 Mabsadd L
.57619 .36741 2.165 -1.25 Mabsadd L
.57619 .36741 0 2.5 Mabsadd L closepath F
.57937 .36904 0 2.5 Mabsadd m
.57937 .36904 -2.165 -1.25 Mabsadd L
.57937 .36904 2.165 -1.25 Mabsadd L
.57937 .36904 0 2.5 Mabsadd L closepath F
.58254 .37068 0 2.5 Mabsadd m
.58254 .37068 -2.165 -1.25 Mabsadd L
.58254 .37068 2.165 -1.25 Mabsadd L
.58254 .37068 0 2.5 Mabsadd L closepath F
.58571 .37234 0 2.5 Mabsadd m
.58571 .37234 -2.165 -1.25 Mabsadd L
.58571 .37234 2.165 -1.25 Mabsadd L
.58571 .37234 0 2.5 Mabsadd L closepath F
.58889 .37401 0 2.5 Mabsadd m
.58889 .37401 -2.165 -1.25 Mabsadd L
.58889 .37401 2.165 -1.25 Mabsadd L
.58889 .37401 0 2.5 Mabsadd L closepath F
.59206 .37571 0 2.5 Mabsadd m
.59206 .37571 -2.165 -1.25 Mabsadd L
.59206 .37571 2.165 -1.25 Mabsadd L
.59206 .37571 0 2.5 Mabsadd L closepath F
.59524 .37742 0 2.5 Mabsadd m
.59524 .37742 -2.165 -1.25 Mabsadd L
.59524 .37742 2.165 -1.25 Mabsadd L
.59524 .37742 0 2.5 Mabsadd L closepath F
.59841 .37914 0 2.5 Mabsadd m
.59841 .37914 -2.165 -1.25 Mabsadd L
.59841 .37914 2.165 -1.25 Mabsadd L
.59841 .37914 0 2.5 Mabsadd L closepath F
.60159 .38089 0 2.5 Mabsadd m
.60159 .38089 -2.165 -1.25 Mabsadd L
.60159 .38089 2.165 -1.25 Mabsadd L
.60159 .38089 0 2.5 Mabsadd L closepath F
.60476 .38265 0 2.5 Mabsadd m
.60476 .38265 -2.165 -1.25 Mabsadd L
.60476 .38265 2.165 -1.25 Mabsadd L
.60476 .38265 0 2.5 Mabsadd L closepath F
.60794 .38443 0 2.5 Mabsadd m
.60794 .38443 -2.165 -1.25 Mabsadd L
.60794 .38443 2.165 -1.25 Mabsadd L
.60794 .38443 0 2.5 Mabsadd L closepath F
.61111 .38623 0 2.5 Mabsadd m
.61111 .38623 -2.165 -1.25 Mabsadd L
.61111 .38623 2.165 -1.25 Mabsadd L
.61111 .38623 0 2.5 Mabsadd L closepath F
.61429 .38804 0 2.5 Mabsadd m
.61429 .38804 -2.165 -1.25 Mabsadd L
.61429 .38804 2.165 -1.25 Mabsadd L
.61429 .38804 0 2.5 Mabsadd L closepath F
.61746 .38988 0 2.5 Mabsadd m
.61746 .38988 -2.165 -1.25 Mabsadd L
.61746 .38988 2.165 -1.25 Mabsadd L
.61746 .38988 0 2.5 Mabsadd L closepath F
.62063 .39173 0 2.5 Mabsadd m
.62063 .39173 -2.165 -1.25 Mabsadd L
.62063 .39173 2.165 -1.25 Mabsadd L
.62063 .39173 0 2.5 Mabsadd L closepath F
.62381 .3936 0 2.5 Mabsadd m
.62381 .3936 -2.165 -1.25 Mabsadd L
.62381 .3936 2.165 -1.25 Mabsadd L
.62381 .3936 0 2.5 Mabsadd L closepath F
.62698 .39549 0 2.5 Mabsadd m
.62698 .39549 -2.165 -1.25 Mabsadd L
.62698 .39549 2.165 -1.25 Mabsadd L
.62698 .39549 0 2.5 Mabsadd L closepath F
.63016 .39739 0 2.5 Mabsadd m
.63016 .39739 -2.165 -1.25 Mabsadd L
.63016 .39739 2.165 -1.25 Mabsadd L
.63016 .39739 0 2.5 Mabsadd L closepath F
.63333 .39932 0 2.5 Mabsadd m
.63333 .39932 -2.165 -1.25 Mabsadd L
.63333 .39932 2.165 -1.25 Mabsadd L
.63333 .39932 0 2.5 Mabsadd L closepath F
.63651 .40127 0 2.5 Mabsadd m
.63651 .40127 -2.165 -1.25 Mabsadd L
.63651 .40127 2.165 -1.25 Mabsadd L
.63651 .40127 0 2.5 Mabsadd L closepath F
.63968 .40323 0 2.5 Mabsadd m
.63968 .40323 -2.165 -1.25 Mabsadd L
.63968 .40323 2.165 -1.25 Mabsadd L
.63968 .40323 0 2.5 Mabsadd L closepath F
.64286 .40522 0 2.5 Mabsadd m
.64286 .40522 -2.165 -1.25 Mabsadd L
.64286 .40522 2.165 -1.25 Mabsadd L
.64286 .40522 0 2.5 Mabsadd L closepath F
.64603 .40722 0 2.5 Mabsadd m
.64603 .40722 -2.165 -1.25 Mabsadd L
.64603 .40722 2.165 -1.25 Mabsadd L
.64603 .40722 0 2.5 Mabsadd L closepath F
.64921 .40925 0 2.5 Mabsadd m
.64921 .40925 -2.165 -1.25 Mabsadd L
.64921 .40925 2.165 -1.25 Mabsadd L
.64921 .40925 0 2.5 Mabsadd L closepath F
.65238 .41129 0 2.5 Mabsadd m
.65238 .41129 -2.165 -1.25 Mabsadd L
.65238 .41129 2.165 -1.25 Mabsadd L
.65238 .41129 0 2.5 Mabsadd L closepath F
.65556 .41336 0 2.5 Mabsadd m
.65556 .41336 -2.165 -1.25 Mabsadd L
.65556 .41336 2.165 -1.25 Mabsadd L
.65556 .41336 0 2.5 Mabsadd L closepath F
.65873 .41545 0 2.5 Mabsadd m
.65873 .41545 -2.165 -1.25 Mabsadd L
.65873 .41545 2.165 -1.25 Mabsadd L
.65873 .41545 0 2.5 Mabsadd L closepath F
.6619 .41755 0 2.5 Mabsadd m
.6619 .41755 -2.165 -1.25 Mabsadd L
.6619 .41755 2.165 -1.25 Mabsadd L
.6619 .41755 0 2.5 Mabsadd L closepath F
.66508 .41968 0 2.5 Mabsadd m
.66508 .41968 -2.165 -1.25 Mabsadd L
.66508 .41968 2.165 -1.25 Mabsadd L
.66508 .41968 0 2.5 Mabsadd L closepath F
.66825 .42183 0 2.5 Mabsadd m
.66825 .42183 -2.165 -1.25 Mabsadd L
.66825 .42183 2.165 -1.25 Mabsadd L
.66825 .42183 0 2.5 Mabsadd L closepath F
.67143 .424 0 2.5 Mabsadd m
.67143 .424 -2.165 -1.25 Mabsadd L
.67143 .424 2.165 -1.25 Mabsadd L
.67143 .424 0 2.5 Mabsadd L closepath F
.6746 .42619 0 2.5 Mabsadd m
.6746 .42619 -2.165 -1.25 Mabsadd L
.6746 .42619 2.165 -1.25 Mabsadd L
.6746 .42619 0 2.5 Mabsadd L closepath F
.67778 .42841 0 2.5 Mabsadd m
.67778 .42841 -2.165 -1.25 Mabsadd L
.67778 .42841 2.165 -1.25 Mabsadd L
.67778 .42841 0 2.5 Mabsadd L closepath F
.68095 .43065 0 2.5 Mabsadd m
.68095 .43065 -2.165 -1.25 Mabsadd L
.68095 .43065 2.165 -1.25 Mabsadd L
.68095 .43065 0 2.5 Mabsadd L closepath F
.68413 .43291 0 2.5 Mabsadd m
.68413 .43291 -2.165 -1.25 Mabsadd L
.68413 .43291 2.165 -1.25 Mabsadd L
.68413 .43291 0 2.5 Mabsadd L closepath F
.6873 .43519 0 2.5 Mabsadd m
.6873 .43519 -2.165 -1.25 Mabsadd L
.6873 .43519 2.165 -1.25 Mabsadd L
.6873 .43519 0 2.5 Mabsadd L closepath F
.69048 .43749 0 2.5 Mabsadd m
.69048 .43749 -2.165 -1.25 Mabsadd L
.69048 .43749 2.165 -1.25 Mabsadd L
.69048 .43749 0 2.5 Mabsadd L closepath F
.69365 .43982 0 2.5 Mabsadd m
.69365 .43982 -2.165 -1.25 Mabsadd L
.69365 .43982 2.165 -1.25 Mabsadd L
.69365 .43982 0 2.5 Mabsadd L closepath F
.69683 .44217 0 2.5 Mabsadd m
.69683 .44217 -2.165 -1.25 Mabsadd L
.69683 .44217 2.165 -1.25 Mabsadd L
.69683 .44217 0 2.5 Mabsadd L closepath F
.7 .44455 0 2.5 Mabsadd m
.7 .44455 -2.165 -1.25 Mabsadd L
.7 .44455 2.165 -1.25 Mabsadd L
.7 .44455 0 2.5 Mabsadd L closepath F
.70317 .44694 0 2.5 Mabsadd m
.70317 .44694 -2.165 -1.25 Mabsadd L
.70317 .44694 2.165 -1.25 Mabsadd L
.70317 .44694 0 2.5 Mabsadd L closepath F
.70635 .44937 0 2.5 Mabsadd m
.70635 .44937 -2.165 -1.25 Mabsadd L
.70635 .44937 2.165 -1.25 Mabsadd L
.70635 .44937 0 2.5 Mabsadd L closepath F
.70952 .45181 0 2.5 Mabsadd m
.70952 .45181 -2.165 -1.25 Mabsadd L
.70952 .45181 2.165 -1.25 Mabsadd L
.70952 .45181 0 2.5 Mabsadd L closepath F
.7127 .45428 0 2.5 Mabsadd m
.7127 .45428 -2.165 -1.25 Mabsadd L
.7127 .45428 2.165 -1.25 Mabsadd L
.7127 .45428 0 2.5 Mabsadd L closepath F
.71587 .45678 0 2.5 Mabsadd m
.71587 .45678 -2.165 -1.25 Mabsadd L
.71587 .45678 2.165 -1.25 Mabsadd L
.71587 .45678 0 2.5 Mabsadd L closepath F
.71905 .4593 0 2.5 Mabsadd m
.71905 .4593 -2.165 -1.25 Mabsadd L
.71905 .4593 2.165 -1.25 Mabsadd L
.71905 .4593 0 2.5 Mabsadd L closepath F
.72222 .46185 0 2.5 Mabsadd m
.72222 .46185 -2.165 -1.25 Mabsadd L
.72222 .46185 2.165 -1.25 Mabsadd L
.72222 .46185 0 2.5 Mabsadd L closepath F
.7254 .46442 0 2.5 Mabsadd m
.7254 .46442 -2.165 -1.25 Mabsadd L
.7254 .46442 2.165 -1.25 Mabsadd L
.7254 .46442 0 2.5 Mabsadd L closepath F
.72857 .46701 0 2.5 Mabsadd m
.72857 .46701 -2.165 -1.25 Mabsadd L
.72857 .46701 2.165 -1.25 Mabsadd L
.72857 .46701 0 2.5 Mabsadd L closepath F
.73175 .46964 0 2.5 Mabsadd m
.73175 .46964 -2.165 -1.25 Mabsadd L
.73175 .46964 2.165 -1.25 Mabsadd L
.73175 .46964 0 2.5 Mabsadd L closepath F
.73492 .47229 0 2.5 Mabsadd m
.73492 .47229 -2.165 -1.25 Mabsadd L
.73492 .47229 2.165 -1.25 Mabsadd L
.73492 .47229 0 2.5 Mabsadd L closepath F
.7381 .47496 0 2.5 Mabsadd m
.7381 .47496 -2.165 -1.25 Mabsadd L
.7381 .47496 2.165 -1.25 Mabsadd L
.7381 .47496 0 2.5 Mabsadd L closepath F
.74127 .47767 0 2.5 Mabsadd m
.74127 .47767 -2.165 -1.25 Mabsadd L
.74127 .47767 2.165 -1.25 Mabsadd L
.74127 .47767 0 2.5 Mabsadd L closepath F
.74444 .48039 0 2.5 Mabsadd m
.74444 .48039 -2.165 -1.25 Mabsadd L
.74444 .48039 2.165 -1.25 Mabsadd L
.74444 .48039 0 2.5 Mabsadd L closepath F
.74762 .48315 0 2.5 Mabsadd m
.74762 .48315 -2.165 -1.25 Mabsadd L
.74762 .48315 2.165 -1.25 Mabsadd L
.74762 .48315 0 2.5 Mabsadd L closepath F
.75079 .48594 0 2.5 Mabsadd m
.75079 .48594 -2.165 -1.25 Mabsadd L
.75079 .48594 2.165 -1.25 Mabsadd L
.75079 .48594 0 2.5 Mabsadd L closepath F
.75397 .48875 0 2.5 Mabsadd m
.75397 .48875 -2.165 -1.25 Mabsadd L
.75397 .48875 2.165 -1.25 Mabsadd L
.75397 .48875 0 2.5 Mabsadd L closepath F
.75714 .49159 0 2.5 Mabsadd m
.75714 .49159 -2.165 -1.25 Mabsadd L
.75714 .49159 2.165 -1.25 Mabsadd L
.75714 .49159 0 2.5 Mabsadd L closepath F
.76032 .49446 0 2.5 Mabsadd m
.76032 .49446 -2.165 -1.25 Mabsadd L
.76032 .49446 2.165 -1.25 Mabsadd L
.76032 .49446 0 2.5 Mabsadd L closepath F
.76349 .49735 0 2.5 Mabsadd m
.76349 .49735 -2.165 -1.25 Mabsadd L
.76349 .49735 2.165 -1.25 Mabsadd L
.76349 .49735 0 2.5 Mabsadd L closepath F
.76667 .50028 0 2.5 Mabsadd m
.76667 .50028 -2.165 -1.25 Mabsadd L
.76667 .50028 2.165 -1.25 Mabsadd L
.76667 .50028 0 2.5 Mabsadd L closepath F
.76984 .50324 0 2.5 Mabsadd m
.76984 .50324 -2.165 -1.25 Mabsadd L
.76984 .50324 2.165 -1.25 Mabsadd L
.76984 .50324 0 2.5 Mabsadd L closepath F
.77302 .50622 0 2.5 Mabsadd m
.77302 .50622 -2.165 -1.25 Mabsadd L
.77302 .50622 2.165 -1.25 Mabsadd L
.77302 .50622 0 2.5 Mabsadd L closepath F
.77619 .50924 0 2.5 Mabsadd m
.77619 .50924 -2.165 -1.25 Mabsadd L
.77619 .50924 2.165 -1.25 Mabsadd L
.77619 .50924 0 2.5 Mabsadd L closepath F
.77937 .51228 0 2.5 Mabsadd m
.77937 .51228 -2.165 -1.25 Mabsadd L
.77937 .51228 2.165 -1.25 Mabsadd L
.77937 .51228 0 2.5 Mabsadd L closepath F
.78254 .51536 0 2.5 Mabsadd m
.78254 .51536 -2.165 -1.25 Mabsadd L
.78254 .51536 2.165 -1.25 Mabsadd L
.78254 .51536 0 2.5 Mabsadd L closepath F
.78571 .51846 0 2.5 Mabsadd m
.78571 .51846 -2.165 -1.25 Mabsadd L
.78571 .51846 2.165 -1.25 Mabsadd L
.78571 .51846 0 2.5 Mabsadd L closepath F
.78889 .5216 0 2.5 Mabsadd m
.78889 .5216 -2.165 -1.25 Mabsadd L
.78889 .5216 2.165 -1.25 Mabsadd L
.78889 .5216 0 2.5 Mabsadd L closepath F
.79206 .52477 0 2.5 Mabsadd m
.79206 .52477 -2.165 -1.25 Mabsadd L
.79206 .52477 2.165 -1.25 Mabsadd L
.79206 .52477 0 2.5 Mabsadd L closepath F
.79524 .52797 0 2.5 Mabsadd m
.79524 .52797 -2.165 -1.25 Mabsadd L
.79524 .52797 2.165 -1.25 Mabsadd L
.79524 .52797 0 2.5 Mabsadd L closepath F
.79841 .5312 0 2.5 Mabsadd m
.79841 .5312 -2.165 -1.25 Mabsadd L
.79841 .5312 2.165 -1.25 Mabsadd L
.79841 .5312 0 2.5 Mabsadd L closepath F
.80159 .53447 0 2.5 Mabsadd m
.80159 .53447 -2.165 -1.25 Mabsadd L
.80159 .53447 2.165 -1.25 Mabsadd L
.80159 .53447 0 2.5 Mabsadd L closepath F
.80476 .53777 0 2.5 Mabsadd m
.80476 .53777 -2.165 -1.25 Mabsadd L
.80476 .53777 2.165 -1.25 Mabsadd L
.80476 .53777 0 2.5 Mabsadd L closepath F
.80794 .5411 0 2.5 Mabsadd m
.80794 .5411 -2.165 -1.25 Mabsadd L
.80794 .5411 2.165 -1.25 Mabsadd L
.80794 .5411 0 2.5 Mabsadd L closepath F
.81111 .54446 0 2.5 Mabsadd m
.81111 .54446 -2.165 -1.25 Mabsadd L
.81111 .54446 2.165 -1.25 Mabsadd L
.81111 .54446 0 2.5 Mabsadd L closepath F
.81429 .54786 0 2.5 Mabsadd m
.81429 .54786 -2.165 -1.25 Mabsadd L
.81429 .54786 2.165 -1.25 Mabsadd L
.81429 .54786 0 2.5 Mabsadd L closepath F
.81746 .55129 0 2.5 Mabsadd m
.81746 .55129 -2.165 -1.25 Mabsadd L
.81746 .55129 2.165 -1.25 Mabsadd L
.81746 .55129 0 2.5 Mabsadd L closepath F
.82063 .55476 0 2.5 Mabsadd m
.82063 .55476 -2.165 -1.25 Mabsadd L
.82063 .55476 2.165 -1.25 Mabsadd L
.82063 .55476 0 2.5 Mabsadd L closepath F
.82381 .55826 0 2.5 Mabsadd m
.82381 .55826 -2.165 -1.25 Mabsadd L
.82381 .55826 2.165 -1.25 Mabsadd L
.82381 .55826 0 2.5 Mabsadd L closepath F
.82698 .56179 0 2.5 Mabsadd m
.82698 .56179 -2.165 -1.25 Mabsadd L
.82698 .56179 2.165 -1.25 Mabsadd L
.82698 .56179 0 2.5 Mabsadd L closepath F
.83016 .56536 0 2.5 Mabsadd m
.83016 .56536 -2.165 -1.25 Mabsadd L
.83016 .56536 2.165 -1.25 Mabsadd L
.83016 .56536 0 2.5 Mabsadd L closepath F
.83333 .56897 0 2.5 Mabsadd m
.83333 .56897 -2.165 -1.25 Mabsadd L
.83333 .56897 2.165 -1.25 Mabsadd L
.83333 .56897 0 2.5 Mabsadd L closepath F
.83651 .57261 0 2.5 Mabsadd m
.83651 .57261 -2.165 -1.25 Mabsadd L
.83651 .57261 2.165 -1.25 Mabsadd L
.83651 .57261 0 2.5 Mabsadd L closepath F
.83968 .57629 0 2.5 Mabsadd m
.83968 .57629 -2.165 -1.25 Mabsadd L
.83968 .57629 2.165 -1.25 Mabsadd L
.83968 .57629 0 2.5 Mabsadd L closepath F
.84286 .58001 0 2.5 Mabsadd m
.84286 .58001 -2.165 -1.25 Mabsadd L
.84286 .58001 2.165 -1.25 Mabsadd L
.84286 .58001 0 2.5 Mabsadd L closepath F
.84603 .58376 0 2.5 Mabsadd m
.84603 .58376 -2.165 -1.25 Mabsadd L
.84603 .58376 2.165 -1.25 Mabsadd L
.84603 .58376 0 2.5 Mabsadd L closepath F
.84921 .58755 0 2.5 Mabsadd m
.84921 .58755 -2.165 -1.25 Mabsadd L
.84921 .58755 2.165 -1.25 Mabsadd L
.84921 .58755 0 2.5 Mabsadd L closepath F
.85238 .59138 0 2.5 Mabsadd m
.85238 .59138 -2.165 -1.25 Mabsadd L
.85238 .59138 2.165 -1.25 Mabsadd L
.85238 .59138 0 2.5 Mabsadd L closepath F
.85556 .59524 0 2.5 Mabsadd m
.85556 .59524 -2.165 -1.25 Mabsadd L
.85556 .59524 2.165 -1.25 Mabsadd L
.85556 .59524 0 2.5 Mabsadd L closepath F
.85873 .59915 0 2.5 Mabsadd m
.85873 .59915 -2.165 -1.25 Mabsadd L
.85873 .59915 2.165 -1.25 Mabsadd L
.85873 .59915 0 2.5 Mabsadd L closepath F
.8619 .60309 0 2.5 Mabsadd m
.8619 .60309 -2.165 -1.25 Mabsadd L
.8619 .60309 2.165 -1.25 Mabsadd L
.8619 .60309 0 2.5 Mabsadd L closepath F
.86508 .60708 0 2.5 Mabsadd m
.86508 .60708 -2.165 -1.25 Mabsadd L
.86508 .60708 2.165 -1.25 Mabsadd L
.86508 .60708 0 2.5 Mabsadd L closepath F
.86825 .6111 0 2.5 Mabsadd m
.86825 .6111 -2.165 -1.25 Mabsadd L
.86825 .6111 2.165 -1.25 Mabsadd L
.86825 .6111 0 2.5 Mabsadd L closepath F
.87143 .61517 0 2.5 Mabsadd m
.87143 .61517 -2.165 -1.25 Mabsadd L
.87143 .61517 2.165 -1.25 Mabsadd L
.87143 .61517 0 2.5 Mabsadd L closepath F
.8746 .61927 0 2.5 Mabsadd m
.8746 .61927 -2.165 -1.25 Mabsadd L
.8746 .61927 2.165 -1.25 Mabsadd L
.8746 .61927 0 2.5 Mabsadd L closepath F
.87778 .62342 0 2.5 Mabsadd m
.87778 .62342 -2.165 -1.25 Mabsadd L
.87778 .62342 2.165 -1.25 Mabsadd L
.87778 .62342 0 2.5 Mabsadd L closepath F
.88095 .6276 0 2.5 Mabsadd m
.88095 .6276 -2.165 -1.25 Mabsadd L
.88095 .6276 2.165 -1.25 Mabsadd L
.88095 .6276 0 2.5 Mabsadd L closepath F
.88413 .63183 0 2.5 Mabsadd m
.88413 .63183 -2.165 -1.25 Mabsadd L
.88413 .63183 2.165 -1.25 Mabsadd L
.88413 .63183 0 2.5 Mabsadd L closepath F
.8873 .6361 0 2.5 Mabsadd m
.8873 .6361 -2.165 -1.25 Mabsadd L
.8873 .6361 2.165 -1.25 Mabsadd L
.8873 .6361 0 2.5 Mabsadd L closepath F
.89048 .64042 0 2.5 Mabsadd m
.89048 .64042 -2.165 -1.25 Mabsadd L
.89048 .64042 2.165 -1.25 Mabsadd L
.89048 .64042 0 2.5 Mabsadd L closepath F
.89365 .64477 0 2.5 Mabsadd m
.89365 .64477 -2.165 -1.25 Mabsadd L
.89365 .64477 2.165 -1.25 Mabsadd L
.89365 .64477 0 2.5 Mabsadd L closepath F
.89683 .64917 0 2.5 Mabsadd m
.89683 .64917 -2.165 -1.25 Mabsadd L
.89683 .64917 2.165 -1.25 Mabsadd L
.89683 .64917 0 2.5 Mabsadd L closepath F
.9 .65362 0 2.5 Mabsadd m
.9 .65362 -2.165 -1.25 Mabsadd L
.9 .65362 2.165 -1.25 Mabsadd L
.9 .65362 0 2.5 Mabsadd L closepath F
.90317 .65811 0 2.5 Mabsadd m
.90317 .65811 -2.165 -1.25 Mabsadd L
.90317 .65811 2.165 -1.25 Mabsadd L
.90317 .65811 0 2.5 Mabsadd L closepath F
.90635 .66264 0 2.5 Mabsadd m
.90635 .66264 -2.165 -1.25 Mabsadd L
.90635 .66264 2.165 -1.25 Mabsadd L
.90635 .66264 0 2.5 Mabsadd L closepath F
.90952 .66722 0 2.5 Mabsadd m
.90952 .66722 -2.165 -1.25 Mabsadd L
.90952 .66722 2.165 -1.25 Mabsadd L
.90952 .66722 0 2.5 Mabsadd L closepath F
.9127 .67185 0 2.5 Mabsadd m
.9127 .67185 -2.165 -1.25 Mabsadd L
.9127 .67185 2.165 -1.25 Mabsadd L
.9127 .67185 0 2.5 Mabsadd L closepath F
.91587 .67652 0 2.5 Mabsadd m
.91587 .67652 -2.165 -1.25 Mabsadd L
.91587 .67652 2.165 -1.25 Mabsadd L
.91587 .67652 0 2.5 Mabsadd L closepath F
.91905 .68124 0 2.5 Mabsadd m
.91905 .68124 -2.165 -1.25 Mabsadd L
.91905 .68124 2.165 -1.25 Mabsadd L
.91905 .68124 0 2.5 Mabsadd L closepath F
.92222 .686 0 2.5 Mabsadd m
.92222 .686 -2.165 -1.25 Mabsadd L
.92222 .686 2.165 -1.25 Mabsadd L
.92222 .686 0 2.5 Mabsadd L closepath F
.9254 .69081 0 2.5 Mabsadd m
.9254 .69081 -2.165 -1.25 Mabsadd L
.9254 .69081 2.165 -1.25 Mabsadd L
.9254 .69081 0 2.5 Mabsadd L closepath F
.92857 .69568 0 2.5 Mabsadd m
.92857 .69568 -2.165 -1.25 Mabsadd L
.92857 .69568 2.165 -1.25 Mabsadd L
.92857 .69568 0 2.5 Mabsadd L closepath F
.93175 .70058 0 2.5 Mabsadd m
.93175 .70058 -2.165 -1.25 Mabsadd L
.93175 .70058 2.165 -1.25 Mabsadd L
.93175 .70058 0 2.5 Mabsadd L closepath F
.93492 .70554 0 2.5 Mabsadd m
.93492 .70554 -2.165 -1.25 Mabsadd L
.93492 .70554 2.165 -1.25 Mabsadd L
.93492 .70554 0 2.5 Mabsadd L closepath F
.9381 .71055 0 2.5 Mabsadd m
.9381 .71055 -2.165 -1.25 Mabsadd L
.9381 .71055 2.165 -1.25 Mabsadd L
.9381 .71055 0 2.5 Mabsadd L closepath F
.94127 .71561 0 2.5 Mabsadd m
.94127 .71561 -2.165 -1.25 Mabsadd L
.94127 .71561 2.165 -1.25 Mabsadd L
.94127 .71561 0 2.5 Mabsadd L closepath F
.94444 .72072 0 2.5 Mabsadd m
.94444 .72072 -2.165 -1.25 Mabsadd L
.94444 .72072 2.165 -1.25 Mabsadd L
.94444 .72072 0 2.5 Mabsadd L closepath F
.94762 .72588 0 2.5 Mabsadd m
.94762 .72588 -2.165 -1.25 Mabsadd L
.94762 .72588 2.165 -1.25 Mabsadd L
.94762 .72588 0 2.5 Mabsadd L closepath F
.95079 .73109 0 2.5 Mabsadd m
.95079 .73109 -2.165 -1.25 Mabsadd L
.95079 .73109 2.165 -1.25 Mabsadd L
.95079 .73109 0 2.5 Mabsadd L closepath F
.95397 .73635 0 2.5 Mabsadd m
.95397 .73635 -2.165 -1.25 Mabsadd L
.95397 .73635 2.165 -1.25 Mabsadd L
.95397 .73635 0 2.5 Mabsadd L closepath F
.95714 .74167 0 2.5 Mabsadd m
.95714 .74167 -2.165 -1.25 Mabsadd L
.95714 .74167 2.165 -1.25 Mabsadd L
.95714 .74167 0 2.5 Mabsadd L closepath F
.96032 .74704 0 2.5 Mabsadd m
.96032 .74704 -2.165 -1.25 Mabsadd L
.96032 .74704 2.165 -1.25 Mabsadd L
.96032 .74704 0 2.5 Mabsadd L closepath F
.96349 .75246 0 2.5 Mabsadd m
.96349 .75246 -2.165 -1.25 Mabsadd L
.96349 .75246 2.165 -1.25 Mabsadd L
.96349 .75246 0 2.5 Mabsadd L closepath F
.96667 .75794 0 2.5 Mabsadd m
.96667 .75794 -2.165 -1.25 Mabsadd L
.96667 .75794 2.165 -1.25 Mabsadd L
.96667 .75794 0 2.5 Mabsadd L closepath F
.96984 .76347 0 2.5 Mabsadd m
.96984 .76347 -2.165 -1.25 Mabsadd L
.96984 .76347 2.165 -1.25 Mabsadd L
.96984 .76347 0 2.5 Mabsadd L closepath F
.97302 .76906 0 2.5 Mabsadd m
.97302 .76906 -2.165 -1.25 Mabsadd L
.97302 .76906 2.165 -1.25 Mabsadd L
.97302 .76906 0 2.5 Mabsadd L closepath F
.97619 .7747 0 2.5 Mabsadd m
.97619 .7747 -2.165 -1.25 Mabsadd L
.97619 .7747 2.165 -1.25 Mabsadd L
.97619 .7747 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wooo]Z1Ol0003ooookJ_oooo]Z5?oonfX002Wo
oo]Z1Ol0003ooookJ_oooo]Z5?oonfX001?ooo]Z0ol007l5oookJPGo001o2OoonfX5o`000?oooo]Z
oooonfXDoookJP004ooonfX3o`00O`Cooo]Z1ol007l8oookJPGo0000oooonf[ooookJQCooo]Z000C
oookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ_oooo]Z5?oo
nfX000?ooo]Z2_l007l6oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[o
oookJQCooo]Z0003oookJP[o001o1_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
0?oooo]Zo?oonfX4o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo
0000oooonf[loookJPKo00004OoonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z
1Ol0003ooookJ_[ooo]Z2?l0000AoookJP004ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`000?oooo]ZnOoonfX9o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7
oookJPGo0000oooonf[goookJP[o00004_oonfX0013ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00
O`Oooo]Z1Ol0003ooookJ_Gooo]Z2ol0000CoookJP004?oonfX6o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l8oookJPGo0000oooonf[doookJP[o00005OoonfX001;ooo]Z1?l007l4oookJPOo
001o2?oonfX5o`000?oooo]Zl_oonfX:o`0001Oooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z
1Ol0003ooookJ_3ooo]Z2ol0000HoookJP00:OoonfX5o`000?oooo]Zk_oonfX;o`0001[ooo]Z000Y
oookJPGo0000oooonf[]oookJP[o00007?oonfX002Wooo]Z1Ol0003ooookJ^_ooo]Z2_l0000Noook
JP00:OoonfX5o`000?oooo]ZjOoonfX;o`0001oooo]Z000YoookJPGo0000oooonf[XoookJP[o0000
8OoonfX002Wooo]Z1Ol0003ooookJ^Kooo]Z2_l0000SoookJP00:OoonfX5o`000?oooo]Zh_oonfX<
o`0002Gooo]Z000YoookJPGo0000oooonf[QoookJP_o00009ooonfX002Wooo]Z1Ol0003ooookJ]oo
oo]Z3?l0000XoookJP00:OoonfX5o`000?oooo]ZgOoonfX<o`0002[ooo]Z000YoookJPGo0000oooo
nf[KoookJP_o0000;OoonfX002Wooo]Z1Ol0003ooookJ]Sooo]Z3?l0000_oookJP00:OoonfX5o`00
0?oooo]Ze_oonfX=o`00033ooo]Z000YoookJPGo0000oooonf[EoookJP_o0000<ooonfX002Wooo]Z
1Ol0003ooookJ]?ooo]Z2ol0000eoookJP00:OoonfX5o`000?oooo]ZdOoonfX;o`0003Oooo]Z000Y
oookJPGo0000oooonf[>oookJPco0000>OoonfX002Wooo]Z1Ol0003ooookJ/cooo]Z3?l0000koook
JP00:OoonfX5o`000?oooo]Zb_oonfX<o`0003gooo]Z000YoookJPGo0000oooonf[7oookJPgo0000
?ooonfX002Wooo]Z1Ol0003ooookJ/Gooo]Z3?l00012oookJP00:OoonfX5o`000?oooo]Z`ooonfX=
o`0004?ooo]Z000YoookJPGo0000oooonf[0oookJPgo0000A_oonfX002Wooo]Z1Ol0003ooookJ[ko
oo]Z3Ol00018oookJP00:OoonfX5o`000?oooo]Z^ooonfX>o`0004[ooo]Z000YoookJPGo0000oooo
nfZioookJPgo0000COoonfX002Wooo]Z1Ol0003ooookJ[Kooo]Z3_l0001?oookJP00:OoonfX5o`00
0?oooo]Z]?oonfX=o`0005;ooo]Z000YoookJPGo0000oooonfZaoookJPko0000E?oonfX002Wooo]Z
1Ol0003ooookJZoooo]Z3_l0001FoookJP00:OoonfX5o`000?oooo]ZZooonfX>o`0005[ooo]Z000Y
oookJPGo0000oooonfZZoookJPko0000FooonfX002Wooo]Z1Ol0003ooookJZKooo]Z3_l0001Ooook
JP00:OoonfX5o`000?oooo]ZXooonfX@o`00063ooo]Z000YoookJPGo0000oooonfZQoookJPko0000
I?oonfX002Wooo]Z1Ol0003ooookJYkooo]Z3ol0001VoookJP00:OoonfX5o`000?oooo]ZV_oonfX@
o`0006Wooo]Z000YoookJPGo0000oooonfZGoookJQ3o0000K?oonfX002Wooo]Z1Ol0003ooookJYGo
oo]Z3ol0001_oookJP006ooonfX5o`00O`Wooo]Z1Ol0003ooookJY;ooo]Z3ol0001boookJP006_oo
nfX7o`00O`Sooo]Z1Ol0003ooookJXkooo]Z4?l0001eoookJP006OoonfX4o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0003ooookJX_ooo]Z4?l0001hoookJP003OoonfX:o`00O`;ooo]Z0ol007l3
oookJP?o001o1ooonfX5o`000?oooo]ZQooonfXBo`0007[ooo]Z000=oookJP[o001o2?oonfX3o`00
O`Oooo]Z1ol0003ooookJX;ooo]Z4Ol0001noookJP007ooonfX3o`00O`Oooo]Z1Ol0003ooookJX7o
oo]Z4Ol00021oookJP006_oonfX2o`00O`;ooo]Z1?l007l7oookJPGo0000oooonfYmoookJQ;o0000
Q?oonfX001[ooo]Z1ol007l8oookJPGo0000oooonfYjoookJQ7o0000R?oonfX001[ooo]Z1_l007l9
oookJPGo0000oooonfYfoookJQ;o0000RooonfX001[ooo]Z0_l007l=oookJPGo0000oooonfYcoook
JQ7o0000SooonfX001[ooo]Z0_l007l=oookJPGo0000oooonfY^oookJQ?o0000T_oonfX001_ooo]Z
1ol007l7oookJPGo0000oooonfYZoookJQ?o0000U_oonfX001_ooo]Z1ol007l7oookJPGo0000oooo
nfYWoookJQ?o0000VOoonfX002Wooo]Z1Ol0003ooookJV;ooo]Z5Ol0002LoookJP00:OoonfX5o`00
0?oooo]ZG_oonfXCo`000003oookJ_l0003ooo]Z09oooo]Z000YoookJPGo0000oooonfYIoookJQGo
0000YOoonfX002Wooo]Z1Ol0003ooookJUKooo]Z5Ol0002XoookJP00:OoonfX5o`000?oooo]ZDOoo
nfXDo`000003oookJ_l0003ooo]Z0:_ooo]Z000YoookJPGo0000oooonfY;oookJQOo0000/OoonfX0
02Wooo]Z1Ol0003ooookJTSooo]Z5Ol000000ooonf[o0000oookJP2coookJP00:OoonfX5o`000?oo
oo]Z@ooonfXFo`000;[ooo]Z000YoookJPGo0000oooonfXnoookJQKo0000_ooonfX002Wooo]Z1Ol0
003ooookJSWooo]Z5_l000000ooonf[o0000oookJP31oookJP00:OoonfX5o`000?oooo]Z<ooonfXI
o`000<Oooo]Z000YoookJPGo0000oooonfX]oookJQ[o0000c?oonfX002Wooo]Z1Ol0003ooookJROo
oo]Z6_l0003BoookJP00:OoonfX5o`000?oooo]Z8_oonfXJo`000=Oooo]Z000YoookJPGo0000oooo
nfXKoookJQco0000g?oonfX002Wooo]Z1Ol0003ooookJQGooo]Z6ol000000ooonf[o0000oookJP3P
oookJP00:OoonfX5o`000?oooo]Z3_oonfXMo`000003oookJ_l0003ooo]Z0>Gooo]Z000YoookJPGo
0000oooonfX7oookJQoo0000kOoonfX002Wooo]Z1Ol0003ooookJQoo000000?ooo]Zo`000?oonfX0
lOoonfX002Wooo]Z1Ol0003hoookJQoo000000?ooo]Zo`000?oonfX0n?oonfX002Wooo]Z1Ol0003`
oookJR3o000000?ooo]Zo`000?oonfX0oooonfX002Wooo]Z1Ol0003WoookJRCo0000oooonfX8oook
JP00:OoonfX5o`0004_ooo]Z1Ol007l5oookJPGo001oA?oonfX3o`00O`Gooo]Z1Ol007l5oookJPGo
001o:OoonfXVo`000003oookJ_l007oo001o00?o001o>ooonfX9o`00O`?ooo]Z1Ol007l5oookJPGo
001o>ooonfX9o`00O`?ooo]Z1Ol007l5oookJPGo001o??oonfX5o`00O`Gooo]Z1Ol007l5oookJPGo
001o1ooonfX002Wooo]Z1Ol0001:oookJPOo001o0ooonfX7o`00Od?ooo]Z0ol007l4oookJPOo001o
0ooonfX7o`00Ob3ooo]Z9_l000000ol007oo0000o`00O`02o`00O`?ooo]Z1ol007ljoookJPWo001o
0_oonfX7o`00O`?ooo]Z1ol007ljoookJPWo001o0_oonfX7o`00O`?ooo]Z1ol007ljoookJPOo001o
0ooonfX7o`00O`?ooo]Z1ol007l6oookJP00:OoonfX5o`0004Wooo]Z1?l007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o@ooonfX3o`00O`Cooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o5_oonfXWo`000003o`00Ool0003o
001o00?ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
>_oonfX4o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o>_oonfX4o`00O`Kooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o>OoonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000YoookJPGo0000BOoonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o@_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`[ooo]Z:ol000000ooonf[o0000oookJP04oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o>_oonfX4
o`00O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Oc[ooo]Z1?l0
07l5oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lhoookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o1OoonfX002Wooo]Z1Ol0001?oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
Od;ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l[
o`000004oookJ_l0003ooo]Zo`0000gooo]Z0ol007l9oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00Oc_ooo]Z1Ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007lkoookJPGo001o2OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lnoook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l5oookJP00:OoonfX5o`0004oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o@_oo
nfX3o`00O`?ooo]Z0ol007l3oookJP03o`00Ool0003o000002ko000000?ooo]Zo`000?oonfX05Ooo
nfX3o`00O`Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o?OoonfX4o`00O`;ooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ocgooo]Z1?l007l8oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ockooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000YoookJPGo0000B_oonfX2
o`00O`;ooo]Z1?l007l01?oonf[o001oo`00Ool007l3oookJP?o001o@_oonfX00ol007oo0000o`00
000^o`000004oookJ_l0003ooo]Zo`00023ooo]Z0ol007l4oookJP;o001o0_oonfX4o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007lnoookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o?_oonfX3o`00O`?ooo]Z0_l007l2oookJPCo001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00Occooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l5oookJP00:OoonfX5o`0004[ooo]Z1ol007l2oookJP?o001o0ooonfX3
o`00OcGooo]Z=?l000000ooonf[o0000o`00000[oookJP?o001o1?oonfX7o`00O`;ooo]Z0ol007l3
oookJP?o001o?ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o?ooonfX3o`00O`;ooo]Z1ol007l2oookJP?o001o0ooonfX3o`00Occooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l5oookJP00
:OoonfX5o`0004[ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00ObSooo]Z>?l000000ooonf[o0000
oookJP0doookJP?o001o1?oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o>OoonfX3o`00O`?ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
OcWooo]Z0ol007l3oookJP?o001o0_oonfX6o`00O`?ooo]Z0ol007l3oookJP?o001o?_oonfX2o`00
O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000Yoook
JPGo0000B_oonfX2o`00O`Oooo]Z0ol007l3oookJP?o001o6?oonfXlo`000004o`00Ool0003ooo]Z
o`0000?o001o>OoonfX6o`00O`Cooo]Z0_l007l7oookJP?o001o0ooonfX3o`00OcWooo]Z0ol007l3
oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007lioookJP?o001o0ooonfX3o`00O`;ooo]Z0_l007l7oookJP?o001o0ooonfX3o`00OcSooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l5oookJP00:OoonfX5o`0004[ooo]Z0_l007l8oookJP?o001o00Cooo]Zo`00Ool0
07oo001o2?oonfY1o`000005oookJ_l0003o001oo`000?oonfX00ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o>_oonfX6o`00O`Cooo]Z0_l007l8oookJP?o001o00Cooo]Zo`00Ool007oo001o
>_oonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00Oc[ooo]Z1?l007l2oookJP?o001o0_oonfX2o`00O`Sooo]Z0ol007l01?oo
nf[o001oo`00Ool007lioookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX002Wooo]Z1Ol0001;oookJP?o001oAol0
00001Ooonf[o0000o`000?oonf[o000000?ooo]Z1?l007l4oookJPOo001o0ooonfX7o`00Occooo]Z
1?l007l5oookJPOo001o0_oonfX7o`00Oc_ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00Oc_ooo]Z
1ol007l4oookJPOo001o0_oonfX7o`00Oc[ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`Kooo]Z
000YoookJPGo0000>_oonfY=o`000003oookJ_l0003ooo]Z00;o00004_oonfX3o`00O`Gooo]Z1Ol0
07l5oookJPGo001o?_oonfX3o`00O`Gooo]Z1ol007l3oookJPGo001o?OoonfX5o`00O`Gooo]Z1Ol0
07l5oookJPGo001o?OoonfX5o`00O`Gooo]Z1ol007l3oookJPGo001o??oonfX5o`00O`Gooo]Z1Ol0
07l5oookJPGo001o1ooonfX002Wooo]Z1Ol0000PoookJUSo000000Gooo]Zo`000?l0003ooo]Zo`00
003ooookJYKooo]Z000YoookJPGo00000ooonfYUo`000006oookJ_l0003ooo]Zo`000?oonf[o0000
oooonfZUoookJP00:OoonfYGo`000009oookJ_l0003ooo]ZoookJ_l0003ooo]Zo`000?oonf[o0000
0?oooo]Z^?oonfX002Wooo]Z@_l000001Ooonf[o0000oookJ_l0003ooo]Z00;o000000?ooo]Zo`00
0?oonfX0oooonf[<oookJP00:OoonfXYo`0000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l000001?oo
nf[o0000oookJ_l0003ooookJ^?ooo]Z000YoookJPgo000000Cooo]Zo`000?oonf[o00000_oonfX0
1?l0003ooo]Zo`000?oonfX2o`000?oooo]ZoooonfX001cooo]Zool0003oo`0002?o00000ooonfX0
01cooo]Zool0003oo`0002?o00000ooonfX001cooo]Zool0003oo`0002?o00000ooonfX001cooo]Z
ool0003oo`0002?o00000ooonfX001cooo]Zool0003oo`0002?o00000ooonfX002Wooo]Z1Ol0001C
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP1C
oookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0D_oonfX00ol0003ooo]ZoookJP0@
oookJP00:OoonfXAo`000?oooo]ZoooonfX8oookJP00:OoonfX/o`000?oooo]Zk?oonfX002Wooo]Z
A_l0003ooookJ];ooo]Z000YoookJU_o0000oooonfZmoookJP00:OoonfX5o`0000;ooo]Z00?o0000
oookJ_l000000_oonfX00ol0003ooo]Zo`00001No`000?oooo]ZZooonfX002Wooo]Z3ol0000@oook
JP03o`000?oonf[o000000;ooo]Z00?o0000oookJ_l000000_oonfYFo`000?oooo]ZVOoonfX002Wo
oo]Z7_l0000KoookJP06o`000?oonf[ooo]Zo`000?oonf[o00001?oonfY;o`000?oooo]ZR_oonfX0
02Wooo]Z;?l0000SoookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]ZA?l0003o
oookJWcooo]Z000YoookJSSo0000;ooonfX00ol0003ooo]Zo`00000oo`000?oooo]ZKooonfX002Wo
oo]ZA?l0000aoookJP07o`000?oonf[ooo]Zo`000?oonf[o0000oookJP0io`000?oooo]ZHooonfX0
02Wooo]Z1Ol00007oookJTCo0000=_oonfX00ol0003ooo]ZoookJP02oookJSKo0000oooonfYGoook
JP00:OoonfX?o`0000cooo]Z?ol0000moookJP03o`000?oonf[o000003;o0000oooonfY<oookJP00
:OoonfXIo`00013ooo]Z>_l00010oookJP03o`000?oonf[o0000033o0000oooonfY2oookJP00:Ooo
nfXRo`0001?ooo]Z>?l00012oookJP03o`000?oonf[o000002ko0000oooonfXhoookJP00:OoonfX/
o`0001Gooo]Z=Ol00015oookJP03o`000?oonf[o000002_o0000oooonfX_oookJP00:OoonfX5o`00
00Cooo]Z00?o0000oookJ_l00000:Ol0000HoookJS7o0000BOoonfX00ol0003ooo]Zo`00000Wo`00
0?oooo]Z9ooonfX002Wooo]Z1Ol0000>oookJP03o`000?oonf[o000002Ko00006ooonfX^o`0004ko
oo]Z9ol0003ooookJQkooo]Z000YoookJPGo00006OoonfXVo`0001cooo]Z;_l0001<oookJP03o`00
0?oonf[ooo]Z02Co0000oooonfXGoookJP00:OoonfX5o`00027ooo]Z00?o0000oookJ_l000008_l0
000OoookJR_o0000CooonfX00ol0003ooo]Zo`00000Ro`000?oooo]Z3ooonfX002Wooo]Z1Ol0000Z
oookJP;o000000?ooo]Zo`000?l000007_l0000QoookJRWo0000DOoonfXSo`000?oooo]Z2?oonfX0
02Wooo]Z1Ol0000boookJP03o`000?oonf[o000001oo00008_oonfXWo`0005Gooo]Z8?l0003ooook
JP7ooo]Z000YoookJPGo0000>ooonfXPo`0002;ooo]Z9ol0001CoookJP03o`000?oonf[o000001oo
0000nOoonfX002Wooo]Z1Ol00012oookJR3o00009?oonfXUo`0005Gooo]Z7_l0003doookJP00:Ooo
nfX5o`0004Wooo]Z7ol0000ToookJRCo0000F?oonfXMo`000>gooo]Z000YoookJPGo0000CooonfX0
0ol0003ooo]Zo`00000Lo`0002Gooo]Z8_l0001JoookJQ_o0000j?oonfX002Wooo]Z1Ol0001Foook
JP03o`000?oonf[o000001[o00009ooonfXRo`0005[ooo]Z6ol0003QoookJP00:OoonfX5o`0005go
oo]Z00?o0000oookJ_l000006_l0000WoookJR3o0000F_oonfXKo`000=cooo]Z000YoookJPGo0000
I?oonfXKo`0002Wooo]Z7ol0001KoookJQWo0000eooonfX002Wooo]Z1Ol0001YoookJP03o`000?oo
nf[o000001So0000:OoonfXOo`0005_ooo]Z6Ol0003BoookJP00:OoonfX5o`00073ooo]Z6Ol0000Y
oookJQoo0000GOoonfXHo`000<cooo]Z000YoookJPGo0000MOoonfX00ol0003ooo]Zo`00000Fo`00
02_ooo]Z7Ol0001MoookJQSo0000aooonfX002Wooo]Z1Ol0001joookJP03o`000?oonf[o000001Go
0000;?oonfXMo`0005gooo]Z6?l00032oookJP00:OoonfX5o`0007oooo]Z00?o0000oookJ_l00000
5Ol0000/oookJQco0000G_oonfXHo`000;gooo]Z000YoookJPGo0000QOoonfXGo`0002cooo]Z7?l0
001OoookJQGo0000^_oonfX002Wooo]Z1Ol0002:oookJQGo0000;ooonfXIo`00067ooo]Z5_l0002d
oookJP00:OoonfX5o`0008oooo]Z5Ol0000_oookJQWo0000GooonfX00ol0003ooo]Zo`00000Co`00
0;7ooo]Z000YoookJPGo0000U?oonfXDo`00033ooo]Z6?l0001RoookJQCo0000[?oonfX002Wooo]Z
1Ol0002GoookJP03o`000?oonf[o000001?o0000;_oonfXJo`00063ooo]Z5Ol0002XoookJP00:Ooo
nfX5o`0009cooo]Z5?l0000`oookJQSo0000HOoonfX00ol0003ooo]Zo`00000Ao`000:Gooo]Z000Y
oookJPGo0000XOoonfXCo`00033ooo]Z6?l0001RoookJQCo0000X?oonfX002Wooo]Z1Ol0002Uoook
JQCo0000<?oonfXFo`0006Cooo]Z4ol0002LoookJP00:OoonfX5o`000:Wooo]Z4ol0000`oookJQSo
0000HooonfXBo`0009Wooo]Z000YoookJPGo0000[OoonfXCo`0003;ooo]Z5_l0001RoookJQ;o0000
U_oonfX002Wooo]Z1Ol0002aoookJQ;o0000<_oonfXFo`0006Cooo]Z4Ol0002BoookJP006ooonfX5
o`00O`Wooo]Z1Ol0002eoookJQ;o0000<OoonfXGo`0006Cooo]Z4?l0002?oookJP006_oonfX7o`00
O`Sooo]Z1Ol0002ioookJQ7o0000<_oonfXFo`0006Cooo]Z4Ol0002;oookJP006OoonfX4o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol0002moookJQ7o0000<ooonfXDo`0006Cooo]Z4Ol00028oook
JP006OoonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000`?oonfXAo`0003?ooo]Z5Ol0001ToookJQ7o
0000Q?oonfX001oooo]Z0ol007l7oookJPOo0000`_oonfX@o`0003Cooo]Z4ol0001UoookJQ7o0000
POoonfX001oooo]Z0ol007l7oookJPGo0000aooonfXAo`0003?ooo]Z4ol0001VoookJQ3o0000O_oo
nfX001[ooo]Z0_l007l2oookJPCo001o1ooonfX5o`000<_ooo]Z3ol0000eoookJQ;o0000I_oonfXA
o`0007[ooo]Z000JoookJPOo001o2?oonfX5o`000<kooo]Z3ol0000eoookJQ?o0000I_oonfX@o`00
07Oooo]Z000JoookJPKo001o2OoonfX5o`000=7ooo]Z3ol0000foookJQ;o0000I_oonfX?o`0007Go
oo]Z000JoookJP;o001o3OoonfX5o`000=Gooo]Z3ol0000coookJQ?o0000IooonfX?o`0007;ooo]Z
000JoookJP;o001o3OoonfX5o`000=Oooo]Z3ol0000eoookJQ;o0000J?oonfX?o`0006kooo]Z000K
oookJPOo001o1ooonfX5o`000=[ooo]Z3ol0000eoookJQ?o0000IooonfX?o`0006_ooo]Z000Koook
JPOo001o1ooonfX5o`000=gooo]Z3ol0000foookJQ7o0000IooonfX?o`0006Wooo]Z000YoookJPGo
0000hOoonfX=o`0003Oooo]Z4Ol0001WoookJPoo0000I_oonfX002Wooo]Z1Ol0003SoookJPoo0000
=OoonfXBo`0006Sooo]Z3Ol0001ToookJP00:OoonfX5o`000>Kooo]Z3ol0000eoookJQ7o0000JOoo
nfX>o`00063ooo]Z000YoookJPGo0000jOoonfX>o`0003Oooo]Z4Ol0001WoookJPoo0000GOoonfX0
02Wooo]Z1Ol0003[oookJPoo0000=OoonfXAo`0006Wooo]Z3_l0001KoookJP00:OoonfX5o`000>oo
oo]Z3Ol0000goookJQ7o0000IooonfX?o`0005Sooo]Z000YoookJPGo0000l_oonfX=o`0003Oooo]Z
3ol0001ZoookJPgo0000E_oonfX002Wooo]Z1Ol0003doookJPgo0000=ooonfXAo`0006Wooo]Z3?l0
001DoookJP00:OoonfX5o`000?Oooo]Z3?l0000hoookJQ3o0000JOoonfX=o`00057ooo]Z000Yoook
JPGo0000nOoonfX=o`0003Oooo]Z3ol0001[oookJPco0000CooonfX002Wooo]Z1Ol0003loookJPco
0000>?oonfX@o`0006Wooo]Z3Ol0001<oookJP00:OoonfX5o`000?kooo]Z3Ol0000goookJPoo0000
J_oonfX=o`0004[ooo]Z000YoookJPGo0000oooonfX1oookJPgo0000>OoonfX=o`0006_ooo]Z3?l0
0018oookJP00:OoonfX5o`000?oooo]Z1?oonfX<o`0003Sooo]Z4?l0001YoookJPgo0000AOoonfX0
02Wooo]Z1Ol0003ooookJPKooo]Z3Ol0000goookJPoo0000JooonfX<o`0004?ooo]Z000YoookJPGo
0000oooonfX9oookJPco0000>?oonfX>o`0006_ooo]Z2ol00012oookJP00:OoonfX5o`000?oooo]Z
2ooonfX<o`0003Sooo]Z3ol0001ZoookJPgo0000?_oonfX002Wooo]Z1Ol0003ooookJPgooo]Z3Ol0
000goookJPoo0000JooonfX<o`0003cooo]Z000YoookJPGo0000oooonfX@oookJPco0000>?oonfX>
o`0006_ooo]Z2ol0000koookJP00:OoonfX5o`000?oooo]Z4_oonfX;o`0003Wooo]Z3_l0001Zoook
JPco0000>OoonfX002Wooo]Z1Ol0003ooookJQCooo]Z2ol0000ioookJPoo0000JooonfX;o`0003Ko
oo]Z000YoookJPGo0000oooonfXGoookJP[o0000>_oonfX>o`0006_ooo]Z2ol0000doookJP00:Ooo
nfX5o`000?oooo]Z6OoonfX;o`0003Wooo]Z3Ol0001[oookJPco0000<_oonfX002Wooo]Z1Ol0003o
oookJQ[ooo]Z3?l0000ioookJPgo0000JooonfX<o`00033ooo]Z000YoookJPGo0000oooonfXLoook
JPco0000>?oonfX>o`0006cooo]Z2_l0000_oookJP00:OoonfX5o`000?oooo]Z7_oonfX;o`0003_o
oo]Z3?l0001/oookJPco0000:ooonfX002Wooo]Z1Ol0003ooookJR7ooo]Z2_l0000joookJPko0000
JooonfX<o`0002Wooo]Z000YoookJPGo0000oooonfXSoookJP[o0000>_oonfX>o`0006_ooo]Z2ol0
000XoookJP00:OoonfX5o`000?oooo]Z9OoonfX;o`0003Wooo]Z3Ol0001[oookJPco00009_oonfX0
02Wooo]Z1Ol0003ooookJRKooo]Z3?l0000ioookJPgo0000KOoonfX:o`0002Cooo]Z000YoookJPGo
0000oooonfXXoookJPco0000>?oonfX>o`0006gooo]Z2Ol0000SoookJP00:OoonfX5o`000?oooo]Z
:_oonfX;o`0003_ooo]Z3?l0001/oookJP[o00008OoonfX002Wooo]Z1Ol0003ooookJRgooo]Z2_l0
000joookJPco0000KOoonfX:o`0001oooo]Z000YoookJPGo0000oooonfX_oookJP[o0000>_oonfX<
o`0006gooo]Z2_l0000MoookJP00:OoonfX5o`000?oooo]Z<OoonfX:o`0003[ooo]Z3?l0001/oook
JP[o00007?oonfX002Wooo]Z1Ol0003ooookJS;ooo]Z2_l0000koookJPco0000K?oonfX:o`0001[o
oo]Z000YoookJPGo0000oooonfXdoookJP[o0000>_oonfX<o`0006gooo]Z2_l0000HoookJP00:Ooo
nfX5o`000?oooo]Z=_oonfX:o`0003[ooo]Z3?l0001]oookJPWo00005ooonfX002Wooo]Z1Ol0003o
oookJSSooo]Z2Ol0000koookJPco0000K?oonfX:o`0001Gooo]Z000CoookJP?o001o1OoonfX5o`00
O`Wooo]Z1Ol0003ooookJSWooo]Z2_l0000joookJPco0000KOoonfX:o`0001?ooo]Z000CoookJP?o
001o1?oonfX7o`00O`Sooo]Z1Ol0003ooookJS_ooo]Z2_l0000joookJPco0000KOoonfX9o`0001;o
oo]Z000CoookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJSgo
oo]Z2_l0000joookJPco0000K?oonfX9o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l7oookJPGo0000oooonfXnoookJP[o0000>ooonfX<o`0006cooo]Z2?l0000@oookJP004ooo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1ooonfX7o`000?oooo]Z?_oonfX:o`0003[ooo]Z3?l0
001]oookJPGo00004OoonfX001?ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003o
oookJT;ooo]Z2_l0000joookJPco0000K?oonfX4o`00017ooo]Z000CoookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007l7oookJPGo0000oooonfY4oookJPWo0000>ooonfX<o`0007oooo]Z000CoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfY5oookJP[o0000>_oonfX<o`0007ko
oo]Z000CoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfY7oookJP[o0000
>_oonfX<o`0007cooo]Z000@oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooo
nfY9oookJP[o0000>_oonfX<o`0007[ooo]Z000@oookJPKo001o1?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Sooo]Z1Ol0003ooookJT[ooo]Z2_l0000koookJP_o0000NOoonfX001;ooo]Z1?l007l4
oookJPOo001o2?oonfX5o`000?oooo]ZC?oonfX8o`0003cooo]Z3?l0001goookJP004ooonfX3o`00
O`Gooo]Z1Ol007l9oookJPGo0000oooonfY>oookJPSo0000??oonfX:o`0007Oooo]Z000YoookJPGo
0000oooonfY@oookJPSo0000??oonfX:o`0007Gooo]Z000YoookJPGo0000oooonfY@oookJPWo0000
??oonfX;o`0007?ooo]Z000YoookJPGo0000oooonfYAoookJP[o0000??oonfX:o`0007;ooo]Z000Y
oookJPGo0000oooonfYCoookJP[o0000??oonfX:o`00073ooo]Z000YoookJPGo0000oooonfYEoook
JPWo0000>ooonfX<o`0006kooo]Z000YoookJPGo0000oooonfYFoookJPWo0000??oonfX;o`0006go
oo]Z000YoookJPGo0000oooonfYHoookJPSo0000??oonfX;o`0006cooo]Z000YoookJPGo0000oooo
nfYJoookJPSo0000??oonfX:o`0006_ooo]Z000YoookJPGo0000oooonfYKoookJPWo0000??oonfX:
o`0006Wooo]Z000YoookJPGo0000oooonfYLoookJPWo0000??oonfX;o`0006Oooo]Z000YoookJPGo
0000oooonfYMoookJPWo0000?OoonfX:o`0006Kooo]Z000YoookJPGo0000oooonfYOoookJPSo0000
??oonfX<o`0006Cooo]Z000YoookJPGo0000oooonfYQoookJPSo0000??oonfX:o`0006Cooo]Z000Y
oookJPGo0000oooonfYRoookJPWo0000??oonfX:o`0006;ooo]Z000YoookJPGo0000oooonfYSoook
JPWo0000??oonfX:o`00067ooo]Z000YoookJPGo0000oooonfYToookJPWo0000?OoonfX:o`0005oo
oo]Z000YoookJPGo0000oooonfYVoookJPSo0000?_oonfX8o`0005oooo]Z000YoookJPGo0000oooo
nfYXoookJPSo0000??oonfX:o`0005gooo]Z000YoookJPGo0000oooonfYYoookJPSo0000??oonfX;
o`0005_ooo]Z000YoookJPGo0000oooonfYZoookJPSo0000?OoonfX:o`0005[ooo]Z000YoookJPGo
0000oooonfY[oookJPSo0000?_oonfX8o`0005[ooo]Z000YoookJPGo0000oooonfY]oookJPSo0000
??oonfX:o`0005Sooo]Z000YoookJPGo0000oooonfY^oookJPWo0000??oonfX:o`0005Kooo]Z000Y
oookJPGo0000oooonfY_oookJPWo0000??oonfX:o`0005Gooo]Z000YoookJPGo0000oooonfY`oook
JPSo0000?_oonfX9o`0005Cooo]Z000YoookJPGo0000oooonfYboookJPSo0000??oonfX:o`0005?o
oo]Z000YoookJPGo0000oooonfYdoookJPOo0000?OoonfX:o`00057ooo]Z000YoookJPGo0000oooo
nfYdoookJPSo0000?OoonfX;o`0004oooo]Z000YoookJPGo0000oooonfYeoookJPSo0000?_oonfX9
o`0004oooo]Z000YoookJPGo0000oooonfYgoookJPSo0000??oonfX:o`0004kooo]Z000YoookJPGo
0000oooonfYhoookJPSo0000?OoonfX:o`0004cooo]Z000YoookJPGo0000oooonfYioookJPSo0000
?_oonfX8o`0004cooo]Z000YoookJPGo0000oooonfYjoookJPWo0000?OoonfX9o`0004[ooo]Z000Y
oookJPGo0000oooonfYloookJPSo0000??oonfX:o`0004Wooo]Z000YoookJPGo0000oooonfYmoook
JPOo0000?_oonfX9o`0004Sooo]Z000YoookJPGo0000oooonfYnoookJPSo0000?_oonfX8o`0004Oo
oo]Z000YoookJPGo0000oooonfZ0oookJPOo0000?OoonfX:o`0004Gooo]Z000YoookJPGo0000oooo
nfZ0oookJPSo0000?OoonfX9o`0004Gooo]Z000CoookJP?o001o1OoonfX5o`00O`Wooo]Z1Ol0003o
oookJX7ooo]Z2?l0000noookJPWo0000@ooonfX001?ooo]Z0ol007l4oookJPOo001o2?oonfX5o`00
0?oooo]ZPooonfX7o`0003gooo]Z2_l00012oookJP004ooonfX3o`00O`?ooo]Z1?l007l01?oonf[o
001oo`00Ool007l8oookJPGo0000oooonfZ4oookJPOo0000?_oonfX8o`0004;ooo]Z000CoookJP?o
001o0ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonfZ5oookJPSo0000?_oonfX8o`00043o
oo]Z000CoookJP?o001o2OoonfX3o`00O`Oooo]Z1ol0003ooookJXCooo]Z2?l0000moookJP[o0000
?_oonfX001?ooo]Z0ol007l9oookJP?o001o1ooonfX5o`000?oooo]ZQooonfX8o`0003gooo]Z2Ol0
000noookJP004ooonfX3o`00O`Cooo]Z0_l007l2oookJPCo001o1ooonfX5o`000?oooo]ZR?oonfX8
o`0003kooo]Z2?l0000moookJP004ooonfX3o`00O`Cooo]Z1ol007l8oookJPGo0000oooonfZ:oook
JPKo0000?_oonfX:o`0003_ooo]Z000CoookJP?o001o1?oonfX6o`00O`Wooo]Z1Ol0003ooookJX_o
oo]Z1ol0000noookJPSo0000>ooonfX0013ooo]Z1_l007l4oookJP;o001o3OoonfX5o`000?oooo]Z
S?oonfX7o`0003kooo]Z2Ol0000ioookJP004?oonfX6o`00O`Cooo]Z0_l007l=oookJPGo0000oooo
nfZ<oookJPSo0000?OoonfX9o`0003Wooo]Z000BoookJPCo001o1OoonfX7o`00O`Oooo]Z1Ol0003o
oookJXgooo]Z2?l0000noookJPWo0000=ooonfX001?ooo]Z0ol007l5oookJPOo001o1ooonfX5o`00
0?oooo]ZSooonfX7o`0003kooo]Z2Ol0000foookJP00:OoonfX5o`000?oooo]ZT?oonfX7o`0003ko
oo]Z2?l0000foookJP00:OoonfX5o`000?oooo]ZTOoonfX7o`0003oooo]Z2?l0000doookJP00:Ooo
nfX5o`000?oooo]ZT_oonfX7o`0003kooo]Z2?l0000doookJP00:OoonfX5o`000?oooo]ZTooonfX8
o`0003gooo]Z2Ol0000boookJP00:OoonfX5o`000?oooo]ZU?oonfX8o`0003kooo]Z2?l0000aoook
JP00:OoonfX5o`000?oooo]ZUOoonfX7o`0003kooo]Z2Ol0000`oookJP00:OoonfX5o`000?oooo]Z
U_oonfX7o`0003oooo]Z2?l0000_oookJP00:OoonfX5o`000?oooo]ZV?oonfX6o`0003kooo]Z2?l0
000_oookJP00:OoonfX5o`000?oooo]ZV?oonfX8o`0003gooo]Z2Ol0000]oookJP00:OoonfX5o`00
0?oooo]ZVOoonfX8o`0003kooo]Z2Ol0000[oookJP00:OoonfX5o`000?oooo]ZV_oonfX7o`0003ko
oo]Z2Ol0000[oookJP00:OoonfX5o`000?oooo]ZVooonfX7o`0003oooo]Z2?l0000ZoookJP00:Ooo
nfX5o`000?oooo]ZWOoonfX6o`0003kooo]Z2Ol0000YoookJP00:OoonfX5o`000?oooo]ZWOoonfX7
o`0003oooo]Z2?l0000XoookJP00:OoonfX5o`000?oooo]ZW_oonfX7o`0003oooo]Z1ol0000Xoook
JP00:OoonfX5o`000?oooo]ZWooonfX7o`0003kooo]Z2Ol0000VoookJP00:OoonfX5o`000?oooo]Z
X?oonfX7o`0003oooo]Z1ol0000VoookJP00:OoonfX5o`000?oooo]ZXOoonfX7o`0003kooo]Z2?l0
000UoookJP00:OoonfX5o`000?oooo]ZX_oonfX7o`0003oooo]Z2?l0000SoookJP00:OoonfX5o`00
0?oooo]ZXooonfX7o`0003kooo]Z2?l0000SoookJP00:OoonfX5o`000?oooo]ZY?oonfX7o`0003ko
oo]Z2Ol0000QoookJP00:OoonfX5o`000?oooo]ZYOoonfX7o`0003gooo]Z2Ol0000QoookJP00:Ooo
nfX5o`000?oooo]ZY_oonfX7o`0003kooo]Z2Ol0000OoookJP00:OoonfX5o`000?oooo]ZYooonfX6
o`0003oooo]Z2?l0000OoookJP00:OoonfX5o`000?oooo]ZZ?oonfX6o`0003oooo]Z2?l0000Noook
JP00:OoonfX5o`000?oooo]ZZOoonfX6o`0003oooo]Z2?l0000MoookJP00:OoonfX5o`000?oooo]Z
ZOoonfX7o`0003oooo]Z2?l0000LoookJP00:OoonfX5o`000?oooo]ZZ_oonfX7o`0003oooo]Z1ol0
000LoookJP00:OoonfX5o`000?oooo]ZZooonfX7o`0003kooo]Z2Ol0000JoookJP00:OoonfX5o`00
0?oooo]Z[?oonfX7o`0003oooo]Z1ol0000JoookJP00:OoonfX5o`000?oooo]Z[OoonfX7o`0003ko
oo]Z2?l0000IoookJP00:OoonfX5o`000?oooo]Z[_oonfX6o`00043ooo]Z1ol0000HoookJP00:Ooo
nfX5o`000?oooo]Z[ooonfX7o`0003kooo]Z2?l0000GoookJP00:OoonfX5o`000?oooo]Z/?oonfX6
o`0003oooo]Z1ol0000GoookJP00:OoonfX5o`000?oooo]Z/?oonfX7o`0003kooo]Z2Ol0000Eoook
JP00:OoonfX5o`000?oooo]Z/OoonfX7o`0003oooo]Z1ol0000EoookJP00:OoonfX5o`000?oooo]Z
/_oonfX7o`0003kooo]Z2Ol0000CoookJP00:OoonfX5o`000?oooo]Z/ooonfX6o`00043ooo]Z1ol0
000CoookJP00:OoonfX5o`000?oooo]Z]?oonfX7o`0003kooo]Z2?l0000BoookJP003ooonfX9o`00
O`?ooo]Z1Ol007l9oookJPGo0000oooonfZeoookJPKo0000@?oonfX6o`0001;ooo]Z000?oookJPWo
001o0_oonfX7o`00O`Sooo]Z1Ol0003ooookJ[Gooo]Z1ol0000ooookJPSo00004?oonfX000oooo]Z
1?l007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`000?oooo]Z]_oonfX7o`0003oo
oo]Z1ol0000@oookJP004?oonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]Z
]ooonfX7o`0003kooo]Z1ol0000@oookJP004OoonfX5o`00O`?ooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`000?oooo]Z]_oonfX7o`0003oooo]Z1Ol0000@oookJP004ooonfX4o`00O`;ooo]Z0ol007l3
oookJP?o001o1ooonfX5o`000?oooo]Z^OoonfX7o`0003kooo]Z1Ol0000@oookJP005?oonfX3o`00
O`;ooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oooo]Z^_oonfX6o`0005?ooo]Z000EoookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0003ooookJ[_ooo]Z1_l0001Boook
JP003ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1ooonfX5o`00
0?oooo]Z_?oonfX6o`00057ooo]Z000?oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l7oookJPGo0000oooonfZloookJPOo0000D?oonfX000oooo]Z1?l007l2oookJP?o
001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0003ooookJ[gooo]Z1ol0001?oook
JP004?oonfX7o`00O`?ooo]Z1ol007l8oookJPGo0000oooonfZnoookJPOo0000C_oonfX0017ooo]Z
1Ol007l5oookJPGo001o2OoonfX5o`000?oooo]Z_ooonfX6o`0004kooo]Z000YoookJPGo0000oooo
nf[0oookJPKo0000COoonfX002Wooo]Z1Ol0003ooookJ/7ooo]Z1_l0001<oookJP00:OoonfX5o`00
0?oooo]Z`OoonfX7o`0004_ooo]Z000YoookJPGo0000oooonf[2oookJPKo0000BooonfX002Wooo]Z
1Ol0003ooookJ/?ooo]Z1_l0001:oookJP00:OoonfX5o`000?oooo]Za?oonfX6o`0004Wooo]Z000Y
oookJPGo0000oooonf[4oookJPOo0000B?oonfX002Wooo]Z1Ol0003ooookJ/Gooo]Z1_l00018oook
JP00:OoonfX5o`000?oooo]ZoooonfXDoookJP00:OoonfX5o`000?oooo]ZoooonfXDoookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-25.4848, -11.704, 0.583309, \
0.0964325}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Making a similar plot for a family of curves corresponding to a \
negative \[Alpha] value gives\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[Trajectory[\(- .01\), \(- .5\)], 
      Trajectory[\(- .01\),  .5], Trajectory[\(- .01\), 1], 
      Trajectory[\(- .01\), 1.5], PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.205686 0.385799 [
[.18254 .19319 -12 -20 ]
[.18254 .19319 12 0 ]
[.34127 .19319 -17 -20 ]
[.34127 .19319 17 0 ]
[.5 .19319 -17 -20 ]
[.5 .19319 17 0 ]
[.65873 .19319 -17 -20 ]
[.65873 .19319 17 0 ]
[.81746 .19319 -17 -20 ]
[.81746 .19319 17 0 ]
[.97619 .19319 -17 -20 ]
[.97619 .19319 17 0 ]
[.01131 .01279 -41.9375 -10 ]
[.01131 .01279 0 10 ]
[.01131 .10924 -51.9375 -10 ]
[.01131 .10924 0 10 ]
[.01131 .30214 -39 -10 ]
[.01131 .30214 0 10 ]
[.01131 .39859 -29 -10 ]
[.01131 .39859 0 10 ]
[.01131 .49503 -39 -10 ]
[.01131 .49503 0 10 ]
[.01131 .59148 -14 -10 ]
[.01131 .59148 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .20569 m
.18254 .21194 L
s
gsave
.18254 .19319 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 .20569 m
.34127 .21194 L
s
gsave
.34127 .19319 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 .20569 m
.5 .21194 L
s
gsave
.5 .19319 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 .20569 m
.65873 .21194 L
s
gsave
.65873 .19319 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 .20569 m
.81746 .21194 L
s
gsave
.81746 .19319 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 .20569 m
.97619 .21194 L
s
gsave
.97619 .19319 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 .20569 m
.05556 .20944 L
s
.0873 .20569 m
.0873 .20944 L
s
.11905 .20569 m
.11905 .20944 L
s
.15079 .20569 m
.15079 .20944 L
s
.21429 .20569 m
.21429 .20944 L
s
.24603 .20569 m
.24603 .20944 L
s
.27778 .20569 m
.27778 .20944 L
s
.30952 .20569 m
.30952 .20944 L
s
.37302 .20569 m
.37302 .20944 L
s
.40476 .20569 m
.40476 .20944 L
s
.43651 .20569 m
.43651 .20944 L
s
.46825 .20569 m
.46825 .20944 L
s
.53175 .20569 m
.53175 .20944 L
s
.56349 .20569 m
.56349 .20944 L
s
.59524 .20569 m
.59524 .20944 L
s
.62698 .20569 m
.62698 .20944 L
s
.69048 .20569 m
.69048 .20944 L
s
.72222 .20569 m
.72222 .20944 L
s
.75397 .20569 m
.75397 .20944 L
s
.78571 .20569 m
.78571 .20944 L
s
.84921 .20569 m
.84921 .20944 L
s
.88095 .20569 m
.88095 .20944 L
s
.9127 .20569 m
.9127 .20944 L
s
.94444 .20569 m
.94444 .20944 L
s
.01 w
0 .20569 m
1 .20569 L
s
.25 Mabswid
.02381 .01279 m
.03006 .01279 L
s
gsave
.01131 .01279 -102.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .10924 m
.03006 .10924 L
s
gsave
.01131 .10924 -112.938 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .30214 m
.03006 .30214 L
s
gsave
.01131 .30214 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .39859 m
.03006 .39859 L
s
gsave
.01131 .39859 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .49503 m
.03006 .49503 L
s
gsave
.01131 .49503 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .59148 m
.03006 .59148 L
s
gsave
.01131 .59148 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03208 m
.02756 .03208 L
s
.02381 .05137 m
.02756 .05137 L
s
.02381 .07066 m
.02756 .07066 L
s
.02381 .08995 m
.02756 .08995 L
s
.02381 .12853 m
.02756 .12853 L
s
.02381 .14782 m
.02756 .14782 L
s
.02381 .16711 m
.02756 .16711 L
s
.02381 .1864 m
.02756 .1864 L
s
.02381 .22498 m
.02756 .22498 L
s
.02381 .24427 m
.02756 .24427 L
s
.02381 .26356 m
.02756 .26356 L
s
.02381 .28285 m
.02756 .28285 L
s
.02381 .32143 m
.02756 .32143 L
s
.02381 .34072 m
.02756 .34072 L
s
.02381 .36001 m
.02756 .36001 L
s
.02381 .3793 m
.02756 .3793 L
s
.02381 .41787 m
.02756 .41787 L
s
.02381 .43716 m
.02756 .43716 L
s
.02381 .45645 m
.02756 .45645 L
s
.02381 .47574 m
.02756 .47574 L
s
.02381 .51432 m
.02756 .51432 L
s
.02381 .53361 m
.02756 .53361 L
s
.02381 .5529 m
.02756 .5529 L
s
.02381 .57219 m
.02756 .57219 L
s
.02381 .61077 m
.02756 .61077 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02698 .01472 m
.03016 .01662 L
.03333 .01852 L
.03651 .02039 L
.03968 .02224 L
.04286 .02407 L
.04603 .02589 L
.04921 .02769 L
.05238 .02947 L
.05556 .03123 L
.05873 .03298 L
.0619 .0347 L
.06508 .03641 L
.06825 .0381 L
.07143 .03978 L
.0746 .04144 L
.07778 .04308 L
.08095 .04471 L
.08413 .04632 L
.0873 .04791 L
.09048 .04949 L
.09365 .05105 L
.09683 .0526 L
.1 .05413 L
.10317 .05564 L
.10635 .05714 L
.10952 .05863 L
.1127 .0601 L
.11587 .06156 L
.11905 .063 L
.12222 .06442 L
.1254 .06584 L
.12857 .06724 L
.13175 .06862 L
.13492 .06999 L
.1381 .07135 L
.14127 .07269 L
.14444 .07402 L
.14762 .07534 L
.15079 .07664 L
.15397 .07793 L
.15714 .07921 L
.16032 .08047 L
.16349 .08173 L
.16667 .08297 L
.16984 .08419 L
.17302 .08541 L
.17619 .08661 L
.17937 .0878 L
.18254 .08898 L
Mistroke
.18571 .09015 L
.18889 .0913 L
.19206 .09245 L
.19524 .09358 L
.19841 .0947 L
.20159 .09581 L
.20476 .09691 L
.20794 .098 L
.21111 .09907 L
.21429 .10014 L
.21746 .10119 L
.22063 .10224 L
.22381 .10327 L
.22698 .1043 L
.23016 .10531 L
.23333 .10632 L
.23651 .10731 L
.23968 .10829 L
.24286 .10927 L
.24603 .11023 L
.24921 .11119 L
.25238 .11213 L
.25556 .11307 L
.25873 .11399 L
.2619 .11491 L
.26508 .11582 L
.26825 .11672 L
.27143 .11761 L
.2746 .11849 L
.27778 .11936 L
.28095 .12022 L
.28413 .12108 L
.2873 .12192 L
.29048 .12276 L
.29365 .12359 L
.29683 .12441 L
.3 .12522 L
.30317 .12603 L
.30635 .12682 L
.30952 .12761 L
.3127 .12839 L
.31587 .12917 L
.31905 .12993 L
.32222 .13069 L
.3254 .13144 L
.32857 .13218 L
.33175 .13292 L
.33492 .13364 L
.3381 .13436 L
.34127 .13508 L
Mistroke
.34444 .13578 L
.34762 .13648 L
.35079 .13718 L
.35397 .13786 L
.35714 .13854 L
.36032 .13921 L
.36349 .13987 L
.36667 .14053 L
.36984 .14118 L
.37302 .14183 L
.37619 .14247 L
.37937 .1431 L
.38254 .14373 L
.38571 .14435 L
.38889 .14496 L
.39206 .14557 L
.39524 .14617 L
.39841 .14676 L
.40159 .14735 L
.40476 .14794 L
.40794 .14851 L
.41111 .14908 L
.41429 .14965 L
.41746 .15021 L
.42063 .15077 L
.42381 .15131 L
.42698 .15186 L
.43016 .1524 L
.43333 .15293 L
.43651 .15346 L
.43968 .15398 L
.44286 .1545 L
.44603 .15501 L
.44921 .15552 L
.45238 .15602 L
.45556 .15651 L
.45873 .15701 L
.4619 .15749 L
.46508 .15797 L
.46825 .15845 L
.47143 .15892 L
.4746 .15939 L
.47778 .15985 L
.48095 .16031 L
.48413 .16077 L
.4873 .16122 L
.49048 .16166 L
.49365 .1621 L
.49683 .16254 L
.5 .16297 L
Mistroke
.50317 .16339 L
.50635 .16382 L
.50952 .16424 L
.5127 .16465 L
.51587 .16506 L
.51905 .16547 L
.52222 .16587 L
.5254 .16627 L
.52857 .16666 L
.53175 .16705 L
.53492 .16744 L
.5381 .16782 L
.54127 .1682 L
.54444 .16857 L
.54762 .16895 L
.55079 .16931 L
.55397 .16968 L
.55714 .17004 L
.56032 .17039 L
.56349 .17075 L
.56667 .1711 L
.56984 .17144 L
.57302 .17178 L
.57619 .17212 L
.57937 .17246 L
.58254 .17279 L
.58571 .17312 L
.58889 .17345 L
.59206 .17377 L
.59524 .17409 L
.59841 .1744 L
.60159 .17472 L
.60476 .17503 L
.60794 .17533 L
.61111 .17564 L
.61429 .17594 L
.61746 .17623 L
.62063 .17653 L
.62381 .17682 L
.62698 .17711 L
.63016 .17739 L
.63333 .17768 L
.63651 .17796 L
.63968 .17823 L
.64286 .17851 L
.64603 .17878 L
.64921 .17905 L
.65238 .17932 L
.65556 .17958 L
.65873 .17984 L
Mistroke
.6619 .1801 L
.66508 .18036 L
.66825 .18061 L
.67143 .18086 L
.6746 .18111 L
.67778 .18135 L
.68095 .1816 L
.68413 .18184 L
.6873 .18208 L
.69048 .18231 L
.69365 .18255 L
.69683 .18278 L
.7 .18301 L
.70317 .18323 L
.70635 .18346 L
.70952 .18368 L
.7127 .1839 L
.71587 .18412 L
.71905 .18433 L
.72222 .18455 L
.7254 .18476 L
.72857 .18497 L
.73175 .18517 L
.73492 .18538 L
.7381 .18558 L
.74127 .18578 L
.74444 .18598 L
.74762 .18618 L
.75079 .18638 L
.75397 .18657 L
.75714 .18676 L
.76032 .18695 L
.76349 .18714 L
.76667 .18732 L
.76984 .18751 L
.77302 .18769 L
.77619 .18787 L
.77937 .18805 L
.78254 .18822 L
.78571 .1884 L
.78889 .18857 L
.79206 .18874 L
.79524 .18891 L
.79841 .18908 L
.80159 .18924 L
.80476 .18941 L
.80794 .18957 L
.81111 .18973 L
.81429 .18989 L
.81746 .19005 L
Mistroke
.82063 .19021 L
.82381 .19036 L
.82698 .19051 L
.83016 .19067 L
.83333 .19082 L
.83651 .19096 L
.83968 .19111 L
.84286 .19126 L
.84603 .1914 L
.84921 .19154 L
.85238 .19169 L
.85556 .19183 L
.85873 .19196 L
.8619 .1921 L
.86508 .19224 L
.86825 .19237 L
.87143 .19251 L
.8746 .19264 L
.87778 .19277 L
.88095 .1929 L
.88413 .19302 L
.8873 .19315 L
.89048 .19328 L
.89365 .1934 L
.89683 .19352 L
.9 .19365 L
.90317 .19377 L
.90635 .19388 L
.90952 .194 L
.9127 .19412 L
.91587 .19424 L
.91905 .19435 L
.92222 .19446 L
.9254 .19458 L
.92857 .19469 L
.93175 .1948 L
.93492 .19491 L
.9381 .19501 L
.94127 .19512 L
.94444 .19523 L
.94762 .19533 L
.95079 .19543 L
.95397 .19554 L
.95714 .19564 L
.96032 .19574 L
.96349 .19584 L
.96667 .19594 L
.96984 .19603 L
.97302 .19613 L
.97619 .19623 L
Mistroke
Mfstroke
.0001 w
.02698 .01472 -1.875 0 Mabsadd m
.02698 .01472 0 2.5 Mabsadd L
.02698 .01472 1.875 0 Mabsadd L
.02698 .01472 0 -2.5 Mabsadd L
.02698 .01472 -1.875 0 Mabsadd L closepath F
.03016 .01662 -1.875 0 Mabsadd m
.03016 .01662 0 2.5 Mabsadd L
.03016 .01662 1.875 0 Mabsadd L
.03016 .01662 0 -2.5 Mabsadd L
.03016 .01662 -1.875 0 Mabsadd L closepath F
.03333 .01852 -1.875 0 Mabsadd m
.03333 .01852 0 2.5 Mabsadd L
.03333 .01852 1.875 0 Mabsadd L
.03333 .01852 0 -2.5 Mabsadd L
.03333 .01852 -1.875 0 Mabsadd L closepath F
.03651 .02039 -1.875 0 Mabsadd m
.03651 .02039 0 2.5 Mabsadd L
.03651 .02039 1.875 0 Mabsadd L
.03651 .02039 0 -2.5 Mabsadd L
.03651 .02039 -1.875 0 Mabsadd L closepath F
.03968 .02224 -1.875 0 Mabsadd m
.03968 .02224 0 2.5 Mabsadd L
.03968 .02224 1.875 0 Mabsadd L
.03968 .02224 0 -2.5 Mabsadd L
.03968 .02224 -1.875 0 Mabsadd L closepath F
.04286 .02407 -1.875 0 Mabsadd m
.04286 .02407 0 2.5 Mabsadd L
.04286 .02407 1.875 0 Mabsadd L
.04286 .02407 0 -2.5 Mabsadd L
.04286 .02407 -1.875 0 Mabsadd L closepath F
.04603 .02589 -1.875 0 Mabsadd m
.04603 .02589 0 2.5 Mabsadd L
.04603 .02589 1.875 0 Mabsadd L
.04603 .02589 0 -2.5 Mabsadd L
.04603 .02589 -1.875 0 Mabsadd L closepath F
.04921 .02769 -1.875 0 Mabsadd m
.04921 .02769 0 2.5 Mabsadd L
.04921 .02769 1.875 0 Mabsadd L
.04921 .02769 0 -2.5 Mabsadd L
.04921 .02769 -1.875 0 Mabsadd L closepath F
.05238 .02947 -1.875 0 Mabsadd m
.05238 .02947 0 2.5 Mabsadd L
.05238 .02947 1.875 0 Mabsadd L
.05238 .02947 0 -2.5 Mabsadd L
.05238 .02947 -1.875 0 Mabsadd L closepath F
.05556 .03123 -1.875 0 Mabsadd m
.05556 .03123 0 2.5 Mabsadd L
.05556 .03123 1.875 0 Mabsadd L
.05556 .03123 0 -2.5 Mabsadd L
.05556 .03123 -1.875 0 Mabsadd L closepath F
.05873 .03298 -1.875 0 Mabsadd m
.05873 .03298 0 2.5 Mabsadd L
.05873 .03298 1.875 0 Mabsadd L
.05873 .03298 0 -2.5 Mabsadd L
.05873 .03298 -1.875 0 Mabsadd L closepath F
.0619 .0347 -1.875 0 Mabsadd m
.0619 .0347 0 2.5 Mabsadd L
.0619 .0347 1.875 0 Mabsadd L
.0619 .0347 0 -2.5 Mabsadd L
.0619 .0347 -1.875 0 Mabsadd L closepath F
.06508 .03641 -1.875 0 Mabsadd m
.06508 .03641 0 2.5 Mabsadd L
.06508 .03641 1.875 0 Mabsadd L
.06508 .03641 0 -2.5 Mabsadd L
.06508 .03641 -1.875 0 Mabsadd L closepath F
.06825 .0381 -1.875 0 Mabsadd m
.06825 .0381 0 2.5 Mabsadd L
.06825 .0381 1.875 0 Mabsadd L
.06825 .0381 0 -2.5 Mabsadd L
.06825 .0381 -1.875 0 Mabsadd L closepath F
.07143 .03978 -1.875 0 Mabsadd m
.07143 .03978 0 2.5 Mabsadd L
.07143 .03978 1.875 0 Mabsadd L
.07143 .03978 0 -2.5 Mabsadd L
.07143 .03978 -1.875 0 Mabsadd L closepath F
.0746 .04144 -1.875 0 Mabsadd m
.0746 .04144 0 2.5 Mabsadd L
.0746 .04144 1.875 0 Mabsadd L
.0746 .04144 0 -2.5 Mabsadd L
.0746 .04144 -1.875 0 Mabsadd L closepath F
.07778 .04308 -1.875 0 Mabsadd m
.07778 .04308 0 2.5 Mabsadd L
.07778 .04308 1.875 0 Mabsadd L
.07778 .04308 0 -2.5 Mabsadd L
.07778 .04308 -1.875 0 Mabsadd L closepath F
.08095 .04471 -1.875 0 Mabsadd m
.08095 .04471 0 2.5 Mabsadd L
.08095 .04471 1.875 0 Mabsadd L
.08095 .04471 0 -2.5 Mabsadd L
.08095 .04471 -1.875 0 Mabsadd L closepath F
.08413 .04632 -1.875 0 Mabsadd m
.08413 .04632 0 2.5 Mabsadd L
.08413 .04632 1.875 0 Mabsadd L
.08413 .04632 0 -2.5 Mabsadd L
.08413 .04632 -1.875 0 Mabsadd L closepath F
.0873 .04791 -1.875 0 Mabsadd m
.0873 .04791 0 2.5 Mabsadd L
.0873 .04791 1.875 0 Mabsadd L
.0873 .04791 0 -2.5 Mabsadd L
.0873 .04791 -1.875 0 Mabsadd L closepath F
.09048 .04949 -1.875 0 Mabsadd m
.09048 .04949 0 2.5 Mabsadd L
.09048 .04949 1.875 0 Mabsadd L
.09048 .04949 0 -2.5 Mabsadd L
.09048 .04949 -1.875 0 Mabsadd L closepath F
.09365 .05105 -1.875 0 Mabsadd m
.09365 .05105 0 2.5 Mabsadd L
.09365 .05105 1.875 0 Mabsadd L
.09365 .05105 0 -2.5 Mabsadd L
.09365 .05105 -1.875 0 Mabsadd L closepath F
.09683 .0526 -1.875 0 Mabsadd m
.09683 .0526 0 2.5 Mabsadd L
.09683 .0526 1.875 0 Mabsadd L
.09683 .0526 0 -2.5 Mabsadd L
.09683 .0526 -1.875 0 Mabsadd L closepath F
.1 .05413 -1.875 0 Mabsadd m
.1 .05413 0 2.5 Mabsadd L
.1 .05413 1.875 0 Mabsadd L
.1 .05413 0 -2.5 Mabsadd L
.1 .05413 -1.875 0 Mabsadd L closepath F
.10317 .05564 -1.875 0 Mabsadd m
.10317 .05564 0 2.5 Mabsadd L
.10317 .05564 1.875 0 Mabsadd L
.10317 .05564 0 -2.5 Mabsadd L
.10317 .05564 -1.875 0 Mabsadd L closepath F
.10635 .05714 -1.875 0 Mabsadd m
.10635 .05714 0 2.5 Mabsadd L
.10635 .05714 1.875 0 Mabsadd L
.10635 .05714 0 -2.5 Mabsadd L
.10635 .05714 -1.875 0 Mabsadd L closepath F
.10952 .05863 -1.875 0 Mabsadd m
.10952 .05863 0 2.5 Mabsadd L
.10952 .05863 1.875 0 Mabsadd L
.10952 .05863 0 -2.5 Mabsadd L
.10952 .05863 -1.875 0 Mabsadd L closepath F
.1127 .0601 -1.875 0 Mabsadd m
.1127 .0601 0 2.5 Mabsadd L
.1127 .0601 1.875 0 Mabsadd L
.1127 .0601 0 -2.5 Mabsadd L
.1127 .0601 -1.875 0 Mabsadd L closepath F
.11587 .06156 -1.875 0 Mabsadd m
.11587 .06156 0 2.5 Mabsadd L
.11587 .06156 1.875 0 Mabsadd L
.11587 .06156 0 -2.5 Mabsadd L
.11587 .06156 -1.875 0 Mabsadd L closepath F
.11905 .063 -1.875 0 Mabsadd m
.11905 .063 0 2.5 Mabsadd L
.11905 .063 1.875 0 Mabsadd L
.11905 .063 0 -2.5 Mabsadd L
.11905 .063 -1.875 0 Mabsadd L closepath F
.12222 .06442 -1.875 0 Mabsadd m
.12222 .06442 0 2.5 Mabsadd L
.12222 .06442 1.875 0 Mabsadd L
.12222 .06442 0 -2.5 Mabsadd L
.12222 .06442 -1.875 0 Mabsadd L closepath F
.1254 .06584 -1.875 0 Mabsadd m
.1254 .06584 0 2.5 Mabsadd L
.1254 .06584 1.875 0 Mabsadd L
.1254 .06584 0 -2.5 Mabsadd L
.1254 .06584 -1.875 0 Mabsadd L closepath F
.12857 .06724 -1.875 0 Mabsadd m
.12857 .06724 0 2.5 Mabsadd L
.12857 .06724 1.875 0 Mabsadd L
.12857 .06724 0 -2.5 Mabsadd L
.12857 .06724 -1.875 0 Mabsadd L closepath F
.13175 .06862 -1.875 0 Mabsadd m
.13175 .06862 0 2.5 Mabsadd L
.13175 .06862 1.875 0 Mabsadd L
.13175 .06862 0 -2.5 Mabsadd L
.13175 .06862 -1.875 0 Mabsadd L closepath F
.13492 .06999 -1.875 0 Mabsadd m
.13492 .06999 0 2.5 Mabsadd L
.13492 .06999 1.875 0 Mabsadd L
.13492 .06999 0 -2.5 Mabsadd L
.13492 .06999 -1.875 0 Mabsadd L closepath F
.1381 .07135 -1.875 0 Mabsadd m
.1381 .07135 0 2.5 Mabsadd L
.1381 .07135 1.875 0 Mabsadd L
.1381 .07135 0 -2.5 Mabsadd L
.1381 .07135 -1.875 0 Mabsadd L closepath F
.14127 .07269 -1.875 0 Mabsadd m
.14127 .07269 0 2.5 Mabsadd L
.14127 .07269 1.875 0 Mabsadd L
.14127 .07269 0 -2.5 Mabsadd L
.14127 .07269 -1.875 0 Mabsadd L closepath F
.14444 .07402 -1.875 0 Mabsadd m
.14444 .07402 0 2.5 Mabsadd L
.14444 .07402 1.875 0 Mabsadd L
.14444 .07402 0 -2.5 Mabsadd L
.14444 .07402 -1.875 0 Mabsadd L closepath F
.14762 .07534 -1.875 0 Mabsadd m
.14762 .07534 0 2.5 Mabsadd L
.14762 .07534 1.875 0 Mabsadd L
.14762 .07534 0 -2.5 Mabsadd L
.14762 .07534 -1.875 0 Mabsadd L closepath F
.15079 .07664 -1.875 0 Mabsadd m
.15079 .07664 0 2.5 Mabsadd L
.15079 .07664 1.875 0 Mabsadd L
.15079 .07664 0 -2.5 Mabsadd L
.15079 .07664 -1.875 0 Mabsadd L closepath F
.15397 .07793 -1.875 0 Mabsadd m
.15397 .07793 0 2.5 Mabsadd L
.15397 .07793 1.875 0 Mabsadd L
.15397 .07793 0 -2.5 Mabsadd L
.15397 .07793 -1.875 0 Mabsadd L closepath F
.15714 .07921 -1.875 0 Mabsadd m
.15714 .07921 0 2.5 Mabsadd L
.15714 .07921 1.875 0 Mabsadd L
.15714 .07921 0 -2.5 Mabsadd L
.15714 .07921 -1.875 0 Mabsadd L closepath F
.16032 .08047 -1.875 0 Mabsadd m
.16032 .08047 0 2.5 Mabsadd L
.16032 .08047 1.875 0 Mabsadd L
.16032 .08047 0 -2.5 Mabsadd L
.16032 .08047 -1.875 0 Mabsadd L closepath F
.16349 .08173 -1.875 0 Mabsadd m
.16349 .08173 0 2.5 Mabsadd L
.16349 .08173 1.875 0 Mabsadd L
.16349 .08173 0 -2.5 Mabsadd L
.16349 .08173 -1.875 0 Mabsadd L closepath F
.16667 .08297 -1.875 0 Mabsadd m
.16667 .08297 0 2.5 Mabsadd L
.16667 .08297 1.875 0 Mabsadd L
.16667 .08297 0 -2.5 Mabsadd L
.16667 .08297 -1.875 0 Mabsadd L closepath F
.16984 .08419 -1.875 0 Mabsadd m
.16984 .08419 0 2.5 Mabsadd L
.16984 .08419 1.875 0 Mabsadd L
.16984 .08419 0 -2.5 Mabsadd L
.16984 .08419 -1.875 0 Mabsadd L closepath F
.17302 .08541 -1.875 0 Mabsadd m
.17302 .08541 0 2.5 Mabsadd L
.17302 .08541 1.875 0 Mabsadd L
.17302 .08541 0 -2.5 Mabsadd L
.17302 .08541 -1.875 0 Mabsadd L closepath F
.17619 .08661 -1.875 0 Mabsadd m
.17619 .08661 0 2.5 Mabsadd L
.17619 .08661 1.875 0 Mabsadd L
.17619 .08661 0 -2.5 Mabsadd L
.17619 .08661 -1.875 0 Mabsadd L closepath F
.17937 .0878 -1.875 0 Mabsadd m
.17937 .0878 0 2.5 Mabsadd L
.17937 .0878 1.875 0 Mabsadd L
.17937 .0878 0 -2.5 Mabsadd L
.17937 .0878 -1.875 0 Mabsadd L closepath F
.18254 .08898 -1.875 0 Mabsadd m
.18254 .08898 0 2.5 Mabsadd L
.18254 .08898 1.875 0 Mabsadd L
.18254 .08898 0 -2.5 Mabsadd L
.18254 .08898 -1.875 0 Mabsadd L closepath F
.18571 .09015 -1.875 0 Mabsadd m
.18571 .09015 0 2.5 Mabsadd L
.18571 .09015 1.875 0 Mabsadd L
.18571 .09015 0 -2.5 Mabsadd L
.18571 .09015 -1.875 0 Mabsadd L closepath F
.18889 .0913 -1.875 0 Mabsadd m
.18889 .0913 0 2.5 Mabsadd L
.18889 .0913 1.875 0 Mabsadd L
.18889 .0913 0 -2.5 Mabsadd L
.18889 .0913 -1.875 0 Mabsadd L closepath F
.19206 .09245 -1.875 0 Mabsadd m
.19206 .09245 0 2.5 Mabsadd L
.19206 .09245 1.875 0 Mabsadd L
.19206 .09245 0 -2.5 Mabsadd L
.19206 .09245 -1.875 0 Mabsadd L closepath F
.19524 .09358 -1.875 0 Mabsadd m
.19524 .09358 0 2.5 Mabsadd L
.19524 .09358 1.875 0 Mabsadd L
.19524 .09358 0 -2.5 Mabsadd L
.19524 .09358 -1.875 0 Mabsadd L closepath F
.19841 .0947 -1.875 0 Mabsadd m
.19841 .0947 0 2.5 Mabsadd L
.19841 .0947 1.875 0 Mabsadd L
.19841 .0947 0 -2.5 Mabsadd L
.19841 .0947 -1.875 0 Mabsadd L closepath F
.20159 .09581 -1.875 0 Mabsadd m
.20159 .09581 0 2.5 Mabsadd L
.20159 .09581 1.875 0 Mabsadd L
.20159 .09581 0 -2.5 Mabsadd L
.20159 .09581 -1.875 0 Mabsadd L closepath F
.20476 .09691 -1.875 0 Mabsadd m
.20476 .09691 0 2.5 Mabsadd L
.20476 .09691 1.875 0 Mabsadd L
.20476 .09691 0 -2.5 Mabsadd L
.20476 .09691 -1.875 0 Mabsadd L closepath F
.20794 .098 -1.875 0 Mabsadd m
.20794 .098 0 2.5 Mabsadd L
.20794 .098 1.875 0 Mabsadd L
.20794 .098 0 -2.5 Mabsadd L
.20794 .098 -1.875 0 Mabsadd L closepath F
.21111 .09907 -1.875 0 Mabsadd m
.21111 .09907 0 2.5 Mabsadd L
.21111 .09907 1.875 0 Mabsadd L
.21111 .09907 0 -2.5 Mabsadd L
.21111 .09907 -1.875 0 Mabsadd L closepath F
.21429 .10014 -1.875 0 Mabsadd m
.21429 .10014 0 2.5 Mabsadd L
.21429 .10014 1.875 0 Mabsadd L
.21429 .10014 0 -2.5 Mabsadd L
.21429 .10014 -1.875 0 Mabsadd L closepath F
.21746 .10119 -1.875 0 Mabsadd m
.21746 .10119 0 2.5 Mabsadd L
.21746 .10119 1.875 0 Mabsadd L
.21746 .10119 0 -2.5 Mabsadd L
.21746 .10119 -1.875 0 Mabsadd L closepath F
.22063 .10224 -1.875 0 Mabsadd m
.22063 .10224 0 2.5 Mabsadd L
.22063 .10224 1.875 0 Mabsadd L
.22063 .10224 0 -2.5 Mabsadd L
.22063 .10224 -1.875 0 Mabsadd L closepath F
.22381 .10327 -1.875 0 Mabsadd m
.22381 .10327 0 2.5 Mabsadd L
.22381 .10327 1.875 0 Mabsadd L
.22381 .10327 0 -2.5 Mabsadd L
.22381 .10327 -1.875 0 Mabsadd L closepath F
.22698 .1043 -1.875 0 Mabsadd m
.22698 .1043 0 2.5 Mabsadd L
.22698 .1043 1.875 0 Mabsadd L
.22698 .1043 0 -2.5 Mabsadd L
.22698 .1043 -1.875 0 Mabsadd L closepath F
.23016 .10531 -1.875 0 Mabsadd m
.23016 .10531 0 2.5 Mabsadd L
.23016 .10531 1.875 0 Mabsadd L
.23016 .10531 0 -2.5 Mabsadd L
.23016 .10531 -1.875 0 Mabsadd L closepath F
.23333 .10632 -1.875 0 Mabsadd m
.23333 .10632 0 2.5 Mabsadd L
.23333 .10632 1.875 0 Mabsadd L
.23333 .10632 0 -2.5 Mabsadd L
.23333 .10632 -1.875 0 Mabsadd L closepath F
.23651 .10731 -1.875 0 Mabsadd m
.23651 .10731 0 2.5 Mabsadd L
.23651 .10731 1.875 0 Mabsadd L
.23651 .10731 0 -2.5 Mabsadd L
.23651 .10731 -1.875 0 Mabsadd L closepath F
.23968 .10829 -1.875 0 Mabsadd m
.23968 .10829 0 2.5 Mabsadd L
.23968 .10829 1.875 0 Mabsadd L
.23968 .10829 0 -2.5 Mabsadd L
.23968 .10829 -1.875 0 Mabsadd L closepath F
.24286 .10927 -1.875 0 Mabsadd m
.24286 .10927 0 2.5 Mabsadd L
.24286 .10927 1.875 0 Mabsadd L
.24286 .10927 0 -2.5 Mabsadd L
.24286 .10927 -1.875 0 Mabsadd L closepath F
.24603 .11023 -1.875 0 Mabsadd m
.24603 .11023 0 2.5 Mabsadd L
.24603 .11023 1.875 0 Mabsadd L
.24603 .11023 0 -2.5 Mabsadd L
.24603 .11023 -1.875 0 Mabsadd L closepath F
.24921 .11119 -1.875 0 Mabsadd m
.24921 .11119 0 2.5 Mabsadd L
.24921 .11119 1.875 0 Mabsadd L
.24921 .11119 0 -2.5 Mabsadd L
.24921 .11119 -1.875 0 Mabsadd L closepath F
.25238 .11213 -1.875 0 Mabsadd m
.25238 .11213 0 2.5 Mabsadd L
.25238 .11213 1.875 0 Mabsadd L
.25238 .11213 0 -2.5 Mabsadd L
.25238 .11213 -1.875 0 Mabsadd L closepath F
.25556 .11307 -1.875 0 Mabsadd m
.25556 .11307 0 2.5 Mabsadd L
.25556 .11307 1.875 0 Mabsadd L
.25556 .11307 0 -2.5 Mabsadd L
.25556 .11307 -1.875 0 Mabsadd L closepath F
.25873 .11399 -1.875 0 Mabsadd m
.25873 .11399 0 2.5 Mabsadd L
.25873 .11399 1.875 0 Mabsadd L
.25873 .11399 0 -2.5 Mabsadd L
.25873 .11399 -1.875 0 Mabsadd L closepath F
.2619 .11491 -1.875 0 Mabsadd m
.2619 .11491 0 2.5 Mabsadd L
.2619 .11491 1.875 0 Mabsadd L
.2619 .11491 0 -2.5 Mabsadd L
.2619 .11491 -1.875 0 Mabsadd L closepath F
.26508 .11582 -1.875 0 Mabsadd m
.26508 .11582 0 2.5 Mabsadd L
.26508 .11582 1.875 0 Mabsadd L
.26508 .11582 0 -2.5 Mabsadd L
.26508 .11582 -1.875 0 Mabsadd L closepath F
.26825 .11672 -1.875 0 Mabsadd m
.26825 .11672 0 2.5 Mabsadd L
.26825 .11672 1.875 0 Mabsadd L
.26825 .11672 0 -2.5 Mabsadd L
.26825 .11672 -1.875 0 Mabsadd L closepath F
.27143 .11761 -1.875 0 Mabsadd m
.27143 .11761 0 2.5 Mabsadd L
.27143 .11761 1.875 0 Mabsadd L
.27143 .11761 0 -2.5 Mabsadd L
.27143 .11761 -1.875 0 Mabsadd L closepath F
.2746 .11849 -1.875 0 Mabsadd m
.2746 .11849 0 2.5 Mabsadd L
.2746 .11849 1.875 0 Mabsadd L
.2746 .11849 0 -2.5 Mabsadd L
.2746 .11849 -1.875 0 Mabsadd L closepath F
.27778 .11936 -1.875 0 Mabsadd m
.27778 .11936 0 2.5 Mabsadd L
.27778 .11936 1.875 0 Mabsadd L
.27778 .11936 0 -2.5 Mabsadd L
.27778 .11936 -1.875 0 Mabsadd L closepath F
.28095 .12022 -1.875 0 Mabsadd m
.28095 .12022 0 2.5 Mabsadd L
.28095 .12022 1.875 0 Mabsadd L
.28095 .12022 0 -2.5 Mabsadd L
.28095 .12022 -1.875 0 Mabsadd L closepath F
.28413 .12108 -1.875 0 Mabsadd m
.28413 .12108 0 2.5 Mabsadd L
.28413 .12108 1.875 0 Mabsadd L
.28413 .12108 0 -2.5 Mabsadd L
.28413 .12108 -1.875 0 Mabsadd L closepath F
.2873 .12192 -1.875 0 Mabsadd m
.2873 .12192 0 2.5 Mabsadd L
.2873 .12192 1.875 0 Mabsadd L
.2873 .12192 0 -2.5 Mabsadd L
.2873 .12192 -1.875 0 Mabsadd L closepath F
.29048 .12276 -1.875 0 Mabsadd m
.29048 .12276 0 2.5 Mabsadd L
.29048 .12276 1.875 0 Mabsadd L
.29048 .12276 0 -2.5 Mabsadd L
.29048 .12276 -1.875 0 Mabsadd L closepath F
.29365 .12359 -1.875 0 Mabsadd m
.29365 .12359 0 2.5 Mabsadd L
.29365 .12359 1.875 0 Mabsadd L
.29365 .12359 0 -2.5 Mabsadd L
.29365 .12359 -1.875 0 Mabsadd L closepath F
.29683 .12441 -1.875 0 Mabsadd m
.29683 .12441 0 2.5 Mabsadd L
.29683 .12441 1.875 0 Mabsadd L
.29683 .12441 0 -2.5 Mabsadd L
.29683 .12441 -1.875 0 Mabsadd L closepath F
.3 .12522 -1.875 0 Mabsadd m
.3 .12522 0 2.5 Mabsadd L
.3 .12522 1.875 0 Mabsadd L
.3 .12522 0 -2.5 Mabsadd L
.3 .12522 -1.875 0 Mabsadd L closepath F
.30317 .12603 -1.875 0 Mabsadd m
.30317 .12603 0 2.5 Mabsadd L
.30317 .12603 1.875 0 Mabsadd L
.30317 .12603 0 -2.5 Mabsadd L
.30317 .12603 -1.875 0 Mabsadd L closepath F
.30635 .12682 -1.875 0 Mabsadd m
.30635 .12682 0 2.5 Mabsadd L
.30635 .12682 1.875 0 Mabsadd L
.30635 .12682 0 -2.5 Mabsadd L
.30635 .12682 -1.875 0 Mabsadd L closepath F
.30952 .12761 -1.875 0 Mabsadd m
.30952 .12761 0 2.5 Mabsadd L
.30952 .12761 1.875 0 Mabsadd L
.30952 .12761 0 -2.5 Mabsadd L
.30952 .12761 -1.875 0 Mabsadd L closepath F
.3127 .12839 -1.875 0 Mabsadd m
.3127 .12839 0 2.5 Mabsadd L
.3127 .12839 1.875 0 Mabsadd L
.3127 .12839 0 -2.5 Mabsadd L
.3127 .12839 -1.875 0 Mabsadd L closepath F
.31587 .12917 -1.875 0 Mabsadd m
.31587 .12917 0 2.5 Mabsadd L
.31587 .12917 1.875 0 Mabsadd L
.31587 .12917 0 -2.5 Mabsadd L
.31587 .12917 -1.875 0 Mabsadd L closepath F
.31905 .12993 -1.875 0 Mabsadd m
.31905 .12993 0 2.5 Mabsadd L
.31905 .12993 1.875 0 Mabsadd L
.31905 .12993 0 -2.5 Mabsadd L
.31905 .12993 -1.875 0 Mabsadd L closepath F
.32222 .13069 -1.875 0 Mabsadd m
.32222 .13069 0 2.5 Mabsadd L
.32222 .13069 1.875 0 Mabsadd L
.32222 .13069 0 -2.5 Mabsadd L
.32222 .13069 -1.875 0 Mabsadd L closepath F
.3254 .13144 -1.875 0 Mabsadd m
.3254 .13144 0 2.5 Mabsadd L
.3254 .13144 1.875 0 Mabsadd L
.3254 .13144 0 -2.5 Mabsadd L
.3254 .13144 -1.875 0 Mabsadd L closepath F
.32857 .13218 -1.875 0 Mabsadd m
.32857 .13218 0 2.5 Mabsadd L
.32857 .13218 1.875 0 Mabsadd L
.32857 .13218 0 -2.5 Mabsadd L
.32857 .13218 -1.875 0 Mabsadd L closepath F
.33175 .13292 -1.875 0 Mabsadd m
.33175 .13292 0 2.5 Mabsadd L
.33175 .13292 1.875 0 Mabsadd L
.33175 .13292 0 -2.5 Mabsadd L
.33175 .13292 -1.875 0 Mabsadd L closepath F
.33492 .13364 -1.875 0 Mabsadd m
.33492 .13364 0 2.5 Mabsadd L
.33492 .13364 1.875 0 Mabsadd L
.33492 .13364 0 -2.5 Mabsadd L
.33492 .13364 -1.875 0 Mabsadd L closepath F
.3381 .13436 -1.875 0 Mabsadd m
.3381 .13436 0 2.5 Mabsadd L
.3381 .13436 1.875 0 Mabsadd L
.3381 .13436 0 -2.5 Mabsadd L
.3381 .13436 -1.875 0 Mabsadd L closepath F
.34127 .13508 -1.875 0 Mabsadd m
.34127 .13508 0 2.5 Mabsadd L
.34127 .13508 1.875 0 Mabsadd L
.34127 .13508 0 -2.5 Mabsadd L
.34127 .13508 -1.875 0 Mabsadd L closepath F
.34444 .13578 -1.875 0 Mabsadd m
.34444 .13578 0 2.5 Mabsadd L
.34444 .13578 1.875 0 Mabsadd L
.34444 .13578 0 -2.5 Mabsadd L
.34444 .13578 -1.875 0 Mabsadd L closepath F
.34762 .13648 -1.875 0 Mabsadd m
.34762 .13648 0 2.5 Mabsadd L
.34762 .13648 1.875 0 Mabsadd L
.34762 .13648 0 -2.5 Mabsadd L
.34762 .13648 -1.875 0 Mabsadd L closepath F
.35079 .13718 -1.875 0 Mabsadd m
.35079 .13718 0 2.5 Mabsadd L
.35079 .13718 1.875 0 Mabsadd L
.35079 .13718 0 -2.5 Mabsadd L
.35079 .13718 -1.875 0 Mabsadd L closepath F
.35397 .13786 -1.875 0 Mabsadd m
.35397 .13786 0 2.5 Mabsadd L
.35397 .13786 1.875 0 Mabsadd L
.35397 .13786 0 -2.5 Mabsadd L
.35397 .13786 -1.875 0 Mabsadd L closepath F
.35714 .13854 -1.875 0 Mabsadd m
.35714 .13854 0 2.5 Mabsadd L
.35714 .13854 1.875 0 Mabsadd L
.35714 .13854 0 -2.5 Mabsadd L
.35714 .13854 -1.875 0 Mabsadd L closepath F
.36032 .13921 -1.875 0 Mabsadd m
.36032 .13921 0 2.5 Mabsadd L
.36032 .13921 1.875 0 Mabsadd L
.36032 .13921 0 -2.5 Mabsadd L
.36032 .13921 -1.875 0 Mabsadd L closepath F
.36349 .13987 -1.875 0 Mabsadd m
.36349 .13987 0 2.5 Mabsadd L
.36349 .13987 1.875 0 Mabsadd L
.36349 .13987 0 -2.5 Mabsadd L
.36349 .13987 -1.875 0 Mabsadd L closepath F
.36667 .14053 -1.875 0 Mabsadd m
.36667 .14053 0 2.5 Mabsadd L
.36667 .14053 1.875 0 Mabsadd L
.36667 .14053 0 -2.5 Mabsadd L
.36667 .14053 -1.875 0 Mabsadd L closepath F
.36984 .14118 -1.875 0 Mabsadd m
.36984 .14118 0 2.5 Mabsadd L
.36984 .14118 1.875 0 Mabsadd L
.36984 .14118 0 -2.5 Mabsadd L
.36984 .14118 -1.875 0 Mabsadd L closepath F
.37302 .14183 -1.875 0 Mabsadd m
.37302 .14183 0 2.5 Mabsadd L
.37302 .14183 1.875 0 Mabsadd L
.37302 .14183 0 -2.5 Mabsadd L
.37302 .14183 -1.875 0 Mabsadd L closepath F
.37619 .14247 -1.875 0 Mabsadd m
.37619 .14247 0 2.5 Mabsadd L
.37619 .14247 1.875 0 Mabsadd L
.37619 .14247 0 -2.5 Mabsadd L
.37619 .14247 -1.875 0 Mabsadd L closepath F
.37937 .1431 -1.875 0 Mabsadd m
.37937 .1431 0 2.5 Mabsadd L
.37937 .1431 1.875 0 Mabsadd L
.37937 .1431 0 -2.5 Mabsadd L
.37937 .1431 -1.875 0 Mabsadd L closepath F
.38254 .14373 -1.875 0 Mabsadd m
.38254 .14373 0 2.5 Mabsadd L
.38254 .14373 1.875 0 Mabsadd L
.38254 .14373 0 -2.5 Mabsadd L
.38254 .14373 -1.875 0 Mabsadd L closepath F
.38571 .14435 -1.875 0 Mabsadd m
.38571 .14435 0 2.5 Mabsadd L
.38571 .14435 1.875 0 Mabsadd L
.38571 .14435 0 -2.5 Mabsadd L
.38571 .14435 -1.875 0 Mabsadd L closepath F
.38889 .14496 -1.875 0 Mabsadd m
.38889 .14496 0 2.5 Mabsadd L
.38889 .14496 1.875 0 Mabsadd L
.38889 .14496 0 -2.5 Mabsadd L
.38889 .14496 -1.875 0 Mabsadd L closepath F
.39206 .14557 -1.875 0 Mabsadd m
.39206 .14557 0 2.5 Mabsadd L
.39206 .14557 1.875 0 Mabsadd L
.39206 .14557 0 -2.5 Mabsadd L
.39206 .14557 -1.875 0 Mabsadd L closepath F
.39524 .14617 -1.875 0 Mabsadd m
.39524 .14617 0 2.5 Mabsadd L
.39524 .14617 1.875 0 Mabsadd L
.39524 .14617 0 -2.5 Mabsadd L
.39524 .14617 -1.875 0 Mabsadd L closepath F
.39841 .14676 -1.875 0 Mabsadd m
.39841 .14676 0 2.5 Mabsadd L
.39841 .14676 1.875 0 Mabsadd L
.39841 .14676 0 -2.5 Mabsadd L
.39841 .14676 -1.875 0 Mabsadd L closepath F
.40159 .14735 -1.875 0 Mabsadd m
.40159 .14735 0 2.5 Mabsadd L
.40159 .14735 1.875 0 Mabsadd L
.40159 .14735 0 -2.5 Mabsadd L
.40159 .14735 -1.875 0 Mabsadd L closepath F
.40476 .14794 -1.875 0 Mabsadd m
.40476 .14794 0 2.5 Mabsadd L
.40476 .14794 1.875 0 Mabsadd L
.40476 .14794 0 -2.5 Mabsadd L
.40476 .14794 -1.875 0 Mabsadd L closepath F
.40794 .14851 -1.875 0 Mabsadd m
.40794 .14851 0 2.5 Mabsadd L
.40794 .14851 1.875 0 Mabsadd L
.40794 .14851 0 -2.5 Mabsadd L
.40794 .14851 -1.875 0 Mabsadd L closepath F
.41111 .14908 -1.875 0 Mabsadd m
.41111 .14908 0 2.5 Mabsadd L
.41111 .14908 1.875 0 Mabsadd L
.41111 .14908 0 -2.5 Mabsadd L
.41111 .14908 -1.875 0 Mabsadd L closepath F
.41429 .14965 -1.875 0 Mabsadd m
.41429 .14965 0 2.5 Mabsadd L
.41429 .14965 1.875 0 Mabsadd L
.41429 .14965 0 -2.5 Mabsadd L
.41429 .14965 -1.875 0 Mabsadd L closepath F
.41746 .15021 -1.875 0 Mabsadd m
.41746 .15021 0 2.5 Mabsadd L
.41746 .15021 1.875 0 Mabsadd L
.41746 .15021 0 -2.5 Mabsadd L
.41746 .15021 -1.875 0 Mabsadd L closepath F
.42063 .15077 -1.875 0 Mabsadd m
.42063 .15077 0 2.5 Mabsadd L
.42063 .15077 1.875 0 Mabsadd L
.42063 .15077 0 -2.5 Mabsadd L
.42063 .15077 -1.875 0 Mabsadd L closepath F
.42381 .15131 -1.875 0 Mabsadd m
.42381 .15131 0 2.5 Mabsadd L
.42381 .15131 1.875 0 Mabsadd L
.42381 .15131 0 -2.5 Mabsadd L
.42381 .15131 -1.875 0 Mabsadd L closepath F
.42698 .15186 -1.875 0 Mabsadd m
.42698 .15186 0 2.5 Mabsadd L
.42698 .15186 1.875 0 Mabsadd L
.42698 .15186 0 -2.5 Mabsadd L
.42698 .15186 -1.875 0 Mabsadd L closepath F
.43016 .1524 -1.875 0 Mabsadd m
.43016 .1524 0 2.5 Mabsadd L
.43016 .1524 1.875 0 Mabsadd L
.43016 .1524 0 -2.5 Mabsadd L
.43016 .1524 -1.875 0 Mabsadd L closepath F
.43333 .15293 -1.875 0 Mabsadd m
.43333 .15293 0 2.5 Mabsadd L
.43333 .15293 1.875 0 Mabsadd L
.43333 .15293 0 -2.5 Mabsadd L
.43333 .15293 -1.875 0 Mabsadd L closepath F
.43651 .15346 -1.875 0 Mabsadd m
.43651 .15346 0 2.5 Mabsadd L
.43651 .15346 1.875 0 Mabsadd L
.43651 .15346 0 -2.5 Mabsadd L
.43651 .15346 -1.875 0 Mabsadd L closepath F
.43968 .15398 -1.875 0 Mabsadd m
.43968 .15398 0 2.5 Mabsadd L
.43968 .15398 1.875 0 Mabsadd L
.43968 .15398 0 -2.5 Mabsadd L
.43968 .15398 -1.875 0 Mabsadd L closepath F
.44286 .1545 -1.875 0 Mabsadd m
.44286 .1545 0 2.5 Mabsadd L
.44286 .1545 1.875 0 Mabsadd L
.44286 .1545 0 -2.5 Mabsadd L
.44286 .1545 -1.875 0 Mabsadd L closepath F
.44603 .15501 -1.875 0 Mabsadd m
.44603 .15501 0 2.5 Mabsadd L
.44603 .15501 1.875 0 Mabsadd L
.44603 .15501 0 -2.5 Mabsadd L
.44603 .15501 -1.875 0 Mabsadd L closepath F
.44921 .15552 -1.875 0 Mabsadd m
.44921 .15552 0 2.5 Mabsadd L
.44921 .15552 1.875 0 Mabsadd L
.44921 .15552 0 -2.5 Mabsadd L
.44921 .15552 -1.875 0 Mabsadd L closepath F
.45238 .15602 -1.875 0 Mabsadd m
.45238 .15602 0 2.5 Mabsadd L
.45238 .15602 1.875 0 Mabsadd L
.45238 .15602 0 -2.5 Mabsadd L
.45238 .15602 -1.875 0 Mabsadd L closepath F
.45556 .15651 -1.875 0 Mabsadd m
.45556 .15651 0 2.5 Mabsadd L
.45556 .15651 1.875 0 Mabsadd L
.45556 .15651 0 -2.5 Mabsadd L
.45556 .15651 -1.875 0 Mabsadd L closepath F
.45873 .15701 -1.875 0 Mabsadd m
.45873 .15701 0 2.5 Mabsadd L
.45873 .15701 1.875 0 Mabsadd L
.45873 .15701 0 -2.5 Mabsadd L
.45873 .15701 -1.875 0 Mabsadd L closepath F
.4619 .15749 -1.875 0 Mabsadd m
.4619 .15749 0 2.5 Mabsadd L
.4619 .15749 1.875 0 Mabsadd L
.4619 .15749 0 -2.5 Mabsadd L
.4619 .15749 -1.875 0 Mabsadd L closepath F
.46508 .15797 -1.875 0 Mabsadd m
.46508 .15797 0 2.5 Mabsadd L
.46508 .15797 1.875 0 Mabsadd L
.46508 .15797 0 -2.5 Mabsadd L
.46508 .15797 -1.875 0 Mabsadd L closepath F
.46825 .15845 -1.875 0 Mabsadd m
.46825 .15845 0 2.5 Mabsadd L
.46825 .15845 1.875 0 Mabsadd L
.46825 .15845 0 -2.5 Mabsadd L
.46825 .15845 -1.875 0 Mabsadd L closepath F
.47143 .15892 -1.875 0 Mabsadd m
.47143 .15892 0 2.5 Mabsadd L
.47143 .15892 1.875 0 Mabsadd L
.47143 .15892 0 -2.5 Mabsadd L
.47143 .15892 -1.875 0 Mabsadd L closepath F
.4746 .15939 -1.875 0 Mabsadd m
.4746 .15939 0 2.5 Mabsadd L
.4746 .15939 1.875 0 Mabsadd L
.4746 .15939 0 -2.5 Mabsadd L
.4746 .15939 -1.875 0 Mabsadd L closepath F
.47778 .15985 -1.875 0 Mabsadd m
.47778 .15985 0 2.5 Mabsadd L
.47778 .15985 1.875 0 Mabsadd L
.47778 .15985 0 -2.5 Mabsadd L
.47778 .15985 -1.875 0 Mabsadd L closepath F
.48095 .16031 -1.875 0 Mabsadd m
.48095 .16031 0 2.5 Mabsadd L
.48095 .16031 1.875 0 Mabsadd L
.48095 .16031 0 -2.5 Mabsadd L
.48095 .16031 -1.875 0 Mabsadd L closepath F
.48413 .16077 -1.875 0 Mabsadd m
.48413 .16077 0 2.5 Mabsadd L
.48413 .16077 1.875 0 Mabsadd L
.48413 .16077 0 -2.5 Mabsadd L
.48413 .16077 -1.875 0 Mabsadd L closepath F
.4873 .16122 -1.875 0 Mabsadd m
.4873 .16122 0 2.5 Mabsadd L
.4873 .16122 1.875 0 Mabsadd L
.4873 .16122 0 -2.5 Mabsadd L
.4873 .16122 -1.875 0 Mabsadd L closepath F
.49048 .16166 -1.875 0 Mabsadd m
.49048 .16166 0 2.5 Mabsadd L
.49048 .16166 1.875 0 Mabsadd L
.49048 .16166 0 -2.5 Mabsadd L
.49048 .16166 -1.875 0 Mabsadd L closepath F
.49365 .1621 -1.875 0 Mabsadd m
.49365 .1621 0 2.5 Mabsadd L
.49365 .1621 1.875 0 Mabsadd L
.49365 .1621 0 -2.5 Mabsadd L
.49365 .1621 -1.875 0 Mabsadd L closepath F
.49683 .16254 -1.875 0 Mabsadd m
.49683 .16254 0 2.5 Mabsadd L
.49683 .16254 1.875 0 Mabsadd L
.49683 .16254 0 -2.5 Mabsadd L
.49683 .16254 -1.875 0 Mabsadd L closepath F
.5 .16297 -1.875 0 Mabsadd m
.5 .16297 0 2.5 Mabsadd L
.5 .16297 1.875 0 Mabsadd L
.5 .16297 0 -2.5 Mabsadd L
.5 .16297 -1.875 0 Mabsadd L closepath F
.50317 .16339 -1.875 0 Mabsadd m
.50317 .16339 0 2.5 Mabsadd L
.50317 .16339 1.875 0 Mabsadd L
.50317 .16339 0 -2.5 Mabsadd L
.50317 .16339 -1.875 0 Mabsadd L closepath F
.50635 .16382 -1.875 0 Mabsadd m
.50635 .16382 0 2.5 Mabsadd L
.50635 .16382 1.875 0 Mabsadd L
.50635 .16382 0 -2.5 Mabsadd L
.50635 .16382 -1.875 0 Mabsadd L closepath F
.50952 .16424 -1.875 0 Mabsadd m
.50952 .16424 0 2.5 Mabsadd L
.50952 .16424 1.875 0 Mabsadd L
.50952 .16424 0 -2.5 Mabsadd L
.50952 .16424 -1.875 0 Mabsadd L closepath F
.5127 .16465 -1.875 0 Mabsadd m
.5127 .16465 0 2.5 Mabsadd L
.5127 .16465 1.875 0 Mabsadd L
.5127 .16465 0 -2.5 Mabsadd L
.5127 .16465 -1.875 0 Mabsadd L closepath F
.51587 .16506 -1.875 0 Mabsadd m
.51587 .16506 0 2.5 Mabsadd L
.51587 .16506 1.875 0 Mabsadd L
.51587 .16506 0 -2.5 Mabsadd L
.51587 .16506 -1.875 0 Mabsadd L closepath F
.51905 .16547 -1.875 0 Mabsadd m
.51905 .16547 0 2.5 Mabsadd L
.51905 .16547 1.875 0 Mabsadd L
.51905 .16547 0 -2.5 Mabsadd L
.51905 .16547 -1.875 0 Mabsadd L closepath F
.52222 .16587 -1.875 0 Mabsadd m
.52222 .16587 0 2.5 Mabsadd L
.52222 .16587 1.875 0 Mabsadd L
.52222 .16587 0 -2.5 Mabsadd L
.52222 .16587 -1.875 0 Mabsadd L closepath F
.5254 .16627 -1.875 0 Mabsadd m
.5254 .16627 0 2.5 Mabsadd L
.5254 .16627 1.875 0 Mabsadd L
.5254 .16627 0 -2.5 Mabsadd L
.5254 .16627 -1.875 0 Mabsadd L closepath F
.52857 .16666 -1.875 0 Mabsadd m
.52857 .16666 0 2.5 Mabsadd L
.52857 .16666 1.875 0 Mabsadd L
.52857 .16666 0 -2.5 Mabsadd L
.52857 .16666 -1.875 0 Mabsadd L closepath F
.53175 .16705 -1.875 0 Mabsadd m
.53175 .16705 0 2.5 Mabsadd L
.53175 .16705 1.875 0 Mabsadd L
.53175 .16705 0 -2.5 Mabsadd L
.53175 .16705 -1.875 0 Mabsadd L closepath F
.53492 .16744 -1.875 0 Mabsadd m
.53492 .16744 0 2.5 Mabsadd L
.53492 .16744 1.875 0 Mabsadd L
.53492 .16744 0 -2.5 Mabsadd L
.53492 .16744 -1.875 0 Mabsadd L closepath F
.5381 .16782 -1.875 0 Mabsadd m
.5381 .16782 0 2.5 Mabsadd L
.5381 .16782 1.875 0 Mabsadd L
.5381 .16782 0 -2.5 Mabsadd L
.5381 .16782 -1.875 0 Mabsadd L closepath F
.54127 .1682 -1.875 0 Mabsadd m
.54127 .1682 0 2.5 Mabsadd L
.54127 .1682 1.875 0 Mabsadd L
.54127 .1682 0 -2.5 Mabsadd L
.54127 .1682 -1.875 0 Mabsadd L closepath F
.54444 .16857 -1.875 0 Mabsadd m
.54444 .16857 0 2.5 Mabsadd L
.54444 .16857 1.875 0 Mabsadd L
.54444 .16857 0 -2.5 Mabsadd L
.54444 .16857 -1.875 0 Mabsadd L closepath F
.54762 .16895 -1.875 0 Mabsadd m
.54762 .16895 0 2.5 Mabsadd L
.54762 .16895 1.875 0 Mabsadd L
.54762 .16895 0 -2.5 Mabsadd L
.54762 .16895 -1.875 0 Mabsadd L closepath F
.55079 .16931 -1.875 0 Mabsadd m
.55079 .16931 0 2.5 Mabsadd L
.55079 .16931 1.875 0 Mabsadd L
.55079 .16931 0 -2.5 Mabsadd L
.55079 .16931 -1.875 0 Mabsadd L closepath F
.55397 .16968 -1.875 0 Mabsadd m
.55397 .16968 0 2.5 Mabsadd L
.55397 .16968 1.875 0 Mabsadd L
.55397 .16968 0 -2.5 Mabsadd L
.55397 .16968 -1.875 0 Mabsadd L closepath F
.55714 .17004 -1.875 0 Mabsadd m
.55714 .17004 0 2.5 Mabsadd L
.55714 .17004 1.875 0 Mabsadd L
.55714 .17004 0 -2.5 Mabsadd L
.55714 .17004 -1.875 0 Mabsadd L closepath F
.56032 .17039 -1.875 0 Mabsadd m
.56032 .17039 0 2.5 Mabsadd L
.56032 .17039 1.875 0 Mabsadd L
.56032 .17039 0 -2.5 Mabsadd L
.56032 .17039 -1.875 0 Mabsadd L closepath F
.56349 .17075 -1.875 0 Mabsadd m
.56349 .17075 0 2.5 Mabsadd L
.56349 .17075 1.875 0 Mabsadd L
.56349 .17075 0 -2.5 Mabsadd L
.56349 .17075 -1.875 0 Mabsadd L closepath F
.56667 .1711 -1.875 0 Mabsadd m
.56667 .1711 0 2.5 Mabsadd L
.56667 .1711 1.875 0 Mabsadd L
.56667 .1711 0 -2.5 Mabsadd L
.56667 .1711 -1.875 0 Mabsadd L closepath F
.56984 .17144 -1.875 0 Mabsadd m
.56984 .17144 0 2.5 Mabsadd L
.56984 .17144 1.875 0 Mabsadd L
.56984 .17144 0 -2.5 Mabsadd L
.56984 .17144 -1.875 0 Mabsadd L closepath F
.57302 .17178 -1.875 0 Mabsadd m
.57302 .17178 0 2.5 Mabsadd L
.57302 .17178 1.875 0 Mabsadd L
.57302 .17178 0 -2.5 Mabsadd L
.57302 .17178 -1.875 0 Mabsadd L closepath F
.57619 .17212 -1.875 0 Mabsadd m
.57619 .17212 0 2.5 Mabsadd L
.57619 .17212 1.875 0 Mabsadd L
.57619 .17212 0 -2.5 Mabsadd L
.57619 .17212 -1.875 0 Mabsadd L closepath F
.57937 .17246 -1.875 0 Mabsadd m
.57937 .17246 0 2.5 Mabsadd L
.57937 .17246 1.875 0 Mabsadd L
.57937 .17246 0 -2.5 Mabsadd L
.57937 .17246 -1.875 0 Mabsadd L closepath F
.58254 .17279 -1.875 0 Mabsadd m
.58254 .17279 0 2.5 Mabsadd L
.58254 .17279 1.875 0 Mabsadd L
.58254 .17279 0 -2.5 Mabsadd L
.58254 .17279 -1.875 0 Mabsadd L closepath F
.58571 .17312 -1.875 0 Mabsadd m
.58571 .17312 0 2.5 Mabsadd L
.58571 .17312 1.875 0 Mabsadd L
.58571 .17312 0 -2.5 Mabsadd L
.58571 .17312 -1.875 0 Mabsadd L closepath F
.58889 .17345 -1.875 0 Mabsadd m
.58889 .17345 0 2.5 Mabsadd L
.58889 .17345 1.875 0 Mabsadd L
.58889 .17345 0 -2.5 Mabsadd L
.58889 .17345 -1.875 0 Mabsadd L closepath F
.59206 .17377 -1.875 0 Mabsadd m
.59206 .17377 0 2.5 Mabsadd L
.59206 .17377 1.875 0 Mabsadd L
.59206 .17377 0 -2.5 Mabsadd L
.59206 .17377 -1.875 0 Mabsadd L closepath F
.59524 .17409 -1.875 0 Mabsadd m
.59524 .17409 0 2.5 Mabsadd L
.59524 .17409 1.875 0 Mabsadd L
.59524 .17409 0 -2.5 Mabsadd L
.59524 .17409 -1.875 0 Mabsadd L closepath F
.59841 .1744 -1.875 0 Mabsadd m
.59841 .1744 0 2.5 Mabsadd L
.59841 .1744 1.875 0 Mabsadd L
.59841 .1744 0 -2.5 Mabsadd L
.59841 .1744 -1.875 0 Mabsadd L closepath F
.60159 .17472 -1.875 0 Mabsadd m
.60159 .17472 0 2.5 Mabsadd L
.60159 .17472 1.875 0 Mabsadd L
.60159 .17472 0 -2.5 Mabsadd L
.60159 .17472 -1.875 0 Mabsadd L closepath F
.60476 .17503 -1.875 0 Mabsadd m
.60476 .17503 0 2.5 Mabsadd L
.60476 .17503 1.875 0 Mabsadd L
.60476 .17503 0 -2.5 Mabsadd L
.60476 .17503 -1.875 0 Mabsadd L closepath F
.60794 .17533 -1.875 0 Mabsadd m
.60794 .17533 0 2.5 Mabsadd L
.60794 .17533 1.875 0 Mabsadd L
.60794 .17533 0 -2.5 Mabsadd L
.60794 .17533 -1.875 0 Mabsadd L closepath F
.61111 .17564 -1.875 0 Mabsadd m
.61111 .17564 0 2.5 Mabsadd L
.61111 .17564 1.875 0 Mabsadd L
.61111 .17564 0 -2.5 Mabsadd L
.61111 .17564 -1.875 0 Mabsadd L closepath F
.61429 .17594 -1.875 0 Mabsadd m
.61429 .17594 0 2.5 Mabsadd L
.61429 .17594 1.875 0 Mabsadd L
.61429 .17594 0 -2.5 Mabsadd L
.61429 .17594 -1.875 0 Mabsadd L closepath F
.61746 .17623 -1.875 0 Mabsadd m
.61746 .17623 0 2.5 Mabsadd L
.61746 .17623 1.875 0 Mabsadd L
.61746 .17623 0 -2.5 Mabsadd L
.61746 .17623 -1.875 0 Mabsadd L closepath F
.62063 .17653 -1.875 0 Mabsadd m
.62063 .17653 0 2.5 Mabsadd L
.62063 .17653 1.875 0 Mabsadd L
.62063 .17653 0 -2.5 Mabsadd L
.62063 .17653 -1.875 0 Mabsadd L closepath F
.62381 .17682 -1.875 0 Mabsadd m
.62381 .17682 0 2.5 Mabsadd L
.62381 .17682 1.875 0 Mabsadd L
.62381 .17682 0 -2.5 Mabsadd L
.62381 .17682 -1.875 0 Mabsadd L closepath F
.62698 .17711 -1.875 0 Mabsadd m
.62698 .17711 0 2.5 Mabsadd L
.62698 .17711 1.875 0 Mabsadd L
.62698 .17711 0 -2.5 Mabsadd L
.62698 .17711 -1.875 0 Mabsadd L closepath F
.63016 .17739 -1.875 0 Mabsadd m
.63016 .17739 0 2.5 Mabsadd L
.63016 .17739 1.875 0 Mabsadd L
.63016 .17739 0 -2.5 Mabsadd L
.63016 .17739 -1.875 0 Mabsadd L closepath F
.63333 .17768 -1.875 0 Mabsadd m
.63333 .17768 0 2.5 Mabsadd L
.63333 .17768 1.875 0 Mabsadd L
.63333 .17768 0 -2.5 Mabsadd L
.63333 .17768 -1.875 0 Mabsadd L closepath F
.63651 .17796 -1.875 0 Mabsadd m
.63651 .17796 0 2.5 Mabsadd L
.63651 .17796 1.875 0 Mabsadd L
.63651 .17796 0 -2.5 Mabsadd L
.63651 .17796 -1.875 0 Mabsadd L closepath F
.63968 .17823 -1.875 0 Mabsadd m
.63968 .17823 0 2.5 Mabsadd L
.63968 .17823 1.875 0 Mabsadd L
.63968 .17823 0 -2.5 Mabsadd L
.63968 .17823 -1.875 0 Mabsadd L closepath F
.64286 .17851 -1.875 0 Mabsadd m
.64286 .17851 0 2.5 Mabsadd L
.64286 .17851 1.875 0 Mabsadd L
.64286 .17851 0 -2.5 Mabsadd L
.64286 .17851 -1.875 0 Mabsadd L closepath F
.64603 .17878 -1.875 0 Mabsadd m
.64603 .17878 0 2.5 Mabsadd L
.64603 .17878 1.875 0 Mabsadd L
.64603 .17878 0 -2.5 Mabsadd L
.64603 .17878 -1.875 0 Mabsadd L closepath F
.64921 .17905 -1.875 0 Mabsadd m
.64921 .17905 0 2.5 Mabsadd L
.64921 .17905 1.875 0 Mabsadd L
.64921 .17905 0 -2.5 Mabsadd L
.64921 .17905 -1.875 0 Mabsadd L closepath F
.65238 .17932 -1.875 0 Mabsadd m
.65238 .17932 0 2.5 Mabsadd L
.65238 .17932 1.875 0 Mabsadd L
.65238 .17932 0 -2.5 Mabsadd L
.65238 .17932 -1.875 0 Mabsadd L closepath F
.65556 .17958 -1.875 0 Mabsadd m
.65556 .17958 0 2.5 Mabsadd L
.65556 .17958 1.875 0 Mabsadd L
.65556 .17958 0 -2.5 Mabsadd L
.65556 .17958 -1.875 0 Mabsadd L closepath F
.65873 .17984 -1.875 0 Mabsadd m
.65873 .17984 0 2.5 Mabsadd L
.65873 .17984 1.875 0 Mabsadd L
.65873 .17984 0 -2.5 Mabsadd L
.65873 .17984 -1.875 0 Mabsadd L closepath F
.6619 .1801 -1.875 0 Mabsadd m
.6619 .1801 0 2.5 Mabsadd L
.6619 .1801 1.875 0 Mabsadd L
.6619 .1801 0 -2.5 Mabsadd L
.6619 .1801 -1.875 0 Mabsadd L closepath F
.66508 .18036 -1.875 0 Mabsadd m
.66508 .18036 0 2.5 Mabsadd L
.66508 .18036 1.875 0 Mabsadd L
.66508 .18036 0 -2.5 Mabsadd L
.66508 .18036 -1.875 0 Mabsadd L closepath F
.66825 .18061 -1.875 0 Mabsadd m
.66825 .18061 0 2.5 Mabsadd L
.66825 .18061 1.875 0 Mabsadd L
.66825 .18061 0 -2.5 Mabsadd L
.66825 .18061 -1.875 0 Mabsadd L closepath F
.67143 .18086 -1.875 0 Mabsadd m
.67143 .18086 0 2.5 Mabsadd L
.67143 .18086 1.875 0 Mabsadd L
.67143 .18086 0 -2.5 Mabsadd L
.67143 .18086 -1.875 0 Mabsadd L closepath F
.6746 .18111 -1.875 0 Mabsadd m
.6746 .18111 0 2.5 Mabsadd L
.6746 .18111 1.875 0 Mabsadd L
.6746 .18111 0 -2.5 Mabsadd L
.6746 .18111 -1.875 0 Mabsadd L closepath F
.67778 .18135 -1.875 0 Mabsadd m
.67778 .18135 0 2.5 Mabsadd L
.67778 .18135 1.875 0 Mabsadd L
.67778 .18135 0 -2.5 Mabsadd L
.67778 .18135 -1.875 0 Mabsadd L closepath F
.68095 .1816 -1.875 0 Mabsadd m
.68095 .1816 0 2.5 Mabsadd L
.68095 .1816 1.875 0 Mabsadd L
.68095 .1816 0 -2.5 Mabsadd L
.68095 .1816 -1.875 0 Mabsadd L closepath F
.68413 .18184 -1.875 0 Mabsadd m
.68413 .18184 0 2.5 Mabsadd L
.68413 .18184 1.875 0 Mabsadd L
.68413 .18184 0 -2.5 Mabsadd L
.68413 .18184 -1.875 0 Mabsadd L closepath F
.6873 .18208 -1.875 0 Mabsadd m
.6873 .18208 0 2.5 Mabsadd L
.6873 .18208 1.875 0 Mabsadd L
.6873 .18208 0 -2.5 Mabsadd L
.6873 .18208 -1.875 0 Mabsadd L closepath F
.69048 .18231 -1.875 0 Mabsadd m
.69048 .18231 0 2.5 Mabsadd L
.69048 .18231 1.875 0 Mabsadd L
.69048 .18231 0 -2.5 Mabsadd L
.69048 .18231 -1.875 0 Mabsadd L closepath F
.69365 .18255 -1.875 0 Mabsadd m
.69365 .18255 0 2.5 Mabsadd L
.69365 .18255 1.875 0 Mabsadd L
.69365 .18255 0 -2.5 Mabsadd L
.69365 .18255 -1.875 0 Mabsadd L closepath F
.69683 .18278 -1.875 0 Mabsadd m
.69683 .18278 0 2.5 Mabsadd L
.69683 .18278 1.875 0 Mabsadd L
.69683 .18278 0 -2.5 Mabsadd L
.69683 .18278 -1.875 0 Mabsadd L closepath F
.7 .18301 -1.875 0 Mabsadd m
.7 .18301 0 2.5 Mabsadd L
.7 .18301 1.875 0 Mabsadd L
.7 .18301 0 -2.5 Mabsadd L
.7 .18301 -1.875 0 Mabsadd L closepath F
.70317 .18323 -1.875 0 Mabsadd m
.70317 .18323 0 2.5 Mabsadd L
.70317 .18323 1.875 0 Mabsadd L
.70317 .18323 0 -2.5 Mabsadd L
.70317 .18323 -1.875 0 Mabsadd L closepath F
.70635 .18346 -1.875 0 Mabsadd m
.70635 .18346 0 2.5 Mabsadd L
.70635 .18346 1.875 0 Mabsadd L
.70635 .18346 0 -2.5 Mabsadd L
.70635 .18346 -1.875 0 Mabsadd L closepath F
.70952 .18368 -1.875 0 Mabsadd m
.70952 .18368 0 2.5 Mabsadd L
.70952 .18368 1.875 0 Mabsadd L
.70952 .18368 0 -2.5 Mabsadd L
.70952 .18368 -1.875 0 Mabsadd L closepath F
.7127 .1839 -1.875 0 Mabsadd m
.7127 .1839 0 2.5 Mabsadd L
.7127 .1839 1.875 0 Mabsadd L
.7127 .1839 0 -2.5 Mabsadd L
.7127 .1839 -1.875 0 Mabsadd L closepath F
.71587 .18412 -1.875 0 Mabsadd m
.71587 .18412 0 2.5 Mabsadd L
.71587 .18412 1.875 0 Mabsadd L
.71587 .18412 0 -2.5 Mabsadd L
.71587 .18412 -1.875 0 Mabsadd L closepath F
.71905 .18433 -1.875 0 Mabsadd m
.71905 .18433 0 2.5 Mabsadd L
.71905 .18433 1.875 0 Mabsadd L
.71905 .18433 0 -2.5 Mabsadd L
.71905 .18433 -1.875 0 Mabsadd L closepath F
.72222 .18455 -1.875 0 Mabsadd m
.72222 .18455 0 2.5 Mabsadd L
.72222 .18455 1.875 0 Mabsadd L
.72222 .18455 0 -2.5 Mabsadd L
.72222 .18455 -1.875 0 Mabsadd L closepath F
.7254 .18476 -1.875 0 Mabsadd m
.7254 .18476 0 2.5 Mabsadd L
.7254 .18476 1.875 0 Mabsadd L
.7254 .18476 0 -2.5 Mabsadd L
.7254 .18476 -1.875 0 Mabsadd L closepath F
.72857 .18497 -1.875 0 Mabsadd m
.72857 .18497 0 2.5 Mabsadd L
.72857 .18497 1.875 0 Mabsadd L
.72857 .18497 0 -2.5 Mabsadd L
.72857 .18497 -1.875 0 Mabsadd L closepath F
.73175 .18517 -1.875 0 Mabsadd m
.73175 .18517 0 2.5 Mabsadd L
.73175 .18517 1.875 0 Mabsadd L
.73175 .18517 0 -2.5 Mabsadd L
.73175 .18517 -1.875 0 Mabsadd L closepath F
.73492 .18538 -1.875 0 Mabsadd m
.73492 .18538 0 2.5 Mabsadd L
.73492 .18538 1.875 0 Mabsadd L
.73492 .18538 0 -2.5 Mabsadd L
.73492 .18538 -1.875 0 Mabsadd L closepath F
.7381 .18558 -1.875 0 Mabsadd m
.7381 .18558 0 2.5 Mabsadd L
.7381 .18558 1.875 0 Mabsadd L
.7381 .18558 0 -2.5 Mabsadd L
.7381 .18558 -1.875 0 Mabsadd L closepath F
.74127 .18578 -1.875 0 Mabsadd m
.74127 .18578 0 2.5 Mabsadd L
.74127 .18578 1.875 0 Mabsadd L
.74127 .18578 0 -2.5 Mabsadd L
.74127 .18578 -1.875 0 Mabsadd L closepath F
.74444 .18598 -1.875 0 Mabsadd m
.74444 .18598 0 2.5 Mabsadd L
.74444 .18598 1.875 0 Mabsadd L
.74444 .18598 0 -2.5 Mabsadd L
.74444 .18598 -1.875 0 Mabsadd L closepath F
.74762 .18618 -1.875 0 Mabsadd m
.74762 .18618 0 2.5 Mabsadd L
.74762 .18618 1.875 0 Mabsadd L
.74762 .18618 0 -2.5 Mabsadd L
.74762 .18618 -1.875 0 Mabsadd L closepath F
.75079 .18638 -1.875 0 Mabsadd m
.75079 .18638 0 2.5 Mabsadd L
.75079 .18638 1.875 0 Mabsadd L
.75079 .18638 0 -2.5 Mabsadd L
.75079 .18638 -1.875 0 Mabsadd L closepath F
.75397 .18657 -1.875 0 Mabsadd m
.75397 .18657 0 2.5 Mabsadd L
.75397 .18657 1.875 0 Mabsadd L
.75397 .18657 0 -2.5 Mabsadd L
.75397 .18657 -1.875 0 Mabsadd L closepath F
.75714 .18676 -1.875 0 Mabsadd m
.75714 .18676 0 2.5 Mabsadd L
.75714 .18676 1.875 0 Mabsadd L
.75714 .18676 0 -2.5 Mabsadd L
.75714 .18676 -1.875 0 Mabsadd L closepath F
.76032 .18695 -1.875 0 Mabsadd m
.76032 .18695 0 2.5 Mabsadd L
.76032 .18695 1.875 0 Mabsadd L
.76032 .18695 0 -2.5 Mabsadd L
.76032 .18695 -1.875 0 Mabsadd L closepath F
.76349 .18714 -1.875 0 Mabsadd m
.76349 .18714 0 2.5 Mabsadd L
.76349 .18714 1.875 0 Mabsadd L
.76349 .18714 0 -2.5 Mabsadd L
.76349 .18714 -1.875 0 Mabsadd L closepath F
.76667 .18732 -1.875 0 Mabsadd m
.76667 .18732 0 2.5 Mabsadd L
.76667 .18732 1.875 0 Mabsadd L
.76667 .18732 0 -2.5 Mabsadd L
.76667 .18732 -1.875 0 Mabsadd L closepath F
.76984 .18751 -1.875 0 Mabsadd m
.76984 .18751 0 2.5 Mabsadd L
.76984 .18751 1.875 0 Mabsadd L
.76984 .18751 0 -2.5 Mabsadd L
.76984 .18751 -1.875 0 Mabsadd L closepath F
.77302 .18769 -1.875 0 Mabsadd m
.77302 .18769 0 2.5 Mabsadd L
.77302 .18769 1.875 0 Mabsadd L
.77302 .18769 0 -2.5 Mabsadd L
.77302 .18769 -1.875 0 Mabsadd L closepath F
.77619 .18787 -1.875 0 Mabsadd m
.77619 .18787 0 2.5 Mabsadd L
.77619 .18787 1.875 0 Mabsadd L
.77619 .18787 0 -2.5 Mabsadd L
.77619 .18787 -1.875 0 Mabsadd L closepath F
.77937 .18805 -1.875 0 Mabsadd m
.77937 .18805 0 2.5 Mabsadd L
.77937 .18805 1.875 0 Mabsadd L
.77937 .18805 0 -2.5 Mabsadd L
.77937 .18805 -1.875 0 Mabsadd L closepath F
.78254 .18822 -1.875 0 Mabsadd m
.78254 .18822 0 2.5 Mabsadd L
.78254 .18822 1.875 0 Mabsadd L
.78254 .18822 0 -2.5 Mabsadd L
.78254 .18822 -1.875 0 Mabsadd L closepath F
.78571 .1884 -1.875 0 Mabsadd m
.78571 .1884 0 2.5 Mabsadd L
.78571 .1884 1.875 0 Mabsadd L
.78571 .1884 0 -2.5 Mabsadd L
.78571 .1884 -1.875 0 Mabsadd L closepath F
.78889 .18857 -1.875 0 Mabsadd m
.78889 .18857 0 2.5 Mabsadd L
.78889 .18857 1.875 0 Mabsadd L
.78889 .18857 0 -2.5 Mabsadd L
.78889 .18857 -1.875 0 Mabsadd L closepath F
.79206 .18874 -1.875 0 Mabsadd m
.79206 .18874 0 2.5 Mabsadd L
.79206 .18874 1.875 0 Mabsadd L
.79206 .18874 0 -2.5 Mabsadd L
.79206 .18874 -1.875 0 Mabsadd L closepath F
.79524 .18891 -1.875 0 Mabsadd m
.79524 .18891 0 2.5 Mabsadd L
.79524 .18891 1.875 0 Mabsadd L
.79524 .18891 0 -2.5 Mabsadd L
.79524 .18891 -1.875 0 Mabsadd L closepath F
.79841 .18908 -1.875 0 Mabsadd m
.79841 .18908 0 2.5 Mabsadd L
.79841 .18908 1.875 0 Mabsadd L
.79841 .18908 0 -2.5 Mabsadd L
.79841 .18908 -1.875 0 Mabsadd L closepath F
.80159 .18924 -1.875 0 Mabsadd m
.80159 .18924 0 2.5 Mabsadd L
.80159 .18924 1.875 0 Mabsadd L
.80159 .18924 0 -2.5 Mabsadd L
.80159 .18924 -1.875 0 Mabsadd L closepath F
.80476 .18941 -1.875 0 Mabsadd m
.80476 .18941 0 2.5 Mabsadd L
.80476 .18941 1.875 0 Mabsadd L
.80476 .18941 0 -2.5 Mabsadd L
.80476 .18941 -1.875 0 Mabsadd L closepath F
.80794 .18957 -1.875 0 Mabsadd m
.80794 .18957 0 2.5 Mabsadd L
.80794 .18957 1.875 0 Mabsadd L
.80794 .18957 0 -2.5 Mabsadd L
.80794 .18957 -1.875 0 Mabsadd L closepath F
.81111 .18973 -1.875 0 Mabsadd m
.81111 .18973 0 2.5 Mabsadd L
.81111 .18973 1.875 0 Mabsadd L
.81111 .18973 0 -2.5 Mabsadd L
.81111 .18973 -1.875 0 Mabsadd L closepath F
.81429 .18989 -1.875 0 Mabsadd m
.81429 .18989 0 2.5 Mabsadd L
.81429 .18989 1.875 0 Mabsadd L
.81429 .18989 0 -2.5 Mabsadd L
.81429 .18989 -1.875 0 Mabsadd L closepath F
.81746 .19005 -1.875 0 Mabsadd m
.81746 .19005 0 2.5 Mabsadd L
.81746 .19005 1.875 0 Mabsadd L
.81746 .19005 0 -2.5 Mabsadd L
.81746 .19005 -1.875 0 Mabsadd L closepath F
.82063 .19021 -1.875 0 Mabsadd m
.82063 .19021 0 2.5 Mabsadd L
.82063 .19021 1.875 0 Mabsadd L
.82063 .19021 0 -2.5 Mabsadd L
.82063 .19021 -1.875 0 Mabsadd L closepath F
.82381 .19036 -1.875 0 Mabsadd m
.82381 .19036 0 2.5 Mabsadd L
.82381 .19036 1.875 0 Mabsadd L
.82381 .19036 0 -2.5 Mabsadd L
.82381 .19036 -1.875 0 Mabsadd L closepath F
.82698 .19051 -1.875 0 Mabsadd m
.82698 .19051 0 2.5 Mabsadd L
.82698 .19051 1.875 0 Mabsadd L
.82698 .19051 0 -2.5 Mabsadd L
.82698 .19051 -1.875 0 Mabsadd L closepath F
.83016 .19067 -1.875 0 Mabsadd m
.83016 .19067 0 2.5 Mabsadd L
.83016 .19067 1.875 0 Mabsadd L
.83016 .19067 0 -2.5 Mabsadd L
.83016 .19067 -1.875 0 Mabsadd L closepath F
.83333 .19082 -1.875 0 Mabsadd m
.83333 .19082 0 2.5 Mabsadd L
.83333 .19082 1.875 0 Mabsadd L
.83333 .19082 0 -2.5 Mabsadd L
.83333 .19082 -1.875 0 Mabsadd L closepath F
.83651 .19096 -1.875 0 Mabsadd m
.83651 .19096 0 2.5 Mabsadd L
.83651 .19096 1.875 0 Mabsadd L
.83651 .19096 0 -2.5 Mabsadd L
.83651 .19096 -1.875 0 Mabsadd L closepath F
.83968 .19111 -1.875 0 Mabsadd m
.83968 .19111 0 2.5 Mabsadd L
.83968 .19111 1.875 0 Mabsadd L
.83968 .19111 0 -2.5 Mabsadd L
.83968 .19111 -1.875 0 Mabsadd L closepath F
.84286 .19126 -1.875 0 Mabsadd m
.84286 .19126 0 2.5 Mabsadd L
.84286 .19126 1.875 0 Mabsadd L
.84286 .19126 0 -2.5 Mabsadd L
.84286 .19126 -1.875 0 Mabsadd L closepath F
.84603 .1914 -1.875 0 Mabsadd m
.84603 .1914 0 2.5 Mabsadd L
.84603 .1914 1.875 0 Mabsadd L
.84603 .1914 0 -2.5 Mabsadd L
.84603 .1914 -1.875 0 Mabsadd L closepath F
.84921 .19154 -1.875 0 Mabsadd m
.84921 .19154 0 2.5 Mabsadd L
.84921 .19154 1.875 0 Mabsadd L
.84921 .19154 0 -2.5 Mabsadd L
.84921 .19154 -1.875 0 Mabsadd L closepath F
.85238 .19169 -1.875 0 Mabsadd m
.85238 .19169 0 2.5 Mabsadd L
.85238 .19169 1.875 0 Mabsadd L
.85238 .19169 0 -2.5 Mabsadd L
.85238 .19169 -1.875 0 Mabsadd L closepath F
.85556 .19183 -1.875 0 Mabsadd m
.85556 .19183 0 2.5 Mabsadd L
.85556 .19183 1.875 0 Mabsadd L
.85556 .19183 0 -2.5 Mabsadd L
.85556 .19183 -1.875 0 Mabsadd L closepath F
.85873 .19196 -1.875 0 Mabsadd m
.85873 .19196 0 2.5 Mabsadd L
.85873 .19196 1.875 0 Mabsadd L
.85873 .19196 0 -2.5 Mabsadd L
.85873 .19196 -1.875 0 Mabsadd L closepath F
.8619 .1921 -1.875 0 Mabsadd m
.8619 .1921 0 2.5 Mabsadd L
.8619 .1921 1.875 0 Mabsadd L
.8619 .1921 0 -2.5 Mabsadd L
.8619 .1921 -1.875 0 Mabsadd L closepath F
.86508 .19224 -1.875 0 Mabsadd m
.86508 .19224 0 2.5 Mabsadd L
.86508 .19224 1.875 0 Mabsadd L
.86508 .19224 0 -2.5 Mabsadd L
.86508 .19224 -1.875 0 Mabsadd L closepath F
.86825 .19237 -1.875 0 Mabsadd m
.86825 .19237 0 2.5 Mabsadd L
.86825 .19237 1.875 0 Mabsadd L
.86825 .19237 0 -2.5 Mabsadd L
.86825 .19237 -1.875 0 Mabsadd L closepath F
.87143 .19251 -1.875 0 Mabsadd m
.87143 .19251 0 2.5 Mabsadd L
.87143 .19251 1.875 0 Mabsadd L
.87143 .19251 0 -2.5 Mabsadd L
.87143 .19251 -1.875 0 Mabsadd L closepath F
.8746 .19264 -1.875 0 Mabsadd m
.8746 .19264 0 2.5 Mabsadd L
.8746 .19264 1.875 0 Mabsadd L
.8746 .19264 0 -2.5 Mabsadd L
.8746 .19264 -1.875 0 Mabsadd L closepath F
.87778 .19277 -1.875 0 Mabsadd m
.87778 .19277 0 2.5 Mabsadd L
.87778 .19277 1.875 0 Mabsadd L
.87778 .19277 0 -2.5 Mabsadd L
.87778 .19277 -1.875 0 Mabsadd L closepath F
.88095 .1929 -1.875 0 Mabsadd m
.88095 .1929 0 2.5 Mabsadd L
.88095 .1929 1.875 0 Mabsadd L
.88095 .1929 0 -2.5 Mabsadd L
.88095 .1929 -1.875 0 Mabsadd L closepath F
.88413 .19302 -1.875 0 Mabsadd m
.88413 .19302 0 2.5 Mabsadd L
.88413 .19302 1.875 0 Mabsadd L
.88413 .19302 0 -2.5 Mabsadd L
.88413 .19302 -1.875 0 Mabsadd L closepath F
.8873 .19315 -1.875 0 Mabsadd m
.8873 .19315 0 2.5 Mabsadd L
.8873 .19315 1.875 0 Mabsadd L
.8873 .19315 0 -2.5 Mabsadd L
.8873 .19315 -1.875 0 Mabsadd L closepath F
.89048 .19328 -1.875 0 Mabsadd m
.89048 .19328 0 2.5 Mabsadd L
.89048 .19328 1.875 0 Mabsadd L
.89048 .19328 0 -2.5 Mabsadd L
.89048 .19328 -1.875 0 Mabsadd L closepath F
.89365 .1934 -1.875 0 Mabsadd m
.89365 .1934 0 2.5 Mabsadd L
.89365 .1934 1.875 0 Mabsadd L
.89365 .1934 0 -2.5 Mabsadd L
.89365 .1934 -1.875 0 Mabsadd L closepath F
.89683 .19352 -1.875 0 Mabsadd m
.89683 .19352 0 2.5 Mabsadd L
.89683 .19352 1.875 0 Mabsadd L
.89683 .19352 0 -2.5 Mabsadd L
.89683 .19352 -1.875 0 Mabsadd L closepath F
.9 .19365 -1.875 0 Mabsadd m
.9 .19365 0 2.5 Mabsadd L
.9 .19365 1.875 0 Mabsadd L
.9 .19365 0 -2.5 Mabsadd L
.9 .19365 -1.875 0 Mabsadd L closepath F
.90317 .19377 -1.875 0 Mabsadd m
.90317 .19377 0 2.5 Mabsadd L
.90317 .19377 1.875 0 Mabsadd L
.90317 .19377 0 -2.5 Mabsadd L
.90317 .19377 -1.875 0 Mabsadd L closepath F
.90635 .19388 -1.875 0 Mabsadd m
.90635 .19388 0 2.5 Mabsadd L
.90635 .19388 1.875 0 Mabsadd L
.90635 .19388 0 -2.5 Mabsadd L
.90635 .19388 -1.875 0 Mabsadd L closepath F
.90952 .194 -1.875 0 Mabsadd m
.90952 .194 0 2.5 Mabsadd L
.90952 .194 1.875 0 Mabsadd L
.90952 .194 0 -2.5 Mabsadd L
.90952 .194 -1.875 0 Mabsadd L closepath F
.9127 .19412 -1.875 0 Mabsadd m
.9127 .19412 0 2.5 Mabsadd L
.9127 .19412 1.875 0 Mabsadd L
.9127 .19412 0 -2.5 Mabsadd L
.9127 .19412 -1.875 0 Mabsadd L closepath F
.91587 .19424 -1.875 0 Mabsadd m
.91587 .19424 0 2.5 Mabsadd L
.91587 .19424 1.875 0 Mabsadd L
.91587 .19424 0 -2.5 Mabsadd L
.91587 .19424 -1.875 0 Mabsadd L closepath F
.91905 .19435 -1.875 0 Mabsadd m
.91905 .19435 0 2.5 Mabsadd L
.91905 .19435 1.875 0 Mabsadd L
.91905 .19435 0 -2.5 Mabsadd L
.91905 .19435 -1.875 0 Mabsadd L closepath F
.92222 .19446 -1.875 0 Mabsadd m
.92222 .19446 0 2.5 Mabsadd L
.92222 .19446 1.875 0 Mabsadd L
.92222 .19446 0 -2.5 Mabsadd L
.92222 .19446 -1.875 0 Mabsadd L closepath F
.9254 .19458 -1.875 0 Mabsadd m
.9254 .19458 0 2.5 Mabsadd L
.9254 .19458 1.875 0 Mabsadd L
.9254 .19458 0 -2.5 Mabsadd L
.9254 .19458 -1.875 0 Mabsadd L closepath F
.92857 .19469 -1.875 0 Mabsadd m
.92857 .19469 0 2.5 Mabsadd L
.92857 .19469 1.875 0 Mabsadd L
.92857 .19469 0 -2.5 Mabsadd L
.92857 .19469 -1.875 0 Mabsadd L closepath F
.93175 .1948 -1.875 0 Mabsadd m
.93175 .1948 0 2.5 Mabsadd L
.93175 .1948 1.875 0 Mabsadd L
.93175 .1948 0 -2.5 Mabsadd L
.93175 .1948 -1.875 0 Mabsadd L closepath F
.93492 .19491 -1.875 0 Mabsadd m
.93492 .19491 0 2.5 Mabsadd L
.93492 .19491 1.875 0 Mabsadd L
.93492 .19491 0 -2.5 Mabsadd L
.93492 .19491 -1.875 0 Mabsadd L closepath F
.9381 .19501 -1.875 0 Mabsadd m
.9381 .19501 0 2.5 Mabsadd L
.9381 .19501 1.875 0 Mabsadd L
.9381 .19501 0 -2.5 Mabsadd L
.9381 .19501 -1.875 0 Mabsadd L closepath F
.94127 .19512 -1.875 0 Mabsadd m
.94127 .19512 0 2.5 Mabsadd L
.94127 .19512 1.875 0 Mabsadd L
.94127 .19512 0 -2.5 Mabsadd L
.94127 .19512 -1.875 0 Mabsadd L closepath F
.94444 .19523 -1.875 0 Mabsadd m
.94444 .19523 0 2.5 Mabsadd L
.94444 .19523 1.875 0 Mabsadd L
.94444 .19523 0 -2.5 Mabsadd L
.94444 .19523 -1.875 0 Mabsadd L closepath F
.94762 .19533 -1.875 0 Mabsadd m
.94762 .19533 0 2.5 Mabsadd L
.94762 .19533 1.875 0 Mabsadd L
.94762 .19533 0 -2.5 Mabsadd L
.94762 .19533 -1.875 0 Mabsadd L closepath F
.95079 .19543 -1.875 0 Mabsadd m
.95079 .19543 0 2.5 Mabsadd L
.95079 .19543 1.875 0 Mabsadd L
.95079 .19543 0 -2.5 Mabsadd L
.95079 .19543 -1.875 0 Mabsadd L closepath F
.95397 .19554 -1.875 0 Mabsadd m
.95397 .19554 0 2.5 Mabsadd L
.95397 .19554 1.875 0 Mabsadd L
.95397 .19554 0 -2.5 Mabsadd L
.95397 .19554 -1.875 0 Mabsadd L closepath F
.95714 .19564 -1.875 0 Mabsadd m
.95714 .19564 0 2.5 Mabsadd L
.95714 .19564 1.875 0 Mabsadd L
.95714 .19564 0 -2.5 Mabsadd L
.95714 .19564 -1.875 0 Mabsadd L closepath F
.96032 .19574 -1.875 0 Mabsadd m
.96032 .19574 0 2.5 Mabsadd L
.96032 .19574 1.875 0 Mabsadd L
.96032 .19574 0 -2.5 Mabsadd L
.96032 .19574 -1.875 0 Mabsadd L closepath F
.96349 .19584 -1.875 0 Mabsadd m
.96349 .19584 0 2.5 Mabsadd L
.96349 .19584 1.875 0 Mabsadd L
.96349 .19584 0 -2.5 Mabsadd L
.96349 .19584 -1.875 0 Mabsadd L closepath F
.96667 .19594 -1.875 0 Mabsadd m
.96667 .19594 0 2.5 Mabsadd L
.96667 .19594 1.875 0 Mabsadd L
.96667 .19594 0 -2.5 Mabsadd L
.96667 .19594 -1.875 0 Mabsadd L closepath F
.96984 .19603 -1.875 0 Mabsadd m
.96984 .19603 0 2.5 Mabsadd L
.96984 .19603 1.875 0 Mabsadd L
.96984 .19603 0 -2.5 Mabsadd L
.96984 .19603 -1.875 0 Mabsadd L closepath F
.97302 .19613 -1.875 0 Mabsadd m
.97302 .19613 0 2.5 Mabsadd L
.97302 .19613 1.875 0 Mabsadd L
.97302 .19613 0 -2.5 Mabsadd L
.97302 .19613 -1.875 0 Mabsadd L closepath F
.97619 .19623 -1.875 0 Mabsadd m
.97619 .19623 0 2.5 Mabsadd L
.97619 .19623 1.875 0 Mabsadd L
.97619 .19623 0 -2.5 Mabsadd L
.97619 .19623 -1.875 0 Mabsadd L closepath F
.0075 w
.02698 .39666 m
.03016 .39475 L
.03333 .39286 L
.03651 .39098 L
.03968 .38913 L
.04286 .3873 L
.04603 .38548 L
.04921 .38368 L
.05238 .3819 L
.05556 .38014 L
.05873 .3784 L
.0619 .37667 L
.06508 .37496 L
.06825 .37327 L
.07143 .37159 L
.0746 .36993 L
.07778 .36829 L
.08095 .36666 L
.08413 .36505 L
.0873 .36346 L
.09048 .36188 L
.09365 .36032 L
.09683 .35877 L
.1 .35724 L
.10317 .35573 L
.10635 .35423 L
.10952 .35274 L
.1127 .35127 L
.11587 .34981 L
.11905 .34837 L
.12222 .34695 L
.1254 .34553 L
.12857 .34414 L
.13175 .34275 L
.13492 .34138 L
.1381 .34002 L
.14127 .33868 L
.14444 .33735 L
.14762 .33603 L
.15079 .33473 L
.15397 .33344 L
.15714 .33216 L
.16032 .3309 L
.16349 .32964 L
.16667 .32841 L
.16984 .32718 L
.17302 .32596 L
.17619 .32476 L
.17937 .32357 L
.18254 .32239 L
Mistroke
.18571 .32122 L
.18889 .32007 L
.19206 .31892 L
.19524 .31779 L
.19841 .31667 L
.20159 .31556 L
.20476 .31446 L
.20794 .31337 L
.21111 .3123 L
.21429 .31123 L
.21746 .31018 L
.22063 .30913 L
.22381 .3081 L
.22698 .30707 L
.23016 .30606 L
.23333 .30506 L
.23651 .30406 L
.23968 .30308 L
.24286 .3021 L
.24603 .30114 L
.24921 .30019 L
.25238 .29924 L
.25556 .2983 L
.25873 .29738 L
.2619 .29646 L
.26508 .29555 L
.26825 .29466 L
.27143 .29377 L
.2746 .29288 L
.27778 .29201 L
.28095 .29115 L
.28413 .29029 L
.2873 .28945 L
.29048 .28861 L
.29365 .28778 L
.29683 .28696 L
.3 .28615 L
.30317 .28534 L
.30635 .28455 L
.30952 .28376 L
.3127 .28298 L
.31587 .2822 L
.31905 .28144 L
.32222 .28068 L
.3254 .27993 L
.32857 .27919 L
.33175 .27845 L
.33492 .27773 L
.3381 .27701 L
.34127 .27629 L
Mistroke
.34444 .27559 L
.34762 .27489 L
.35079 .2742 L
.35397 .27351 L
.35714 .27283 L
.36032 .27216 L
.36349 .2715 L
.36667 .27084 L
.36984 .27019 L
.37302 .26954 L
.37619 .2689 L
.37937 .26827 L
.38254 .26765 L
.38571 .26703 L
.38889 .26641 L
.39206 .2658 L
.39524 .2652 L
.39841 .26461 L
.40159 .26402 L
.40476 .26344 L
.40794 .26286 L
.41111 .26229 L
.41429 .26172 L
.41746 .26116 L
.42063 .26061 L
.42381 .26006 L
.42698 .25951 L
.43016 .25897 L
.43333 .25844 L
.43651 .25791 L
.43968 .25739 L
.44286 .25687 L
.44603 .25636 L
.44921 .25586 L
.45238 .25535 L
.45556 .25486 L
.45873 .25437 L
.4619 .25388 L
.46508 .2534 L
.46825 .25292 L
.47143 .25245 L
.4746 .25198 L
.47778 .25152 L
.48095 .25106 L
.48413 .2506 L
.4873 .25016 L
.49048 .24971 L
.49365 .24927 L
.49683 .24883 L
.5 .2484 L
Mistroke
.50317 .24798 L
.50635 .24755 L
.50952 .24713 L
.5127 .24672 L
.51587 .24631 L
.51905 .2459 L
.52222 .2455 L
.5254 .2451 L
.52857 .24471 L
.53175 .24432 L
.53492 .24393 L
.5381 .24355 L
.54127 .24317 L
.54444 .2428 L
.54762 .24243 L
.55079 .24206 L
.55397 .24169 L
.55714 .24133 L
.56032 .24098 L
.56349 .24062 L
.56667 .24028 L
.56984 .23993 L
.57302 .23959 L
.57619 .23925 L
.57937 .23891 L
.58254 .23858 L
.58571 .23825 L
.58889 .23793 L
.59206 .2376 L
.59524 .23728 L
.59841 .23697 L
.60159 .23666 L
.60476 .23635 L
.60794 .23604 L
.61111 .23574 L
.61429 .23543 L
.61746 .23514 L
.62063 .23484 L
.62381 .23455 L
.62698 .23426 L
.63016 .23398 L
.63333 .23369 L
.63651 .23341 L
.63968 .23314 L
.64286 .23286 L
.64603 .23259 L
.64921 .23232 L
.65238 .23205 L
.65556 .23179 L
.65873 .23153 L
Mistroke
.6619 .23127 L
.66508 .23102 L
.66825 .23076 L
.67143 .23051 L
.6746 .23026 L
.67778 .23002 L
.68095 .22977 L
.68413 .22953 L
.6873 .2293 L
.69048 .22906 L
.69365 .22883 L
.69683 .22859 L
.7 .22836 L
.70317 .22814 L
.70635 .22791 L
.70952 .22769 L
.7127 .22747 L
.71587 .22725 L
.71905 .22704 L
.72222 .22682 L
.7254 .22661 L
.72857 .2264 L
.73175 .2262 L
.73492 .22599 L
.7381 .22579 L
.74127 .22559 L
.74444 .22539 L
.74762 .22519 L
.75079 .225 L
.75397 .2248 L
.75714 .22461 L
.76032 .22442 L
.76349 .22424 L
.76667 .22405 L
.76984 .22387 L
.77302 .22368 L
.77619 .2235 L
.77937 .22333 L
.78254 .22315 L
.78571 .22297 L
.78889 .2228 L
.79206 .22263 L
.79524 .22246 L
.79841 .22229 L
.80159 .22213 L
.80476 .22196 L
.80794 .2218 L
.81111 .22164 L
.81429 .22148 L
.81746 .22132 L
Mistroke
.82063 .22117 L
.82381 .22101 L
.82698 .22086 L
.83016 .22071 L
.83333 .22056 L
.83651 .22041 L
.83968 .22026 L
.84286 .22011 L
.84603 .21997 L
.84921 .21983 L
.85238 .21969 L
.85556 .21955 L
.85873 .21941 L
.8619 .21927 L
.86508 .21913 L
.86825 .219 L
.87143 .21887 L
.8746 .21873 L
.87778 .2186 L
.88095 .21847 L
.88413 .21835 L
.8873 .21822 L
.89048 .21809 L
.89365 .21797 L
.89683 .21785 L
.9 .21773 L
.90317 .21761 L
.90635 .21749 L
.90952 .21737 L
.9127 .21725 L
.91587 .21714 L
.91905 .21702 L
.92222 .21691 L
.9254 .2168 L
.92857 .21668 L
.93175 .21657 L
.93492 .21647 L
.9381 .21636 L
.94127 .21625 L
.94444 .21615 L
.94762 .21604 L
.95079 .21594 L
.95397 .21584 L
.95714 .21573 L
.96032 .21563 L
.96349 .21553 L
.96667 .21544 L
.96984 .21534 L
.97302 .21524 L
.97619 .21515 L
Mistroke
Mfstroke
.0001 w
.02698 .39666 0 2.5 Mabsadd m
.02698 .39666 -0.56518 .7779 Mabsadd L
.02698 .39666 -2.37764 .77254 Mabsadd L
.02698 .39666 -0.91448 -0.29713 Mabsadd L
.02698 .39666 -1.46946 -2.02254 Mabsadd L
.02698 .39666 0 -0.96154 Mabsadd L
.02698 .39666 1.46946 -2.02254 Mabsadd L
.02698 .39666 .91448 -0.29713 Mabsadd L
.02698 .39666 2.37764 .77254 Mabsadd L
.02698 .39666 .56518 .7779 Mabsadd L
.02698 .39666 0 2.5 Mabsadd L closepath F
.03016 .39475 0 2.5 Mabsadd m
.03016 .39475 -0.56518 .7779 Mabsadd L
.03016 .39475 -2.37764 .77254 Mabsadd L
.03016 .39475 -0.91448 -0.29713 Mabsadd L
.03016 .39475 -1.46946 -2.02254 Mabsadd L
.03016 .39475 0 -0.96154 Mabsadd L
.03016 .39475 1.46946 -2.02254 Mabsadd L
.03016 .39475 .91448 -0.29713 Mabsadd L
.03016 .39475 2.37764 .77254 Mabsadd L
.03016 .39475 .56518 .7779 Mabsadd L
.03016 .39475 0 2.5 Mabsadd L closepath F
.03333 .39286 0 2.5 Mabsadd m
.03333 .39286 -0.56518 .7779 Mabsadd L
.03333 .39286 -2.37764 .77254 Mabsadd L
.03333 .39286 -0.91448 -0.29713 Mabsadd L
.03333 .39286 -1.46946 -2.02254 Mabsadd L
.03333 .39286 0 -0.96154 Mabsadd L
.03333 .39286 1.46946 -2.02254 Mabsadd L
.03333 .39286 .91448 -0.29713 Mabsadd L
.03333 .39286 2.37764 .77254 Mabsadd L
.03333 .39286 .56518 .7779 Mabsadd L
.03333 .39286 0 2.5 Mabsadd L closepath F
.03651 .39098 0 2.5 Mabsadd m
.03651 .39098 -0.56518 .7779 Mabsadd L
.03651 .39098 -2.37764 .77254 Mabsadd L
.03651 .39098 -0.91448 -0.29713 Mabsadd L
.03651 .39098 -1.46946 -2.02254 Mabsadd L
.03651 .39098 0 -0.96154 Mabsadd L
.03651 .39098 1.46946 -2.02254 Mabsadd L
.03651 .39098 .91448 -0.29713 Mabsadd L
.03651 .39098 2.37764 .77254 Mabsadd L
.03651 .39098 .56518 .7779 Mabsadd L
.03651 .39098 0 2.5 Mabsadd L closepath F
.03968 .38913 0 2.5 Mabsadd m
.03968 .38913 -0.56518 .7779 Mabsadd L
.03968 .38913 -2.37764 .77254 Mabsadd L
.03968 .38913 -0.91448 -0.29713 Mabsadd L
.03968 .38913 -1.46946 -2.02254 Mabsadd L
.03968 .38913 0 -0.96154 Mabsadd L
.03968 .38913 1.46946 -2.02254 Mabsadd L
.03968 .38913 .91448 -0.29713 Mabsadd L
.03968 .38913 2.37764 .77254 Mabsadd L
.03968 .38913 .56518 .7779 Mabsadd L
.03968 .38913 0 2.5 Mabsadd L closepath F
.04286 .3873 0 2.5 Mabsadd m
.04286 .3873 -0.56518 .7779 Mabsadd L
.04286 .3873 -2.37764 .77254 Mabsadd L
.04286 .3873 -0.91448 -0.29713 Mabsadd L
.04286 .3873 -1.46946 -2.02254 Mabsadd L
.04286 .3873 0 -0.96154 Mabsadd L
.04286 .3873 1.46946 -2.02254 Mabsadd L
.04286 .3873 .91448 -0.29713 Mabsadd L
.04286 .3873 2.37764 .77254 Mabsadd L
.04286 .3873 .56518 .7779 Mabsadd L
.04286 .3873 0 2.5 Mabsadd L closepath F
.04603 .38548 0 2.5 Mabsadd m
.04603 .38548 -0.56518 .7779 Mabsadd L
.04603 .38548 -2.37764 .77254 Mabsadd L
.04603 .38548 -0.91448 -0.29713 Mabsadd L
.04603 .38548 -1.46946 -2.02254 Mabsadd L
.04603 .38548 0 -0.96154 Mabsadd L
.04603 .38548 1.46946 -2.02254 Mabsadd L
.04603 .38548 .91448 -0.29713 Mabsadd L
.04603 .38548 2.37764 .77254 Mabsadd L
.04603 .38548 .56518 .7779 Mabsadd L
.04603 .38548 0 2.5 Mabsadd L closepath F
.04921 .38368 0 2.5 Mabsadd m
.04921 .38368 -0.56518 .7779 Mabsadd L
.04921 .38368 -2.37764 .77254 Mabsadd L
.04921 .38368 -0.91448 -0.29713 Mabsadd L
.04921 .38368 -1.46946 -2.02254 Mabsadd L
.04921 .38368 0 -0.96154 Mabsadd L
.04921 .38368 1.46946 -2.02254 Mabsadd L
.04921 .38368 .91448 -0.29713 Mabsadd L
.04921 .38368 2.37764 .77254 Mabsadd L
.04921 .38368 .56518 .7779 Mabsadd L
.04921 .38368 0 2.5 Mabsadd L closepath F
.05238 .3819 0 2.5 Mabsadd m
.05238 .3819 -0.56518 .7779 Mabsadd L
.05238 .3819 -2.37764 .77254 Mabsadd L
.05238 .3819 -0.91448 -0.29713 Mabsadd L
.05238 .3819 -1.46946 -2.02254 Mabsadd L
.05238 .3819 0 -0.96154 Mabsadd L
.05238 .3819 1.46946 -2.02254 Mabsadd L
.05238 .3819 .91448 -0.29713 Mabsadd L
.05238 .3819 2.37764 .77254 Mabsadd L
.05238 .3819 .56518 .7779 Mabsadd L
.05238 .3819 0 2.5 Mabsadd L closepath F
.05556 .38014 0 2.5 Mabsadd m
.05556 .38014 -0.56518 .7779 Mabsadd L
.05556 .38014 -2.37764 .77254 Mabsadd L
.05556 .38014 -0.91448 -0.29713 Mabsadd L
.05556 .38014 -1.46946 -2.02254 Mabsadd L
.05556 .38014 0 -0.96154 Mabsadd L
.05556 .38014 1.46946 -2.02254 Mabsadd L
.05556 .38014 .91448 -0.29713 Mabsadd L
.05556 .38014 2.37764 .77254 Mabsadd L
.05556 .38014 .56518 .7779 Mabsadd L
.05556 .38014 0 2.5 Mabsadd L closepath F
.05873 .3784 0 2.5 Mabsadd m
.05873 .3784 -0.56518 .7779 Mabsadd L
.05873 .3784 -2.37764 .77254 Mabsadd L
.05873 .3784 -0.91448 -0.29713 Mabsadd L
.05873 .3784 -1.46946 -2.02254 Mabsadd L
.05873 .3784 0 -0.96154 Mabsadd L
.05873 .3784 1.46946 -2.02254 Mabsadd L
.05873 .3784 .91448 -0.29713 Mabsadd L
.05873 .3784 2.37764 .77254 Mabsadd L
.05873 .3784 .56518 .7779 Mabsadd L
.05873 .3784 0 2.5 Mabsadd L closepath F
.0619 .37667 0 2.5 Mabsadd m
.0619 .37667 -0.56518 .7779 Mabsadd L
.0619 .37667 -2.37764 .77254 Mabsadd L
.0619 .37667 -0.91448 -0.29713 Mabsadd L
.0619 .37667 -1.46946 -2.02254 Mabsadd L
.0619 .37667 0 -0.96154 Mabsadd L
.0619 .37667 1.46946 -2.02254 Mabsadd L
.0619 .37667 .91448 -0.29713 Mabsadd L
.0619 .37667 2.37764 .77254 Mabsadd L
.0619 .37667 .56518 .7779 Mabsadd L
.0619 .37667 0 2.5 Mabsadd L closepath F
.06508 .37496 0 2.5 Mabsadd m
.06508 .37496 -0.56518 .7779 Mabsadd L
.06508 .37496 -2.37764 .77254 Mabsadd L
.06508 .37496 -0.91448 -0.29713 Mabsadd L
.06508 .37496 -1.46946 -2.02254 Mabsadd L
.06508 .37496 0 -0.96154 Mabsadd L
.06508 .37496 1.46946 -2.02254 Mabsadd L
.06508 .37496 .91448 -0.29713 Mabsadd L
.06508 .37496 2.37764 .77254 Mabsadd L
.06508 .37496 .56518 .7779 Mabsadd L
.06508 .37496 0 2.5 Mabsadd L closepath F
.06825 .37327 0 2.5 Mabsadd m
.06825 .37327 -0.56518 .7779 Mabsadd L
.06825 .37327 -2.37764 .77254 Mabsadd L
.06825 .37327 -0.91448 -0.29713 Mabsadd L
.06825 .37327 -1.46946 -2.02254 Mabsadd L
.06825 .37327 0 -0.96154 Mabsadd L
.06825 .37327 1.46946 -2.02254 Mabsadd L
.06825 .37327 .91448 -0.29713 Mabsadd L
.06825 .37327 2.37764 .77254 Mabsadd L
.06825 .37327 .56518 .7779 Mabsadd L
.06825 .37327 0 2.5 Mabsadd L closepath F
.07143 .37159 0 2.5 Mabsadd m
.07143 .37159 -0.56518 .7779 Mabsadd L
.07143 .37159 -2.37764 .77254 Mabsadd L
.07143 .37159 -0.91448 -0.29713 Mabsadd L
.07143 .37159 -1.46946 -2.02254 Mabsadd L
.07143 .37159 0 -0.96154 Mabsadd L
.07143 .37159 1.46946 -2.02254 Mabsadd L
.07143 .37159 .91448 -0.29713 Mabsadd L
.07143 .37159 2.37764 .77254 Mabsadd L
.07143 .37159 .56518 .7779 Mabsadd L
.07143 .37159 0 2.5 Mabsadd L closepath F
.0746 .36993 0 2.5 Mabsadd m
.0746 .36993 -0.56518 .7779 Mabsadd L
.0746 .36993 -2.37764 .77254 Mabsadd L
.0746 .36993 -0.91448 -0.29713 Mabsadd L
.0746 .36993 -1.46946 -2.02254 Mabsadd L
.0746 .36993 0 -0.96154 Mabsadd L
.0746 .36993 1.46946 -2.02254 Mabsadd L
.0746 .36993 .91448 -0.29713 Mabsadd L
.0746 .36993 2.37764 .77254 Mabsadd L
.0746 .36993 .56518 .7779 Mabsadd L
.0746 .36993 0 2.5 Mabsadd L closepath F
.07778 .36829 0 2.5 Mabsadd m
.07778 .36829 -0.56518 .7779 Mabsadd L
.07778 .36829 -2.37764 .77254 Mabsadd L
.07778 .36829 -0.91448 -0.29713 Mabsadd L
.07778 .36829 -1.46946 -2.02254 Mabsadd L
.07778 .36829 0 -0.96154 Mabsadd L
.07778 .36829 1.46946 -2.02254 Mabsadd L
.07778 .36829 .91448 -0.29713 Mabsadd L
.07778 .36829 2.37764 .77254 Mabsadd L
.07778 .36829 .56518 .7779 Mabsadd L
.07778 .36829 0 2.5 Mabsadd L closepath F
.08095 .36666 0 2.5 Mabsadd m
.08095 .36666 -0.56518 .7779 Mabsadd L
.08095 .36666 -2.37764 .77254 Mabsadd L
.08095 .36666 -0.91448 -0.29713 Mabsadd L
.08095 .36666 -1.46946 -2.02254 Mabsadd L
.08095 .36666 0 -0.96154 Mabsadd L
.08095 .36666 1.46946 -2.02254 Mabsadd L
.08095 .36666 .91448 -0.29713 Mabsadd L
.08095 .36666 2.37764 .77254 Mabsadd L
.08095 .36666 .56518 .7779 Mabsadd L
.08095 .36666 0 2.5 Mabsadd L closepath F
.08413 .36505 0 2.5 Mabsadd m
.08413 .36505 -0.56518 .7779 Mabsadd L
.08413 .36505 -2.37764 .77254 Mabsadd L
.08413 .36505 -0.91448 -0.29713 Mabsadd L
.08413 .36505 -1.46946 -2.02254 Mabsadd L
.08413 .36505 0 -0.96154 Mabsadd L
.08413 .36505 1.46946 -2.02254 Mabsadd L
.08413 .36505 .91448 -0.29713 Mabsadd L
.08413 .36505 2.37764 .77254 Mabsadd L
.08413 .36505 .56518 .7779 Mabsadd L
.08413 .36505 0 2.5 Mabsadd L closepath F
.0873 .36346 0 2.5 Mabsadd m
.0873 .36346 -0.56518 .7779 Mabsadd L
.0873 .36346 -2.37764 .77254 Mabsadd L
.0873 .36346 -0.91448 -0.29713 Mabsadd L
.0873 .36346 -1.46946 -2.02254 Mabsadd L
.0873 .36346 0 -0.96154 Mabsadd L
.0873 .36346 1.46946 -2.02254 Mabsadd L
.0873 .36346 .91448 -0.29713 Mabsadd L
.0873 .36346 2.37764 .77254 Mabsadd L
.0873 .36346 .56518 .7779 Mabsadd L
.0873 .36346 0 2.5 Mabsadd L closepath F
.09048 .36188 0 2.5 Mabsadd m
.09048 .36188 -0.56518 .7779 Mabsadd L
.09048 .36188 -2.37764 .77254 Mabsadd L
.09048 .36188 -0.91448 -0.29713 Mabsadd L
.09048 .36188 -1.46946 -2.02254 Mabsadd L
.09048 .36188 0 -0.96154 Mabsadd L
.09048 .36188 1.46946 -2.02254 Mabsadd L
.09048 .36188 .91448 -0.29713 Mabsadd L
.09048 .36188 2.37764 .77254 Mabsadd L
.09048 .36188 .56518 .7779 Mabsadd L
.09048 .36188 0 2.5 Mabsadd L closepath F
.09365 .36032 0 2.5 Mabsadd m
.09365 .36032 -0.56518 .7779 Mabsadd L
.09365 .36032 -2.37764 .77254 Mabsadd L
.09365 .36032 -0.91448 -0.29713 Mabsadd L
.09365 .36032 -1.46946 -2.02254 Mabsadd L
.09365 .36032 0 -0.96154 Mabsadd L
.09365 .36032 1.46946 -2.02254 Mabsadd L
.09365 .36032 .91448 -0.29713 Mabsadd L
.09365 .36032 2.37764 .77254 Mabsadd L
.09365 .36032 .56518 .7779 Mabsadd L
.09365 .36032 0 2.5 Mabsadd L closepath F
.09683 .35877 0 2.5 Mabsadd m
.09683 .35877 -0.56518 .7779 Mabsadd L
.09683 .35877 -2.37764 .77254 Mabsadd L
.09683 .35877 -0.91448 -0.29713 Mabsadd L
.09683 .35877 -1.46946 -2.02254 Mabsadd L
.09683 .35877 0 -0.96154 Mabsadd L
.09683 .35877 1.46946 -2.02254 Mabsadd L
.09683 .35877 .91448 -0.29713 Mabsadd L
.09683 .35877 2.37764 .77254 Mabsadd L
.09683 .35877 .56518 .7779 Mabsadd L
.09683 .35877 0 2.5 Mabsadd L closepath F
.1 .35724 0 2.5 Mabsadd m
.1 .35724 -0.56518 .7779 Mabsadd L
.1 .35724 -2.37764 .77254 Mabsadd L
.1 .35724 -0.91448 -0.29713 Mabsadd L
.1 .35724 -1.46946 -2.02254 Mabsadd L
.1 .35724 0 -0.96154 Mabsadd L
.1 .35724 1.46946 -2.02254 Mabsadd L
.1 .35724 .91448 -0.29713 Mabsadd L
.1 .35724 2.37764 .77254 Mabsadd L
.1 .35724 .56518 .7779 Mabsadd L
.1 .35724 0 2.5 Mabsadd L closepath F
.10317 .35573 0 2.5 Mabsadd m
.10317 .35573 -0.56518 .7779 Mabsadd L
.10317 .35573 -2.37764 .77254 Mabsadd L
.10317 .35573 -0.91448 -0.29713 Mabsadd L
.10317 .35573 -1.46946 -2.02254 Mabsadd L
.10317 .35573 0 -0.96154 Mabsadd L
.10317 .35573 1.46946 -2.02254 Mabsadd L
.10317 .35573 .91448 -0.29713 Mabsadd L
.10317 .35573 2.37764 .77254 Mabsadd L
.10317 .35573 .56518 .7779 Mabsadd L
.10317 .35573 0 2.5 Mabsadd L closepath F
.10635 .35423 0 2.5 Mabsadd m
.10635 .35423 -0.56518 .7779 Mabsadd L
.10635 .35423 -2.37764 .77254 Mabsadd L
.10635 .35423 -0.91448 -0.29713 Mabsadd L
.10635 .35423 -1.46946 -2.02254 Mabsadd L
.10635 .35423 0 -0.96154 Mabsadd L
.10635 .35423 1.46946 -2.02254 Mabsadd L
.10635 .35423 .91448 -0.29713 Mabsadd L
.10635 .35423 2.37764 .77254 Mabsadd L
.10635 .35423 .56518 .7779 Mabsadd L
.10635 .35423 0 2.5 Mabsadd L closepath F
.10952 .35274 0 2.5 Mabsadd m
.10952 .35274 -0.56518 .7779 Mabsadd L
.10952 .35274 -2.37764 .77254 Mabsadd L
.10952 .35274 -0.91448 -0.29713 Mabsadd L
.10952 .35274 -1.46946 -2.02254 Mabsadd L
.10952 .35274 0 -0.96154 Mabsadd L
.10952 .35274 1.46946 -2.02254 Mabsadd L
.10952 .35274 .91448 -0.29713 Mabsadd L
.10952 .35274 2.37764 .77254 Mabsadd L
.10952 .35274 .56518 .7779 Mabsadd L
.10952 .35274 0 2.5 Mabsadd L closepath F
.1127 .35127 0 2.5 Mabsadd m
.1127 .35127 -0.56518 .7779 Mabsadd L
.1127 .35127 -2.37764 .77254 Mabsadd L
.1127 .35127 -0.91448 -0.29713 Mabsadd L
.1127 .35127 -1.46946 -2.02254 Mabsadd L
.1127 .35127 0 -0.96154 Mabsadd L
.1127 .35127 1.46946 -2.02254 Mabsadd L
.1127 .35127 .91448 -0.29713 Mabsadd L
.1127 .35127 2.37764 .77254 Mabsadd L
.1127 .35127 .56518 .7779 Mabsadd L
.1127 .35127 0 2.5 Mabsadd L closepath F
.11587 .34981 0 2.5 Mabsadd m
.11587 .34981 -0.56518 .7779 Mabsadd L
.11587 .34981 -2.37764 .77254 Mabsadd L
.11587 .34981 -0.91448 -0.29713 Mabsadd L
.11587 .34981 -1.46946 -2.02254 Mabsadd L
.11587 .34981 0 -0.96154 Mabsadd L
.11587 .34981 1.46946 -2.02254 Mabsadd L
.11587 .34981 .91448 -0.29713 Mabsadd L
.11587 .34981 2.37764 .77254 Mabsadd L
.11587 .34981 .56518 .7779 Mabsadd L
.11587 .34981 0 2.5 Mabsadd L closepath F
.11905 .34837 0 2.5 Mabsadd m
.11905 .34837 -0.56518 .7779 Mabsadd L
.11905 .34837 -2.37764 .77254 Mabsadd L
.11905 .34837 -0.91448 -0.29713 Mabsadd L
.11905 .34837 -1.46946 -2.02254 Mabsadd L
.11905 .34837 0 -0.96154 Mabsadd L
.11905 .34837 1.46946 -2.02254 Mabsadd L
.11905 .34837 .91448 -0.29713 Mabsadd L
.11905 .34837 2.37764 .77254 Mabsadd L
.11905 .34837 .56518 .7779 Mabsadd L
.11905 .34837 0 2.5 Mabsadd L closepath F
.12222 .34695 0 2.5 Mabsadd m
.12222 .34695 -0.56518 .7779 Mabsadd L
.12222 .34695 -2.37764 .77254 Mabsadd L
.12222 .34695 -0.91448 -0.29713 Mabsadd L
.12222 .34695 -1.46946 -2.02254 Mabsadd L
.12222 .34695 0 -0.96154 Mabsadd L
.12222 .34695 1.46946 -2.02254 Mabsadd L
.12222 .34695 .91448 -0.29713 Mabsadd L
.12222 .34695 2.37764 .77254 Mabsadd L
.12222 .34695 .56518 .7779 Mabsadd L
.12222 .34695 0 2.5 Mabsadd L closepath F
.1254 .34553 0 2.5 Mabsadd m
.1254 .34553 -0.56518 .7779 Mabsadd L
.1254 .34553 -2.37764 .77254 Mabsadd L
.1254 .34553 -0.91448 -0.29713 Mabsadd L
.1254 .34553 -1.46946 -2.02254 Mabsadd L
.1254 .34553 0 -0.96154 Mabsadd L
.1254 .34553 1.46946 -2.02254 Mabsadd L
.1254 .34553 .91448 -0.29713 Mabsadd L
.1254 .34553 2.37764 .77254 Mabsadd L
.1254 .34553 .56518 .7779 Mabsadd L
.1254 .34553 0 2.5 Mabsadd L closepath F
.12857 .34414 0 2.5 Mabsadd m
.12857 .34414 -0.56518 .7779 Mabsadd L
.12857 .34414 -2.37764 .77254 Mabsadd L
.12857 .34414 -0.91448 -0.29713 Mabsadd L
.12857 .34414 -1.46946 -2.02254 Mabsadd L
.12857 .34414 0 -0.96154 Mabsadd L
.12857 .34414 1.46946 -2.02254 Mabsadd L
.12857 .34414 .91448 -0.29713 Mabsadd L
.12857 .34414 2.37764 .77254 Mabsadd L
.12857 .34414 .56518 .7779 Mabsadd L
.12857 .34414 0 2.5 Mabsadd L closepath F
.13175 .34275 0 2.5 Mabsadd m
.13175 .34275 -0.56518 .7779 Mabsadd L
.13175 .34275 -2.37764 .77254 Mabsadd L
.13175 .34275 -0.91448 -0.29713 Mabsadd L
.13175 .34275 -1.46946 -2.02254 Mabsadd L
.13175 .34275 0 -0.96154 Mabsadd L
.13175 .34275 1.46946 -2.02254 Mabsadd L
.13175 .34275 .91448 -0.29713 Mabsadd L
.13175 .34275 2.37764 .77254 Mabsadd L
.13175 .34275 .56518 .7779 Mabsadd L
.13175 .34275 0 2.5 Mabsadd L closepath F
.13492 .34138 0 2.5 Mabsadd m
.13492 .34138 -0.56518 .7779 Mabsadd L
.13492 .34138 -2.37764 .77254 Mabsadd L
.13492 .34138 -0.91448 -0.29713 Mabsadd L
.13492 .34138 -1.46946 -2.02254 Mabsadd L
.13492 .34138 0 -0.96154 Mabsadd L
.13492 .34138 1.46946 -2.02254 Mabsadd L
.13492 .34138 .91448 -0.29713 Mabsadd L
.13492 .34138 2.37764 .77254 Mabsadd L
.13492 .34138 .56518 .7779 Mabsadd L
.13492 .34138 0 2.5 Mabsadd L closepath F
.1381 .34002 0 2.5 Mabsadd m
.1381 .34002 -0.56518 .7779 Mabsadd L
.1381 .34002 -2.37764 .77254 Mabsadd L
.1381 .34002 -0.91448 -0.29713 Mabsadd L
.1381 .34002 -1.46946 -2.02254 Mabsadd L
.1381 .34002 0 -0.96154 Mabsadd L
.1381 .34002 1.46946 -2.02254 Mabsadd L
.1381 .34002 .91448 -0.29713 Mabsadd L
.1381 .34002 2.37764 .77254 Mabsadd L
.1381 .34002 .56518 .7779 Mabsadd L
.1381 .34002 0 2.5 Mabsadd L closepath F
.14127 .33868 0 2.5 Mabsadd m
.14127 .33868 -0.56518 .7779 Mabsadd L
.14127 .33868 -2.37764 .77254 Mabsadd L
.14127 .33868 -0.91448 -0.29713 Mabsadd L
.14127 .33868 -1.46946 -2.02254 Mabsadd L
.14127 .33868 0 -0.96154 Mabsadd L
.14127 .33868 1.46946 -2.02254 Mabsadd L
.14127 .33868 .91448 -0.29713 Mabsadd L
.14127 .33868 2.37764 .77254 Mabsadd L
.14127 .33868 .56518 .7779 Mabsadd L
.14127 .33868 0 2.5 Mabsadd L closepath F
.14444 .33735 0 2.5 Mabsadd m
.14444 .33735 -0.56518 .7779 Mabsadd L
.14444 .33735 -2.37764 .77254 Mabsadd L
.14444 .33735 -0.91448 -0.29713 Mabsadd L
.14444 .33735 -1.46946 -2.02254 Mabsadd L
.14444 .33735 0 -0.96154 Mabsadd L
.14444 .33735 1.46946 -2.02254 Mabsadd L
.14444 .33735 .91448 -0.29713 Mabsadd L
.14444 .33735 2.37764 .77254 Mabsadd L
.14444 .33735 .56518 .7779 Mabsadd L
.14444 .33735 0 2.5 Mabsadd L closepath F
.14762 .33603 0 2.5 Mabsadd m
.14762 .33603 -0.56518 .7779 Mabsadd L
.14762 .33603 -2.37764 .77254 Mabsadd L
.14762 .33603 -0.91448 -0.29713 Mabsadd L
.14762 .33603 -1.46946 -2.02254 Mabsadd L
.14762 .33603 0 -0.96154 Mabsadd L
.14762 .33603 1.46946 -2.02254 Mabsadd L
.14762 .33603 .91448 -0.29713 Mabsadd L
.14762 .33603 2.37764 .77254 Mabsadd L
.14762 .33603 .56518 .7779 Mabsadd L
.14762 .33603 0 2.5 Mabsadd L closepath F
.15079 .33473 0 2.5 Mabsadd m
.15079 .33473 -0.56518 .7779 Mabsadd L
.15079 .33473 -2.37764 .77254 Mabsadd L
.15079 .33473 -0.91448 -0.29713 Mabsadd L
.15079 .33473 -1.46946 -2.02254 Mabsadd L
.15079 .33473 0 -0.96154 Mabsadd L
.15079 .33473 1.46946 -2.02254 Mabsadd L
.15079 .33473 .91448 -0.29713 Mabsadd L
.15079 .33473 2.37764 .77254 Mabsadd L
.15079 .33473 .56518 .7779 Mabsadd L
.15079 .33473 0 2.5 Mabsadd L closepath F
.15397 .33344 0 2.5 Mabsadd m
.15397 .33344 -0.56518 .7779 Mabsadd L
.15397 .33344 -2.37764 .77254 Mabsadd L
.15397 .33344 -0.91448 -0.29713 Mabsadd L
.15397 .33344 -1.46946 -2.02254 Mabsadd L
.15397 .33344 0 -0.96154 Mabsadd L
.15397 .33344 1.46946 -2.02254 Mabsadd L
.15397 .33344 .91448 -0.29713 Mabsadd L
.15397 .33344 2.37764 .77254 Mabsadd L
.15397 .33344 .56518 .7779 Mabsadd L
.15397 .33344 0 2.5 Mabsadd L closepath F
.15714 .33216 0 2.5 Mabsadd m
.15714 .33216 -0.56518 .7779 Mabsadd L
.15714 .33216 -2.37764 .77254 Mabsadd L
.15714 .33216 -0.91448 -0.29713 Mabsadd L
.15714 .33216 -1.46946 -2.02254 Mabsadd L
.15714 .33216 0 -0.96154 Mabsadd L
.15714 .33216 1.46946 -2.02254 Mabsadd L
.15714 .33216 .91448 -0.29713 Mabsadd L
.15714 .33216 2.37764 .77254 Mabsadd L
.15714 .33216 .56518 .7779 Mabsadd L
.15714 .33216 0 2.5 Mabsadd L closepath F
.16032 .3309 0 2.5 Mabsadd m
.16032 .3309 -0.56518 .7779 Mabsadd L
.16032 .3309 -2.37764 .77254 Mabsadd L
.16032 .3309 -0.91448 -0.29713 Mabsadd L
.16032 .3309 -1.46946 -2.02254 Mabsadd L
.16032 .3309 0 -0.96154 Mabsadd L
.16032 .3309 1.46946 -2.02254 Mabsadd L
.16032 .3309 .91448 -0.29713 Mabsadd L
.16032 .3309 2.37764 .77254 Mabsadd L
.16032 .3309 .56518 .7779 Mabsadd L
.16032 .3309 0 2.5 Mabsadd L closepath F
.16349 .32964 0 2.5 Mabsadd m
.16349 .32964 -0.56518 .7779 Mabsadd L
.16349 .32964 -2.37764 .77254 Mabsadd L
.16349 .32964 -0.91448 -0.29713 Mabsadd L
.16349 .32964 -1.46946 -2.02254 Mabsadd L
.16349 .32964 0 -0.96154 Mabsadd L
.16349 .32964 1.46946 -2.02254 Mabsadd L
.16349 .32964 .91448 -0.29713 Mabsadd L
.16349 .32964 2.37764 .77254 Mabsadd L
.16349 .32964 .56518 .7779 Mabsadd L
.16349 .32964 0 2.5 Mabsadd L closepath F
.16667 .32841 0 2.5 Mabsadd m
.16667 .32841 -0.56518 .7779 Mabsadd L
.16667 .32841 -2.37764 .77254 Mabsadd L
.16667 .32841 -0.91448 -0.29713 Mabsadd L
.16667 .32841 -1.46946 -2.02254 Mabsadd L
.16667 .32841 0 -0.96154 Mabsadd L
.16667 .32841 1.46946 -2.02254 Mabsadd L
.16667 .32841 .91448 -0.29713 Mabsadd L
.16667 .32841 2.37764 .77254 Mabsadd L
.16667 .32841 .56518 .7779 Mabsadd L
.16667 .32841 0 2.5 Mabsadd L closepath F
.16984 .32718 0 2.5 Mabsadd m
.16984 .32718 -0.56518 .7779 Mabsadd L
.16984 .32718 -2.37764 .77254 Mabsadd L
.16984 .32718 -0.91448 -0.29713 Mabsadd L
.16984 .32718 -1.46946 -2.02254 Mabsadd L
.16984 .32718 0 -0.96154 Mabsadd L
.16984 .32718 1.46946 -2.02254 Mabsadd L
.16984 .32718 .91448 -0.29713 Mabsadd L
.16984 .32718 2.37764 .77254 Mabsadd L
.16984 .32718 .56518 .7779 Mabsadd L
.16984 .32718 0 2.5 Mabsadd L closepath F
.17302 .32596 0 2.5 Mabsadd m
.17302 .32596 -0.56518 .7779 Mabsadd L
.17302 .32596 -2.37764 .77254 Mabsadd L
.17302 .32596 -0.91448 -0.29713 Mabsadd L
.17302 .32596 -1.46946 -2.02254 Mabsadd L
.17302 .32596 0 -0.96154 Mabsadd L
.17302 .32596 1.46946 -2.02254 Mabsadd L
.17302 .32596 .91448 -0.29713 Mabsadd L
.17302 .32596 2.37764 .77254 Mabsadd L
.17302 .32596 .56518 .7779 Mabsadd L
.17302 .32596 0 2.5 Mabsadd L closepath F
.17619 .32476 0 2.5 Mabsadd m
.17619 .32476 -0.56518 .7779 Mabsadd L
.17619 .32476 -2.37764 .77254 Mabsadd L
.17619 .32476 -0.91448 -0.29713 Mabsadd L
.17619 .32476 -1.46946 -2.02254 Mabsadd L
.17619 .32476 0 -0.96154 Mabsadd L
.17619 .32476 1.46946 -2.02254 Mabsadd L
.17619 .32476 .91448 -0.29713 Mabsadd L
.17619 .32476 2.37764 .77254 Mabsadd L
.17619 .32476 .56518 .7779 Mabsadd L
.17619 .32476 0 2.5 Mabsadd L closepath F
.17937 .32357 0 2.5 Mabsadd m
.17937 .32357 -0.56518 .7779 Mabsadd L
.17937 .32357 -2.37764 .77254 Mabsadd L
.17937 .32357 -0.91448 -0.29713 Mabsadd L
.17937 .32357 -1.46946 -2.02254 Mabsadd L
.17937 .32357 0 -0.96154 Mabsadd L
.17937 .32357 1.46946 -2.02254 Mabsadd L
.17937 .32357 .91448 -0.29713 Mabsadd L
.17937 .32357 2.37764 .77254 Mabsadd L
.17937 .32357 .56518 .7779 Mabsadd L
.17937 .32357 0 2.5 Mabsadd L closepath F
.18254 .32239 0 2.5 Mabsadd m
.18254 .32239 -0.56518 .7779 Mabsadd L
.18254 .32239 -2.37764 .77254 Mabsadd L
.18254 .32239 -0.91448 -0.29713 Mabsadd L
.18254 .32239 -1.46946 -2.02254 Mabsadd L
.18254 .32239 0 -0.96154 Mabsadd L
.18254 .32239 1.46946 -2.02254 Mabsadd L
.18254 .32239 .91448 -0.29713 Mabsadd L
.18254 .32239 2.37764 .77254 Mabsadd L
.18254 .32239 .56518 .7779 Mabsadd L
.18254 .32239 0 2.5 Mabsadd L closepath F
.18571 .32122 0 2.5 Mabsadd m
.18571 .32122 -0.56518 .7779 Mabsadd L
.18571 .32122 -2.37764 .77254 Mabsadd L
.18571 .32122 -0.91448 -0.29713 Mabsadd L
.18571 .32122 -1.46946 -2.02254 Mabsadd L
.18571 .32122 0 -0.96154 Mabsadd L
.18571 .32122 1.46946 -2.02254 Mabsadd L
.18571 .32122 .91448 -0.29713 Mabsadd L
.18571 .32122 2.37764 .77254 Mabsadd L
.18571 .32122 .56518 .7779 Mabsadd L
.18571 .32122 0 2.5 Mabsadd L closepath F
.18889 .32007 0 2.5 Mabsadd m
.18889 .32007 -0.56518 .7779 Mabsadd L
.18889 .32007 -2.37764 .77254 Mabsadd L
.18889 .32007 -0.91448 -0.29713 Mabsadd L
.18889 .32007 -1.46946 -2.02254 Mabsadd L
.18889 .32007 0 -0.96154 Mabsadd L
.18889 .32007 1.46946 -2.02254 Mabsadd L
.18889 .32007 .91448 -0.29713 Mabsadd L
.18889 .32007 2.37764 .77254 Mabsadd L
.18889 .32007 .56518 .7779 Mabsadd L
.18889 .32007 0 2.5 Mabsadd L closepath F
.19206 .31892 0 2.5 Mabsadd m
.19206 .31892 -0.56518 .7779 Mabsadd L
.19206 .31892 -2.37764 .77254 Mabsadd L
.19206 .31892 -0.91448 -0.29713 Mabsadd L
.19206 .31892 -1.46946 -2.02254 Mabsadd L
.19206 .31892 0 -0.96154 Mabsadd L
.19206 .31892 1.46946 -2.02254 Mabsadd L
.19206 .31892 .91448 -0.29713 Mabsadd L
.19206 .31892 2.37764 .77254 Mabsadd L
.19206 .31892 .56518 .7779 Mabsadd L
.19206 .31892 0 2.5 Mabsadd L closepath F
.19524 .31779 0 2.5 Mabsadd m
.19524 .31779 -0.56518 .7779 Mabsadd L
.19524 .31779 -2.37764 .77254 Mabsadd L
.19524 .31779 -0.91448 -0.29713 Mabsadd L
.19524 .31779 -1.46946 -2.02254 Mabsadd L
.19524 .31779 0 -0.96154 Mabsadd L
.19524 .31779 1.46946 -2.02254 Mabsadd L
.19524 .31779 .91448 -0.29713 Mabsadd L
.19524 .31779 2.37764 .77254 Mabsadd L
.19524 .31779 .56518 .7779 Mabsadd L
.19524 .31779 0 2.5 Mabsadd L closepath F
.19841 .31667 0 2.5 Mabsadd m
.19841 .31667 -0.56518 .7779 Mabsadd L
.19841 .31667 -2.37764 .77254 Mabsadd L
.19841 .31667 -0.91448 -0.29713 Mabsadd L
.19841 .31667 -1.46946 -2.02254 Mabsadd L
.19841 .31667 0 -0.96154 Mabsadd L
.19841 .31667 1.46946 -2.02254 Mabsadd L
.19841 .31667 .91448 -0.29713 Mabsadd L
.19841 .31667 2.37764 .77254 Mabsadd L
.19841 .31667 .56518 .7779 Mabsadd L
.19841 .31667 0 2.5 Mabsadd L closepath F
.20159 .31556 0 2.5 Mabsadd m
.20159 .31556 -0.56518 .7779 Mabsadd L
.20159 .31556 -2.37764 .77254 Mabsadd L
.20159 .31556 -0.91448 -0.29713 Mabsadd L
.20159 .31556 -1.46946 -2.02254 Mabsadd L
.20159 .31556 0 -0.96154 Mabsadd L
.20159 .31556 1.46946 -2.02254 Mabsadd L
.20159 .31556 .91448 -0.29713 Mabsadd L
.20159 .31556 2.37764 .77254 Mabsadd L
.20159 .31556 .56518 .7779 Mabsadd L
.20159 .31556 0 2.5 Mabsadd L closepath F
.20476 .31446 0 2.5 Mabsadd m
.20476 .31446 -0.56518 .7779 Mabsadd L
.20476 .31446 -2.37764 .77254 Mabsadd L
.20476 .31446 -0.91448 -0.29713 Mabsadd L
.20476 .31446 -1.46946 -2.02254 Mabsadd L
.20476 .31446 0 -0.96154 Mabsadd L
.20476 .31446 1.46946 -2.02254 Mabsadd L
.20476 .31446 .91448 -0.29713 Mabsadd L
.20476 .31446 2.37764 .77254 Mabsadd L
.20476 .31446 .56518 .7779 Mabsadd L
.20476 .31446 0 2.5 Mabsadd L closepath F
.20794 .31337 0 2.5 Mabsadd m
.20794 .31337 -0.56518 .7779 Mabsadd L
.20794 .31337 -2.37764 .77254 Mabsadd L
.20794 .31337 -0.91448 -0.29713 Mabsadd L
.20794 .31337 -1.46946 -2.02254 Mabsadd L
.20794 .31337 0 -0.96154 Mabsadd L
.20794 .31337 1.46946 -2.02254 Mabsadd L
.20794 .31337 .91448 -0.29713 Mabsadd L
.20794 .31337 2.37764 .77254 Mabsadd L
.20794 .31337 .56518 .7779 Mabsadd L
.20794 .31337 0 2.5 Mabsadd L closepath F
.21111 .3123 0 2.5 Mabsadd m
.21111 .3123 -0.56518 .7779 Mabsadd L
.21111 .3123 -2.37764 .77254 Mabsadd L
.21111 .3123 -0.91448 -0.29713 Mabsadd L
.21111 .3123 -1.46946 -2.02254 Mabsadd L
.21111 .3123 0 -0.96154 Mabsadd L
.21111 .3123 1.46946 -2.02254 Mabsadd L
.21111 .3123 .91448 -0.29713 Mabsadd L
.21111 .3123 2.37764 .77254 Mabsadd L
.21111 .3123 .56518 .7779 Mabsadd L
.21111 .3123 0 2.5 Mabsadd L closepath F
.21429 .31123 0 2.5 Mabsadd m
.21429 .31123 -0.56518 .7779 Mabsadd L
.21429 .31123 -2.37764 .77254 Mabsadd L
.21429 .31123 -0.91448 -0.29713 Mabsadd L
.21429 .31123 -1.46946 -2.02254 Mabsadd L
.21429 .31123 0 -0.96154 Mabsadd L
.21429 .31123 1.46946 -2.02254 Mabsadd L
.21429 .31123 .91448 -0.29713 Mabsadd L
.21429 .31123 2.37764 .77254 Mabsadd L
.21429 .31123 .56518 .7779 Mabsadd L
.21429 .31123 0 2.5 Mabsadd L closepath F
.21746 .31018 0 2.5 Mabsadd m
.21746 .31018 -0.56518 .7779 Mabsadd L
.21746 .31018 -2.37764 .77254 Mabsadd L
.21746 .31018 -0.91448 -0.29713 Mabsadd L
.21746 .31018 -1.46946 -2.02254 Mabsadd L
.21746 .31018 0 -0.96154 Mabsadd L
.21746 .31018 1.46946 -2.02254 Mabsadd L
.21746 .31018 .91448 -0.29713 Mabsadd L
.21746 .31018 2.37764 .77254 Mabsadd L
.21746 .31018 .56518 .7779 Mabsadd L
.21746 .31018 0 2.5 Mabsadd L closepath F
.22063 .30913 0 2.5 Mabsadd m
.22063 .30913 -0.56518 .7779 Mabsadd L
.22063 .30913 -2.37764 .77254 Mabsadd L
.22063 .30913 -0.91448 -0.29713 Mabsadd L
.22063 .30913 -1.46946 -2.02254 Mabsadd L
.22063 .30913 0 -0.96154 Mabsadd L
.22063 .30913 1.46946 -2.02254 Mabsadd L
.22063 .30913 .91448 -0.29713 Mabsadd L
.22063 .30913 2.37764 .77254 Mabsadd L
.22063 .30913 .56518 .7779 Mabsadd L
.22063 .30913 0 2.5 Mabsadd L closepath F
.22381 .3081 0 2.5 Mabsadd m
.22381 .3081 -0.56518 .7779 Mabsadd L
.22381 .3081 -2.37764 .77254 Mabsadd L
.22381 .3081 -0.91448 -0.29713 Mabsadd L
.22381 .3081 -1.46946 -2.02254 Mabsadd L
.22381 .3081 0 -0.96154 Mabsadd L
.22381 .3081 1.46946 -2.02254 Mabsadd L
.22381 .3081 .91448 -0.29713 Mabsadd L
.22381 .3081 2.37764 .77254 Mabsadd L
.22381 .3081 .56518 .7779 Mabsadd L
.22381 .3081 0 2.5 Mabsadd L closepath F
.22698 .30707 0 2.5 Mabsadd m
.22698 .30707 -0.56518 .7779 Mabsadd L
.22698 .30707 -2.37764 .77254 Mabsadd L
.22698 .30707 -0.91448 -0.29713 Mabsadd L
.22698 .30707 -1.46946 -2.02254 Mabsadd L
.22698 .30707 0 -0.96154 Mabsadd L
.22698 .30707 1.46946 -2.02254 Mabsadd L
.22698 .30707 .91448 -0.29713 Mabsadd L
.22698 .30707 2.37764 .77254 Mabsadd L
.22698 .30707 .56518 .7779 Mabsadd L
.22698 .30707 0 2.5 Mabsadd L closepath F
.23016 .30606 0 2.5 Mabsadd m
.23016 .30606 -0.56518 .7779 Mabsadd L
.23016 .30606 -2.37764 .77254 Mabsadd L
.23016 .30606 -0.91448 -0.29713 Mabsadd L
.23016 .30606 -1.46946 -2.02254 Mabsadd L
.23016 .30606 0 -0.96154 Mabsadd L
.23016 .30606 1.46946 -2.02254 Mabsadd L
.23016 .30606 .91448 -0.29713 Mabsadd L
.23016 .30606 2.37764 .77254 Mabsadd L
.23016 .30606 .56518 .7779 Mabsadd L
.23016 .30606 0 2.5 Mabsadd L closepath F
.23333 .30506 0 2.5 Mabsadd m
.23333 .30506 -0.56518 .7779 Mabsadd L
.23333 .30506 -2.37764 .77254 Mabsadd L
.23333 .30506 -0.91448 -0.29713 Mabsadd L
.23333 .30506 -1.46946 -2.02254 Mabsadd L
.23333 .30506 0 -0.96154 Mabsadd L
.23333 .30506 1.46946 -2.02254 Mabsadd L
.23333 .30506 .91448 -0.29713 Mabsadd L
.23333 .30506 2.37764 .77254 Mabsadd L
.23333 .30506 .56518 .7779 Mabsadd L
.23333 .30506 0 2.5 Mabsadd L closepath F
.23651 .30406 0 2.5 Mabsadd m
.23651 .30406 -0.56518 .7779 Mabsadd L
.23651 .30406 -2.37764 .77254 Mabsadd L
.23651 .30406 -0.91448 -0.29713 Mabsadd L
.23651 .30406 -1.46946 -2.02254 Mabsadd L
.23651 .30406 0 -0.96154 Mabsadd L
.23651 .30406 1.46946 -2.02254 Mabsadd L
.23651 .30406 .91448 -0.29713 Mabsadd L
.23651 .30406 2.37764 .77254 Mabsadd L
.23651 .30406 .56518 .7779 Mabsadd L
.23651 .30406 0 2.5 Mabsadd L closepath F
.23968 .30308 0 2.5 Mabsadd m
.23968 .30308 -0.56518 .7779 Mabsadd L
.23968 .30308 -2.37764 .77254 Mabsadd L
.23968 .30308 -0.91448 -0.29713 Mabsadd L
.23968 .30308 -1.46946 -2.02254 Mabsadd L
.23968 .30308 0 -0.96154 Mabsadd L
.23968 .30308 1.46946 -2.02254 Mabsadd L
.23968 .30308 .91448 -0.29713 Mabsadd L
.23968 .30308 2.37764 .77254 Mabsadd L
.23968 .30308 .56518 .7779 Mabsadd L
.23968 .30308 0 2.5 Mabsadd L closepath F
.24286 .3021 0 2.5 Mabsadd m
.24286 .3021 -0.56518 .7779 Mabsadd L
.24286 .3021 -2.37764 .77254 Mabsadd L
.24286 .3021 -0.91448 -0.29713 Mabsadd L
.24286 .3021 -1.46946 -2.02254 Mabsadd L
.24286 .3021 0 -0.96154 Mabsadd L
.24286 .3021 1.46946 -2.02254 Mabsadd L
.24286 .3021 .91448 -0.29713 Mabsadd L
.24286 .3021 2.37764 .77254 Mabsadd L
.24286 .3021 .56518 .7779 Mabsadd L
.24286 .3021 0 2.5 Mabsadd L closepath F
.24603 .30114 0 2.5 Mabsadd m
.24603 .30114 -0.56518 .7779 Mabsadd L
.24603 .30114 -2.37764 .77254 Mabsadd L
.24603 .30114 -0.91448 -0.29713 Mabsadd L
.24603 .30114 -1.46946 -2.02254 Mabsadd L
.24603 .30114 0 -0.96154 Mabsadd L
.24603 .30114 1.46946 -2.02254 Mabsadd L
.24603 .30114 .91448 -0.29713 Mabsadd L
.24603 .30114 2.37764 .77254 Mabsadd L
.24603 .30114 .56518 .7779 Mabsadd L
.24603 .30114 0 2.5 Mabsadd L closepath F
.24921 .30019 0 2.5 Mabsadd m
.24921 .30019 -0.56518 .7779 Mabsadd L
.24921 .30019 -2.37764 .77254 Mabsadd L
.24921 .30019 -0.91448 -0.29713 Mabsadd L
.24921 .30019 -1.46946 -2.02254 Mabsadd L
.24921 .30019 0 -0.96154 Mabsadd L
.24921 .30019 1.46946 -2.02254 Mabsadd L
.24921 .30019 .91448 -0.29713 Mabsadd L
.24921 .30019 2.37764 .77254 Mabsadd L
.24921 .30019 .56518 .7779 Mabsadd L
.24921 .30019 0 2.5 Mabsadd L closepath F
.25238 .29924 0 2.5 Mabsadd m
.25238 .29924 -0.56518 .7779 Mabsadd L
.25238 .29924 -2.37764 .77254 Mabsadd L
.25238 .29924 -0.91448 -0.29713 Mabsadd L
.25238 .29924 -1.46946 -2.02254 Mabsadd L
.25238 .29924 0 -0.96154 Mabsadd L
.25238 .29924 1.46946 -2.02254 Mabsadd L
.25238 .29924 .91448 -0.29713 Mabsadd L
.25238 .29924 2.37764 .77254 Mabsadd L
.25238 .29924 .56518 .7779 Mabsadd L
.25238 .29924 0 2.5 Mabsadd L closepath F
.25556 .2983 0 2.5 Mabsadd m
.25556 .2983 -0.56518 .7779 Mabsadd L
.25556 .2983 -2.37764 .77254 Mabsadd L
.25556 .2983 -0.91448 -0.29713 Mabsadd L
.25556 .2983 -1.46946 -2.02254 Mabsadd L
.25556 .2983 0 -0.96154 Mabsadd L
.25556 .2983 1.46946 -2.02254 Mabsadd L
.25556 .2983 .91448 -0.29713 Mabsadd L
.25556 .2983 2.37764 .77254 Mabsadd L
.25556 .2983 .56518 .7779 Mabsadd L
.25556 .2983 0 2.5 Mabsadd L closepath F
.25873 .29738 0 2.5 Mabsadd m
.25873 .29738 -0.56518 .7779 Mabsadd L
.25873 .29738 -2.37764 .77254 Mabsadd L
.25873 .29738 -0.91448 -0.29713 Mabsadd L
.25873 .29738 -1.46946 -2.02254 Mabsadd L
.25873 .29738 0 -0.96154 Mabsadd L
.25873 .29738 1.46946 -2.02254 Mabsadd L
.25873 .29738 .91448 -0.29713 Mabsadd L
.25873 .29738 2.37764 .77254 Mabsadd L
.25873 .29738 .56518 .7779 Mabsadd L
.25873 .29738 0 2.5 Mabsadd L closepath F
.2619 .29646 0 2.5 Mabsadd m
.2619 .29646 -0.56518 .7779 Mabsadd L
.2619 .29646 -2.37764 .77254 Mabsadd L
.2619 .29646 -0.91448 -0.29713 Mabsadd L
.2619 .29646 -1.46946 -2.02254 Mabsadd L
.2619 .29646 0 -0.96154 Mabsadd L
.2619 .29646 1.46946 -2.02254 Mabsadd L
.2619 .29646 .91448 -0.29713 Mabsadd L
.2619 .29646 2.37764 .77254 Mabsadd L
.2619 .29646 .56518 .7779 Mabsadd L
.2619 .29646 0 2.5 Mabsadd L closepath F
.26508 .29555 0 2.5 Mabsadd m
.26508 .29555 -0.56518 .7779 Mabsadd L
.26508 .29555 -2.37764 .77254 Mabsadd L
.26508 .29555 -0.91448 -0.29713 Mabsadd L
.26508 .29555 -1.46946 -2.02254 Mabsadd L
.26508 .29555 0 -0.96154 Mabsadd L
.26508 .29555 1.46946 -2.02254 Mabsadd L
.26508 .29555 .91448 -0.29713 Mabsadd L
.26508 .29555 2.37764 .77254 Mabsadd L
.26508 .29555 .56518 .7779 Mabsadd L
.26508 .29555 0 2.5 Mabsadd L closepath F
.26825 .29466 0 2.5 Mabsadd m
.26825 .29466 -0.56518 .7779 Mabsadd L
.26825 .29466 -2.37764 .77254 Mabsadd L
.26825 .29466 -0.91448 -0.29713 Mabsadd L
.26825 .29466 -1.46946 -2.02254 Mabsadd L
.26825 .29466 0 -0.96154 Mabsadd L
.26825 .29466 1.46946 -2.02254 Mabsadd L
.26825 .29466 .91448 -0.29713 Mabsadd L
.26825 .29466 2.37764 .77254 Mabsadd L
.26825 .29466 .56518 .7779 Mabsadd L
.26825 .29466 0 2.5 Mabsadd L closepath F
.27143 .29377 0 2.5 Mabsadd m
.27143 .29377 -0.56518 .7779 Mabsadd L
.27143 .29377 -2.37764 .77254 Mabsadd L
.27143 .29377 -0.91448 -0.29713 Mabsadd L
.27143 .29377 -1.46946 -2.02254 Mabsadd L
.27143 .29377 0 -0.96154 Mabsadd L
.27143 .29377 1.46946 -2.02254 Mabsadd L
.27143 .29377 .91448 -0.29713 Mabsadd L
.27143 .29377 2.37764 .77254 Mabsadd L
.27143 .29377 .56518 .7779 Mabsadd L
.27143 .29377 0 2.5 Mabsadd L closepath F
.2746 .29288 0 2.5 Mabsadd m
.2746 .29288 -0.56518 .7779 Mabsadd L
.2746 .29288 -2.37764 .77254 Mabsadd L
.2746 .29288 -0.91448 -0.29713 Mabsadd L
.2746 .29288 -1.46946 -2.02254 Mabsadd L
.2746 .29288 0 -0.96154 Mabsadd L
.2746 .29288 1.46946 -2.02254 Mabsadd L
.2746 .29288 .91448 -0.29713 Mabsadd L
.2746 .29288 2.37764 .77254 Mabsadd L
.2746 .29288 .56518 .7779 Mabsadd L
.2746 .29288 0 2.5 Mabsadd L closepath F
.27778 .29201 0 2.5 Mabsadd m
.27778 .29201 -0.56518 .7779 Mabsadd L
.27778 .29201 -2.37764 .77254 Mabsadd L
.27778 .29201 -0.91448 -0.29713 Mabsadd L
.27778 .29201 -1.46946 -2.02254 Mabsadd L
.27778 .29201 0 -0.96154 Mabsadd L
.27778 .29201 1.46946 -2.02254 Mabsadd L
.27778 .29201 .91448 -0.29713 Mabsadd L
.27778 .29201 2.37764 .77254 Mabsadd L
.27778 .29201 .56518 .7779 Mabsadd L
.27778 .29201 0 2.5 Mabsadd L closepath F
.28095 .29115 0 2.5 Mabsadd m
.28095 .29115 -0.56518 .7779 Mabsadd L
.28095 .29115 -2.37764 .77254 Mabsadd L
.28095 .29115 -0.91448 -0.29713 Mabsadd L
.28095 .29115 -1.46946 -2.02254 Mabsadd L
.28095 .29115 0 -0.96154 Mabsadd L
.28095 .29115 1.46946 -2.02254 Mabsadd L
.28095 .29115 .91448 -0.29713 Mabsadd L
.28095 .29115 2.37764 .77254 Mabsadd L
.28095 .29115 .56518 .7779 Mabsadd L
.28095 .29115 0 2.5 Mabsadd L closepath F
.28413 .29029 0 2.5 Mabsadd m
.28413 .29029 -0.56518 .7779 Mabsadd L
.28413 .29029 -2.37764 .77254 Mabsadd L
.28413 .29029 -0.91448 -0.29713 Mabsadd L
.28413 .29029 -1.46946 -2.02254 Mabsadd L
.28413 .29029 0 -0.96154 Mabsadd L
.28413 .29029 1.46946 -2.02254 Mabsadd L
.28413 .29029 .91448 -0.29713 Mabsadd L
.28413 .29029 2.37764 .77254 Mabsadd L
.28413 .29029 .56518 .7779 Mabsadd L
.28413 .29029 0 2.5 Mabsadd L closepath F
.2873 .28945 0 2.5 Mabsadd m
.2873 .28945 -0.56518 .7779 Mabsadd L
.2873 .28945 -2.37764 .77254 Mabsadd L
.2873 .28945 -0.91448 -0.29713 Mabsadd L
.2873 .28945 -1.46946 -2.02254 Mabsadd L
.2873 .28945 0 -0.96154 Mabsadd L
.2873 .28945 1.46946 -2.02254 Mabsadd L
.2873 .28945 .91448 -0.29713 Mabsadd L
.2873 .28945 2.37764 .77254 Mabsadd L
.2873 .28945 .56518 .7779 Mabsadd L
.2873 .28945 0 2.5 Mabsadd L closepath F
.29048 .28861 0 2.5 Mabsadd m
.29048 .28861 -0.56518 .7779 Mabsadd L
.29048 .28861 -2.37764 .77254 Mabsadd L
.29048 .28861 -0.91448 -0.29713 Mabsadd L
.29048 .28861 -1.46946 -2.02254 Mabsadd L
.29048 .28861 0 -0.96154 Mabsadd L
.29048 .28861 1.46946 -2.02254 Mabsadd L
.29048 .28861 .91448 -0.29713 Mabsadd L
.29048 .28861 2.37764 .77254 Mabsadd L
.29048 .28861 .56518 .7779 Mabsadd L
.29048 .28861 0 2.5 Mabsadd L closepath F
.29365 .28778 0 2.5 Mabsadd m
.29365 .28778 -0.56518 .7779 Mabsadd L
.29365 .28778 -2.37764 .77254 Mabsadd L
.29365 .28778 -0.91448 -0.29713 Mabsadd L
.29365 .28778 -1.46946 -2.02254 Mabsadd L
.29365 .28778 0 -0.96154 Mabsadd L
.29365 .28778 1.46946 -2.02254 Mabsadd L
.29365 .28778 .91448 -0.29713 Mabsadd L
.29365 .28778 2.37764 .77254 Mabsadd L
.29365 .28778 .56518 .7779 Mabsadd L
.29365 .28778 0 2.5 Mabsadd L closepath F
.29683 .28696 0 2.5 Mabsadd m
.29683 .28696 -0.56518 .7779 Mabsadd L
.29683 .28696 -2.37764 .77254 Mabsadd L
.29683 .28696 -0.91448 -0.29713 Mabsadd L
.29683 .28696 -1.46946 -2.02254 Mabsadd L
.29683 .28696 0 -0.96154 Mabsadd L
.29683 .28696 1.46946 -2.02254 Mabsadd L
.29683 .28696 .91448 -0.29713 Mabsadd L
.29683 .28696 2.37764 .77254 Mabsadd L
.29683 .28696 .56518 .7779 Mabsadd L
.29683 .28696 0 2.5 Mabsadd L closepath F
.3 .28615 0 2.5 Mabsadd m
.3 .28615 -0.56518 .7779 Mabsadd L
.3 .28615 -2.37764 .77254 Mabsadd L
.3 .28615 -0.91448 -0.29713 Mabsadd L
.3 .28615 -1.46946 -2.02254 Mabsadd L
.3 .28615 0 -0.96154 Mabsadd L
.3 .28615 1.46946 -2.02254 Mabsadd L
.3 .28615 .91448 -0.29713 Mabsadd L
.3 .28615 2.37764 .77254 Mabsadd L
.3 .28615 .56518 .7779 Mabsadd L
.3 .28615 0 2.5 Mabsadd L closepath F
.30317 .28534 0 2.5 Mabsadd m
.30317 .28534 -0.56518 .7779 Mabsadd L
.30317 .28534 -2.37764 .77254 Mabsadd L
.30317 .28534 -0.91448 -0.29713 Mabsadd L
.30317 .28534 -1.46946 -2.02254 Mabsadd L
.30317 .28534 0 -0.96154 Mabsadd L
.30317 .28534 1.46946 -2.02254 Mabsadd L
.30317 .28534 .91448 -0.29713 Mabsadd L
.30317 .28534 2.37764 .77254 Mabsadd L
.30317 .28534 .56518 .7779 Mabsadd L
.30317 .28534 0 2.5 Mabsadd L closepath F
.30635 .28455 0 2.5 Mabsadd m
.30635 .28455 -0.56518 .7779 Mabsadd L
.30635 .28455 -2.37764 .77254 Mabsadd L
.30635 .28455 -0.91448 -0.29713 Mabsadd L
.30635 .28455 -1.46946 -2.02254 Mabsadd L
.30635 .28455 0 -0.96154 Mabsadd L
.30635 .28455 1.46946 -2.02254 Mabsadd L
.30635 .28455 .91448 -0.29713 Mabsadd L
.30635 .28455 2.37764 .77254 Mabsadd L
.30635 .28455 .56518 .7779 Mabsadd L
.30635 .28455 0 2.5 Mabsadd L closepath F
.30952 .28376 0 2.5 Mabsadd m
.30952 .28376 -0.56518 .7779 Mabsadd L
.30952 .28376 -2.37764 .77254 Mabsadd L
.30952 .28376 -0.91448 -0.29713 Mabsadd L
.30952 .28376 -1.46946 -2.02254 Mabsadd L
.30952 .28376 0 -0.96154 Mabsadd L
.30952 .28376 1.46946 -2.02254 Mabsadd L
.30952 .28376 .91448 -0.29713 Mabsadd L
.30952 .28376 2.37764 .77254 Mabsadd L
.30952 .28376 .56518 .7779 Mabsadd L
.30952 .28376 0 2.5 Mabsadd L closepath F
.3127 .28298 0 2.5 Mabsadd m
.3127 .28298 -0.56518 .7779 Mabsadd L
.3127 .28298 -2.37764 .77254 Mabsadd L
.3127 .28298 -0.91448 -0.29713 Mabsadd L
.3127 .28298 -1.46946 -2.02254 Mabsadd L
.3127 .28298 0 -0.96154 Mabsadd L
.3127 .28298 1.46946 -2.02254 Mabsadd L
.3127 .28298 .91448 -0.29713 Mabsadd L
.3127 .28298 2.37764 .77254 Mabsadd L
.3127 .28298 .56518 .7779 Mabsadd L
.3127 .28298 0 2.5 Mabsadd L closepath F
.31587 .2822 0 2.5 Mabsadd m
.31587 .2822 -0.56518 .7779 Mabsadd L
.31587 .2822 -2.37764 .77254 Mabsadd L
.31587 .2822 -0.91448 -0.29713 Mabsadd L
.31587 .2822 -1.46946 -2.02254 Mabsadd L
.31587 .2822 0 -0.96154 Mabsadd L
.31587 .2822 1.46946 -2.02254 Mabsadd L
.31587 .2822 .91448 -0.29713 Mabsadd L
.31587 .2822 2.37764 .77254 Mabsadd L
.31587 .2822 .56518 .7779 Mabsadd L
.31587 .2822 0 2.5 Mabsadd L closepath F
.31905 .28144 0 2.5 Mabsadd m
.31905 .28144 -0.56518 .7779 Mabsadd L
.31905 .28144 -2.37764 .77254 Mabsadd L
.31905 .28144 -0.91448 -0.29713 Mabsadd L
.31905 .28144 -1.46946 -2.02254 Mabsadd L
.31905 .28144 0 -0.96154 Mabsadd L
.31905 .28144 1.46946 -2.02254 Mabsadd L
.31905 .28144 .91448 -0.29713 Mabsadd L
.31905 .28144 2.37764 .77254 Mabsadd L
.31905 .28144 .56518 .7779 Mabsadd L
.31905 .28144 0 2.5 Mabsadd L closepath F
.32222 .28068 0 2.5 Mabsadd m
.32222 .28068 -0.56518 .7779 Mabsadd L
.32222 .28068 -2.37764 .77254 Mabsadd L
.32222 .28068 -0.91448 -0.29713 Mabsadd L
.32222 .28068 -1.46946 -2.02254 Mabsadd L
.32222 .28068 0 -0.96154 Mabsadd L
.32222 .28068 1.46946 -2.02254 Mabsadd L
.32222 .28068 .91448 -0.29713 Mabsadd L
.32222 .28068 2.37764 .77254 Mabsadd L
.32222 .28068 .56518 .7779 Mabsadd L
.32222 .28068 0 2.5 Mabsadd L closepath F
.3254 .27993 0 2.5 Mabsadd m
.3254 .27993 -0.56518 .7779 Mabsadd L
.3254 .27993 -2.37764 .77254 Mabsadd L
.3254 .27993 -0.91448 -0.29713 Mabsadd L
.3254 .27993 -1.46946 -2.02254 Mabsadd L
.3254 .27993 0 -0.96154 Mabsadd L
.3254 .27993 1.46946 -2.02254 Mabsadd L
.3254 .27993 .91448 -0.29713 Mabsadd L
.3254 .27993 2.37764 .77254 Mabsadd L
.3254 .27993 .56518 .7779 Mabsadd L
.3254 .27993 0 2.5 Mabsadd L closepath F
.32857 .27919 0 2.5 Mabsadd m
.32857 .27919 -0.56518 .7779 Mabsadd L
.32857 .27919 -2.37764 .77254 Mabsadd L
.32857 .27919 -0.91448 -0.29713 Mabsadd L
.32857 .27919 -1.46946 -2.02254 Mabsadd L
.32857 .27919 0 -0.96154 Mabsadd L
.32857 .27919 1.46946 -2.02254 Mabsadd L
.32857 .27919 .91448 -0.29713 Mabsadd L
.32857 .27919 2.37764 .77254 Mabsadd L
.32857 .27919 .56518 .7779 Mabsadd L
.32857 .27919 0 2.5 Mabsadd L closepath F
.33175 .27845 0 2.5 Mabsadd m
.33175 .27845 -0.56518 .7779 Mabsadd L
.33175 .27845 -2.37764 .77254 Mabsadd L
.33175 .27845 -0.91448 -0.29713 Mabsadd L
.33175 .27845 -1.46946 -2.02254 Mabsadd L
.33175 .27845 0 -0.96154 Mabsadd L
.33175 .27845 1.46946 -2.02254 Mabsadd L
.33175 .27845 .91448 -0.29713 Mabsadd L
.33175 .27845 2.37764 .77254 Mabsadd L
.33175 .27845 .56518 .7779 Mabsadd L
.33175 .27845 0 2.5 Mabsadd L closepath F
.33492 .27773 0 2.5 Mabsadd m
.33492 .27773 -0.56518 .7779 Mabsadd L
.33492 .27773 -2.37764 .77254 Mabsadd L
.33492 .27773 -0.91448 -0.29713 Mabsadd L
.33492 .27773 -1.46946 -2.02254 Mabsadd L
.33492 .27773 0 -0.96154 Mabsadd L
.33492 .27773 1.46946 -2.02254 Mabsadd L
.33492 .27773 .91448 -0.29713 Mabsadd L
.33492 .27773 2.37764 .77254 Mabsadd L
.33492 .27773 .56518 .7779 Mabsadd L
.33492 .27773 0 2.5 Mabsadd L closepath F
.3381 .27701 0 2.5 Mabsadd m
.3381 .27701 -0.56518 .7779 Mabsadd L
.3381 .27701 -2.37764 .77254 Mabsadd L
.3381 .27701 -0.91448 -0.29713 Mabsadd L
.3381 .27701 -1.46946 -2.02254 Mabsadd L
.3381 .27701 0 -0.96154 Mabsadd L
.3381 .27701 1.46946 -2.02254 Mabsadd L
.3381 .27701 .91448 -0.29713 Mabsadd L
.3381 .27701 2.37764 .77254 Mabsadd L
.3381 .27701 .56518 .7779 Mabsadd L
.3381 .27701 0 2.5 Mabsadd L closepath F
.34127 .27629 0 2.5 Mabsadd m
.34127 .27629 -0.56518 .7779 Mabsadd L
.34127 .27629 -2.37764 .77254 Mabsadd L
.34127 .27629 -0.91448 -0.29713 Mabsadd L
.34127 .27629 -1.46946 -2.02254 Mabsadd L
.34127 .27629 0 -0.96154 Mabsadd L
.34127 .27629 1.46946 -2.02254 Mabsadd L
.34127 .27629 .91448 -0.29713 Mabsadd L
.34127 .27629 2.37764 .77254 Mabsadd L
.34127 .27629 .56518 .7779 Mabsadd L
.34127 .27629 0 2.5 Mabsadd L closepath F
.34444 .27559 0 2.5 Mabsadd m
.34444 .27559 -0.56518 .7779 Mabsadd L
.34444 .27559 -2.37764 .77254 Mabsadd L
.34444 .27559 -0.91448 -0.29713 Mabsadd L
.34444 .27559 -1.46946 -2.02254 Mabsadd L
.34444 .27559 0 -0.96154 Mabsadd L
.34444 .27559 1.46946 -2.02254 Mabsadd L
.34444 .27559 .91448 -0.29713 Mabsadd L
.34444 .27559 2.37764 .77254 Mabsadd L
.34444 .27559 .56518 .7779 Mabsadd L
.34444 .27559 0 2.5 Mabsadd L closepath F
.34762 .27489 0 2.5 Mabsadd m
.34762 .27489 -0.56518 .7779 Mabsadd L
.34762 .27489 -2.37764 .77254 Mabsadd L
.34762 .27489 -0.91448 -0.29713 Mabsadd L
.34762 .27489 -1.46946 -2.02254 Mabsadd L
.34762 .27489 0 -0.96154 Mabsadd L
.34762 .27489 1.46946 -2.02254 Mabsadd L
.34762 .27489 .91448 -0.29713 Mabsadd L
.34762 .27489 2.37764 .77254 Mabsadd L
.34762 .27489 .56518 .7779 Mabsadd L
.34762 .27489 0 2.5 Mabsadd L closepath F
.35079 .2742 0 2.5 Mabsadd m
.35079 .2742 -0.56518 .7779 Mabsadd L
.35079 .2742 -2.37764 .77254 Mabsadd L
.35079 .2742 -0.91448 -0.29713 Mabsadd L
.35079 .2742 -1.46946 -2.02254 Mabsadd L
.35079 .2742 0 -0.96154 Mabsadd L
.35079 .2742 1.46946 -2.02254 Mabsadd L
.35079 .2742 .91448 -0.29713 Mabsadd L
.35079 .2742 2.37764 .77254 Mabsadd L
.35079 .2742 .56518 .7779 Mabsadd L
.35079 .2742 0 2.5 Mabsadd L closepath F
.35397 .27351 0 2.5 Mabsadd m
.35397 .27351 -0.56518 .7779 Mabsadd L
.35397 .27351 -2.37764 .77254 Mabsadd L
.35397 .27351 -0.91448 -0.29713 Mabsadd L
.35397 .27351 -1.46946 -2.02254 Mabsadd L
.35397 .27351 0 -0.96154 Mabsadd L
.35397 .27351 1.46946 -2.02254 Mabsadd L
.35397 .27351 .91448 -0.29713 Mabsadd L
.35397 .27351 2.37764 .77254 Mabsadd L
.35397 .27351 .56518 .7779 Mabsadd L
.35397 .27351 0 2.5 Mabsadd L closepath F
.35714 .27283 0 2.5 Mabsadd m
.35714 .27283 -0.56518 .7779 Mabsadd L
.35714 .27283 -2.37764 .77254 Mabsadd L
.35714 .27283 -0.91448 -0.29713 Mabsadd L
.35714 .27283 -1.46946 -2.02254 Mabsadd L
.35714 .27283 0 -0.96154 Mabsadd L
.35714 .27283 1.46946 -2.02254 Mabsadd L
.35714 .27283 .91448 -0.29713 Mabsadd L
.35714 .27283 2.37764 .77254 Mabsadd L
.35714 .27283 .56518 .7779 Mabsadd L
.35714 .27283 0 2.5 Mabsadd L closepath F
.36032 .27216 0 2.5 Mabsadd m
.36032 .27216 -0.56518 .7779 Mabsadd L
.36032 .27216 -2.37764 .77254 Mabsadd L
.36032 .27216 -0.91448 -0.29713 Mabsadd L
.36032 .27216 -1.46946 -2.02254 Mabsadd L
.36032 .27216 0 -0.96154 Mabsadd L
.36032 .27216 1.46946 -2.02254 Mabsadd L
.36032 .27216 .91448 -0.29713 Mabsadd L
.36032 .27216 2.37764 .77254 Mabsadd L
.36032 .27216 .56518 .7779 Mabsadd L
.36032 .27216 0 2.5 Mabsadd L closepath F
.36349 .2715 0 2.5 Mabsadd m
.36349 .2715 -0.56518 .7779 Mabsadd L
.36349 .2715 -2.37764 .77254 Mabsadd L
.36349 .2715 -0.91448 -0.29713 Mabsadd L
.36349 .2715 -1.46946 -2.02254 Mabsadd L
.36349 .2715 0 -0.96154 Mabsadd L
.36349 .2715 1.46946 -2.02254 Mabsadd L
.36349 .2715 .91448 -0.29713 Mabsadd L
.36349 .2715 2.37764 .77254 Mabsadd L
.36349 .2715 .56518 .7779 Mabsadd L
.36349 .2715 0 2.5 Mabsadd L closepath F
.36667 .27084 0 2.5 Mabsadd m
.36667 .27084 -0.56518 .7779 Mabsadd L
.36667 .27084 -2.37764 .77254 Mabsadd L
.36667 .27084 -0.91448 -0.29713 Mabsadd L
.36667 .27084 -1.46946 -2.02254 Mabsadd L
.36667 .27084 0 -0.96154 Mabsadd L
.36667 .27084 1.46946 -2.02254 Mabsadd L
.36667 .27084 .91448 -0.29713 Mabsadd L
.36667 .27084 2.37764 .77254 Mabsadd L
.36667 .27084 .56518 .7779 Mabsadd L
.36667 .27084 0 2.5 Mabsadd L closepath F
.36984 .27019 0 2.5 Mabsadd m
.36984 .27019 -0.56518 .7779 Mabsadd L
.36984 .27019 -2.37764 .77254 Mabsadd L
.36984 .27019 -0.91448 -0.29713 Mabsadd L
.36984 .27019 -1.46946 -2.02254 Mabsadd L
.36984 .27019 0 -0.96154 Mabsadd L
.36984 .27019 1.46946 -2.02254 Mabsadd L
.36984 .27019 .91448 -0.29713 Mabsadd L
.36984 .27019 2.37764 .77254 Mabsadd L
.36984 .27019 .56518 .7779 Mabsadd L
.36984 .27019 0 2.5 Mabsadd L closepath F
.37302 .26954 0 2.5 Mabsadd m
.37302 .26954 -0.56518 .7779 Mabsadd L
.37302 .26954 -2.37764 .77254 Mabsadd L
.37302 .26954 -0.91448 -0.29713 Mabsadd L
.37302 .26954 -1.46946 -2.02254 Mabsadd L
.37302 .26954 0 -0.96154 Mabsadd L
.37302 .26954 1.46946 -2.02254 Mabsadd L
.37302 .26954 .91448 -0.29713 Mabsadd L
.37302 .26954 2.37764 .77254 Mabsadd L
.37302 .26954 .56518 .7779 Mabsadd L
.37302 .26954 0 2.5 Mabsadd L closepath F
.37619 .2689 0 2.5 Mabsadd m
.37619 .2689 -0.56518 .7779 Mabsadd L
.37619 .2689 -2.37764 .77254 Mabsadd L
.37619 .2689 -0.91448 -0.29713 Mabsadd L
.37619 .2689 -1.46946 -2.02254 Mabsadd L
.37619 .2689 0 -0.96154 Mabsadd L
.37619 .2689 1.46946 -2.02254 Mabsadd L
.37619 .2689 .91448 -0.29713 Mabsadd L
.37619 .2689 2.37764 .77254 Mabsadd L
.37619 .2689 .56518 .7779 Mabsadd L
.37619 .2689 0 2.5 Mabsadd L closepath F
.37937 .26827 0 2.5 Mabsadd m
.37937 .26827 -0.56518 .7779 Mabsadd L
.37937 .26827 -2.37764 .77254 Mabsadd L
.37937 .26827 -0.91448 -0.29713 Mabsadd L
.37937 .26827 -1.46946 -2.02254 Mabsadd L
.37937 .26827 0 -0.96154 Mabsadd L
.37937 .26827 1.46946 -2.02254 Mabsadd L
.37937 .26827 .91448 -0.29713 Mabsadd L
.37937 .26827 2.37764 .77254 Mabsadd L
.37937 .26827 .56518 .7779 Mabsadd L
.37937 .26827 0 2.5 Mabsadd L closepath F
.38254 .26765 0 2.5 Mabsadd m
.38254 .26765 -0.56518 .7779 Mabsadd L
.38254 .26765 -2.37764 .77254 Mabsadd L
.38254 .26765 -0.91448 -0.29713 Mabsadd L
.38254 .26765 -1.46946 -2.02254 Mabsadd L
.38254 .26765 0 -0.96154 Mabsadd L
.38254 .26765 1.46946 -2.02254 Mabsadd L
.38254 .26765 .91448 -0.29713 Mabsadd L
.38254 .26765 2.37764 .77254 Mabsadd L
.38254 .26765 .56518 .7779 Mabsadd L
.38254 .26765 0 2.5 Mabsadd L closepath F
.38571 .26703 0 2.5 Mabsadd m
.38571 .26703 -0.56518 .7779 Mabsadd L
.38571 .26703 -2.37764 .77254 Mabsadd L
.38571 .26703 -0.91448 -0.29713 Mabsadd L
.38571 .26703 -1.46946 -2.02254 Mabsadd L
.38571 .26703 0 -0.96154 Mabsadd L
.38571 .26703 1.46946 -2.02254 Mabsadd L
.38571 .26703 .91448 -0.29713 Mabsadd L
.38571 .26703 2.37764 .77254 Mabsadd L
.38571 .26703 .56518 .7779 Mabsadd L
.38571 .26703 0 2.5 Mabsadd L closepath F
.38889 .26641 0 2.5 Mabsadd m
.38889 .26641 -0.56518 .7779 Mabsadd L
.38889 .26641 -2.37764 .77254 Mabsadd L
.38889 .26641 -0.91448 -0.29713 Mabsadd L
.38889 .26641 -1.46946 -2.02254 Mabsadd L
.38889 .26641 0 -0.96154 Mabsadd L
.38889 .26641 1.46946 -2.02254 Mabsadd L
.38889 .26641 .91448 -0.29713 Mabsadd L
.38889 .26641 2.37764 .77254 Mabsadd L
.38889 .26641 .56518 .7779 Mabsadd L
.38889 .26641 0 2.5 Mabsadd L closepath F
.39206 .2658 0 2.5 Mabsadd m
.39206 .2658 -0.56518 .7779 Mabsadd L
.39206 .2658 -2.37764 .77254 Mabsadd L
.39206 .2658 -0.91448 -0.29713 Mabsadd L
.39206 .2658 -1.46946 -2.02254 Mabsadd L
.39206 .2658 0 -0.96154 Mabsadd L
.39206 .2658 1.46946 -2.02254 Mabsadd L
.39206 .2658 .91448 -0.29713 Mabsadd L
.39206 .2658 2.37764 .77254 Mabsadd L
.39206 .2658 .56518 .7779 Mabsadd L
.39206 .2658 0 2.5 Mabsadd L closepath F
.39524 .2652 0 2.5 Mabsadd m
.39524 .2652 -0.56518 .7779 Mabsadd L
.39524 .2652 -2.37764 .77254 Mabsadd L
.39524 .2652 -0.91448 -0.29713 Mabsadd L
.39524 .2652 -1.46946 -2.02254 Mabsadd L
.39524 .2652 0 -0.96154 Mabsadd L
.39524 .2652 1.46946 -2.02254 Mabsadd L
.39524 .2652 .91448 -0.29713 Mabsadd L
.39524 .2652 2.37764 .77254 Mabsadd L
.39524 .2652 .56518 .7779 Mabsadd L
.39524 .2652 0 2.5 Mabsadd L closepath F
.39841 .26461 0 2.5 Mabsadd m
.39841 .26461 -0.56518 .7779 Mabsadd L
.39841 .26461 -2.37764 .77254 Mabsadd L
.39841 .26461 -0.91448 -0.29713 Mabsadd L
.39841 .26461 -1.46946 -2.02254 Mabsadd L
.39841 .26461 0 -0.96154 Mabsadd L
.39841 .26461 1.46946 -2.02254 Mabsadd L
.39841 .26461 .91448 -0.29713 Mabsadd L
.39841 .26461 2.37764 .77254 Mabsadd L
.39841 .26461 .56518 .7779 Mabsadd L
.39841 .26461 0 2.5 Mabsadd L closepath F
.40159 .26402 0 2.5 Mabsadd m
.40159 .26402 -0.56518 .7779 Mabsadd L
.40159 .26402 -2.37764 .77254 Mabsadd L
.40159 .26402 -0.91448 -0.29713 Mabsadd L
.40159 .26402 -1.46946 -2.02254 Mabsadd L
.40159 .26402 0 -0.96154 Mabsadd L
.40159 .26402 1.46946 -2.02254 Mabsadd L
.40159 .26402 .91448 -0.29713 Mabsadd L
.40159 .26402 2.37764 .77254 Mabsadd L
.40159 .26402 .56518 .7779 Mabsadd L
.40159 .26402 0 2.5 Mabsadd L closepath F
.40476 .26344 0 2.5 Mabsadd m
.40476 .26344 -0.56518 .7779 Mabsadd L
.40476 .26344 -2.37764 .77254 Mabsadd L
.40476 .26344 -0.91448 -0.29713 Mabsadd L
.40476 .26344 -1.46946 -2.02254 Mabsadd L
.40476 .26344 0 -0.96154 Mabsadd L
.40476 .26344 1.46946 -2.02254 Mabsadd L
.40476 .26344 .91448 -0.29713 Mabsadd L
.40476 .26344 2.37764 .77254 Mabsadd L
.40476 .26344 .56518 .7779 Mabsadd L
.40476 .26344 0 2.5 Mabsadd L closepath F
.40794 .26286 0 2.5 Mabsadd m
.40794 .26286 -0.56518 .7779 Mabsadd L
.40794 .26286 -2.37764 .77254 Mabsadd L
.40794 .26286 -0.91448 -0.29713 Mabsadd L
.40794 .26286 -1.46946 -2.02254 Mabsadd L
.40794 .26286 0 -0.96154 Mabsadd L
.40794 .26286 1.46946 -2.02254 Mabsadd L
.40794 .26286 .91448 -0.29713 Mabsadd L
.40794 .26286 2.37764 .77254 Mabsadd L
.40794 .26286 .56518 .7779 Mabsadd L
.40794 .26286 0 2.5 Mabsadd L closepath F
.41111 .26229 0 2.5 Mabsadd m
.41111 .26229 -0.56518 .7779 Mabsadd L
.41111 .26229 -2.37764 .77254 Mabsadd L
.41111 .26229 -0.91448 -0.29713 Mabsadd L
.41111 .26229 -1.46946 -2.02254 Mabsadd L
.41111 .26229 0 -0.96154 Mabsadd L
.41111 .26229 1.46946 -2.02254 Mabsadd L
.41111 .26229 .91448 -0.29713 Mabsadd L
.41111 .26229 2.37764 .77254 Mabsadd L
.41111 .26229 .56518 .7779 Mabsadd L
.41111 .26229 0 2.5 Mabsadd L closepath F
.41429 .26172 0 2.5 Mabsadd m
.41429 .26172 -0.56518 .7779 Mabsadd L
.41429 .26172 -2.37764 .77254 Mabsadd L
.41429 .26172 -0.91448 -0.29713 Mabsadd L
.41429 .26172 -1.46946 -2.02254 Mabsadd L
.41429 .26172 0 -0.96154 Mabsadd L
.41429 .26172 1.46946 -2.02254 Mabsadd L
.41429 .26172 .91448 -0.29713 Mabsadd L
.41429 .26172 2.37764 .77254 Mabsadd L
.41429 .26172 .56518 .7779 Mabsadd L
.41429 .26172 0 2.5 Mabsadd L closepath F
.41746 .26116 0 2.5 Mabsadd m
.41746 .26116 -0.56518 .7779 Mabsadd L
.41746 .26116 -2.37764 .77254 Mabsadd L
.41746 .26116 -0.91448 -0.29713 Mabsadd L
.41746 .26116 -1.46946 -2.02254 Mabsadd L
.41746 .26116 0 -0.96154 Mabsadd L
.41746 .26116 1.46946 -2.02254 Mabsadd L
.41746 .26116 .91448 -0.29713 Mabsadd L
.41746 .26116 2.37764 .77254 Mabsadd L
.41746 .26116 .56518 .7779 Mabsadd L
.41746 .26116 0 2.5 Mabsadd L closepath F
.42063 .26061 0 2.5 Mabsadd m
.42063 .26061 -0.56518 .7779 Mabsadd L
.42063 .26061 -2.37764 .77254 Mabsadd L
.42063 .26061 -0.91448 -0.29713 Mabsadd L
.42063 .26061 -1.46946 -2.02254 Mabsadd L
.42063 .26061 0 -0.96154 Mabsadd L
.42063 .26061 1.46946 -2.02254 Mabsadd L
.42063 .26061 .91448 -0.29713 Mabsadd L
.42063 .26061 2.37764 .77254 Mabsadd L
.42063 .26061 .56518 .7779 Mabsadd L
.42063 .26061 0 2.5 Mabsadd L closepath F
.42381 .26006 0 2.5 Mabsadd m
.42381 .26006 -0.56518 .7779 Mabsadd L
.42381 .26006 -2.37764 .77254 Mabsadd L
.42381 .26006 -0.91448 -0.29713 Mabsadd L
.42381 .26006 -1.46946 -2.02254 Mabsadd L
.42381 .26006 0 -0.96154 Mabsadd L
.42381 .26006 1.46946 -2.02254 Mabsadd L
.42381 .26006 .91448 -0.29713 Mabsadd L
.42381 .26006 2.37764 .77254 Mabsadd L
.42381 .26006 .56518 .7779 Mabsadd L
.42381 .26006 0 2.5 Mabsadd L closepath F
.42698 .25951 0 2.5 Mabsadd m
.42698 .25951 -0.56518 .7779 Mabsadd L
.42698 .25951 -2.37764 .77254 Mabsadd L
.42698 .25951 -0.91448 -0.29713 Mabsadd L
.42698 .25951 -1.46946 -2.02254 Mabsadd L
.42698 .25951 0 -0.96154 Mabsadd L
.42698 .25951 1.46946 -2.02254 Mabsadd L
.42698 .25951 .91448 -0.29713 Mabsadd L
.42698 .25951 2.37764 .77254 Mabsadd L
.42698 .25951 .56518 .7779 Mabsadd L
.42698 .25951 0 2.5 Mabsadd L closepath F
.43016 .25897 0 2.5 Mabsadd m
.43016 .25897 -0.56518 .7779 Mabsadd L
.43016 .25897 -2.37764 .77254 Mabsadd L
.43016 .25897 -0.91448 -0.29713 Mabsadd L
.43016 .25897 -1.46946 -2.02254 Mabsadd L
.43016 .25897 0 -0.96154 Mabsadd L
.43016 .25897 1.46946 -2.02254 Mabsadd L
.43016 .25897 .91448 -0.29713 Mabsadd L
.43016 .25897 2.37764 .77254 Mabsadd L
.43016 .25897 .56518 .7779 Mabsadd L
.43016 .25897 0 2.5 Mabsadd L closepath F
.43333 .25844 0 2.5 Mabsadd m
.43333 .25844 -0.56518 .7779 Mabsadd L
.43333 .25844 -2.37764 .77254 Mabsadd L
.43333 .25844 -0.91448 -0.29713 Mabsadd L
.43333 .25844 -1.46946 -2.02254 Mabsadd L
.43333 .25844 0 -0.96154 Mabsadd L
.43333 .25844 1.46946 -2.02254 Mabsadd L
.43333 .25844 .91448 -0.29713 Mabsadd L
.43333 .25844 2.37764 .77254 Mabsadd L
.43333 .25844 .56518 .7779 Mabsadd L
.43333 .25844 0 2.5 Mabsadd L closepath F
.43651 .25791 0 2.5 Mabsadd m
.43651 .25791 -0.56518 .7779 Mabsadd L
.43651 .25791 -2.37764 .77254 Mabsadd L
.43651 .25791 -0.91448 -0.29713 Mabsadd L
.43651 .25791 -1.46946 -2.02254 Mabsadd L
.43651 .25791 0 -0.96154 Mabsadd L
.43651 .25791 1.46946 -2.02254 Mabsadd L
.43651 .25791 .91448 -0.29713 Mabsadd L
.43651 .25791 2.37764 .77254 Mabsadd L
.43651 .25791 .56518 .7779 Mabsadd L
.43651 .25791 0 2.5 Mabsadd L closepath F
.43968 .25739 0 2.5 Mabsadd m
.43968 .25739 -0.56518 .7779 Mabsadd L
.43968 .25739 -2.37764 .77254 Mabsadd L
.43968 .25739 -0.91448 -0.29713 Mabsadd L
.43968 .25739 -1.46946 -2.02254 Mabsadd L
.43968 .25739 0 -0.96154 Mabsadd L
.43968 .25739 1.46946 -2.02254 Mabsadd L
.43968 .25739 .91448 -0.29713 Mabsadd L
.43968 .25739 2.37764 .77254 Mabsadd L
.43968 .25739 .56518 .7779 Mabsadd L
.43968 .25739 0 2.5 Mabsadd L closepath F
.44286 .25687 0 2.5 Mabsadd m
.44286 .25687 -0.56518 .7779 Mabsadd L
.44286 .25687 -2.37764 .77254 Mabsadd L
.44286 .25687 -0.91448 -0.29713 Mabsadd L
.44286 .25687 -1.46946 -2.02254 Mabsadd L
.44286 .25687 0 -0.96154 Mabsadd L
.44286 .25687 1.46946 -2.02254 Mabsadd L
.44286 .25687 .91448 -0.29713 Mabsadd L
.44286 .25687 2.37764 .77254 Mabsadd L
.44286 .25687 .56518 .7779 Mabsadd L
.44286 .25687 0 2.5 Mabsadd L closepath F
.44603 .25636 0 2.5 Mabsadd m
.44603 .25636 -0.56518 .7779 Mabsadd L
.44603 .25636 -2.37764 .77254 Mabsadd L
.44603 .25636 -0.91448 -0.29713 Mabsadd L
.44603 .25636 -1.46946 -2.02254 Mabsadd L
.44603 .25636 0 -0.96154 Mabsadd L
.44603 .25636 1.46946 -2.02254 Mabsadd L
.44603 .25636 .91448 -0.29713 Mabsadd L
.44603 .25636 2.37764 .77254 Mabsadd L
.44603 .25636 .56518 .7779 Mabsadd L
.44603 .25636 0 2.5 Mabsadd L closepath F
.44921 .25586 0 2.5 Mabsadd m
.44921 .25586 -0.56518 .7779 Mabsadd L
.44921 .25586 -2.37764 .77254 Mabsadd L
.44921 .25586 -0.91448 -0.29713 Mabsadd L
.44921 .25586 -1.46946 -2.02254 Mabsadd L
.44921 .25586 0 -0.96154 Mabsadd L
.44921 .25586 1.46946 -2.02254 Mabsadd L
.44921 .25586 .91448 -0.29713 Mabsadd L
.44921 .25586 2.37764 .77254 Mabsadd L
.44921 .25586 .56518 .7779 Mabsadd L
.44921 .25586 0 2.5 Mabsadd L closepath F
.45238 .25535 0 2.5 Mabsadd m
.45238 .25535 -0.56518 .7779 Mabsadd L
.45238 .25535 -2.37764 .77254 Mabsadd L
.45238 .25535 -0.91448 -0.29713 Mabsadd L
.45238 .25535 -1.46946 -2.02254 Mabsadd L
.45238 .25535 0 -0.96154 Mabsadd L
.45238 .25535 1.46946 -2.02254 Mabsadd L
.45238 .25535 .91448 -0.29713 Mabsadd L
.45238 .25535 2.37764 .77254 Mabsadd L
.45238 .25535 .56518 .7779 Mabsadd L
.45238 .25535 0 2.5 Mabsadd L closepath F
.45556 .25486 0 2.5 Mabsadd m
.45556 .25486 -0.56518 .7779 Mabsadd L
.45556 .25486 -2.37764 .77254 Mabsadd L
.45556 .25486 -0.91448 -0.29713 Mabsadd L
.45556 .25486 -1.46946 -2.02254 Mabsadd L
.45556 .25486 0 -0.96154 Mabsadd L
.45556 .25486 1.46946 -2.02254 Mabsadd L
.45556 .25486 .91448 -0.29713 Mabsadd L
.45556 .25486 2.37764 .77254 Mabsadd L
.45556 .25486 .56518 .7779 Mabsadd L
.45556 .25486 0 2.5 Mabsadd L closepath F
.45873 .25437 0 2.5 Mabsadd m
.45873 .25437 -0.56518 .7779 Mabsadd L
.45873 .25437 -2.37764 .77254 Mabsadd L
.45873 .25437 -0.91448 -0.29713 Mabsadd L
.45873 .25437 -1.46946 -2.02254 Mabsadd L
.45873 .25437 0 -0.96154 Mabsadd L
.45873 .25437 1.46946 -2.02254 Mabsadd L
.45873 .25437 .91448 -0.29713 Mabsadd L
.45873 .25437 2.37764 .77254 Mabsadd L
.45873 .25437 .56518 .7779 Mabsadd L
.45873 .25437 0 2.5 Mabsadd L closepath F
.4619 .25388 0 2.5 Mabsadd m
.4619 .25388 -0.56518 .7779 Mabsadd L
.4619 .25388 -2.37764 .77254 Mabsadd L
.4619 .25388 -0.91448 -0.29713 Mabsadd L
.4619 .25388 -1.46946 -2.02254 Mabsadd L
.4619 .25388 0 -0.96154 Mabsadd L
.4619 .25388 1.46946 -2.02254 Mabsadd L
.4619 .25388 .91448 -0.29713 Mabsadd L
.4619 .25388 2.37764 .77254 Mabsadd L
.4619 .25388 .56518 .7779 Mabsadd L
.4619 .25388 0 2.5 Mabsadd L closepath F
.46508 .2534 0 2.5 Mabsadd m
.46508 .2534 -0.56518 .7779 Mabsadd L
.46508 .2534 -2.37764 .77254 Mabsadd L
.46508 .2534 -0.91448 -0.29713 Mabsadd L
.46508 .2534 -1.46946 -2.02254 Mabsadd L
.46508 .2534 0 -0.96154 Mabsadd L
.46508 .2534 1.46946 -2.02254 Mabsadd L
.46508 .2534 .91448 -0.29713 Mabsadd L
.46508 .2534 2.37764 .77254 Mabsadd L
.46508 .2534 .56518 .7779 Mabsadd L
.46508 .2534 0 2.5 Mabsadd L closepath F
.46825 .25292 0 2.5 Mabsadd m
.46825 .25292 -0.56518 .7779 Mabsadd L
.46825 .25292 -2.37764 .77254 Mabsadd L
.46825 .25292 -0.91448 -0.29713 Mabsadd L
.46825 .25292 -1.46946 -2.02254 Mabsadd L
.46825 .25292 0 -0.96154 Mabsadd L
.46825 .25292 1.46946 -2.02254 Mabsadd L
.46825 .25292 .91448 -0.29713 Mabsadd L
.46825 .25292 2.37764 .77254 Mabsadd L
.46825 .25292 .56518 .7779 Mabsadd L
.46825 .25292 0 2.5 Mabsadd L closepath F
.47143 .25245 0 2.5 Mabsadd m
.47143 .25245 -0.56518 .7779 Mabsadd L
.47143 .25245 -2.37764 .77254 Mabsadd L
.47143 .25245 -0.91448 -0.29713 Mabsadd L
.47143 .25245 -1.46946 -2.02254 Mabsadd L
.47143 .25245 0 -0.96154 Mabsadd L
.47143 .25245 1.46946 -2.02254 Mabsadd L
.47143 .25245 .91448 -0.29713 Mabsadd L
.47143 .25245 2.37764 .77254 Mabsadd L
.47143 .25245 .56518 .7779 Mabsadd L
.47143 .25245 0 2.5 Mabsadd L closepath F
.4746 .25198 0 2.5 Mabsadd m
.4746 .25198 -0.56518 .7779 Mabsadd L
.4746 .25198 -2.37764 .77254 Mabsadd L
.4746 .25198 -0.91448 -0.29713 Mabsadd L
.4746 .25198 -1.46946 -2.02254 Mabsadd L
.4746 .25198 0 -0.96154 Mabsadd L
.4746 .25198 1.46946 -2.02254 Mabsadd L
.4746 .25198 .91448 -0.29713 Mabsadd L
.4746 .25198 2.37764 .77254 Mabsadd L
.4746 .25198 .56518 .7779 Mabsadd L
.4746 .25198 0 2.5 Mabsadd L closepath F
.47778 .25152 0 2.5 Mabsadd m
.47778 .25152 -0.56518 .7779 Mabsadd L
.47778 .25152 -2.37764 .77254 Mabsadd L
.47778 .25152 -0.91448 -0.29713 Mabsadd L
.47778 .25152 -1.46946 -2.02254 Mabsadd L
.47778 .25152 0 -0.96154 Mabsadd L
.47778 .25152 1.46946 -2.02254 Mabsadd L
.47778 .25152 .91448 -0.29713 Mabsadd L
.47778 .25152 2.37764 .77254 Mabsadd L
.47778 .25152 .56518 .7779 Mabsadd L
.47778 .25152 0 2.5 Mabsadd L closepath F
.48095 .25106 0 2.5 Mabsadd m
.48095 .25106 -0.56518 .7779 Mabsadd L
.48095 .25106 -2.37764 .77254 Mabsadd L
.48095 .25106 -0.91448 -0.29713 Mabsadd L
.48095 .25106 -1.46946 -2.02254 Mabsadd L
.48095 .25106 0 -0.96154 Mabsadd L
.48095 .25106 1.46946 -2.02254 Mabsadd L
.48095 .25106 .91448 -0.29713 Mabsadd L
.48095 .25106 2.37764 .77254 Mabsadd L
.48095 .25106 .56518 .7779 Mabsadd L
.48095 .25106 0 2.5 Mabsadd L closepath F
.48413 .2506 0 2.5 Mabsadd m
.48413 .2506 -0.56518 .7779 Mabsadd L
.48413 .2506 -2.37764 .77254 Mabsadd L
.48413 .2506 -0.91448 -0.29713 Mabsadd L
.48413 .2506 -1.46946 -2.02254 Mabsadd L
.48413 .2506 0 -0.96154 Mabsadd L
.48413 .2506 1.46946 -2.02254 Mabsadd L
.48413 .2506 .91448 -0.29713 Mabsadd L
.48413 .2506 2.37764 .77254 Mabsadd L
.48413 .2506 .56518 .7779 Mabsadd L
.48413 .2506 0 2.5 Mabsadd L closepath F
.4873 .25016 0 2.5 Mabsadd m
.4873 .25016 -0.56518 .7779 Mabsadd L
.4873 .25016 -2.37764 .77254 Mabsadd L
.4873 .25016 -0.91448 -0.29713 Mabsadd L
.4873 .25016 -1.46946 -2.02254 Mabsadd L
.4873 .25016 0 -0.96154 Mabsadd L
.4873 .25016 1.46946 -2.02254 Mabsadd L
.4873 .25016 .91448 -0.29713 Mabsadd L
.4873 .25016 2.37764 .77254 Mabsadd L
.4873 .25016 .56518 .7779 Mabsadd L
.4873 .25016 0 2.5 Mabsadd L closepath F
.49048 .24971 0 2.5 Mabsadd m
.49048 .24971 -0.56518 .7779 Mabsadd L
.49048 .24971 -2.37764 .77254 Mabsadd L
.49048 .24971 -0.91448 -0.29713 Mabsadd L
.49048 .24971 -1.46946 -2.02254 Mabsadd L
.49048 .24971 0 -0.96154 Mabsadd L
.49048 .24971 1.46946 -2.02254 Mabsadd L
.49048 .24971 .91448 -0.29713 Mabsadd L
.49048 .24971 2.37764 .77254 Mabsadd L
.49048 .24971 .56518 .7779 Mabsadd L
.49048 .24971 0 2.5 Mabsadd L closepath F
.49365 .24927 0 2.5 Mabsadd m
.49365 .24927 -0.56518 .7779 Mabsadd L
.49365 .24927 -2.37764 .77254 Mabsadd L
.49365 .24927 -0.91448 -0.29713 Mabsadd L
.49365 .24927 -1.46946 -2.02254 Mabsadd L
.49365 .24927 0 -0.96154 Mabsadd L
.49365 .24927 1.46946 -2.02254 Mabsadd L
.49365 .24927 .91448 -0.29713 Mabsadd L
.49365 .24927 2.37764 .77254 Mabsadd L
.49365 .24927 .56518 .7779 Mabsadd L
.49365 .24927 0 2.5 Mabsadd L closepath F
.49683 .24883 0 2.5 Mabsadd m
.49683 .24883 -0.56518 .7779 Mabsadd L
.49683 .24883 -2.37764 .77254 Mabsadd L
.49683 .24883 -0.91448 -0.29713 Mabsadd L
.49683 .24883 -1.46946 -2.02254 Mabsadd L
.49683 .24883 0 -0.96154 Mabsadd L
.49683 .24883 1.46946 -2.02254 Mabsadd L
.49683 .24883 .91448 -0.29713 Mabsadd L
.49683 .24883 2.37764 .77254 Mabsadd L
.49683 .24883 .56518 .7779 Mabsadd L
.49683 .24883 0 2.5 Mabsadd L closepath F
.5 .2484 0 2.5 Mabsadd m
.5 .2484 -0.56518 .7779 Mabsadd L
.5 .2484 -2.37764 .77254 Mabsadd L
.5 .2484 -0.91448 -0.29713 Mabsadd L
.5 .2484 -1.46946 -2.02254 Mabsadd L
.5 .2484 0 -0.96154 Mabsadd L
.5 .2484 1.46946 -2.02254 Mabsadd L
.5 .2484 .91448 -0.29713 Mabsadd L
.5 .2484 2.37764 .77254 Mabsadd L
.5 .2484 .56518 .7779 Mabsadd L
.5 .2484 0 2.5 Mabsadd L closepath F
.50317 .24798 0 2.5 Mabsadd m
.50317 .24798 -0.56518 .7779 Mabsadd L
.50317 .24798 -2.37764 .77254 Mabsadd L
.50317 .24798 -0.91448 -0.29713 Mabsadd L
.50317 .24798 -1.46946 -2.02254 Mabsadd L
.50317 .24798 0 -0.96154 Mabsadd L
.50317 .24798 1.46946 -2.02254 Mabsadd L
.50317 .24798 .91448 -0.29713 Mabsadd L
.50317 .24798 2.37764 .77254 Mabsadd L
.50317 .24798 .56518 .7779 Mabsadd L
.50317 .24798 0 2.5 Mabsadd L closepath F
.50635 .24755 0 2.5 Mabsadd m
.50635 .24755 -0.56518 .7779 Mabsadd L
.50635 .24755 -2.37764 .77254 Mabsadd L
.50635 .24755 -0.91448 -0.29713 Mabsadd L
.50635 .24755 -1.46946 -2.02254 Mabsadd L
.50635 .24755 0 -0.96154 Mabsadd L
.50635 .24755 1.46946 -2.02254 Mabsadd L
.50635 .24755 .91448 -0.29713 Mabsadd L
.50635 .24755 2.37764 .77254 Mabsadd L
.50635 .24755 .56518 .7779 Mabsadd L
.50635 .24755 0 2.5 Mabsadd L closepath F
.50952 .24713 0 2.5 Mabsadd m
.50952 .24713 -0.56518 .7779 Mabsadd L
.50952 .24713 -2.37764 .77254 Mabsadd L
.50952 .24713 -0.91448 -0.29713 Mabsadd L
.50952 .24713 -1.46946 -2.02254 Mabsadd L
.50952 .24713 0 -0.96154 Mabsadd L
.50952 .24713 1.46946 -2.02254 Mabsadd L
.50952 .24713 .91448 -0.29713 Mabsadd L
.50952 .24713 2.37764 .77254 Mabsadd L
.50952 .24713 .56518 .7779 Mabsadd L
.50952 .24713 0 2.5 Mabsadd L closepath F
.5127 .24672 0 2.5 Mabsadd m
.5127 .24672 -0.56518 .7779 Mabsadd L
.5127 .24672 -2.37764 .77254 Mabsadd L
.5127 .24672 -0.91448 -0.29713 Mabsadd L
.5127 .24672 -1.46946 -2.02254 Mabsadd L
.5127 .24672 0 -0.96154 Mabsadd L
.5127 .24672 1.46946 -2.02254 Mabsadd L
.5127 .24672 .91448 -0.29713 Mabsadd L
.5127 .24672 2.37764 .77254 Mabsadd L
.5127 .24672 .56518 .7779 Mabsadd L
.5127 .24672 0 2.5 Mabsadd L closepath F
.51587 .24631 0 2.5 Mabsadd m
.51587 .24631 -0.56518 .7779 Mabsadd L
.51587 .24631 -2.37764 .77254 Mabsadd L
.51587 .24631 -0.91448 -0.29713 Mabsadd L
.51587 .24631 -1.46946 -2.02254 Mabsadd L
.51587 .24631 0 -0.96154 Mabsadd L
.51587 .24631 1.46946 -2.02254 Mabsadd L
.51587 .24631 .91448 -0.29713 Mabsadd L
.51587 .24631 2.37764 .77254 Mabsadd L
.51587 .24631 .56518 .7779 Mabsadd L
.51587 .24631 0 2.5 Mabsadd L closepath F
.51905 .2459 0 2.5 Mabsadd m
.51905 .2459 -0.56518 .7779 Mabsadd L
.51905 .2459 -2.37764 .77254 Mabsadd L
.51905 .2459 -0.91448 -0.29713 Mabsadd L
.51905 .2459 -1.46946 -2.02254 Mabsadd L
.51905 .2459 0 -0.96154 Mabsadd L
.51905 .2459 1.46946 -2.02254 Mabsadd L
.51905 .2459 .91448 -0.29713 Mabsadd L
.51905 .2459 2.37764 .77254 Mabsadd L
.51905 .2459 .56518 .7779 Mabsadd L
.51905 .2459 0 2.5 Mabsadd L closepath F
.52222 .2455 0 2.5 Mabsadd m
.52222 .2455 -0.56518 .7779 Mabsadd L
.52222 .2455 -2.37764 .77254 Mabsadd L
.52222 .2455 -0.91448 -0.29713 Mabsadd L
.52222 .2455 -1.46946 -2.02254 Mabsadd L
.52222 .2455 0 -0.96154 Mabsadd L
.52222 .2455 1.46946 -2.02254 Mabsadd L
.52222 .2455 .91448 -0.29713 Mabsadd L
.52222 .2455 2.37764 .77254 Mabsadd L
.52222 .2455 .56518 .7779 Mabsadd L
.52222 .2455 0 2.5 Mabsadd L closepath F
.5254 .2451 0 2.5 Mabsadd m
.5254 .2451 -0.56518 .7779 Mabsadd L
.5254 .2451 -2.37764 .77254 Mabsadd L
.5254 .2451 -0.91448 -0.29713 Mabsadd L
.5254 .2451 -1.46946 -2.02254 Mabsadd L
.5254 .2451 0 -0.96154 Mabsadd L
.5254 .2451 1.46946 -2.02254 Mabsadd L
.5254 .2451 .91448 -0.29713 Mabsadd L
.5254 .2451 2.37764 .77254 Mabsadd L
.5254 .2451 .56518 .7779 Mabsadd L
.5254 .2451 0 2.5 Mabsadd L closepath F
.52857 .24471 0 2.5 Mabsadd m
.52857 .24471 -0.56518 .7779 Mabsadd L
.52857 .24471 -2.37764 .77254 Mabsadd L
.52857 .24471 -0.91448 -0.29713 Mabsadd L
.52857 .24471 -1.46946 -2.02254 Mabsadd L
.52857 .24471 0 -0.96154 Mabsadd L
.52857 .24471 1.46946 -2.02254 Mabsadd L
.52857 .24471 .91448 -0.29713 Mabsadd L
.52857 .24471 2.37764 .77254 Mabsadd L
.52857 .24471 .56518 .7779 Mabsadd L
.52857 .24471 0 2.5 Mabsadd L closepath F
.53175 .24432 0 2.5 Mabsadd m
.53175 .24432 -0.56518 .7779 Mabsadd L
.53175 .24432 -2.37764 .77254 Mabsadd L
.53175 .24432 -0.91448 -0.29713 Mabsadd L
.53175 .24432 -1.46946 -2.02254 Mabsadd L
.53175 .24432 0 -0.96154 Mabsadd L
.53175 .24432 1.46946 -2.02254 Mabsadd L
.53175 .24432 .91448 -0.29713 Mabsadd L
.53175 .24432 2.37764 .77254 Mabsadd L
.53175 .24432 .56518 .7779 Mabsadd L
.53175 .24432 0 2.5 Mabsadd L closepath F
.53492 .24393 0 2.5 Mabsadd m
.53492 .24393 -0.56518 .7779 Mabsadd L
.53492 .24393 -2.37764 .77254 Mabsadd L
.53492 .24393 -0.91448 -0.29713 Mabsadd L
.53492 .24393 -1.46946 -2.02254 Mabsadd L
.53492 .24393 0 -0.96154 Mabsadd L
.53492 .24393 1.46946 -2.02254 Mabsadd L
.53492 .24393 .91448 -0.29713 Mabsadd L
.53492 .24393 2.37764 .77254 Mabsadd L
.53492 .24393 .56518 .7779 Mabsadd L
.53492 .24393 0 2.5 Mabsadd L closepath F
.5381 .24355 0 2.5 Mabsadd m
.5381 .24355 -0.56518 .7779 Mabsadd L
.5381 .24355 -2.37764 .77254 Mabsadd L
.5381 .24355 -0.91448 -0.29713 Mabsadd L
.5381 .24355 -1.46946 -2.02254 Mabsadd L
.5381 .24355 0 -0.96154 Mabsadd L
.5381 .24355 1.46946 -2.02254 Mabsadd L
.5381 .24355 .91448 -0.29713 Mabsadd L
.5381 .24355 2.37764 .77254 Mabsadd L
.5381 .24355 .56518 .7779 Mabsadd L
.5381 .24355 0 2.5 Mabsadd L closepath F
.54127 .24317 0 2.5 Mabsadd m
.54127 .24317 -0.56518 .7779 Mabsadd L
.54127 .24317 -2.37764 .77254 Mabsadd L
.54127 .24317 -0.91448 -0.29713 Mabsadd L
.54127 .24317 -1.46946 -2.02254 Mabsadd L
.54127 .24317 0 -0.96154 Mabsadd L
.54127 .24317 1.46946 -2.02254 Mabsadd L
.54127 .24317 .91448 -0.29713 Mabsadd L
.54127 .24317 2.37764 .77254 Mabsadd L
.54127 .24317 .56518 .7779 Mabsadd L
.54127 .24317 0 2.5 Mabsadd L closepath F
.54444 .2428 0 2.5 Mabsadd m
.54444 .2428 -0.56518 .7779 Mabsadd L
.54444 .2428 -2.37764 .77254 Mabsadd L
.54444 .2428 -0.91448 -0.29713 Mabsadd L
.54444 .2428 -1.46946 -2.02254 Mabsadd L
.54444 .2428 0 -0.96154 Mabsadd L
.54444 .2428 1.46946 -2.02254 Mabsadd L
.54444 .2428 .91448 -0.29713 Mabsadd L
.54444 .2428 2.37764 .77254 Mabsadd L
.54444 .2428 .56518 .7779 Mabsadd L
.54444 .2428 0 2.5 Mabsadd L closepath F
.54762 .24243 0 2.5 Mabsadd m
.54762 .24243 -0.56518 .7779 Mabsadd L
.54762 .24243 -2.37764 .77254 Mabsadd L
.54762 .24243 -0.91448 -0.29713 Mabsadd L
.54762 .24243 -1.46946 -2.02254 Mabsadd L
.54762 .24243 0 -0.96154 Mabsadd L
.54762 .24243 1.46946 -2.02254 Mabsadd L
.54762 .24243 .91448 -0.29713 Mabsadd L
.54762 .24243 2.37764 .77254 Mabsadd L
.54762 .24243 .56518 .7779 Mabsadd L
.54762 .24243 0 2.5 Mabsadd L closepath F
.55079 .24206 0 2.5 Mabsadd m
.55079 .24206 -0.56518 .7779 Mabsadd L
.55079 .24206 -2.37764 .77254 Mabsadd L
.55079 .24206 -0.91448 -0.29713 Mabsadd L
.55079 .24206 -1.46946 -2.02254 Mabsadd L
.55079 .24206 0 -0.96154 Mabsadd L
.55079 .24206 1.46946 -2.02254 Mabsadd L
.55079 .24206 .91448 -0.29713 Mabsadd L
.55079 .24206 2.37764 .77254 Mabsadd L
.55079 .24206 .56518 .7779 Mabsadd L
.55079 .24206 0 2.5 Mabsadd L closepath F
.55397 .24169 0 2.5 Mabsadd m
.55397 .24169 -0.56518 .7779 Mabsadd L
.55397 .24169 -2.37764 .77254 Mabsadd L
.55397 .24169 -0.91448 -0.29713 Mabsadd L
.55397 .24169 -1.46946 -2.02254 Mabsadd L
.55397 .24169 0 -0.96154 Mabsadd L
.55397 .24169 1.46946 -2.02254 Mabsadd L
.55397 .24169 .91448 -0.29713 Mabsadd L
.55397 .24169 2.37764 .77254 Mabsadd L
.55397 .24169 .56518 .7779 Mabsadd L
.55397 .24169 0 2.5 Mabsadd L closepath F
.55714 .24133 0 2.5 Mabsadd m
.55714 .24133 -0.56518 .7779 Mabsadd L
.55714 .24133 -2.37764 .77254 Mabsadd L
.55714 .24133 -0.91448 -0.29713 Mabsadd L
.55714 .24133 -1.46946 -2.02254 Mabsadd L
.55714 .24133 0 -0.96154 Mabsadd L
.55714 .24133 1.46946 -2.02254 Mabsadd L
.55714 .24133 .91448 -0.29713 Mabsadd L
.55714 .24133 2.37764 .77254 Mabsadd L
.55714 .24133 .56518 .7779 Mabsadd L
.55714 .24133 0 2.5 Mabsadd L closepath F
.56032 .24098 0 2.5 Mabsadd m
.56032 .24098 -0.56518 .7779 Mabsadd L
.56032 .24098 -2.37764 .77254 Mabsadd L
.56032 .24098 -0.91448 -0.29713 Mabsadd L
.56032 .24098 -1.46946 -2.02254 Mabsadd L
.56032 .24098 0 -0.96154 Mabsadd L
.56032 .24098 1.46946 -2.02254 Mabsadd L
.56032 .24098 .91448 -0.29713 Mabsadd L
.56032 .24098 2.37764 .77254 Mabsadd L
.56032 .24098 .56518 .7779 Mabsadd L
.56032 .24098 0 2.5 Mabsadd L closepath F
.56349 .24062 0 2.5 Mabsadd m
.56349 .24062 -0.56518 .7779 Mabsadd L
.56349 .24062 -2.37764 .77254 Mabsadd L
.56349 .24062 -0.91448 -0.29713 Mabsadd L
.56349 .24062 -1.46946 -2.02254 Mabsadd L
.56349 .24062 0 -0.96154 Mabsadd L
.56349 .24062 1.46946 -2.02254 Mabsadd L
.56349 .24062 .91448 -0.29713 Mabsadd L
.56349 .24062 2.37764 .77254 Mabsadd L
.56349 .24062 .56518 .7779 Mabsadd L
.56349 .24062 0 2.5 Mabsadd L closepath F
.56667 .24028 0 2.5 Mabsadd m
.56667 .24028 -0.56518 .7779 Mabsadd L
.56667 .24028 -2.37764 .77254 Mabsadd L
.56667 .24028 -0.91448 -0.29713 Mabsadd L
.56667 .24028 -1.46946 -2.02254 Mabsadd L
.56667 .24028 0 -0.96154 Mabsadd L
.56667 .24028 1.46946 -2.02254 Mabsadd L
.56667 .24028 .91448 -0.29713 Mabsadd L
.56667 .24028 2.37764 .77254 Mabsadd L
.56667 .24028 .56518 .7779 Mabsadd L
.56667 .24028 0 2.5 Mabsadd L closepath F
.56984 .23993 0 2.5 Mabsadd m
.56984 .23993 -0.56518 .7779 Mabsadd L
.56984 .23993 -2.37764 .77254 Mabsadd L
.56984 .23993 -0.91448 -0.29713 Mabsadd L
.56984 .23993 -1.46946 -2.02254 Mabsadd L
.56984 .23993 0 -0.96154 Mabsadd L
.56984 .23993 1.46946 -2.02254 Mabsadd L
.56984 .23993 .91448 -0.29713 Mabsadd L
.56984 .23993 2.37764 .77254 Mabsadd L
.56984 .23993 .56518 .7779 Mabsadd L
.56984 .23993 0 2.5 Mabsadd L closepath F
.57302 .23959 0 2.5 Mabsadd m
.57302 .23959 -0.56518 .7779 Mabsadd L
.57302 .23959 -2.37764 .77254 Mabsadd L
.57302 .23959 -0.91448 -0.29713 Mabsadd L
.57302 .23959 -1.46946 -2.02254 Mabsadd L
.57302 .23959 0 -0.96154 Mabsadd L
.57302 .23959 1.46946 -2.02254 Mabsadd L
.57302 .23959 .91448 -0.29713 Mabsadd L
.57302 .23959 2.37764 .77254 Mabsadd L
.57302 .23959 .56518 .7779 Mabsadd L
.57302 .23959 0 2.5 Mabsadd L closepath F
.57619 .23925 0 2.5 Mabsadd m
.57619 .23925 -0.56518 .7779 Mabsadd L
.57619 .23925 -2.37764 .77254 Mabsadd L
.57619 .23925 -0.91448 -0.29713 Mabsadd L
.57619 .23925 -1.46946 -2.02254 Mabsadd L
.57619 .23925 0 -0.96154 Mabsadd L
.57619 .23925 1.46946 -2.02254 Mabsadd L
.57619 .23925 .91448 -0.29713 Mabsadd L
.57619 .23925 2.37764 .77254 Mabsadd L
.57619 .23925 .56518 .7779 Mabsadd L
.57619 .23925 0 2.5 Mabsadd L closepath F
.57937 .23891 0 2.5 Mabsadd m
.57937 .23891 -0.56518 .7779 Mabsadd L
.57937 .23891 -2.37764 .77254 Mabsadd L
.57937 .23891 -0.91448 -0.29713 Mabsadd L
.57937 .23891 -1.46946 -2.02254 Mabsadd L
.57937 .23891 0 -0.96154 Mabsadd L
.57937 .23891 1.46946 -2.02254 Mabsadd L
.57937 .23891 .91448 -0.29713 Mabsadd L
.57937 .23891 2.37764 .77254 Mabsadd L
.57937 .23891 .56518 .7779 Mabsadd L
.57937 .23891 0 2.5 Mabsadd L closepath F
.58254 .23858 0 2.5 Mabsadd m
.58254 .23858 -0.56518 .7779 Mabsadd L
.58254 .23858 -2.37764 .77254 Mabsadd L
.58254 .23858 -0.91448 -0.29713 Mabsadd L
.58254 .23858 -1.46946 -2.02254 Mabsadd L
.58254 .23858 0 -0.96154 Mabsadd L
.58254 .23858 1.46946 -2.02254 Mabsadd L
.58254 .23858 .91448 -0.29713 Mabsadd L
.58254 .23858 2.37764 .77254 Mabsadd L
.58254 .23858 .56518 .7779 Mabsadd L
.58254 .23858 0 2.5 Mabsadd L closepath F
.58571 .23825 0 2.5 Mabsadd m
.58571 .23825 -0.56518 .7779 Mabsadd L
.58571 .23825 -2.37764 .77254 Mabsadd L
.58571 .23825 -0.91448 -0.29713 Mabsadd L
.58571 .23825 -1.46946 -2.02254 Mabsadd L
.58571 .23825 0 -0.96154 Mabsadd L
.58571 .23825 1.46946 -2.02254 Mabsadd L
.58571 .23825 .91448 -0.29713 Mabsadd L
.58571 .23825 2.37764 .77254 Mabsadd L
.58571 .23825 .56518 .7779 Mabsadd L
.58571 .23825 0 2.5 Mabsadd L closepath F
.58889 .23793 0 2.5 Mabsadd m
.58889 .23793 -0.56518 .7779 Mabsadd L
.58889 .23793 -2.37764 .77254 Mabsadd L
.58889 .23793 -0.91448 -0.29713 Mabsadd L
.58889 .23793 -1.46946 -2.02254 Mabsadd L
.58889 .23793 0 -0.96154 Mabsadd L
.58889 .23793 1.46946 -2.02254 Mabsadd L
.58889 .23793 .91448 -0.29713 Mabsadd L
.58889 .23793 2.37764 .77254 Mabsadd L
.58889 .23793 .56518 .7779 Mabsadd L
.58889 .23793 0 2.5 Mabsadd L closepath F
.59206 .2376 0 2.5 Mabsadd m
.59206 .2376 -0.56518 .7779 Mabsadd L
.59206 .2376 -2.37764 .77254 Mabsadd L
.59206 .2376 -0.91448 -0.29713 Mabsadd L
.59206 .2376 -1.46946 -2.02254 Mabsadd L
.59206 .2376 0 -0.96154 Mabsadd L
.59206 .2376 1.46946 -2.02254 Mabsadd L
.59206 .2376 .91448 -0.29713 Mabsadd L
.59206 .2376 2.37764 .77254 Mabsadd L
.59206 .2376 .56518 .7779 Mabsadd L
.59206 .2376 0 2.5 Mabsadd L closepath F
.59524 .23728 0 2.5 Mabsadd m
.59524 .23728 -0.56518 .7779 Mabsadd L
.59524 .23728 -2.37764 .77254 Mabsadd L
.59524 .23728 -0.91448 -0.29713 Mabsadd L
.59524 .23728 -1.46946 -2.02254 Mabsadd L
.59524 .23728 0 -0.96154 Mabsadd L
.59524 .23728 1.46946 -2.02254 Mabsadd L
.59524 .23728 .91448 -0.29713 Mabsadd L
.59524 .23728 2.37764 .77254 Mabsadd L
.59524 .23728 .56518 .7779 Mabsadd L
.59524 .23728 0 2.5 Mabsadd L closepath F
.59841 .23697 0 2.5 Mabsadd m
.59841 .23697 -0.56518 .7779 Mabsadd L
.59841 .23697 -2.37764 .77254 Mabsadd L
.59841 .23697 -0.91448 -0.29713 Mabsadd L
.59841 .23697 -1.46946 -2.02254 Mabsadd L
.59841 .23697 0 -0.96154 Mabsadd L
.59841 .23697 1.46946 -2.02254 Mabsadd L
.59841 .23697 .91448 -0.29713 Mabsadd L
.59841 .23697 2.37764 .77254 Mabsadd L
.59841 .23697 .56518 .7779 Mabsadd L
.59841 .23697 0 2.5 Mabsadd L closepath F
.60159 .23666 0 2.5 Mabsadd m
.60159 .23666 -0.56518 .7779 Mabsadd L
.60159 .23666 -2.37764 .77254 Mabsadd L
.60159 .23666 -0.91448 -0.29713 Mabsadd L
.60159 .23666 -1.46946 -2.02254 Mabsadd L
.60159 .23666 0 -0.96154 Mabsadd L
.60159 .23666 1.46946 -2.02254 Mabsadd L
.60159 .23666 .91448 -0.29713 Mabsadd L
.60159 .23666 2.37764 .77254 Mabsadd L
.60159 .23666 .56518 .7779 Mabsadd L
.60159 .23666 0 2.5 Mabsadd L closepath F
.60476 .23635 0 2.5 Mabsadd m
.60476 .23635 -0.56518 .7779 Mabsadd L
.60476 .23635 -2.37764 .77254 Mabsadd L
.60476 .23635 -0.91448 -0.29713 Mabsadd L
.60476 .23635 -1.46946 -2.02254 Mabsadd L
.60476 .23635 0 -0.96154 Mabsadd L
.60476 .23635 1.46946 -2.02254 Mabsadd L
.60476 .23635 .91448 -0.29713 Mabsadd L
.60476 .23635 2.37764 .77254 Mabsadd L
.60476 .23635 .56518 .7779 Mabsadd L
.60476 .23635 0 2.5 Mabsadd L closepath F
.60794 .23604 0 2.5 Mabsadd m
.60794 .23604 -0.56518 .7779 Mabsadd L
.60794 .23604 -2.37764 .77254 Mabsadd L
.60794 .23604 -0.91448 -0.29713 Mabsadd L
.60794 .23604 -1.46946 -2.02254 Mabsadd L
.60794 .23604 0 -0.96154 Mabsadd L
.60794 .23604 1.46946 -2.02254 Mabsadd L
.60794 .23604 .91448 -0.29713 Mabsadd L
.60794 .23604 2.37764 .77254 Mabsadd L
.60794 .23604 .56518 .7779 Mabsadd L
.60794 .23604 0 2.5 Mabsadd L closepath F
.61111 .23574 0 2.5 Mabsadd m
.61111 .23574 -0.56518 .7779 Mabsadd L
.61111 .23574 -2.37764 .77254 Mabsadd L
.61111 .23574 -0.91448 -0.29713 Mabsadd L
.61111 .23574 -1.46946 -2.02254 Mabsadd L
.61111 .23574 0 -0.96154 Mabsadd L
.61111 .23574 1.46946 -2.02254 Mabsadd L
.61111 .23574 .91448 -0.29713 Mabsadd L
.61111 .23574 2.37764 .77254 Mabsadd L
.61111 .23574 .56518 .7779 Mabsadd L
.61111 .23574 0 2.5 Mabsadd L closepath F
.61429 .23543 0 2.5 Mabsadd m
.61429 .23543 -0.56518 .7779 Mabsadd L
.61429 .23543 -2.37764 .77254 Mabsadd L
.61429 .23543 -0.91448 -0.29713 Mabsadd L
.61429 .23543 -1.46946 -2.02254 Mabsadd L
.61429 .23543 0 -0.96154 Mabsadd L
.61429 .23543 1.46946 -2.02254 Mabsadd L
.61429 .23543 .91448 -0.29713 Mabsadd L
.61429 .23543 2.37764 .77254 Mabsadd L
.61429 .23543 .56518 .7779 Mabsadd L
.61429 .23543 0 2.5 Mabsadd L closepath F
.61746 .23514 0 2.5 Mabsadd m
.61746 .23514 -0.56518 .7779 Mabsadd L
.61746 .23514 -2.37764 .77254 Mabsadd L
.61746 .23514 -0.91448 -0.29713 Mabsadd L
.61746 .23514 -1.46946 -2.02254 Mabsadd L
.61746 .23514 0 -0.96154 Mabsadd L
.61746 .23514 1.46946 -2.02254 Mabsadd L
.61746 .23514 .91448 -0.29713 Mabsadd L
.61746 .23514 2.37764 .77254 Mabsadd L
.61746 .23514 .56518 .7779 Mabsadd L
.61746 .23514 0 2.5 Mabsadd L closepath F
.62063 .23484 0 2.5 Mabsadd m
.62063 .23484 -0.56518 .7779 Mabsadd L
.62063 .23484 -2.37764 .77254 Mabsadd L
.62063 .23484 -0.91448 -0.29713 Mabsadd L
.62063 .23484 -1.46946 -2.02254 Mabsadd L
.62063 .23484 0 -0.96154 Mabsadd L
.62063 .23484 1.46946 -2.02254 Mabsadd L
.62063 .23484 .91448 -0.29713 Mabsadd L
.62063 .23484 2.37764 .77254 Mabsadd L
.62063 .23484 .56518 .7779 Mabsadd L
.62063 .23484 0 2.5 Mabsadd L closepath F
.62381 .23455 0 2.5 Mabsadd m
.62381 .23455 -0.56518 .7779 Mabsadd L
.62381 .23455 -2.37764 .77254 Mabsadd L
.62381 .23455 -0.91448 -0.29713 Mabsadd L
.62381 .23455 -1.46946 -2.02254 Mabsadd L
.62381 .23455 0 -0.96154 Mabsadd L
.62381 .23455 1.46946 -2.02254 Mabsadd L
.62381 .23455 .91448 -0.29713 Mabsadd L
.62381 .23455 2.37764 .77254 Mabsadd L
.62381 .23455 .56518 .7779 Mabsadd L
.62381 .23455 0 2.5 Mabsadd L closepath F
.62698 .23426 0 2.5 Mabsadd m
.62698 .23426 -0.56518 .7779 Mabsadd L
.62698 .23426 -2.37764 .77254 Mabsadd L
.62698 .23426 -0.91448 -0.29713 Mabsadd L
.62698 .23426 -1.46946 -2.02254 Mabsadd L
.62698 .23426 0 -0.96154 Mabsadd L
.62698 .23426 1.46946 -2.02254 Mabsadd L
.62698 .23426 .91448 -0.29713 Mabsadd L
.62698 .23426 2.37764 .77254 Mabsadd L
.62698 .23426 .56518 .7779 Mabsadd L
.62698 .23426 0 2.5 Mabsadd L closepath F
.63016 .23398 0 2.5 Mabsadd m
.63016 .23398 -0.56518 .7779 Mabsadd L
.63016 .23398 -2.37764 .77254 Mabsadd L
.63016 .23398 -0.91448 -0.29713 Mabsadd L
.63016 .23398 -1.46946 -2.02254 Mabsadd L
.63016 .23398 0 -0.96154 Mabsadd L
.63016 .23398 1.46946 -2.02254 Mabsadd L
.63016 .23398 .91448 -0.29713 Mabsadd L
.63016 .23398 2.37764 .77254 Mabsadd L
.63016 .23398 .56518 .7779 Mabsadd L
.63016 .23398 0 2.5 Mabsadd L closepath F
.63333 .23369 0 2.5 Mabsadd m
.63333 .23369 -0.56518 .7779 Mabsadd L
.63333 .23369 -2.37764 .77254 Mabsadd L
.63333 .23369 -0.91448 -0.29713 Mabsadd L
.63333 .23369 -1.46946 -2.02254 Mabsadd L
.63333 .23369 0 -0.96154 Mabsadd L
.63333 .23369 1.46946 -2.02254 Mabsadd L
.63333 .23369 .91448 -0.29713 Mabsadd L
.63333 .23369 2.37764 .77254 Mabsadd L
.63333 .23369 .56518 .7779 Mabsadd L
.63333 .23369 0 2.5 Mabsadd L closepath F
.63651 .23341 0 2.5 Mabsadd m
.63651 .23341 -0.56518 .7779 Mabsadd L
.63651 .23341 -2.37764 .77254 Mabsadd L
.63651 .23341 -0.91448 -0.29713 Mabsadd L
.63651 .23341 -1.46946 -2.02254 Mabsadd L
.63651 .23341 0 -0.96154 Mabsadd L
.63651 .23341 1.46946 -2.02254 Mabsadd L
.63651 .23341 .91448 -0.29713 Mabsadd L
.63651 .23341 2.37764 .77254 Mabsadd L
.63651 .23341 .56518 .7779 Mabsadd L
.63651 .23341 0 2.5 Mabsadd L closepath F
.63968 .23314 0 2.5 Mabsadd m
.63968 .23314 -0.56518 .7779 Mabsadd L
.63968 .23314 -2.37764 .77254 Mabsadd L
.63968 .23314 -0.91448 -0.29713 Mabsadd L
.63968 .23314 -1.46946 -2.02254 Mabsadd L
.63968 .23314 0 -0.96154 Mabsadd L
.63968 .23314 1.46946 -2.02254 Mabsadd L
.63968 .23314 .91448 -0.29713 Mabsadd L
.63968 .23314 2.37764 .77254 Mabsadd L
.63968 .23314 .56518 .7779 Mabsadd L
.63968 .23314 0 2.5 Mabsadd L closepath F
.64286 .23286 0 2.5 Mabsadd m
.64286 .23286 -0.56518 .7779 Mabsadd L
.64286 .23286 -2.37764 .77254 Mabsadd L
.64286 .23286 -0.91448 -0.29713 Mabsadd L
.64286 .23286 -1.46946 -2.02254 Mabsadd L
.64286 .23286 0 -0.96154 Mabsadd L
.64286 .23286 1.46946 -2.02254 Mabsadd L
.64286 .23286 .91448 -0.29713 Mabsadd L
.64286 .23286 2.37764 .77254 Mabsadd L
.64286 .23286 .56518 .7779 Mabsadd L
.64286 .23286 0 2.5 Mabsadd L closepath F
.64603 .23259 0 2.5 Mabsadd m
.64603 .23259 -0.56518 .7779 Mabsadd L
.64603 .23259 -2.37764 .77254 Mabsadd L
.64603 .23259 -0.91448 -0.29713 Mabsadd L
.64603 .23259 -1.46946 -2.02254 Mabsadd L
.64603 .23259 0 -0.96154 Mabsadd L
.64603 .23259 1.46946 -2.02254 Mabsadd L
.64603 .23259 .91448 -0.29713 Mabsadd L
.64603 .23259 2.37764 .77254 Mabsadd L
.64603 .23259 .56518 .7779 Mabsadd L
.64603 .23259 0 2.5 Mabsadd L closepath F
.64921 .23232 0 2.5 Mabsadd m
.64921 .23232 -0.56518 .7779 Mabsadd L
.64921 .23232 -2.37764 .77254 Mabsadd L
.64921 .23232 -0.91448 -0.29713 Mabsadd L
.64921 .23232 -1.46946 -2.02254 Mabsadd L
.64921 .23232 0 -0.96154 Mabsadd L
.64921 .23232 1.46946 -2.02254 Mabsadd L
.64921 .23232 .91448 -0.29713 Mabsadd L
.64921 .23232 2.37764 .77254 Mabsadd L
.64921 .23232 .56518 .7779 Mabsadd L
.64921 .23232 0 2.5 Mabsadd L closepath F
.65238 .23205 0 2.5 Mabsadd m
.65238 .23205 -0.56518 .7779 Mabsadd L
.65238 .23205 -2.37764 .77254 Mabsadd L
.65238 .23205 -0.91448 -0.29713 Mabsadd L
.65238 .23205 -1.46946 -2.02254 Mabsadd L
.65238 .23205 0 -0.96154 Mabsadd L
.65238 .23205 1.46946 -2.02254 Mabsadd L
.65238 .23205 .91448 -0.29713 Mabsadd L
.65238 .23205 2.37764 .77254 Mabsadd L
.65238 .23205 .56518 .7779 Mabsadd L
.65238 .23205 0 2.5 Mabsadd L closepath F
.65556 .23179 0 2.5 Mabsadd m
.65556 .23179 -0.56518 .7779 Mabsadd L
.65556 .23179 -2.37764 .77254 Mabsadd L
.65556 .23179 -0.91448 -0.29713 Mabsadd L
.65556 .23179 -1.46946 -2.02254 Mabsadd L
.65556 .23179 0 -0.96154 Mabsadd L
.65556 .23179 1.46946 -2.02254 Mabsadd L
.65556 .23179 .91448 -0.29713 Mabsadd L
.65556 .23179 2.37764 .77254 Mabsadd L
.65556 .23179 .56518 .7779 Mabsadd L
.65556 .23179 0 2.5 Mabsadd L closepath F
.65873 .23153 0 2.5 Mabsadd m
.65873 .23153 -0.56518 .7779 Mabsadd L
.65873 .23153 -2.37764 .77254 Mabsadd L
.65873 .23153 -0.91448 -0.29713 Mabsadd L
.65873 .23153 -1.46946 -2.02254 Mabsadd L
.65873 .23153 0 -0.96154 Mabsadd L
.65873 .23153 1.46946 -2.02254 Mabsadd L
.65873 .23153 .91448 -0.29713 Mabsadd L
.65873 .23153 2.37764 .77254 Mabsadd L
.65873 .23153 .56518 .7779 Mabsadd L
.65873 .23153 0 2.5 Mabsadd L closepath F
.6619 .23127 0 2.5 Mabsadd m
.6619 .23127 -0.56518 .7779 Mabsadd L
.6619 .23127 -2.37764 .77254 Mabsadd L
.6619 .23127 -0.91448 -0.29713 Mabsadd L
.6619 .23127 -1.46946 -2.02254 Mabsadd L
.6619 .23127 0 -0.96154 Mabsadd L
.6619 .23127 1.46946 -2.02254 Mabsadd L
.6619 .23127 .91448 -0.29713 Mabsadd L
.6619 .23127 2.37764 .77254 Mabsadd L
.6619 .23127 .56518 .7779 Mabsadd L
.6619 .23127 0 2.5 Mabsadd L closepath F
.66508 .23102 0 2.5 Mabsadd m
.66508 .23102 -0.56518 .7779 Mabsadd L
.66508 .23102 -2.37764 .77254 Mabsadd L
.66508 .23102 -0.91448 -0.29713 Mabsadd L
.66508 .23102 -1.46946 -2.02254 Mabsadd L
.66508 .23102 0 -0.96154 Mabsadd L
.66508 .23102 1.46946 -2.02254 Mabsadd L
.66508 .23102 .91448 -0.29713 Mabsadd L
.66508 .23102 2.37764 .77254 Mabsadd L
.66508 .23102 .56518 .7779 Mabsadd L
.66508 .23102 0 2.5 Mabsadd L closepath F
.66825 .23076 0 2.5 Mabsadd m
.66825 .23076 -0.56518 .7779 Mabsadd L
.66825 .23076 -2.37764 .77254 Mabsadd L
.66825 .23076 -0.91448 -0.29713 Mabsadd L
.66825 .23076 -1.46946 -2.02254 Mabsadd L
.66825 .23076 0 -0.96154 Mabsadd L
.66825 .23076 1.46946 -2.02254 Mabsadd L
.66825 .23076 .91448 -0.29713 Mabsadd L
.66825 .23076 2.37764 .77254 Mabsadd L
.66825 .23076 .56518 .7779 Mabsadd L
.66825 .23076 0 2.5 Mabsadd L closepath F
.67143 .23051 0 2.5 Mabsadd m
.67143 .23051 -0.56518 .7779 Mabsadd L
.67143 .23051 -2.37764 .77254 Mabsadd L
.67143 .23051 -0.91448 -0.29713 Mabsadd L
.67143 .23051 -1.46946 -2.02254 Mabsadd L
.67143 .23051 0 -0.96154 Mabsadd L
.67143 .23051 1.46946 -2.02254 Mabsadd L
.67143 .23051 .91448 -0.29713 Mabsadd L
.67143 .23051 2.37764 .77254 Mabsadd L
.67143 .23051 .56518 .7779 Mabsadd L
.67143 .23051 0 2.5 Mabsadd L closepath F
.6746 .23026 0 2.5 Mabsadd m
.6746 .23026 -0.56518 .7779 Mabsadd L
.6746 .23026 -2.37764 .77254 Mabsadd L
.6746 .23026 -0.91448 -0.29713 Mabsadd L
.6746 .23026 -1.46946 -2.02254 Mabsadd L
.6746 .23026 0 -0.96154 Mabsadd L
.6746 .23026 1.46946 -2.02254 Mabsadd L
.6746 .23026 .91448 -0.29713 Mabsadd L
.6746 .23026 2.37764 .77254 Mabsadd L
.6746 .23026 .56518 .7779 Mabsadd L
.6746 .23026 0 2.5 Mabsadd L closepath F
.67778 .23002 0 2.5 Mabsadd m
.67778 .23002 -0.56518 .7779 Mabsadd L
.67778 .23002 -2.37764 .77254 Mabsadd L
.67778 .23002 -0.91448 -0.29713 Mabsadd L
.67778 .23002 -1.46946 -2.02254 Mabsadd L
.67778 .23002 0 -0.96154 Mabsadd L
.67778 .23002 1.46946 -2.02254 Mabsadd L
.67778 .23002 .91448 -0.29713 Mabsadd L
.67778 .23002 2.37764 .77254 Mabsadd L
.67778 .23002 .56518 .7779 Mabsadd L
.67778 .23002 0 2.5 Mabsadd L closepath F
.68095 .22977 0 2.5 Mabsadd m
.68095 .22977 -0.56518 .7779 Mabsadd L
.68095 .22977 -2.37764 .77254 Mabsadd L
.68095 .22977 -0.91448 -0.29713 Mabsadd L
.68095 .22977 -1.46946 -2.02254 Mabsadd L
.68095 .22977 0 -0.96154 Mabsadd L
.68095 .22977 1.46946 -2.02254 Mabsadd L
.68095 .22977 .91448 -0.29713 Mabsadd L
.68095 .22977 2.37764 .77254 Mabsadd L
.68095 .22977 .56518 .7779 Mabsadd L
.68095 .22977 0 2.5 Mabsadd L closepath F
.68413 .22953 0 2.5 Mabsadd m
.68413 .22953 -0.56518 .7779 Mabsadd L
.68413 .22953 -2.37764 .77254 Mabsadd L
.68413 .22953 -0.91448 -0.29713 Mabsadd L
.68413 .22953 -1.46946 -2.02254 Mabsadd L
.68413 .22953 0 -0.96154 Mabsadd L
.68413 .22953 1.46946 -2.02254 Mabsadd L
.68413 .22953 .91448 -0.29713 Mabsadd L
.68413 .22953 2.37764 .77254 Mabsadd L
.68413 .22953 .56518 .7779 Mabsadd L
.68413 .22953 0 2.5 Mabsadd L closepath F
.6873 .2293 0 2.5 Mabsadd m
.6873 .2293 -0.56518 .7779 Mabsadd L
.6873 .2293 -2.37764 .77254 Mabsadd L
.6873 .2293 -0.91448 -0.29713 Mabsadd L
.6873 .2293 -1.46946 -2.02254 Mabsadd L
.6873 .2293 0 -0.96154 Mabsadd L
.6873 .2293 1.46946 -2.02254 Mabsadd L
.6873 .2293 .91448 -0.29713 Mabsadd L
.6873 .2293 2.37764 .77254 Mabsadd L
.6873 .2293 .56518 .7779 Mabsadd L
.6873 .2293 0 2.5 Mabsadd L closepath F
.69048 .22906 0 2.5 Mabsadd m
.69048 .22906 -0.56518 .7779 Mabsadd L
.69048 .22906 -2.37764 .77254 Mabsadd L
.69048 .22906 -0.91448 -0.29713 Mabsadd L
.69048 .22906 -1.46946 -2.02254 Mabsadd L
.69048 .22906 0 -0.96154 Mabsadd L
.69048 .22906 1.46946 -2.02254 Mabsadd L
.69048 .22906 .91448 -0.29713 Mabsadd L
.69048 .22906 2.37764 .77254 Mabsadd L
.69048 .22906 .56518 .7779 Mabsadd L
.69048 .22906 0 2.5 Mabsadd L closepath F
.69365 .22883 0 2.5 Mabsadd m
.69365 .22883 -0.56518 .7779 Mabsadd L
.69365 .22883 -2.37764 .77254 Mabsadd L
.69365 .22883 -0.91448 -0.29713 Mabsadd L
.69365 .22883 -1.46946 -2.02254 Mabsadd L
.69365 .22883 0 -0.96154 Mabsadd L
.69365 .22883 1.46946 -2.02254 Mabsadd L
.69365 .22883 .91448 -0.29713 Mabsadd L
.69365 .22883 2.37764 .77254 Mabsadd L
.69365 .22883 .56518 .7779 Mabsadd L
.69365 .22883 0 2.5 Mabsadd L closepath F
.69683 .22859 0 2.5 Mabsadd m
.69683 .22859 -0.56518 .7779 Mabsadd L
.69683 .22859 -2.37764 .77254 Mabsadd L
.69683 .22859 -0.91448 -0.29713 Mabsadd L
.69683 .22859 -1.46946 -2.02254 Mabsadd L
.69683 .22859 0 -0.96154 Mabsadd L
.69683 .22859 1.46946 -2.02254 Mabsadd L
.69683 .22859 .91448 -0.29713 Mabsadd L
.69683 .22859 2.37764 .77254 Mabsadd L
.69683 .22859 .56518 .7779 Mabsadd L
.69683 .22859 0 2.5 Mabsadd L closepath F
.7 .22836 0 2.5 Mabsadd m
.7 .22836 -0.56518 .7779 Mabsadd L
.7 .22836 -2.37764 .77254 Mabsadd L
.7 .22836 -0.91448 -0.29713 Mabsadd L
.7 .22836 -1.46946 -2.02254 Mabsadd L
.7 .22836 0 -0.96154 Mabsadd L
.7 .22836 1.46946 -2.02254 Mabsadd L
.7 .22836 .91448 -0.29713 Mabsadd L
.7 .22836 2.37764 .77254 Mabsadd L
.7 .22836 .56518 .7779 Mabsadd L
.7 .22836 0 2.5 Mabsadd L closepath F
.70317 .22814 0 2.5 Mabsadd m
.70317 .22814 -0.56518 .7779 Mabsadd L
.70317 .22814 -2.37764 .77254 Mabsadd L
.70317 .22814 -0.91448 -0.29713 Mabsadd L
.70317 .22814 -1.46946 -2.02254 Mabsadd L
.70317 .22814 0 -0.96154 Mabsadd L
.70317 .22814 1.46946 -2.02254 Mabsadd L
.70317 .22814 .91448 -0.29713 Mabsadd L
.70317 .22814 2.37764 .77254 Mabsadd L
.70317 .22814 .56518 .7779 Mabsadd L
.70317 .22814 0 2.5 Mabsadd L closepath F
.70635 .22791 0 2.5 Mabsadd m
.70635 .22791 -0.56518 .7779 Mabsadd L
.70635 .22791 -2.37764 .77254 Mabsadd L
.70635 .22791 -0.91448 -0.29713 Mabsadd L
.70635 .22791 -1.46946 -2.02254 Mabsadd L
.70635 .22791 0 -0.96154 Mabsadd L
.70635 .22791 1.46946 -2.02254 Mabsadd L
.70635 .22791 .91448 -0.29713 Mabsadd L
.70635 .22791 2.37764 .77254 Mabsadd L
.70635 .22791 .56518 .7779 Mabsadd L
.70635 .22791 0 2.5 Mabsadd L closepath F
.70952 .22769 0 2.5 Mabsadd m
.70952 .22769 -0.56518 .7779 Mabsadd L
.70952 .22769 -2.37764 .77254 Mabsadd L
.70952 .22769 -0.91448 -0.29713 Mabsadd L
.70952 .22769 -1.46946 -2.02254 Mabsadd L
.70952 .22769 0 -0.96154 Mabsadd L
.70952 .22769 1.46946 -2.02254 Mabsadd L
.70952 .22769 .91448 -0.29713 Mabsadd L
.70952 .22769 2.37764 .77254 Mabsadd L
.70952 .22769 .56518 .7779 Mabsadd L
.70952 .22769 0 2.5 Mabsadd L closepath F
.7127 .22747 0 2.5 Mabsadd m
.7127 .22747 -0.56518 .7779 Mabsadd L
.7127 .22747 -2.37764 .77254 Mabsadd L
.7127 .22747 -0.91448 -0.29713 Mabsadd L
.7127 .22747 -1.46946 -2.02254 Mabsadd L
.7127 .22747 0 -0.96154 Mabsadd L
.7127 .22747 1.46946 -2.02254 Mabsadd L
.7127 .22747 .91448 -0.29713 Mabsadd L
.7127 .22747 2.37764 .77254 Mabsadd L
.7127 .22747 .56518 .7779 Mabsadd L
.7127 .22747 0 2.5 Mabsadd L closepath F
.71587 .22725 0 2.5 Mabsadd m
.71587 .22725 -0.56518 .7779 Mabsadd L
.71587 .22725 -2.37764 .77254 Mabsadd L
.71587 .22725 -0.91448 -0.29713 Mabsadd L
.71587 .22725 -1.46946 -2.02254 Mabsadd L
.71587 .22725 0 -0.96154 Mabsadd L
.71587 .22725 1.46946 -2.02254 Mabsadd L
.71587 .22725 .91448 -0.29713 Mabsadd L
.71587 .22725 2.37764 .77254 Mabsadd L
.71587 .22725 .56518 .7779 Mabsadd L
.71587 .22725 0 2.5 Mabsadd L closepath F
.71905 .22704 0 2.5 Mabsadd m
.71905 .22704 -0.56518 .7779 Mabsadd L
.71905 .22704 -2.37764 .77254 Mabsadd L
.71905 .22704 -0.91448 -0.29713 Mabsadd L
.71905 .22704 -1.46946 -2.02254 Mabsadd L
.71905 .22704 0 -0.96154 Mabsadd L
.71905 .22704 1.46946 -2.02254 Mabsadd L
.71905 .22704 .91448 -0.29713 Mabsadd L
.71905 .22704 2.37764 .77254 Mabsadd L
.71905 .22704 .56518 .7779 Mabsadd L
.71905 .22704 0 2.5 Mabsadd L closepath F
.72222 .22682 0 2.5 Mabsadd m
.72222 .22682 -0.56518 .7779 Mabsadd L
.72222 .22682 -2.37764 .77254 Mabsadd L
.72222 .22682 -0.91448 -0.29713 Mabsadd L
.72222 .22682 -1.46946 -2.02254 Mabsadd L
.72222 .22682 0 -0.96154 Mabsadd L
.72222 .22682 1.46946 -2.02254 Mabsadd L
.72222 .22682 .91448 -0.29713 Mabsadd L
.72222 .22682 2.37764 .77254 Mabsadd L
.72222 .22682 .56518 .7779 Mabsadd L
.72222 .22682 0 2.5 Mabsadd L closepath F
.7254 .22661 0 2.5 Mabsadd m
.7254 .22661 -0.56518 .7779 Mabsadd L
.7254 .22661 -2.37764 .77254 Mabsadd L
.7254 .22661 -0.91448 -0.29713 Mabsadd L
.7254 .22661 -1.46946 -2.02254 Mabsadd L
.7254 .22661 0 -0.96154 Mabsadd L
.7254 .22661 1.46946 -2.02254 Mabsadd L
.7254 .22661 .91448 -0.29713 Mabsadd L
.7254 .22661 2.37764 .77254 Mabsadd L
.7254 .22661 .56518 .7779 Mabsadd L
.7254 .22661 0 2.5 Mabsadd L closepath F
.72857 .2264 0 2.5 Mabsadd m
.72857 .2264 -0.56518 .7779 Mabsadd L
.72857 .2264 -2.37764 .77254 Mabsadd L
.72857 .2264 -0.91448 -0.29713 Mabsadd L
.72857 .2264 -1.46946 -2.02254 Mabsadd L
.72857 .2264 0 -0.96154 Mabsadd L
.72857 .2264 1.46946 -2.02254 Mabsadd L
.72857 .2264 .91448 -0.29713 Mabsadd L
.72857 .2264 2.37764 .77254 Mabsadd L
.72857 .2264 .56518 .7779 Mabsadd L
.72857 .2264 0 2.5 Mabsadd L closepath F
.73175 .2262 0 2.5 Mabsadd m
.73175 .2262 -0.56518 .7779 Mabsadd L
.73175 .2262 -2.37764 .77254 Mabsadd L
.73175 .2262 -0.91448 -0.29713 Mabsadd L
.73175 .2262 -1.46946 -2.02254 Mabsadd L
.73175 .2262 0 -0.96154 Mabsadd L
.73175 .2262 1.46946 -2.02254 Mabsadd L
.73175 .2262 .91448 -0.29713 Mabsadd L
.73175 .2262 2.37764 .77254 Mabsadd L
.73175 .2262 .56518 .7779 Mabsadd L
.73175 .2262 0 2.5 Mabsadd L closepath F
.73492 .22599 0 2.5 Mabsadd m
.73492 .22599 -0.56518 .7779 Mabsadd L
.73492 .22599 -2.37764 .77254 Mabsadd L
.73492 .22599 -0.91448 -0.29713 Mabsadd L
.73492 .22599 -1.46946 -2.02254 Mabsadd L
.73492 .22599 0 -0.96154 Mabsadd L
.73492 .22599 1.46946 -2.02254 Mabsadd L
.73492 .22599 .91448 -0.29713 Mabsadd L
.73492 .22599 2.37764 .77254 Mabsadd L
.73492 .22599 .56518 .7779 Mabsadd L
.73492 .22599 0 2.5 Mabsadd L closepath F
.7381 .22579 0 2.5 Mabsadd m
.7381 .22579 -0.56518 .7779 Mabsadd L
.7381 .22579 -2.37764 .77254 Mabsadd L
.7381 .22579 -0.91448 -0.29713 Mabsadd L
.7381 .22579 -1.46946 -2.02254 Mabsadd L
.7381 .22579 0 -0.96154 Mabsadd L
.7381 .22579 1.46946 -2.02254 Mabsadd L
.7381 .22579 .91448 -0.29713 Mabsadd L
.7381 .22579 2.37764 .77254 Mabsadd L
.7381 .22579 .56518 .7779 Mabsadd L
.7381 .22579 0 2.5 Mabsadd L closepath F
.74127 .22559 0 2.5 Mabsadd m
.74127 .22559 -0.56518 .7779 Mabsadd L
.74127 .22559 -2.37764 .77254 Mabsadd L
.74127 .22559 -0.91448 -0.29713 Mabsadd L
.74127 .22559 -1.46946 -2.02254 Mabsadd L
.74127 .22559 0 -0.96154 Mabsadd L
.74127 .22559 1.46946 -2.02254 Mabsadd L
.74127 .22559 .91448 -0.29713 Mabsadd L
.74127 .22559 2.37764 .77254 Mabsadd L
.74127 .22559 .56518 .7779 Mabsadd L
.74127 .22559 0 2.5 Mabsadd L closepath F
.74444 .22539 0 2.5 Mabsadd m
.74444 .22539 -0.56518 .7779 Mabsadd L
.74444 .22539 -2.37764 .77254 Mabsadd L
.74444 .22539 -0.91448 -0.29713 Mabsadd L
.74444 .22539 -1.46946 -2.02254 Mabsadd L
.74444 .22539 0 -0.96154 Mabsadd L
.74444 .22539 1.46946 -2.02254 Mabsadd L
.74444 .22539 .91448 -0.29713 Mabsadd L
.74444 .22539 2.37764 .77254 Mabsadd L
.74444 .22539 .56518 .7779 Mabsadd L
.74444 .22539 0 2.5 Mabsadd L closepath F
.74762 .22519 0 2.5 Mabsadd m
.74762 .22519 -0.56518 .7779 Mabsadd L
.74762 .22519 -2.37764 .77254 Mabsadd L
.74762 .22519 -0.91448 -0.29713 Mabsadd L
.74762 .22519 -1.46946 -2.02254 Mabsadd L
.74762 .22519 0 -0.96154 Mabsadd L
.74762 .22519 1.46946 -2.02254 Mabsadd L
.74762 .22519 .91448 -0.29713 Mabsadd L
.74762 .22519 2.37764 .77254 Mabsadd L
.74762 .22519 .56518 .7779 Mabsadd L
.74762 .22519 0 2.5 Mabsadd L closepath F
.75079 .225 0 2.5 Mabsadd m
.75079 .225 -0.56518 .7779 Mabsadd L
.75079 .225 -2.37764 .77254 Mabsadd L
.75079 .225 -0.91448 -0.29713 Mabsadd L
.75079 .225 -1.46946 -2.02254 Mabsadd L
.75079 .225 0 -0.96154 Mabsadd L
.75079 .225 1.46946 -2.02254 Mabsadd L
.75079 .225 .91448 -0.29713 Mabsadd L
.75079 .225 2.37764 .77254 Mabsadd L
.75079 .225 .56518 .7779 Mabsadd L
.75079 .225 0 2.5 Mabsadd L closepath F
.75397 .2248 0 2.5 Mabsadd m
.75397 .2248 -0.56518 .7779 Mabsadd L
.75397 .2248 -2.37764 .77254 Mabsadd L
.75397 .2248 -0.91448 -0.29713 Mabsadd L
.75397 .2248 -1.46946 -2.02254 Mabsadd L
.75397 .2248 0 -0.96154 Mabsadd L
.75397 .2248 1.46946 -2.02254 Mabsadd L
.75397 .2248 .91448 -0.29713 Mabsadd L
.75397 .2248 2.37764 .77254 Mabsadd L
.75397 .2248 .56518 .7779 Mabsadd L
.75397 .2248 0 2.5 Mabsadd L closepath F
.75714 .22461 0 2.5 Mabsadd m
.75714 .22461 -0.56518 .7779 Mabsadd L
.75714 .22461 -2.37764 .77254 Mabsadd L
.75714 .22461 -0.91448 -0.29713 Mabsadd L
.75714 .22461 -1.46946 -2.02254 Mabsadd L
.75714 .22461 0 -0.96154 Mabsadd L
.75714 .22461 1.46946 -2.02254 Mabsadd L
.75714 .22461 .91448 -0.29713 Mabsadd L
.75714 .22461 2.37764 .77254 Mabsadd L
.75714 .22461 .56518 .7779 Mabsadd L
.75714 .22461 0 2.5 Mabsadd L closepath F
.76032 .22442 0 2.5 Mabsadd m
.76032 .22442 -0.56518 .7779 Mabsadd L
.76032 .22442 -2.37764 .77254 Mabsadd L
.76032 .22442 -0.91448 -0.29713 Mabsadd L
.76032 .22442 -1.46946 -2.02254 Mabsadd L
.76032 .22442 0 -0.96154 Mabsadd L
.76032 .22442 1.46946 -2.02254 Mabsadd L
.76032 .22442 .91448 -0.29713 Mabsadd L
.76032 .22442 2.37764 .77254 Mabsadd L
.76032 .22442 .56518 .7779 Mabsadd L
.76032 .22442 0 2.5 Mabsadd L closepath F
.76349 .22424 0 2.5 Mabsadd m
.76349 .22424 -0.56518 .7779 Mabsadd L
.76349 .22424 -2.37764 .77254 Mabsadd L
.76349 .22424 -0.91448 -0.29713 Mabsadd L
.76349 .22424 -1.46946 -2.02254 Mabsadd L
.76349 .22424 0 -0.96154 Mabsadd L
.76349 .22424 1.46946 -2.02254 Mabsadd L
.76349 .22424 .91448 -0.29713 Mabsadd L
.76349 .22424 2.37764 .77254 Mabsadd L
.76349 .22424 .56518 .7779 Mabsadd L
.76349 .22424 0 2.5 Mabsadd L closepath F
.76667 .22405 0 2.5 Mabsadd m
.76667 .22405 -0.56518 .7779 Mabsadd L
.76667 .22405 -2.37764 .77254 Mabsadd L
.76667 .22405 -0.91448 -0.29713 Mabsadd L
.76667 .22405 -1.46946 -2.02254 Mabsadd L
.76667 .22405 0 -0.96154 Mabsadd L
.76667 .22405 1.46946 -2.02254 Mabsadd L
.76667 .22405 .91448 -0.29713 Mabsadd L
.76667 .22405 2.37764 .77254 Mabsadd L
.76667 .22405 .56518 .7779 Mabsadd L
.76667 .22405 0 2.5 Mabsadd L closepath F
.76984 .22387 0 2.5 Mabsadd m
.76984 .22387 -0.56518 .7779 Mabsadd L
.76984 .22387 -2.37764 .77254 Mabsadd L
.76984 .22387 -0.91448 -0.29713 Mabsadd L
.76984 .22387 -1.46946 -2.02254 Mabsadd L
.76984 .22387 0 -0.96154 Mabsadd L
.76984 .22387 1.46946 -2.02254 Mabsadd L
.76984 .22387 .91448 -0.29713 Mabsadd L
.76984 .22387 2.37764 .77254 Mabsadd L
.76984 .22387 .56518 .7779 Mabsadd L
.76984 .22387 0 2.5 Mabsadd L closepath F
.77302 .22368 0 2.5 Mabsadd m
.77302 .22368 -0.56518 .7779 Mabsadd L
.77302 .22368 -2.37764 .77254 Mabsadd L
.77302 .22368 -0.91448 -0.29713 Mabsadd L
.77302 .22368 -1.46946 -2.02254 Mabsadd L
.77302 .22368 0 -0.96154 Mabsadd L
.77302 .22368 1.46946 -2.02254 Mabsadd L
.77302 .22368 .91448 -0.29713 Mabsadd L
.77302 .22368 2.37764 .77254 Mabsadd L
.77302 .22368 .56518 .7779 Mabsadd L
.77302 .22368 0 2.5 Mabsadd L closepath F
.77619 .2235 0 2.5 Mabsadd m
.77619 .2235 -0.56518 .7779 Mabsadd L
.77619 .2235 -2.37764 .77254 Mabsadd L
.77619 .2235 -0.91448 -0.29713 Mabsadd L
.77619 .2235 -1.46946 -2.02254 Mabsadd L
.77619 .2235 0 -0.96154 Mabsadd L
.77619 .2235 1.46946 -2.02254 Mabsadd L
.77619 .2235 .91448 -0.29713 Mabsadd L
.77619 .2235 2.37764 .77254 Mabsadd L
.77619 .2235 .56518 .7779 Mabsadd L
.77619 .2235 0 2.5 Mabsadd L closepath F
.77937 .22333 0 2.5 Mabsadd m
.77937 .22333 -0.56518 .7779 Mabsadd L
.77937 .22333 -2.37764 .77254 Mabsadd L
.77937 .22333 -0.91448 -0.29713 Mabsadd L
.77937 .22333 -1.46946 -2.02254 Mabsadd L
.77937 .22333 0 -0.96154 Mabsadd L
.77937 .22333 1.46946 -2.02254 Mabsadd L
.77937 .22333 .91448 -0.29713 Mabsadd L
.77937 .22333 2.37764 .77254 Mabsadd L
.77937 .22333 .56518 .7779 Mabsadd L
.77937 .22333 0 2.5 Mabsadd L closepath F
.78254 .22315 0 2.5 Mabsadd m
.78254 .22315 -0.56518 .7779 Mabsadd L
.78254 .22315 -2.37764 .77254 Mabsadd L
.78254 .22315 -0.91448 -0.29713 Mabsadd L
.78254 .22315 -1.46946 -2.02254 Mabsadd L
.78254 .22315 0 -0.96154 Mabsadd L
.78254 .22315 1.46946 -2.02254 Mabsadd L
.78254 .22315 .91448 -0.29713 Mabsadd L
.78254 .22315 2.37764 .77254 Mabsadd L
.78254 .22315 .56518 .7779 Mabsadd L
.78254 .22315 0 2.5 Mabsadd L closepath F
.78571 .22297 0 2.5 Mabsadd m
.78571 .22297 -0.56518 .7779 Mabsadd L
.78571 .22297 -2.37764 .77254 Mabsadd L
.78571 .22297 -0.91448 -0.29713 Mabsadd L
.78571 .22297 -1.46946 -2.02254 Mabsadd L
.78571 .22297 0 -0.96154 Mabsadd L
.78571 .22297 1.46946 -2.02254 Mabsadd L
.78571 .22297 .91448 -0.29713 Mabsadd L
.78571 .22297 2.37764 .77254 Mabsadd L
.78571 .22297 .56518 .7779 Mabsadd L
.78571 .22297 0 2.5 Mabsadd L closepath F
.78889 .2228 0 2.5 Mabsadd m
.78889 .2228 -0.56518 .7779 Mabsadd L
.78889 .2228 -2.37764 .77254 Mabsadd L
.78889 .2228 -0.91448 -0.29713 Mabsadd L
.78889 .2228 -1.46946 -2.02254 Mabsadd L
.78889 .2228 0 -0.96154 Mabsadd L
.78889 .2228 1.46946 -2.02254 Mabsadd L
.78889 .2228 .91448 -0.29713 Mabsadd L
.78889 .2228 2.37764 .77254 Mabsadd L
.78889 .2228 .56518 .7779 Mabsadd L
.78889 .2228 0 2.5 Mabsadd L closepath F
.79206 .22263 0 2.5 Mabsadd m
.79206 .22263 -0.56518 .7779 Mabsadd L
.79206 .22263 -2.37764 .77254 Mabsadd L
.79206 .22263 -0.91448 -0.29713 Mabsadd L
.79206 .22263 -1.46946 -2.02254 Mabsadd L
.79206 .22263 0 -0.96154 Mabsadd L
.79206 .22263 1.46946 -2.02254 Mabsadd L
.79206 .22263 .91448 -0.29713 Mabsadd L
.79206 .22263 2.37764 .77254 Mabsadd L
.79206 .22263 .56518 .7779 Mabsadd L
.79206 .22263 0 2.5 Mabsadd L closepath F
.79524 .22246 0 2.5 Mabsadd m
.79524 .22246 -0.56518 .7779 Mabsadd L
.79524 .22246 -2.37764 .77254 Mabsadd L
.79524 .22246 -0.91448 -0.29713 Mabsadd L
.79524 .22246 -1.46946 -2.02254 Mabsadd L
.79524 .22246 0 -0.96154 Mabsadd L
.79524 .22246 1.46946 -2.02254 Mabsadd L
.79524 .22246 .91448 -0.29713 Mabsadd L
.79524 .22246 2.37764 .77254 Mabsadd L
.79524 .22246 .56518 .7779 Mabsadd L
.79524 .22246 0 2.5 Mabsadd L closepath F
.79841 .22229 0 2.5 Mabsadd m
.79841 .22229 -0.56518 .7779 Mabsadd L
.79841 .22229 -2.37764 .77254 Mabsadd L
.79841 .22229 -0.91448 -0.29713 Mabsadd L
.79841 .22229 -1.46946 -2.02254 Mabsadd L
.79841 .22229 0 -0.96154 Mabsadd L
.79841 .22229 1.46946 -2.02254 Mabsadd L
.79841 .22229 .91448 -0.29713 Mabsadd L
.79841 .22229 2.37764 .77254 Mabsadd L
.79841 .22229 .56518 .7779 Mabsadd L
.79841 .22229 0 2.5 Mabsadd L closepath F
.80159 .22213 0 2.5 Mabsadd m
.80159 .22213 -0.56518 .7779 Mabsadd L
.80159 .22213 -2.37764 .77254 Mabsadd L
.80159 .22213 -0.91448 -0.29713 Mabsadd L
.80159 .22213 -1.46946 -2.02254 Mabsadd L
.80159 .22213 0 -0.96154 Mabsadd L
.80159 .22213 1.46946 -2.02254 Mabsadd L
.80159 .22213 .91448 -0.29713 Mabsadd L
.80159 .22213 2.37764 .77254 Mabsadd L
.80159 .22213 .56518 .7779 Mabsadd L
.80159 .22213 0 2.5 Mabsadd L closepath F
.80476 .22196 0 2.5 Mabsadd m
.80476 .22196 -0.56518 .7779 Mabsadd L
.80476 .22196 -2.37764 .77254 Mabsadd L
.80476 .22196 -0.91448 -0.29713 Mabsadd L
.80476 .22196 -1.46946 -2.02254 Mabsadd L
.80476 .22196 0 -0.96154 Mabsadd L
.80476 .22196 1.46946 -2.02254 Mabsadd L
.80476 .22196 .91448 -0.29713 Mabsadd L
.80476 .22196 2.37764 .77254 Mabsadd L
.80476 .22196 .56518 .7779 Mabsadd L
.80476 .22196 0 2.5 Mabsadd L closepath F
.80794 .2218 0 2.5 Mabsadd m
.80794 .2218 -0.56518 .7779 Mabsadd L
.80794 .2218 -2.37764 .77254 Mabsadd L
.80794 .2218 -0.91448 -0.29713 Mabsadd L
.80794 .2218 -1.46946 -2.02254 Mabsadd L
.80794 .2218 0 -0.96154 Mabsadd L
.80794 .2218 1.46946 -2.02254 Mabsadd L
.80794 .2218 .91448 -0.29713 Mabsadd L
.80794 .2218 2.37764 .77254 Mabsadd L
.80794 .2218 .56518 .7779 Mabsadd L
.80794 .2218 0 2.5 Mabsadd L closepath F
.81111 .22164 0 2.5 Mabsadd m
.81111 .22164 -0.56518 .7779 Mabsadd L
.81111 .22164 -2.37764 .77254 Mabsadd L
.81111 .22164 -0.91448 -0.29713 Mabsadd L
.81111 .22164 -1.46946 -2.02254 Mabsadd L
.81111 .22164 0 -0.96154 Mabsadd L
.81111 .22164 1.46946 -2.02254 Mabsadd L
.81111 .22164 .91448 -0.29713 Mabsadd L
.81111 .22164 2.37764 .77254 Mabsadd L
.81111 .22164 .56518 .7779 Mabsadd L
.81111 .22164 0 2.5 Mabsadd L closepath F
.81429 .22148 0 2.5 Mabsadd m
.81429 .22148 -0.56518 .7779 Mabsadd L
.81429 .22148 -2.37764 .77254 Mabsadd L
.81429 .22148 -0.91448 -0.29713 Mabsadd L
.81429 .22148 -1.46946 -2.02254 Mabsadd L
.81429 .22148 0 -0.96154 Mabsadd L
.81429 .22148 1.46946 -2.02254 Mabsadd L
.81429 .22148 .91448 -0.29713 Mabsadd L
.81429 .22148 2.37764 .77254 Mabsadd L
.81429 .22148 .56518 .7779 Mabsadd L
.81429 .22148 0 2.5 Mabsadd L closepath F
.81746 .22132 0 2.5 Mabsadd m
.81746 .22132 -0.56518 .7779 Mabsadd L
.81746 .22132 -2.37764 .77254 Mabsadd L
.81746 .22132 -0.91448 -0.29713 Mabsadd L
.81746 .22132 -1.46946 -2.02254 Mabsadd L
.81746 .22132 0 -0.96154 Mabsadd L
.81746 .22132 1.46946 -2.02254 Mabsadd L
.81746 .22132 .91448 -0.29713 Mabsadd L
.81746 .22132 2.37764 .77254 Mabsadd L
.81746 .22132 .56518 .7779 Mabsadd L
.81746 .22132 0 2.5 Mabsadd L closepath F
.82063 .22117 0 2.5 Mabsadd m
.82063 .22117 -0.56518 .7779 Mabsadd L
.82063 .22117 -2.37764 .77254 Mabsadd L
.82063 .22117 -0.91448 -0.29713 Mabsadd L
.82063 .22117 -1.46946 -2.02254 Mabsadd L
.82063 .22117 0 -0.96154 Mabsadd L
.82063 .22117 1.46946 -2.02254 Mabsadd L
.82063 .22117 .91448 -0.29713 Mabsadd L
.82063 .22117 2.37764 .77254 Mabsadd L
.82063 .22117 .56518 .7779 Mabsadd L
.82063 .22117 0 2.5 Mabsadd L closepath F
.82381 .22101 0 2.5 Mabsadd m
.82381 .22101 -0.56518 .7779 Mabsadd L
.82381 .22101 -2.37764 .77254 Mabsadd L
.82381 .22101 -0.91448 -0.29713 Mabsadd L
.82381 .22101 -1.46946 -2.02254 Mabsadd L
.82381 .22101 0 -0.96154 Mabsadd L
.82381 .22101 1.46946 -2.02254 Mabsadd L
.82381 .22101 .91448 -0.29713 Mabsadd L
.82381 .22101 2.37764 .77254 Mabsadd L
.82381 .22101 .56518 .7779 Mabsadd L
.82381 .22101 0 2.5 Mabsadd L closepath F
.82698 .22086 0 2.5 Mabsadd m
.82698 .22086 -0.56518 .7779 Mabsadd L
.82698 .22086 -2.37764 .77254 Mabsadd L
.82698 .22086 -0.91448 -0.29713 Mabsadd L
.82698 .22086 -1.46946 -2.02254 Mabsadd L
.82698 .22086 0 -0.96154 Mabsadd L
.82698 .22086 1.46946 -2.02254 Mabsadd L
.82698 .22086 .91448 -0.29713 Mabsadd L
.82698 .22086 2.37764 .77254 Mabsadd L
.82698 .22086 .56518 .7779 Mabsadd L
.82698 .22086 0 2.5 Mabsadd L closepath F
.83016 .22071 0 2.5 Mabsadd m
.83016 .22071 -0.56518 .7779 Mabsadd L
.83016 .22071 -2.37764 .77254 Mabsadd L
.83016 .22071 -0.91448 -0.29713 Mabsadd L
.83016 .22071 -1.46946 -2.02254 Mabsadd L
.83016 .22071 0 -0.96154 Mabsadd L
.83016 .22071 1.46946 -2.02254 Mabsadd L
.83016 .22071 .91448 -0.29713 Mabsadd L
.83016 .22071 2.37764 .77254 Mabsadd L
.83016 .22071 .56518 .7779 Mabsadd L
.83016 .22071 0 2.5 Mabsadd L closepath F
.83333 .22056 0 2.5 Mabsadd m
.83333 .22056 -0.56518 .7779 Mabsadd L
.83333 .22056 -2.37764 .77254 Mabsadd L
.83333 .22056 -0.91448 -0.29713 Mabsadd L
.83333 .22056 -1.46946 -2.02254 Mabsadd L
.83333 .22056 0 -0.96154 Mabsadd L
.83333 .22056 1.46946 -2.02254 Mabsadd L
.83333 .22056 .91448 -0.29713 Mabsadd L
.83333 .22056 2.37764 .77254 Mabsadd L
.83333 .22056 .56518 .7779 Mabsadd L
.83333 .22056 0 2.5 Mabsadd L closepath F
.83651 .22041 0 2.5 Mabsadd m
.83651 .22041 -0.56518 .7779 Mabsadd L
.83651 .22041 -2.37764 .77254 Mabsadd L
.83651 .22041 -0.91448 -0.29713 Mabsadd L
.83651 .22041 -1.46946 -2.02254 Mabsadd L
.83651 .22041 0 -0.96154 Mabsadd L
.83651 .22041 1.46946 -2.02254 Mabsadd L
.83651 .22041 .91448 -0.29713 Mabsadd L
.83651 .22041 2.37764 .77254 Mabsadd L
.83651 .22041 .56518 .7779 Mabsadd L
.83651 .22041 0 2.5 Mabsadd L closepath F
.83968 .22026 0 2.5 Mabsadd m
.83968 .22026 -0.56518 .7779 Mabsadd L
.83968 .22026 -2.37764 .77254 Mabsadd L
.83968 .22026 -0.91448 -0.29713 Mabsadd L
.83968 .22026 -1.46946 -2.02254 Mabsadd L
.83968 .22026 0 -0.96154 Mabsadd L
.83968 .22026 1.46946 -2.02254 Mabsadd L
.83968 .22026 .91448 -0.29713 Mabsadd L
.83968 .22026 2.37764 .77254 Mabsadd L
.83968 .22026 .56518 .7779 Mabsadd L
.83968 .22026 0 2.5 Mabsadd L closepath F
.84286 .22011 0 2.5 Mabsadd m
.84286 .22011 -0.56518 .7779 Mabsadd L
.84286 .22011 -2.37764 .77254 Mabsadd L
.84286 .22011 -0.91448 -0.29713 Mabsadd L
.84286 .22011 -1.46946 -2.02254 Mabsadd L
.84286 .22011 0 -0.96154 Mabsadd L
.84286 .22011 1.46946 -2.02254 Mabsadd L
.84286 .22011 .91448 -0.29713 Mabsadd L
.84286 .22011 2.37764 .77254 Mabsadd L
.84286 .22011 .56518 .7779 Mabsadd L
.84286 .22011 0 2.5 Mabsadd L closepath F
.84603 .21997 0 2.5 Mabsadd m
.84603 .21997 -0.56518 .7779 Mabsadd L
.84603 .21997 -2.37764 .77254 Mabsadd L
.84603 .21997 -0.91448 -0.29713 Mabsadd L
.84603 .21997 -1.46946 -2.02254 Mabsadd L
.84603 .21997 0 -0.96154 Mabsadd L
.84603 .21997 1.46946 -2.02254 Mabsadd L
.84603 .21997 .91448 -0.29713 Mabsadd L
.84603 .21997 2.37764 .77254 Mabsadd L
.84603 .21997 .56518 .7779 Mabsadd L
.84603 .21997 0 2.5 Mabsadd L closepath F
.84921 .21983 0 2.5 Mabsadd m
.84921 .21983 -0.56518 .7779 Mabsadd L
.84921 .21983 -2.37764 .77254 Mabsadd L
.84921 .21983 -0.91448 -0.29713 Mabsadd L
.84921 .21983 -1.46946 -2.02254 Mabsadd L
.84921 .21983 0 -0.96154 Mabsadd L
.84921 .21983 1.46946 -2.02254 Mabsadd L
.84921 .21983 .91448 -0.29713 Mabsadd L
.84921 .21983 2.37764 .77254 Mabsadd L
.84921 .21983 .56518 .7779 Mabsadd L
.84921 .21983 0 2.5 Mabsadd L closepath F
.85238 .21969 0 2.5 Mabsadd m
.85238 .21969 -0.56518 .7779 Mabsadd L
.85238 .21969 -2.37764 .77254 Mabsadd L
.85238 .21969 -0.91448 -0.29713 Mabsadd L
.85238 .21969 -1.46946 -2.02254 Mabsadd L
.85238 .21969 0 -0.96154 Mabsadd L
.85238 .21969 1.46946 -2.02254 Mabsadd L
.85238 .21969 .91448 -0.29713 Mabsadd L
.85238 .21969 2.37764 .77254 Mabsadd L
.85238 .21969 .56518 .7779 Mabsadd L
.85238 .21969 0 2.5 Mabsadd L closepath F
.85556 .21955 0 2.5 Mabsadd m
.85556 .21955 -0.56518 .7779 Mabsadd L
.85556 .21955 -2.37764 .77254 Mabsadd L
.85556 .21955 -0.91448 -0.29713 Mabsadd L
.85556 .21955 -1.46946 -2.02254 Mabsadd L
.85556 .21955 0 -0.96154 Mabsadd L
.85556 .21955 1.46946 -2.02254 Mabsadd L
.85556 .21955 .91448 -0.29713 Mabsadd L
.85556 .21955 2.37764 .77254 Mabsadd L
.85556 .21955 .56518 .7779 Mabsadd L
.85556 .21955 0 2.5 Mabsadd L closepath F
.85873 .21941 0 2.5 Mabsadd m
.85873 .21941 -0.56518 .7779 Mabsadd L
.85873 .21941 -2.37764 .77254 Mabsadd L
.85873 .21941 -0.91448 -0.29713 Mabsadd L
.85873 .21941 -1.46946 -2.02254 Mabsadd L
.85873 .21941 0 -0.96154 Mabsadd L
.85873 .21941 1.46946 -2.02254 Mabsadd L
.85873 .21941 .91448 -0.29713 Mabsadd L
.85873 .21941 2.37764 .77254 Mabsadd L
.85873 .21941 .56518 .7779 Mabsadd L
.85873 .21941 0 2.5 Mabsadd L closepath F
.8619 .21927 0 2.5 Mabsadd m
.8619 .21927 -0.56518 .7779 Mabsadd L
.8619 .21927 -2.37764 .77254 Mabsadd L
.8619 .21927 -0.91448 -0.29713 Mabsadd L
.8619 .21927 -1.46946 -2.02254 Mabsadd L
.8619 .21927 0 -0.96154 Mabsadd L
.8619 .21927 1.46946 -2.02254 Mabsadd L
.8619 .21927 .91448 -0.29713 Mabsadd L
.8619 .21927 2.37764 .77254 Mabsadd L
.8619 .21927 .56518 .7779 Mabsadd L
.8619 .21927 0 2.5 Mabsadd L closepath F
.86508 .21913 0 2.5 Mabsadd m
.86508 .21913 -0.56518 .7779 Mabsadd L
.86508 .21913 -2.37764 .77254 Mabsadd L
.86508 .21913 -0.91448 -0.29713 Mabsadd L
.86508 .21913 -1.46946 -2.02254 Mabsadd L
.86508 .21913 0 -0.96154 Mabsadd L
.86508 .21913 1.46946 -2.02254 Mabsadd L
.86508 .21913 .91448 -0.29713 Mabsadd L
.86508 .21913 2.37764 .77254 Mabsadd L
.86508 .21913 .56518 .7779 Mabsadd L
.86508 .21913 0 2.5 Mabsadd L closepath F
.86825 .219 0 2.5 Mabsadd m
.86825 .219 -0.56518 .7779 Mabsadd L
.86825 .219 -2.37764 .77254 Mabsadd L
.86825 .219 -0.91448 -0.29713 Mabsadd L
.86825 .219 -1.46946 -2.02254 Mabsadd L
.86825 .219 0 -0.96154 Mabsadd L
.86825 .219 1.46946 -2.02254 Mabsadd L
.86825 .219 .91448 -0.29713 Mabsadd L
.86825 .219 2.37764 .77254 Mabsadd L
.86825 .219 .56518 .7779 Mabsadd L
.86825 .219 0 2.5 Mabsadd L closepath F
.87143 .21887 0 2.5 Mabsadd m
.87143 .21887 -0.56518 .7779 Mabsadd L
.87143 .21887 -2.37764 .77254 Mabsadd L
.87143 .21887 -0.91448 -0.29713 Mabsadd L
.87143 .21887 -1.46946 -2.02254 Mabsadd L
.87143 .21887 0 -0.96154 Mabsadd L
.87143 .21887 1.46946 -2.02254 Mabsadd L
.87143 .21887 .91448 -0.29713 Mabsadd L
.87143 .21887 2.37764 .77254 Mabsadd L
.87143 .21887 .56518 .7779 Mabsadd L
.87143 .21887 0 2.5 Mabsadd L closepath F
.8746 .21873 0 2.5 Mabsadd m
.8746 .21873 -0.56518 .7779 Mabsadd L
.8746 .21873 -2.37764 .77254 Mabsadd L
.8746 .21873 -0.91448 -0.29713 Mabsadd L
.8746 .21873 -1.46946 -2.02254 Mabsadd L
.8746 .21873 0 -0.96154 Mabsadd L
.8746 .21873 1.46946 -2.02254 Mabsadd L
.8746 .21873 .91448 -0.29713 Mabsadd L
.8746 .21873 2.37764 .77254 Mabsadd L
.8746 .21873 .56518 .7779 Mabsadd L
.8746 .21873 0 2.5 Mabsadd L closepath F
.87778 .2186 0 2.5 Mabsadd m
.87778 .2186 -0.56518 .7779 Mabsadd L
.87778 .2186 -2.37764 .77254 Mabsadd L
.87778 .2186 -0.91448 -0.29713 Mabsadd L
.87778 .2186 -1.46946 -2.02254 Mabsadd L
.87778 .2186 0 -0.96154 Mabsadd L
.87778 .2186 1.46946 -2.02254 Mabsadd L
.87778 .2186 .91448 -0.29713 Mabsadd L
.87778 .2186 2.37764 .77254 Mabsadd L
.87778 .2186 .56518 .7779 Mabsadd L
.87778 .2186 0 2.5 Mabsadd L closepath F
.88095 .21847 0 2.5 Mabsadd m
.88095 .21847 -0.56518 .7779 Mabsadd L
.88095 .21847 -2.37764 .77254 Mabsadd L
.88095 .21847 -0.91448 -0.29713 Mabsadd L
.88095 .21847 -1.46946 -2.02254 Mabsadd L
.88095 .21847 0 -0.96154 Mabsadd L
.88095 .21847 1.46946 -2.02254 Mabsadd L
.88095 .21847 .91448 -0.29713 Mabsadd L
.88095 .21847 2.37764 .77254 Mabsadd L
.88095 .21847 .56518 .7779 Mabsadd L
.88095 .21847 0 2.5 Mabsadd L closepath F
.88413 .21835 0 2.5 Mabsadd m
.88413 .21835 -0.56518 .7779 Mabsadd L
.88413 .21835 -2.37764 .77254 Mabsadd L
.88413 .21835 -0.91448 -0.29713 Mabsadd L
.88413 .21835 -1.46946 -2.02254 Mabsadd L
.88413 .21835 0 -0.96154 Mabsadd L
.88413 .21835 1.46946 -2.02254 Mabsadd L
.88413 .21835 .91448 -0.29713 Mabsadd L
.88413 .21835 2.37764 .77254 Mabsadd L
.88413 .21835 .56518 .7779 Mabsadd L
.88413 .21835 0 2.5 Mabsadd L closepath F
.8873 .21822 0 2.5 Mabsadd m
.8873 .21822 -0.56518 .7779 Mabsadd L
.8873 .21822 -2.37764 .77254 Mabsadd L
.8873 .21822 -0.91448 -0.29713 Mabsadd L
.8873 .21822 -1.46946 -2.02254 Mabsadd L
.8873 .21822 0 -0.96154 Mabsadd L
.8873 .21822 1.46946 -2.02254 Mabsadd L
.8873 .21822 .91448 -0.29713 Mabsadd L
.8873 .21822 2.37764 .77254 Mabsadd L
.8873 .21822 .56518 .7779 Mabsadd L
.8873 .21822 0 2.5 Mabsadd L closepath F
.89048 .21809 0 2.5 Mabsadd m
.89048 .21809 -0.56518 .7779 Mabsadd L
.89048 .21809 -2.37764 .77254 Mabsadd L
.89048 .21809 -0.91448 -0.29713 Mabsadd L
.89048 .21809 -1.46946 -2.02254 Mabsadd L
.89048 .21809 0 -0.96154 Mabsadd L
.89048 .21809 1.46946 -2.02254 Mabsadd L
.89048 .21809 .91448 -0.29713 Mabsadd L
.89048 .21809 2.37764 .77254 Mabsadd L
.89048 .21809 .56518 .7779 Mabsadd L
.89048 .21809 0 2.5 Mabsadd L closepath F
.89365 .21797 0 2.5 Mabsadd m
.89365 .21797 -0.56518 .7779 Mabsadd L
.89365 .21797 -2.37764 .77254 Mabsadd L
.89365 .21797 -0.91448 -0.29713 Mabsadd L
.89365 .21797 -1.46946 -2.02254 Mabsadd L
.89365 .21797 0 -0.96154 Mabsadd L
.89365 .21797 1.46946 -2.02254 Mabsadd L
.89365 .21797 .91448 -0.29713 Mabsadd L
.89365 .21797 2.37764 .77254 Mabsadd L
.89365 .21797 .56518 .7779 Mabsadd L
.89365 .21797 0 2.5 Mabsadd L closepath F
.89683 .21785 0 2.5 Mabsadd m
.89683 .21785 -0.56518 .7779 Mabsadd L
.89683 .21785 -2.37764 .77254 Mabsadd L
.89683 .21785 -0.91448 -0.29713 Mabsadd L
.89683 .21785 -1.46946 -2.02254 Mabsadd L
.89683 .21785 0 -0.96154 Mabsadd L
.89683 .21785 1.46946 -2.02254 Mabsadd L
.89683 .21785 .91448 -0.29713 Mabsadd L
.89683 .21785 2.37764 .77254 Mabsadd L
.89683 .21785 .56518 .7779 Mabsadd L
.89683 .21785 0 2.5 Mabsadd L closepath F
.9 .21773 0 2.5 Mabsadd m
.9 .21773 -0.56518 .7779 Mabsadd L
.9 .21773 -2.37764 .77254 Mabsadd L
.9 .21773 -0.91448 -0.29713 Mabsadd L
.9 .21773 -1.46946 -2.02254 Mabsadd L
.9 .21773 0 -0.96154 Mabsadd L
.9 .21773 1.46946 -2.02254 Mabsadd L
.9 .21773 .91448 -0.29713 Mabsadd L
.9 .21773 2.37764 .77254 Mabsadd L
.9 .21773 .56518 .7779 Mabsadd L
.9 .21773 0 2.5 Mabsadd L closepath F
.90317 .21761 0 2.5 Mabsadd m
.90317 .21761 -0.56518 .7779 Mabsadd L
.90317 .21761 -2.37764 .77254 Mabsadd L
.90317 .21761 -0.91448 -0.29713 Mabsadd L
.90317 .21761 -1.46946 -2.02254 Mabsadd L
.90317 .21761 0 -0.96154 Mabsadd L
.90317 .21761 1.46946 -2.02254 Mabsadd L
.90317 .21761 .91448 -0.29713 Mabsadd L
.90317 .21761 2.37764 .77254 Mabsadd L
.90317 .21761 .56518 .7779 Mabsadd L
.90317 .21761 0 2.5 Mabsadd L closepath F
.90635 .21749 0 2.5 Mabsadd m
.90635 .21749 -0.56518 .7779 Mabsadd L
.90635 .21749 -2.37764 .77254 Mabsadd L
.90635 .21749 -0.91448 -0.29713 Mabsadd L
.90635 .21749 -1.46946 -2.02254 Mabsadd L
.90635 .21749 0 -0.96154 Mabsadd L
.90635 .21749 1.46946 -2.02254 Mabsadd L
.90635 .21749 .91448 -0.29713 Mabsadd L
.90635 .21749 2.37764 .77254 Mabsadd L
.90635 .21749 .56518 .7779 Mabsadd L
.90635 .21749 0 2.5 Mabsadd L closepath F
.90952 .21737 0 2.5 Mabsadd m
.90952 .21737 -0.56518 .7779 Mabsadd L
.90952 .21737 -2.37764 .77254 Mabsadd L
.90952 .21737 -0.91448 -0.29713 Mabsadd L
.90952 .21737 -1.46946 -2.02254 Mabsadd L
.90952 .21737 0 -0.96154 Mabsadd L
.90952 .21737 1.46946 -2.02254 Mabsadd L
.90952 .21737 .91448 -0.29713 Mabsadd L
.90952 .21737 2.37764 .77254 Mabsadd L
.90952 .21737 .56518 .7779 Mabsadd L
.90952 .21737 0 2.5 Mabsadd L closepath F
.9127 .21725 0 2.5 Mabsadd m
.9127 .21725 -0.56518 .7779 Mabsadd L
.9127 .21725 -2.37764 .77254 Mabsadd L
.9127 .21725 -0.91448 -0.29713 Mabsadd L
.9127 .21725 -1.46946 -2.02254 Mabsadd L
.9127 .21725 0 -0.96154 Mabsadd L
.9127 .21725 1.46946 -2.02254 Mabsadd L
.9127 .21725 .91448 -0.29713 Mabsadd L
.9127 .21725 2.37764 .77254 Mabsadd L
.9127 .21725 .56518 .7779 Mabsadd L
.9127 .21725 0 2.5 Mabsadd L closepath F
.91587 .21714 0 2.5 Mabsadd m
.91587 .21714 -0.56518 .7779 Mabsadd L
.91587 .21714 -2.37764 .77254 Mabsadd L
.91587 .21714 -0.91448 -0.29713 Mabsadd L
.91587 .21714 -1.46946 -2.02254 Mabsadd L
.91587 .21714 0 -0.96154 Mabsadd L
.91587 .21714 1.46946 -2.02254 Mabsadd L
.91587 .21714 .91448 -0.29713 Mabsadd L
.91587 .21714 2.37764 .77254 Mabsadd L
.91587 .21714 .56518 .7779 Mabsadd L
.91587 .21714 0 2.5 Mabsadd L closepath F
.91905 .21702 0 2.5 Mabsadd m
.91905 .21702 -0.56518 .7779 Mabsadd L
.91905 .21702 -2.37764 .77254 Mabsadd L
.91905 .21702 -0.91448 -0.29713 Mabsadd L
.91905 .21702 -1.46946 -2.02254 Mabsadd L
.91905 .21702 0 -0.96154 Mabsadd L
.91905 .21702 1.46946 -2.02254 Mabsadd L
.91905 .21702 .91448 -0.29713 Mabsadd L
.91905 .21702 2.37764 .77254 Mabsadd L
.91905 .21702 .56518 .7779 Mabsadd L
.91905 .21702 0 2.5 Mabsadd L closepath F
.92222 .21691 0 2.5 Mabsadd m
.92222 .21691 -0.56518 .7779 Mabsadd L
.92222 .21691 -2.37764 .77254 Mabsadd L
.92222 .21691 -0.91448 -0.29713 Mabsadd L
.92222 .21691 -1.46946 -2.02254 Mabsadd L
.92222 .21691 0 -0.96154 Mabsadd L
.92222 .21691 1.46946 -2.02254 Mabsadd L
.92222 .21691 .91448 -0.29713 Mabsadd L
.92222 .21691 2.37764 .77254 Mabsadd L
.92222 .21691 .56518 .7779 Mabsadd L
.92222 .21691 0 2.5 Mabsadd L closepath F
.9254 .2168 0 2.5 Mabsadd m
.9254 .2168 -0.56518 .7779 Mabsadd L
.9254 .2168 -2.37764 .77254 Mabsadd L
.9254 .2168 -0.91448 -0.29713 Mabsadd L
.9254 .2168 -1.46946 -2.02254 Mabsadd L
.9254 .2168 0 -0.96154 Mabsadd L
.9254 .2168 1.46946 -2.02254 Mabsadd L
.9254 .2168 .91448 -0.29713 Mabsadd L
.9254 .2168 2.37764 .77254 Mabsadd L
.9254 .2168 .56518 .7779 Mabsadd L
.9254 .2168 0 2.5 Mabsadd L closepath F
.92857 .21668 0 2.5 Mabsadd m
.92857 .21668 -0.56518 .7779 Mabsadd L
.92857 .21668 -2.37764 .77254 Mabsadd L
.92857 .21668 -0.91448 -0.29713 Mabsadd L
.92857 .21668 -1.46946 -2.02254 Mabsadd L
.92857 .21668 0 -0.96154 Mabsadd L
.92857 .21668 1.46946 -2.02254 Mabsadd L
.92857 .21668 .91448 -0.29713 Mabsadd L
.92857 .21668 2.37764 .77254 Mabsadd L
.92857 .21668 .56518 .7779 Mabsadd L
.92857 .21668 0 2.5 Mabsadd L closepath F
.93175 .21657 0 2.5 Mabsadd m
.93175 .21657 -0.56518 .7779 Mabsadd L
.93175 .21657 -2.37764 .77254 Mabsadd L
.93175 .21657 -0.91448 -0.29713 Mabsadd L
.93175 .21657 -1.46946 -2.02254 Mabsadd L
.93175 .21657 0 -0.96154 Mabsadd L
.93175 .21657 1.46946 -2.02254 Mabsadd L
.93175 .21657 .91448 -0.29713 Mabsadd L
.93175 .21657 2.37764 .77254 Mabsadd L
.93175 .21657 .56518 .7779 Mabsadd L
.93175 .21657 0 2.5 Mabsadd L closepath F
.93492 .21647 0 2.5 Mabsadd m
.93492 .21647 -0.56518 .7779 Mabsadd L
.93492 .21647 -2.37764 .77254 Mabsadd L
.93492 .21647 -0.91448 -0.29713 Mabsadd L
.93492 .21647 -1.46946 -2.02254 Mabsadd L
.93492 .21647 0 -0.96154 Mabsadd L
.93492 .21647 1.46946 -2.02254 Mabsadd L
.93492 .21647 .91448 -0.29713 Mabsadd L
.93492 .21647 2.37764 .77254 Mabsadd L
.93492 .21647 .56518 .7779 Mabsadd L
.93492 .21647 0 2.5 Mabsadd L closepath F
.9381 .21636 0 2.5 Mabsadd m
.9381 .21636 -0.56518 .7779 Mabsadd L
.9381 .21636 -2.37764 .77254 Mabsadd L
.9381 .21636 -0.91448 -0.29713 Mabsadd L
.9381 .21636 -1.46946 -2.02254 Mabsadd L
.9381 .21636 0 -0.96154 Mabsadd L
.9381 .21636 1.46946 -2.02254 Mabsadd L
.9381 .21636 .91448 -0.29713 Mabsadd L
.9381 .21636 2.37764 .77254 Mabsadd L
.9381 .21636 .56518 .7779 Mabsadd L
.9381 .21636 0 2.5 Mabsadd L closepath F
.94127 .21625 0 2.5 Mabsadd m
.94127 .21625 -0.56518 .7779 Mabsadd L
.94127 .21625 -2.37764 .77254 Mabsadd L
.94127 .21625 -0.91448 -0.29713 Mabsadd L
.94127 .21625 -1.46946 -2.02254 Mabsadd L
.94127 .21625 0 -0.96154 Mabsadd L
.94127 .21625 1.46946 -2.02254 Mabsadd L
.94127 .21625 .91448 -0.29713 Mabsadd L
.94127 .21625 2.37764 .77254 Mabsadd L
.94127 .21625 .56518 .7779 Mabsadd L
.94127 .21625 0 2.5 Mabsadd L closepath F
.94444 .21615 0 2.5 Mabsadd m
.94444 .21615 -0.56518 .7779 Mabsadd L
.94444 .21615 -2.37764 .77254 Mabsadd L
.94444 .21615 -0.91448 -0.29713 Mabsadd L
.94444 .21615 -1.46946 -2.02254 Mabsadd L
.94444 .21615 0 -0.96154 Mabsadd L
.94444 .21615 1.46946 -2.02254 Mabsadd L
.94444 .21615 .91448 -0.29713 Mabsadd L
.94444 .21615 2.37764 .77254 Mabsadd L
.94444 .21615 .56518 .7779 Mabsadd L
.94444 .21615 0 2.5 Mabsadd L closepath F
.94762 .21604 0 2.5 Mabsadd m
.94762 .21604 -0.56518 .7779 Mabsadd L
.94762 .21604 -2.37764 .77254 Mabsadd L
.94762 .21604 -0.91448 -0.29713 Mabsadd L
.94762 .21604 -1.46946 -2.02254 Mabsadd L
.94762 .21604 0 -0.96154 Mabsadd L
.94762 .21604 1.46946 -2.02254 Mabsadd L
.94762 .21604 .91448 -0.29713 Mabsadd L
.94762 .21604 2.37764 .77254 Mabsadd L
.94762 .21604 .56518 .7779 Mabsadd L
.94762 .21604 0 2.5 Mabsadd L closepath F
.95079 .21594 0 2.5 Mabsadd m
.95079 .21594 -0.56518 .7779 Mabsadd L
.95079 .21594 -2.37764 .77254 Mabsadd L
.95079 .21594 -0.91448 -0.29713 Mabsadd L
.95079 .21594 -1.46946 -2.02254 Mabsadd L
.95079 .21594 0 -0.96154 Mabsadd L
.95079 .21594 1.46946 -2.02254 Mabsadd L
.95079 .21594 .91448 -0.29713 Mabsadd L
.95079 .21594 2.37764 .77254 Mabsadd L
.95079 .21594 .56518 .7779 Mabsadd L
.95079 .21594 0 2.5 Mabsadd L closepath F
.95397 .21584 0 2.5 Mabsadd m
.95397 .21584 -0.56518 .7779 Mabsadd L
.95397 .21584 -2.37764 .77254 Mabsadd L
.95397 .21584 -0.91448 -0.29713 Mabsadd L
.95397 .21584 -1.46946 -2.02254 Mabsadd L
.95397 .21584 0 -0.96154 Mabsadd L
.95397 .21584 1.46946 -2.02254 Mabsadd L
.95397 .21584 .91448 -0.29713 Mabsadd L
.95397 .21584 2.37764 .77254 Mabsadd L
.95397 .21584 .56518 .7779 Mabsadd L
.95397 .21584 0 2.5 Mabsadd L closepath F
.95714 .21573 0 2.5 Mabsadd m
.95714 .21573 -0.56518 .7779 Mabsadd L
.95714 .21573 -2.37764 .77254 Mabsadd L
.95714 .21573 -0.91448 -0.29713 Mabsadd L
.95714 .21573 -1.46946 -2.02254 Mabsadd L
.95714 .21573 0 -0.96154 Mabsadd L
.95714 .21573 1.46946 -2.02254 Mabsadd L
.95714 .21573 .91448 -0.29713 Mabsadd L
.95714 .21573 2.37764 .77254 Mabsadd L
.95714 .21573 .56518 .7779 Mabsadd L
.95714 .21573 0 2.5 Mabsadd L closepath F
.96032 .21563 0 2.5 Mabsadd m
.96032 .21563 -0.56518 .7779 Mabsadd L
.96032 .21563 -2.37764 .77254 Mabsadd L
.96032 .21563 -0.91448 -0.29713 Mabsadd L
.96032 .21563 -1.46946 -2.02254 Mabsadd L
.96032 .21563 0 -0.96154 Mabsadd L
.96032 .21563 1.46946 -2.02254 Mabsadd L
.96032 .21563 .91448 -0.29713 Mabsadd L
.96032 .21563 2.37764 .77254 Mabsadd L
.96032 .21563 .56518 .7779 Mabsadd L
.96032 .21563 0 2.5 Mabsadd L closepath F
.96349 .21553 0 2.5 Mabsadd m
.96349 .21553 -0.56518 .7779 Mabsadd L
.96349 .21553 -2.37764 .77254 Mabsadd L
.96349 .21553 -0.91448 -0.29713 Mabsadd L
.96349 .21553 -1.46946 -2.02254 Mabsadd L
.96349 .21553 0 -0.96154 Mabsadd L
.96349 .21553 1.46946 -2.02254 Mabsadd L
.96349 .21553 .91448 -0.29713 Mabsadd L
.96349 .21553 2.37764 .77254 Mabsadd L
.96349 .21553 .56518 .7779 Mabsadd L
.96349 .21553 0 2.5 Mabsadd L closepath F
.96667 .21544 0 2.5 Mabsadd m
.96667 .21544 -0.56518 .7779 Mabsadd L
.96667 .21544 -2.37764 .77254 Mabsadd L
.96667 .21544 -0.91448 -0.29713 Mabsadd L
.96667 .21544 -1.46946 -2.02254 Mabsadd L
.96667 .21544 0 -0.96154 Mabsadd L
.96667 .21544 1.46946 -2.02254 Mabsadd L
.96667 .21544 .91448 -0.29713 Mabsadd L
.96667 .21544 2.37764 .77254 Mabsadd L
.96667 .21544 .56518 .7779 Mabsadd L
.96667 .21544 0 2.5 Mabsadd L closepath F
.96984 .21534 0 2.5 Mabsadd m
.96984 .21534 -0.56518 .7779 Mabsadd L
.96984 .21534 -2.37764 .77254 Mabsadd L
.96984 .21534 -0.91448 -0.29713 Mabsadd L
.96984 .21534 -1.46946 -2.02254 Mabsadd L
.96984 .21534 0 -0.96154 Mabsadd L
.96984 .21534 1.46946 -2.02254 Mabsadd L
.96984 .21534 .91448 -0.29713 Mabsadd L
.96984 .21534 2.37764 .77254 Mabsadd L
.96984 .21534 .56518 .7779 Mabsadd L
.96984 .21534 0 2.5 Mabsadd L closepath F
.97302 .21524 0 2.5 Mabsadd m
.97302 .21524 -0.56518 .7779 Mabsadd L
.97302 .21524 -2.37764 .77254 Mabsadd L
.97302 .21524 -0.91448 -0.29713 Mabsadd L
.97302 .21524 -1.46946 -2.02254 Mabsadd L
.97302 .21524 0 -0.96154 Mabsadd L
.97302 .21524 1.46946 -2.02254 Mabsadd L
.97302 .21524 .91448 -0.29713 Mabsadd L
.97302 .21524 2.37764 .77254 Mabsadd L
.97302 .21524 .56518 .7779 Mabsadd L
.97302 .21524 0 2.5 Mabsadd L closepath F
.97619 .21515 0 2.5 Mabsadd m
.97619 .21515 -0.56518 .7779 Mabsadd L
.97619 .21515 -2.37764 .77254 Mabsadd L
.97619 .21515 -0.91448 -0.29713 Mabsadd L
.97619 .21515 -1.46946 -2.02254 Mabsadd L
.97619 .21515 0 -0.96154 Mabsadd L
.97619 .21515 1.46946 -2.02254 Mabsadd L
.97619 .21515 .91448 -0.29713 Mabsadd L
.97619 .21515 2.37764 .77254 Mabsadd L
.97619 .21515 .56518 .7779 Mabsadd L
.97619 .21515 0 2.5 Mabsadd L closepath F
.0075 w
.02698 .58763 m
.03016 .58381 L
.03333 .58003 L
.03651 .57628 L
.03968 .57258 L
.04286 .56891 L
.04603 .56528 L
.04921 .56168 L
.05238 .55812 L
.05556 .5546 L
.05873 .55111 L
.0619 .54765 L
.06508 .54423 L
.06825 .54085 L
.07143 .5375 L
.0746 .53418 L
.07778 .53089 L
.08095 .52764 L
.08413 .52442 L
.0873 .52123 L
.09048 .51808 L
.09365 .51495 L
.09683 .51186 L
.1 .5088 L
.10317 .50577 L
.10635 .50277 L
.10952 .4998 L
.1127 .49686 L
.11587 .49394 L
.11905 .49106 L
.12222 .48821 L
.1254 .48538 L
.12857 .48259 L
.13175 .47982 L
.13492 .47707 L
.1381 .47436 L
.14127 .47167 L
.14444 .46901 L
.14762 .46638 L
.15079 .46377 L
.15397 .46119 L
.15714 .45864 L
.16032 .45611 L
.16349 .4536 L
.16667 .45113 L
.16984 .44867 L
.17302 .44624 L
.17619 .44384 L
.17937 .44145 L
.18254 .4391 L
Mistroke
.18571 .43676 L
.18889 .43445 L
.19206 .43216 L
.19524 .4299 L
.19841 .42766 L
.20159 .42544 L
.20476 .42324 L
.20794 .42106 L
.21111 .41891 L
.21429 .41678 L
.21746 .41467 L
.22063 .41258 L
.22381 .41051 L
.22698 .40846 L
.23016 .40643 L
.23333 .40442 L
.23651 .40244 L
.23968 .40047 L
.24286 .39852 L
.24603 .39659 L
.24921 .39468 L
.25238 .39279 L
.25556 .39092 L
.25873 .38907 L
.2619 .38724 L
.26508 .38542 L
.26825 .38362 L
.27143 .38185 L
.2746 .38008 L
.27778 .37834 L
.28095 .37661 L
.28413 .3749 L
.2873 .37321 L
.29048 .37154 L
.29365 .36988 L
.29683 .36824 L
.3 .36661 L
.30317 .365 L
.30635 .36341 L
.30952 .36183 L
.3127 .36027 L
.31587 .35872 L
.31905 .35719 L
.32222 .35568 L
.3254 .35418 L
.32857 .35269 L
.33175 .35122 L
.33492 .34977 L
.3381 .34833 L
.34127 .3469 L
Mistroke
.34444 .34549 L
.34762 .34409 L
.35079 .34271 L
.35397 .34134 L
.35714 .33998 L
.36032 .33864 L
.36349 .33731 L
.36667 .33599 L
.36984 .33469 L
.37302 .3334 L
.37619 .33212 L
.37937 .33086 L
.38254 .3296 L
.38571 .32837 L
.38889 .32714 L
.39206 .32592 L
.39524 .32472 L
.39841 .32353 L
.40159 .32235 L
.40476 .32119 L
.40794 .32003 L
.41111 .31889 L
.41429 .31776 L
.41746 .31664 L
.42063 .31553 L
.42381 .31443 L
.42698 .31334 L
.43016 .31226 L
.43333 .3112 L
.43651 .31014 L
.43968 .3091 L
.44286 .30806 L
.44603 .30704 L
.44921 .30603 L
.45238 .30502 L
.45556 .30403 L
.45873 .30305 L
.4619 .30207 L
.46508 .30111 L
.46825 .30015 L
.47143 .29921 L
.4746 .29827 L
.47778 .29735 L
.48095 .29643 L
.48413 .29552 L
.4873 .29463 L
.49048 .29374 L
.49365 .29286 L
.49683 .29198 L
.5 .29112 L
Mistroke
.50317 .29027 L
.50635 .28942 L
.50952 .28858 L
.5127 .28775 L
.51587 .28693 L
.51905 .28612 L
.52222 .28532 L
.5254 .28452 L
.52857 .28373 L
.53175 .28295 L
.53492 .28218 L
.5381 .28141 L
.54127 .28066 L
.54444 .27991 L
.54762 .27917 L
.55079 .27843 L
.55397 .2777 L
.55714 .27698 L
.56032 .27627 L
.56349 .27556 L
.56667 .27487 L
.56984 .27417 L
.57302 .27349 L
.57619 .27281 L
.57937 .27214 L
.58254 .27147 L
.58571 .27082 L
.58889 .27017 L
.59206 .26952 L
.59524 .26888 L
.59841 .26825 L
.60159 .26762 L
.60476 .26701 L
.60794 .26639 L
.61111 .26579 L
.61429 .26518 L
.61746 .26459 L
.62063 .264 L
.62381 .26342 L
.62698 .26284 L
.63016 .26227 L
.63333 .2617 L
.63651 .26114 L
.63968 .26059 L
.64286 .26004 L
.64603 .2595 L
.64921 .25896 L
.65238 .25842 L
.65556 .2579 L
.65873 .25737 L
Mistroke
.6619 .25686 L
.66508 .25635 L
.66825 .25584 L
.67143 .25534 L
.6746 .25484 L
.67778 .25435 L
.68095 .25386 L
.68413 .25338 L
.6873 .2529 L
.69048 .25243 L
.69365 .25196 L
.69683 .2515 L
.7 .25104 L
.70317 .25059 L
.70635 .25014 L
.70952 .2497 L
.7127 .24926 L
.71587 .24882 L
.71905 .24839 L
.72222 .24796 L
.7254 .24754 L
.72857 .24712 L
.73175 .24671 L
.73492 .2463 L
.7381 .24589 L
.74127 .24549 L
.74444 .24509 L
.74762 .2447 L
.75079 .24431 L
.75397 .24392 L
.75714 .24354 L
.76032 .24316 L
.76349 .24278 L
.76667 .24241 L
.76984 .24205 L
.77302 .24168 L
.77619 .24132 L
.77937 .24097 L
.78254 .24061 L
.78571 .24026 L
.78889 .23992 L
.79206 .23958 L
.79524 .23924 L
.79841 .2389 L
.80159 .23857 L
.80476 .23824 L
.80794 .23792 L
.81111 .23759 L
.81429 .23727 L
.81746 .23696 L
Mistroke
.82063 .23665 L
.82381 .23634 L
.82698 .23603 L
.83016 .23573 L
.83333 .23543 L
.83651 .23513 L
.83968 .23483 L
.84286 .23454 L
.84603 .23425 L
.84921 .23397 L
.85238 .23368 L
.85556 .2334 L
.85873 .23313 L
.8619 .23285 L
.86508 .23258 L
.86825 .23231 L
.87143 .23205 L
.8746 .23178 L
.87778 .23152 L
.88095 .23126 L
.88413 .23101 L
.8873 .23075 L
.89048 .2305 L
.89365 .23026 L
.89683 .23001 L
.9 .22977 L
.90317 .22953 L
.90635 .22929 L
.90952 .22905 L
.9127 .22882 L
.91587 .22859 L
.91905 .22836 L
.92222 .22813 L
.9254 .22791 L
.92857 .22768 L
.93175 .22746 L
.93492 .22725 L
.9381 .22703 L
.94127 .22682 L
.94444 .22661 L
.94762 .2264 L
.95079 .22619 L
.95397 .22598 L
.95714 .22578 L
.96032 .22558 L
.96349 .22538 L
.96667 .22518 L
.96984 .22499 L
.97302 .2248 L
.97619 .22461 L
Mistroke
Mfstroke
.0001 w
.02698 .58763 -2.5 2.5 Mabsadd m
.02698 .58763 2.5 2.5 Mabsadd L
.02698 .58763 2.5 -2.5 Mabsadd L
.02698 .58763 -2.5 -2.5 Mabsadd L
.02698 .58763 -2.5 2.5 Mabsadd L closepath F
.03016 .58381 -2.5 2.5 Mabsadd m
.03016 .58381 2.5 2.5 Mabsadd L
.03016 .58381 2.5 -2.5 Mabsadd L
.03016 .58381 -2.5 -2.5 Mabsadd L
.03016 .58381 -2.5 2.5 Mabsadd L closepath F
.03333 .58003 -2.5 2.5 Mabsadd m
.03333 .58003 2.5 2.5 Mabsadd L
.03333 .58003 2.5 -2.5 Mabsadd L
.03333 .58003 -2.5 -2.5 Mabsadd L
.03333 .58003 -2.5 2.5 Mabsadd L closepath F
.03651 .57628 -2.5 2.5 Mabsadd m
.03651 .57628 2.5 2.5 Mabsadd L
.03651 .57628 2.5 -2.5 Mabsadd L
.03651 .57628 -2.5 -2.5 Mabsadd L
.03651 .57628 -2.5 2.5 Mabsadd L closepath F
.03968 .57258 -2.5 2.5 Mabsadd m
.03968 .57258 2.5 2.5 Mabsadd L
.03968 .57258 2.5 -2.5 Mabsadd L
.03968 .57258 -2.5 -2.5 Mabsadd L
.03968 .57258 -2.5 2.5 Mabsadd L closepath F
.04286 .56891 -2.5 2.5 Mabsadd m
.04286 .56891 2.5 2.5 Mabsadd L
.04286 .56891 2.5 -2.5 Mabsadd L
.04286 .56891 -2.5 -2.5 Mabsadd L
.04286 .56891 -2.5 2.5 Mabsadd L closepath F
.04603 .56528 -2.5 2.5 Mabsadd m
.04603 .56528 2.5 2.5 Mabsadd L
.04603 .56528 2.5 -2.5 Mabsadd L
.04603 .56528 -2.5 -2.5 Mabsadd L
.04603 .56528 -2.5 2.5 Mabsadd L closepath F
.04921 .56168 -2.5 2.5 Mabsadd m
.04921 .56168 2.5 2.5 Mabsadd L
.04921 .56168 2.5 -2.5 Mabsadd L
.04921 .56168 -2.5 -2.5 Mabsadd L
.04921 .56168 -2.5 2.5 Mabsadd L closepath F
.05238 .55812 -2.5 2.5 Mabsadd m
.05238 .55812 2.5 2.5 Mabsadd L
.05238 .55812 2.5 -2.5 Mabsadd L
.05238 .55812 -2.5 -2.5 Mabsadd L
.05238 .55812 -2.5 2.5 Mabsadd L closepath F
.05556 .5546 -2.5 2.5 Mabsadd m
.05556 .5546 2.5 2.5 Mabsadd L
.05556 .5546 2.5 -2.5 Mabsadd L
.05556 .5546 -2.5 -2.5 Mabsadd L
.05556 .5546 -2.5 2.5 Mabsadd L closepath F
.05873 .55111 -2.5 2.5 Mabsadd m
.05873 .55111 2.5 2.5 Mabsadd L
.05873 .55111 2.5 -2.5 Mabsadd L
.05873 .55111 -2.5 -2.5 Mabsadd L
.05873 .55111 -2.5 2.5 Mabsadd L closepath F
.0619 .54765 -2.5 2.5 Mabsadd m
.0619 .54765 2.5 2.5 Mabsadd L
.0619 .54765 2.5 -2.5 Mabsadd L
.0619 .54765 -2.5 -2.5 Mabsadd L
.0619 .54765 -2.5 2.5 Mabsadd L closepath F
.06508 .54423 -2.5 2.5 Mabsadd m
.06508 .54423 2.5 2.5 Mabsadd L
.06508 .54423 2.5 -2.5 Mabsadd L
.06508 .54423 -2.5 -2.5 Mabsadd L
.06508 .54423 -2.5 2.5 Mabsadd L closepath F
.06825 .54085 -2.5 2.5 Mabsadd m
.06825 .54085 2.5 2.5 Mabsadd L
.06825 .54085 2.5 -2.5 Mabsadd L
.06825 .54085 -2.5 -2.5 Mabsadd L
.06825 .54085 -2.5 2.5 Mabsadd L closepath F
.07143 .5375 -2.5 2.5 Mabsadd m
.07143 .5375 2.5 2.5 Mabsadd L
.07143 .5375 2.5 -2.5 Mabsadd L
.07143 .5375 -2.5 -2.5 Mabsadd L
.07143 .5375 -2.5 2.5 Mabsadd L closepath F
.0746 .53418 -2.5 2.5 Mabsadd m
.0746 .53418 2.5 2.5 Mabsadd L
.0746 .53418 2.5 -2.5 Mabsadd L
.0746 .53418 -2.5 -2.5 Mabsadd L
.0746 .53418 -2.5 2.5 Mabsadd L closepath F
.07778 .53089 -2.5 2.5 Mabsadd m
.07778 .53089 2.5 2.5 Mabsadd L
.07778 .53089 2.5 -2.5 Mabsadd L
.07778 .53089 -2.5 -2.5 Mabsadd L
.07778 .53089 -2.5 2.5 Mabsadd L closepath F
.08095 .52764 -2.5 2.5 Mabsadd m
.08095 .52764 2.5 2.5 Mabsadd L
.08095 .52764 2.5 -2.5 Mabsadd L
.08095 .52764 -2.5 -2.5 Mabsadd L
.08095 .52764 -2.5 2.5 Mabsadd L closepath F
.08413 .52442 -2.5 2.5 Mabsadd m
.08413 .52442 2.5 2.5 Mabsadd L
.08413 .52442 2.5 -2.5 Mabsadd L
.08413 .52442 -2.5 -2.5 Mabsadd L
.08413 .52442 -2.5 2.5 Mabsadd L closepath F
.0873 .52123 -2.5 2.5 Mabsadd m
.0873 .52123 2.5 2.5 Mabsadd L
.0873 .52123 2.5 -2.5 Mabsadd L
.0873 .52123 -2.5 -2.5 Mabsadd L
.0873 .52123 -2.5 2.5 Mabsadd L closepath F
.09048 .51808 -2.5 2.5 Mabsadd m
.09048 .51808 2.5 2.5 Mabsadd L
.09048 .51808 2.5 -2.5 Mabsadd L
.09048 .51808 -2.5 -2.5 Mabsadd L
.09048 .51808 -2.5 2.5 Mabsadd L closepath F
.09365 .51495 -2.5 2.5 Mabsadd m
.09365 .51495 2.5 2.5 Mabsadd L
.09365 .51495 2.5 -2.5 Mabsadd L
.09365 .51495 -2.5 -2.5 Mabsadd L
.09365 .51495 -2.5 2.5 Mabsadd L closepath F
.09683 .51186 -2.5 2.5 Mabsadd m
.09683 .51186 2.5 2.5 Mabsadd L
.09683 .51186 2.5 -2.5 Mabsadd L
.09683 .51186 -2.5 -2.5 Mabsadd L
.09683 .51186 -2.5 2.5 Mabsadd L closepath F
.1 .5088 -2.5 2.5 Mabsadd m
.1 .5088 2.5 2.5 Mabsadd L
.1 .5088 2.5 -2.5 Mabsadd L
.1 .5088 -2.5 -2.5 Mabsadd L
.1 .5088 -2.5 2.5 Mabsadd L closepath F
.10317 .50577 -2.5 2.5 Mabsadd m
.10317 .50577 2.5 2.5 Mabsadd L
.10317 .50577 2.5 -2.5 Mabsadd L
.10317 .50577 -2.5 -2.5 Mabsadd L
.10317 .50577 -2.5 2.5 Mabsadd L closepath F
.10635 .50277 -2.5 2.5 Mabsadd m
.10635 .50277 2.5 2.5 Mabsadd L
.10635 .50277 2.5 -2.5 Mabsadd L
.10635 .50277 -2.5 -2.5 Mabsadd L
.10635 .50277 -2.5 2.5 Mabsadd L closepath F
.10952 .4998 -2.5 2.5 Mabsadd m
.10952 .4998 2.5 2.5 Mabsadd L
.10952 .4998 2.5 -2.5 Mabsadd L
.10952 .4998 -2.5 -2.5 Mabsadd L
.10952 .4998 -2.5 2.5 Mabsadd L closepath F
.1127 .49686 -2.5 2.5 Mabsadd m
.1127 .49686 2.5 2.5 Mabsadd L
.1127 .49686 2.5 -2.5 Mabsadd L
.1127 .49686 -2.5 -2.5 Mabsadd L
.1127 .49686 -2.5 2.5 Mabsadd L closepath F
.11587 .49394 -2.5 2.5 Mabsadd m
.11587 .49394 2.5 2.5 Mabsadd L
.11587 .49394 2.5 -2.5 Mabsadd L
.11587 .49394 -2.5 -2.5 Mabsadd L
.11587 .49394 -2.5 2.5 Mabsadd L closepath F
.11905 .49106 -2.5 2.5 Mabsadd m
.11905 .49106 2.5 2.5 Mabsadd L
.11905 .49106 2.5 -2.5 Mabsadd L
.11905 .49106 -2.5 -2.5 Mabsadd L
.11905 .49106 -2.5 2.5 Mabsadd L closepath F
.12222 .48821 -2.5 2.5 Mabsadd m
.12222 .48821 2.5 2.5 Mabsadd L
.12222 .48821 2.5 -2.5 Mabsadd L
.12222 .48821 -2.5 -2.5 Mabsadd L
.12222 .48821 -2.5 2.5 Mabsadd L closepath F
.1254 .48538 -2.5 2.5 Mabsadd m
.1254 .48538 2.5 2.5 Mabsadd L
.1254 .48538 2.5 -2.5 Mabsadd L
.1254 .48538 -2.5 -2.5 Mabsadd L
.1254 .48538 -2.5 2.5 Mabsadd L closepath F
.12857 .48259 -2.5 2.5 Mabsadd m
.12857 .48259 2.5 2.5 Mabsadd L
.12857 .48259 2.5 -2.5 Mabsadd L
.12857 .48259 -2.5 -2.5 Mabsadd L
.12857 .48259 -2.5 2.5 Mabsadd L closepath F
.13175 .47982 -2.5 2.5 Mabsadd m
.13175 .47982 2.5 2.5 Mabsadd L
.13175 .47982 2.5 -2.5 Mabsadd L
.13175 .47982 -2.5 -2.5 Mabsadd L
.13175 .47982 -2.5 2.5 Mabsadd L closepath F
.13492 .47707 -2.5 2.5 Mabsadd m
.13492 .47707 2.5 2.5 Mabsadd L
.13492 .47707 2.5 -2.5 Mabsadd L
.13492 .47707 -2.5 -2.5 Mabsadd L
.13492 .47707 -2.5 2.5 Mabsadd L closepath F
.1381 .47436 -2.5 2.5 Mabsadd m
.1381 .47436 2.5 2.5 Mabsadd L
.1381 .47436 2.5 -2.5 Mabsadd L
.1381 .47436 -2.5 -2.5 Mabsadd L
.1381 .47436 -2.5 2.5 Mabsadd L closepath F
.14127 .47167 -2.5 2.5 Mabsadd m
.14127 .47167 2.5 2.5 Mabsadd L
.14127 .47167 2.5 -2.5 Mabsadd L
.14127 .47167 -2.5 -2.5 Mabsadd L
.14127 .47167 -2.5 2.5 Mabsadd L closepath F
.14444 .46901 -2.5 2.5 Mabsadd m
.14444 .46901 2.5 2.5 Mabsadd L
.14444 .46901 2.5 -2.5 Mabsadd L
.14444 .46901 -2.5 -2.5 Mabsadd L
.14444 .46901 -2.5 2.5 Mabsadd L closepath F
.14762 .46638 -2.5 2.5 Mabsadd m
.14762 .46638 2.5 2.5 Mabsadd L
.14762 .46638 2.5 -2.5 Mabsadd L
.14762 .46638 -2.5 -2.5 Mabsadd L
.14762 .46638 -2.5 2.5 Mabsadd L closepath F
.15079 .46377 -2.5 2.5 Mabsadd m
.15079 .46377 2.5 2.5 Mabsadd L
.15079 .46377 2.5 -2.5 Mabsadd L
.15079 .46377 -2.5 -2.5 Mabsadd L
.15079 .46377 -2.5 2.5 Mabsadd L closepath F
.15397 .46119 -2.5 2.5 Mabsadd m
.15397 .46119 2.5 2.5 Mabsadd L
.15397 .46119 2.5 -2.5 Mabsadd L
.15397 .46119 -2.5 -2.5 Mabsadd L
.15397 .46119 -2.5 2.5 Mabsadd L closepath F
.15714 .45864 -2.5 2.5 Mabsadd m
.15714 .45864 2.5 2.5 Mabsadd L
.15714 .45864 2.5 -2.5 Mabsadd L
.15714 .45864 -2.5 -2.5 Mabsadd L
.15714 .45864 -2.5 2.5 Mabsadd L closepath F
.16032 .45611 -2.5 2.5 Mabsadd m
.16032 .45611 2.5 2.5 Mabsadd L
.16032 .45611 2.5 -2.5 Mabsadd L
.16032 .45611 -2.5 -2.5 Mabsadd L
.16032 .45611 -2.5 2.5 Mabsadd L closepath F
.16349 .4536 -2.5 2.5 Mabsadd m
.16349 .4536 2.5 2.5 Mabsadd L
.16349 .4536 2.5 -2.5 Mabsadd L
.16349 .4536 -2.5 -2.5 Mabsadd L
.16349 .4536 -2.5 2.5 Mabsadd L closepath F
.16667 .45113 -2.5 2.5 Mabsadd m
.16667 .45113 2.5 2.5 Mabsadd L
.16667 .45113 2.5 -2.5 Mabsadd L
.16667 .45113 -2.5 -2.5 Mabsadd L
.16667 .45113 -2.5 2.5 Mabsadd L closepath F
.16984 .44867 -2.5 2.5 Mabsadd m
.16984 .44867 2.5 2.5 Mabsadd L
.16984 .44867 2.5 -2.5 Mabsadd L
.16984 .44867 -2.5 -2.5 Mabsadd L
.16984 .44867 -2.5 2.5 Mabsadd L closepath F
.17302 .44624 -2.5 2.5 Mabsadd m
.17302 .44624 2.5 2.5 Mabsadd L
.17302 .44624 2.5 -2.5 Mabsadd L
.17302 .44624 -2.5 -2.5 Mabsadd L
.17302 .44624 -2.5 2.5 Mabsadd L closepath F
.17619 .44384 -2.5 2.5 Mabsadd m
.17619 .44384 2.5 2.5 Mabsadd L
.17619 .44384 2.5 -2.5 Mabsadd L
.17619 .44384 -2.5 -2.5 Mabsadd L
.17619 .44384 -2.5 2.5 Mabsadd L closepath F
.17937 .44145 -2.5 2.5 Mabsadd m
.17937 .44145 2.5 2.5 Mabsadd L
.17937 .44145 2.5 -2.5 Mabsadd L
.17937 .44145 -2.5 -2.5 Mabsadd L
.17937 .44145 -2.5 2.5 Mabsadd L closepath F
.18254 .4391 -2.5 2.5 Mabsadd m
.18254 .4391 2.5 2.5 Mabsadd L
.18254 .4391 2.5 -2.5 Mabsadd L
.18254 .4391 -2.5 -2.5 Mabsadd L
.18254 .4391 -2.5 2.5 Mabsadd L closepath F
.18571 .43676 -2.5 2.5 Mabsadd m
.18571 .43676 2.5 2.5 Mabsadd L
.18571 .43676 2.5 -2.5 Mabsadd L
.18571 .43676 -2.5 -2.5 Mabsadd L
.18571 .43676 -2.5 2.5 Mabsadd L closepath F
.18889 .43445 -2.5 2.5 Mabsadd m
.18889 .43445 2.5 2.5 Mabsadd L
.18889 .43445 2.5 -2.5 Mabsadd L
.18889 .43445 -2.5 -2.5 Mabsadd L
.18889 .43445 -2.5 2.5 Mabsadd L closepath F
.19206 .43216 -2.5 2.5 Mabsadd m
.19206 .43216 2.5 2.5 Mabsadd L
.19206 .43216 2.5 -2.5 Mabsadd L
.19206 .43216 -2.5 -2.5 Mabsadd L
.19206 .43216 -2.5 2.5 Mabsadd L closepath F
.19524 .4299 -2.5 2.5 Mabsadd m
.19524 .4299 2.5 2.5 Mabsadd L
.19524 .4299 2.5 -2.5 Mabsadd L
.19524 .4299 -2.5 -2.5 Mabsadd L
.19524 .4299 -2.5 2.5 Mabsadd L closepath F
.19841 .42766 -2.5 2.5 Mabsadd m
.19841 .42766 2.5 2.5 Mabsadd L
.19841 .42766 2.5 -2.5 Mabsadd L
.19841 .42766 -2.5 -2.5 Mabsadd L
.19841 .42766 -2.5 2.5 Mabsadd L closepath F
.20159 .42544 -2.5 2.5 Mabsadd m
.20159 .42544 2.5 2.5 Mabsadd L
.20159 .42544 2.5 -2.5 Mabsadd L
.20159 .42544 -2.5 -2.5 Mabsadd L
.20159 .42544 -2.5 2.5 Mabsadd L closepath F
.20476 .42324 -2.5 2.5 Mabsadd m
.20476 .42324 2.5 2.5 Mabsadd L
.20476 .42324 2.5 -2.5 Mabsadd L
.20476 .42324 -2.5 -2.5 Mabsadd L
.20476 .42324 -2.5 2.5 Mabsadd L closepath F
.20794 .42106 -2.5 2.5 Mabsadd m
.20794 .42106 2.5 2.5 Mabsadd L
.20794 .42106 2.5 -2.5 Mabsadd L
.20794 .42106 -2.5 -2.5 Mabsadd L
.20794 .42106 -2.5 2.5 Mabsadd L closepath F
.21111 .41891 -2.5 2.5 Mabsadd m
.21111 .41891 2.5 2.5 Mabsadd L
.21111 .41891 2.5 -2.5 Mabsadd L
.21111 .41891 -2.5 -2.5 Mabsadd L
.21111 .41891 -2.5 2.5 Mabsadd L closepath F
.21429 .41678 -2.5 2.5 Mabsadd m
.21429 .41678 2.5 2.5 Mabsadd L
.21429 .41678 2.5 -2.5 Mabsadd L
.21429 .41678 -2.5 -2.5 Mabsadd L
.21429 .41678 -2.5 2.5 Mabsadd L closepath F
.21746 .41467 -2.5 2.5 Mabsadd m
.21746 .41467 2.5 2.5 Mabsadd L
.21746 .41467 2.5 -2.5 Mabsadd L
.21746 .41467 -2.5 -2.5 Mabsadd L
.21746 .41467 -2.5 2.5 Mabsadd L closepath F
.22063 .41258 -2.5 2.5 Mabsadd m
.22063 .41258 2.5 2.5 Mabsadd L
.22063 .41258 2.5 -2.5 Mabsadd L
.22063 .41258 -2.5 -2.5 Mabsadd L
.22063 .41258 -2.5 2.5 Mabsadd L closepath F
.22381 .41051 -2.5 2.5 Mabsadd m
.22381 .41051 2.5 2.5 Mabsadd L
.22381 .41051 2.5 -2.5 Mabsadd L
.22381 .41051 -2.5 -2.5 Mabsadd L
.22381 .41051 -2.5 2.5 Mabsadd L closepath F
.22698 .40846 -2.5 2.5 Mabsadd m
.22698 .40846 2.5 2.5 Mabsadd L
.22698 .40846 2.5 -2.5 Mabsadd L
.22698 .40846 -2.5 -2.5 Mabsadd L
.22698 .40846 -2.5 2.5 Mabsadd L closepath F
.23016 .40643 -2.5 2.5 Mabsadd m
.23016 .40643 2.5 2.5 Mabsadd L
.23016 .40643 2.5 -2.5 Mabsadd L
.23016 .40643 -2.5 -2.5 Mabsadd L
.23016 .40643 -2.5 2.5 Mabsadd L closepath F
.23333 .40442 -2.5 2.5 Mabsadd m
.23333 .40442 2.5 2.5 Mabsadd L
.23333 .40442 2.5 -2.5 Mabsadd L
.23333 .40442 -2.5 -2.5 Mabsadd L
.23333 .40442 -2.5 2.5 Mabsadd L closepath F
.23651 .40244 -2.5 2.5 Mabsadd m
.23651 .40244 2.5 2.5 Mabsadd L
.23651 .40244 2.5 -2.5 Mabsadd L
.23651 .40244 -2.5 -2.5 Mabsadd L
.23651 .40244 -2.5 2.5 Mabsadd L closepath F
.23968 .40047 -2.5 2.5 Mabsadd m
.23968 .40047 2.5 2.5 Mabsadd L
.23968 .40047 2.5 -2.5 Mabsadd L
.23968 .40047 -2.5 -2.5 Mabsadd L
.23968 .40047 -2.5 2.5 Mabsadd L closepath F
.24286 .39852 -2.5 2.5 Mabsadd m
.24286 .39852 2.5 2.5 Mabsadd L
.24286 .39852 2.5 -2.5 Mabsadd L
.24286 .39852 -2.5 -2.5 Mabsadd L
.24286 .39852 -2.5 2.5 Mabsadd L closepath F
.24603 .39659 -2.5 2.5 Mabsadd m
.24603 .39659 2.5 2.5 Mabsadd L
.24603 .39659 2.5 -2.5 Mabsadd L
.24603 .39659 -2.5 -2.5 Mabsadd L
.24603 .39659 -2.5 2.5 Mabsadd L closepath F
.24921 .39468 -2.5 2.5 Mabsadd m
.24921 .39468 2.5 2.5 Mabsadd L
.24921 .39468 2.5 -2.5 Mabsadd L
.24921 .39468 -2.5 -2.5 Mabsadd L
.24921 .39468 -2.5 2.5 Mabsadd L closepath F
.25238 .39279 -2.5 2.5 Mabsadd m
.25238 .39279 2.5 2.5 Mabsadd L
.25238 .39279 2.5 -2.5 Mabsadd L
.25238 .39279 -2.5 -2.5 Mabsadd L
.25238 .39279 -2.5 2.5 Mabsadd L closepath F
.25556 .39092 -2.5 2.5 Mabsadd m
.25556 .39092 2.5 2.5 Mabsadd L
.25556 .39092 2.5 -2.5 Mabsadd L
.25556 .39092 -2.5 -2.5 Mabsadd L
.25556 .39092 -2.5 2.5 Mabsadd L closepath F
.25873 .38907 -2.5 2.5 Mabsadd m
.25873 .38907 2.5 2.5 Mabsadd L
.25873 .38907 2.5 -2.5 Mabsadd L
.25873 .38907 -2.5 -2.5 Mabsadd L
.25873 .38907 -2.5 2.5 Mabsadd L closepath F
.2619 .38724 -2.5 2.5 Mabsadd m
.2619 .38724 2.5 2.5 Mabsadd L
.2619 .38724 2.5 -2.5 Mabsadd L
.2619 .38724 -2.5 -2.5 Mabsadd L
.2619 .38724 -2.5 2.5 Mabsadd L closepath F
.26508 .38542 -2.5 2.5 Mabsadd m
.26508 .38542 2.5 2.5 Mabsadd L
.26508 .38542 2.5 -2.5 Mabsadd L
.26508 .38542 -2.5 -2.5 Mabsadd L
.26508 .38542 -2.5 2.5 Mabsadd L closepath F
.26825 .38362 -2.5 2.5 Mabsadd m
.26825 .38362 2.5 2.5 Mabsadd L
.26825 .38362 2.5 -2.5 Mabsadd L
.26825 .38362 -2.5 -2.5 Mabsadd L
.26825 .38362 -2.5 2.5 Mabsadd L closepath F
.27143 .38185 -2.5 2.5 Mabsadd m
.27143 .38185 2.5 2.5 Mabsadd L
.27143 .38185 2.5 -2.5 Mabsadd L
.27143 .38185 -2.5 -2.5 Mabsadd L
.27143 .38185 -2.5 2.5 Mabsadd L closepath F
.2746 .38008 -2.5 2.5 Mabsadd m
.2746 .38008 2.5 2.5 Mabsadd L
.2746 .38008 2.5 -2.5 Mabsadd L
.2746 .38008 -2.5 -2.5 Mabsadd L
.2746 .38008 -2.5 2.5 Mabsadd L closepath F
.27778 .37834 -2.5 2.5 Mabsadd m
.27778 .37834 2.5 2.5 Mabsadd L
.27778 .37834 2.5 -2.5 Mabsadd L
.27778 .37834 -2.5 -2.5 Mabsadd L
.27778 .37834 -2.5 2.5 Mabsadd L closepath F
.28095 .37661 -2.5 2.5 Mabsadd m
.28095 .37661 2.5 2.5 Mabsadd L
.28095 .37661 2.5 -2.5 Mabsadd L
.28095 .37661 -2.5 -2.5 Mabsadd L
.28095 .37661 -2.5 2.5 Mabsadd L closepath F
.28413 .3749 -2.5 2.5 Mabsadd m
.28413 .3749 2.5 2.5 Mabsadd L
.28413 .3749 2.5 -2.5 Mabsadd L
.28413 .3749 -2.5 -2.5 Mabsadd L
.28413 .3749 -2.5 2.5 Mabsadd L closepath F
.2873 .37321 -2.5 2.5 Mabsadd m
.2873 .37321 2.5 2.5 Mabsadd L
.2873 .37321 2.5 -2.5 Mabsadd L
.2873 .37321 -2.5 -2.5 Mabsadd L
.2873 .37321 -2.5 2.5 Mabsadd L closepath F
.29048 .37154 -2.5 2.5 Mabsadd m
.29048 .37154 2.5 2.5 Mabsadd L
.29048 .37154 2.5 -2.5 Mabsadd L
.29048 .37154 -2.5 -2.5 Mabsadd L
.29048 .37154 -2.5 2.5 Mabsadd L closepath F
.29365 .36988 -2.5 2.5 Mabsadd m
.29365 .36988 2.5 2.5 Mabsadd L
.29365 .36988 2.5 -2.5 Mabsadd L
.29365 .36988 -2.5 -2.5 Mabsadd L
.29365 .36988 -2.5 2.5 Mabsadd L closepath F
.29683 .36824 -2.5 2.5 Mabsadd m
.29683 .36824 2.5 2.5 Mabsadd L
.29683 .36824 2.5 -2.5 Mabsadd L
.29683 .36824 -2.5 -2.5 Mabsadd L
.29683 .36824 -2.5 2.5 Mabsadd L closepath F
.3 .36661 -2.5 2.5 Mabsadd m
.3 .36661 2.5 2.5 Mabsadd L
.3 .36661 2.5 -2.5 Mabsadd L
.3 .36661 -2.5 -2.5 Mabsadd L
.3 .36661 -2.5 2.5 Mabsadd L closepath F
.30317 .365 -2.5 2.5 Mabsadd m
.30317 .365 2.5 2.5 Mabsadd L
.30317 .365 2.5 -2.5 Mabsadd L
.30317 .365 -2.5 -2.5 Mabsadd L
.30317 .365 -2.5 2.5 Mabsadd L closepath F
.30635 .36341 -2.5 2.5 Mabsadd m
.30635 .36341 2.5 2.5 Mabsadd L
.30635 .36341 2.5 -2.5 Mabsadd L
.30635 .36341 -2.5 -2.5 Mabsadd L
.30635 .36341 -2.5 2.5 Mabsadd L closepath F
.30952 .36183 -2.5 2.5 Mabsadd m
.30952 .36183 2.5 2.5 Mabsadd L
.30952 .36183 2.5 -2.5 Mabsadd L
.30952 .36183 -2.5 -2.5 Mabsadd L
.30952 .36183 -2.5 2.5 Mabsadd L closepath F
.3127 .36027 -2.5 2.5 Mabsadd m
.3127 .36027 2.5 2.5 Mabsadd L
.3127 .36027 2.5 -2.5 Mabsadd L
.3127 .36027 -2.5 -2.5 Mabsadd L
.3127 .36027 -2.5 2.5 Mabsadd L closepath F
.31587 .35872 -2.5 2.5 Mabsadd m
.31587 .35872 2.5 2.5 Mabsadd L
.31587 .35872 2.5 -2.5 Mabsadd L
.31587 .35872 -2.5 -2.5 Mabsadd L
.31587 .35872 -2.5 2.5 Mabsadd L closepath F
.31905 .35719 -2.5 2.5 Mabsadd m
.31905 .35719 2.5 2.5 Mabsadd L
.31905 .35719 2.5 -2.5 Mabsadd L
.31905 .35719 -2.5 -2.5 Mabsadd L
.31905 .35719 -2.5 2.5 Mabsadd L closepath F
.32222 .35568 -2.5 2.5 Mabsadd m
.32222 .35568 2.5 2.5 Mabsadd L
.32222 .35568 2.5 -2.5 Mabsadd L
.32222 .35568 -2.5 -2.5 Mabsadd L
.32222 .35568 -2.5 2.5 Mabsadd L closepath F
.3254 .35418 -2.5 2.5 Mabsadd m
.3254 .35418 2.5 2.5 Mabsadd L
.3254 .35418 2.5 -2.5 Mabsadd L
.3254 .35418 -2.5 -2.5 Mabsadd L
.3254 .35418 -2.5 2.5 Mabsadd L closepath F
.32857 .35269 -2.5 2.5 Mabsadd m
.32857 .35269 2.5 2.5 Mabsadd L
.32857 .35269 2.5 -2.5 Mabsadd L
.32857 .35269 -2.5 -2.5 Mabsadd L
.32857 .35269 -2.5 2.5 Mabsadd L closepath F
.33175 .35122 -2.5 2.5 Mabsadd m
.33175 .35122 2.5 2.5 Mabsadd L
.33175 .35122 2.5 -2.5 Mabsadd L
.33175 .35122 -2.5 -2.5 Mabsadd L
.33175 .35122 -2.5 2.5 Mabsadd L closepath F
.33492 .34977 -2.5 2.5 Mabsadd m
.33492 .34977 2.5 2.5 Mabsadd L
.33492 .34977 2.5 -2.5 Mabsadd L
.33492 .34977 -2.5 -2.5 Mabsadd L
.33492 .34977 -2.5 2.5 Mabsadd L closepath F
.3381 .34833 -2.5 2.5 Mabsadd m
.3381 .34833 2.5 2.5 Mabsadd L
.3381 .34833 2.5 -2.5 Mabsadd L
.3381 .34833 -2.5 -2.5 Mabsadd L
.3381 .34833 -2.5 2.5 Mabsadd L closepath F
.34127 .3469 -2.5 2.5 Mabsadd m
.34127 .3469 2.5 2.5 Mabsadd L
.34127 .3469 2.5 -2.5 Mabsadd L
.34127 .3469 -2.5 -2.5 Mabsadd L
.34127 .3469 -2.5 2.5 Mabsadd L closepath F
.34444 .34549 -2.5 2.5 Mabsadd m
.34444 .34549 2.5 2.5 Mabsadd L
.34444 .34549 2.5 -2.5 Mabsadd L
.34444 .34549 -2.5 -2.5 Mabsadd L
.34444 .34549 -2.5 2.5 Mabsadd L closepath F
.34762 .34409 -2.5 2.5 Mabsadd m
.34762 .34409 2.5 2.5 Mabsadd L
.34762 .34409 2.5 -2.5 Mabsadd L
.34762 .34409 -2.5 -2.5 Mabsadd L
.34762 .34409 -2.5 2.5 Mabsadd L closepath F
.35079 .34271 -2.5 2.5 Mabsadd m
.35079 .34271 2.5 2.5 Mabsadd L
.35079 .34271 2.5 -2.5 Mabsadd L
.35079 .34271 -2.5 -2.5 Mabsadd L
.35079 .34271 -2.5 2.5 Mabsadd L closepath F
.35397 .34134 -2.5 2.5 Mabsadd m
.35397 .34134 2.5 2.5 Mabsadd L
.35397 .34134 2.5 -2.5 Mabsadd L
.35397 .34134 -2.5 -2.5 Mabsadd L
.35397 .34134 -2.5 2.5 Mabsadd L closepath F
.35714 .33998 -2.5 2.5 Mabsadd m
.35714 .33998 2.5 2.5 Mabsadd L
.35714 .33998 2.5 -2.5 Mabsadd L
.35714 .33998 -2.5 -2.5 Mabsadd L
.35714 .33998 -2.5 2.5 Mabsadd L closepath F
.36032 .33864 -2.5 2.5 Mabsadd m
.36032 .33864 2.5 2.5 Mabsadd L
.36032 .33864 2.5 -2.5 Mabsadd L
.36032 .33864 -2.5 -2.5 Mabsadd L
.36032 .33864 -2.5 2.5 Mabsadd L closepath F
.36349 .33731 -2.5 2.5 Mabsadd m
.36349 .33731 2.5 2.5 Mabsadd L
.36349 .33731 2.5 -2.5 Mabsadd L
.36349 .33731 -2.5 -2.5 Mabsadd L
.36349 .33731 -2.5 2.5 Mabsadd L closepath F
.36667 .33599 -2.5 2.5 Mabsadd m
.36667 .33599 2.5 2.5 Mabsadd L
.36667 .33599 2.5 -2.5 Mabsadd L
.36667 .33599 -2.5 -2.5 Mabsadd L
.36667 .33599 -2.5 2.5 Mabsadd L closepath F
.36984 .33469 -2.5 2.5 Mabsadd m
.36984 .33469 2.5 2.5 Mabsadd L
.36984 .33469 2.5 -2.5 Mabsadd L
.36984 .33469 -2.5 -2.5 Mabsadd L
.36984 .33469 -2.5 2.5 Mabsadd L closepath F
.37302 .3334 -2.5 2.5 Mabsadd m
.37302 .3334 2.5 2.5 Mabsadd L
.37302 .3334 2.5 -2.5 Mabsadd L
.37302 .3334 -2.5 -2.5 Mabsadd L
.37302 .3334 -2.5 2.5 Mabsadd L closepath F
.37619 .33212 -2.5 2.5 Mabsadd m
.37619 .33212 2.5 2.5 Mabsadd L
.37619 .33212 2.5 -2.5 Mabsadd L
.37619 .33212 -2.5 -2.5 Mabsadd L
.37619 .33212 -2.5 2.5 Mabsadd L closepath F
.37937 .33086 -2.5 2.5 Mabsadd m
.37937 .33086 2.5 2.5 Mabsadd L
.37937 .33086 2.5 -2.5 Mabsadd L
.37937 .33086 -2.5 -2.5 Mabsadd L
.37937 .33086 -2.5 2.5 Mabsadd L closepath F
.38254 .3296 -2.5 2.5 Mabsadd m
.38254 .3296 2.5 2.5 Mabsadd L
.38254 .3296 2.5 -2.5 Mabsadd L
.38254 .3296 -2.5 -2.5 Mabsadd L
.38254 .3296 -2.5 2.5 Mabsadd L closepath F
.38571 .32837 -2.5 2.5 Mabsadd m
.38571 .32837 2.5 2.5 Mabsadd L
.38571 .32837 2.5 -2.5 Mabsadd L
.38571 .32837 -2.5 -2.5 Mabsadd L
.38571 .32837 -2.5 2.5 Mabsadd L closepath F
.38889 .32714 -2.5 2.5 Mabsadd m
.38889 .32714 2.5 2.5 Mabsadd L
.38889 .32714 2.5 -2.5 Mabsadd L
.38889 .32714 -2.5 -2.5 Mabsadd L
.38889 .32714 -2.5 2.5 Mabsadd L closepath F
.39206 .32592 -2.5 2.5 Mabsadd m
.39206 .32592 2.5 2.5 Mabsadd L
.39206 .32592 2.5 -2.5 Mabsadd L
.39206 .32592 -2.5 -2.5 Mabsadd L
.39206 .32592 -2.5 2.5 Mabsadd L closepath F
.39524 .32472 -2.5 2.5 Mabsadd m
.39524 .32472 2.5 2.5 Mabsadd L
.39524 .32472 2.5 -2.5 Mabsadd L
.39524 .32472 -2.5 -2.5 Mabsadd L
.39524 .32472 -2.5 2.5 Mabsadd L closepath F
.39841 .32353 -2.5 2.5 Mabsadd m
.39841 .32353 2.5 2.5 Mabsadd L
.39841 .32353 2.5 -2.5 Mabsadd L
.39841 .32353 -2.5 -2.5 Mabsadd L
.39841 .32353 -2.5 2.5 Mabsadd L closepath F
.40159 .32235 -2.5 2.5 Mabsadd m
.40159 .32235 2.5 2.5 Mabsadd L
.40159 .32235 2.5 -2.5 Mabsadd L
.40159 .32235 -2.5 -2.5 Mabsadd L
.40159 .32235 -2.5 2.5 Mabsadd L closepath F
.40476 .32119 -2.5 2.5 Mabsadd m
.40476 .32119 2.5 2.5 Mabsadd L
.40476 .32119 2.5 -2.5 Mabsadd L
.40476 .32119 -2.5 -2.5 Mabsadd L
.40476 .32119 -2.5 2.5 Mabsadd L closepath F
.40794 .32003 -2.5 2.5 Mabsadd m
.40794 .32003 2.5 2.5 Mabsadd L
.40794 .32003 2.5 -2.5 Mabsadd L
.40794 .32003 -2.5 -2.5 Mabsadd L
.40794 .32003 -2.5 2.5 Mabsadd L closepath F
.41111 .31889 -2.5 2.5 Mabsadd m
.41111 .31889 2.5 2.5 Mabsadd L
.41111 .31889 2.5 -2.5 Mabsadd L
.41111 .31889 -2.5 -2.5 Mabsadd L
.41111 .31889 -2.5 2.5 Mabsadd L closepath F
.41429 .31776 -2.5 2.5 Mabsadd m
.41429 .31776 2.5 2.5 Mabsadd L
.41429 .31776 2.5 -2.5 Mabsadd L
.41429 .31776 -2.5 -2.5 Mabsadd L
.41429 .31776 -2.5 2.5 Mabsadd L closepath F
.41746 .31664 -2.5 2.5 Mabsadd m
.41746 .31664 2.5 2.5 Mabsadd L
.41746 .31664 2.5 -2.5 Mabsadd L
.41746 .31664 -2.5 -2.5 Mabsadd L
.41746 .31664 -2.5 2.5 Mabsadd L closepath F
.42063 .31553 -2.5 2.5 Mabsadd m
.42063 .31553 2.5 2.5 Mabsadd L
.42063 .31553 2.5 -2.5 Mabsadd L
.42063 .31553 -2.5 -2.5 Mabsadd L
.42063 .31553 -2.5 2.5 Mabsadd L closepath F
.42381 .31443 -2.5 2.5 Mabsadd m
.42381 .31443 2.5 2.5 Mabsadd L
.42381 .31443 2.5 -2.5 Mabsadd L
.42381 .31443 -2.5 -2.5 Mabsadd L
.42381 .31443 -2.5 2.5 Mabsadd L closepath F
.42698 .31334 -2.5 2.5 Mabsadd m
.42698 .31334 2.5 2.5 Mabsadd L
.42698 .31334 2.5 -2.5 Mabsadd L
.42698 .31334 -2.5 -2.5 Mabsadd L
.42698 .31334 -2.5 2.5 Mabsadd L closepath F
.43016 .31226 -2.5 2.5 Mabsadd m
.43016 .31226 2.5 2.5 Mabsadd L
.43016 .31226 2.5 -2.5 Mabsadd L
.43016 .31226 -2.5 -2.5 Mabsadd L
.43016 .31226 -2.5 2.5 Mabsadd L closepath F
.43333 .3112 -2.5 2.5 Mabsadd m
.43333 .3112 2.5 2.5 Mabsadd L
.43333 .3112 2.5 -2.5 Mabsadd L
.43333 .3112 -2.5 -2.5 Mabsadd L
.43333 .3112 -2.5 2.5 Mabsadd L closepath F
.43651 .31014 -2.5 2.5 Mabsadd m
.43651 .31014 2.5 2.5 Mabsadd L
.43651 .31014 2.5 -2.5 Mabsadd L
.43651 .31014 -2.5 -2.5 Mabsadd L
.43651 .31014 -2.5 2.5 Mabsadd L closepath F
.43968 .3091 -2.5 2.5 Mabsadd m
.43968 .3091 2.5 2.5 Mabsadd L
.43968 .3091 2.5 -2.5 Mabsadd L
.43968 .3091 -2.5 -2.5 Mabsadd L
.43968 .3091 -2.5 2.5 Mabsadd L closepath F
.44286 .30806 -2.5 2.5 Mabsadd m
.44286 .30806 2.5 2.5 Mabsadd L
.44286 .30806 2.5 -2.5 Mabsadd L
.44286 .30806 -2.5 -2.5 Mabsadd L
.44286 .30806 -2.5 2.5 Mabsadd L closepath F
.44603 .30704 -2.5 2.5 Mabsadd m
.44603 .30704 2.5 2.5 Mabsadd L
.44603 .30704 2.5 -2.5 Mabsadd L
.44603 .30704 -2.5 -2.5 Mabsadd L
.44603 .30704 -2.5 2.5 Mabsadd L closepath F
.44921 .30603 -2.5 2.5 Mabsadd m
.44921 .30603 2.5 2.5 Mabsadd L
.44921 .30603 2.5 -2.5 Mabsadd L
.44921 .30603 -2.5 -2.5 Mabsadd L
.44921 .30603 -2.5 2.5 Mabsadd L closepath F
.45238 .30502 -2.5 2.5 Mabsadd m
.45238 .30502 2.5 2.5 Mabsadd L
.45238 .30502 2.5 -2.5 Mabsadd L
.45238 .30502 -2.5 -2.5 Mabsadd L
.45238 .30502 -2.5 2.5 Mabsadd L closepath F
.45556 .30403 -2.5 2.5 Mabsadd m
.45556 .30403 2.5 2.5 Mabsadd L
.45556 .30403 2.5 -2.5 Mabsadd L
.45556 .30403 -2.5 -2.5 Mabsadd L
.45556 .30403 -2.5 2.5 Mabsadd L closepath F
.45873 .30305 -2.5 2.5 Mabsadd m
.45873 .30305 2.5 2.5 Mabsadd L
.45873 .30305 2.5 -2.5 Mabsadd L
.45873 .30305 -2.5 -2.5 Mabsadd L
.45873 .30305 -2.5 2.5 Mabsadd L closepath F
.4619 .30207 -2.5 2.5 Mabsadd m
.4619 .30207 2.5 2.5 Mabsadd L
.4619 .30207 2.5 -2.5 Mabsadd L
.4619 .30207 -2.5 -2.5 Mabsadd L
.4619 .30207 -2.5 2.5 Mabsadd L closepath F
.46508 .30111 -2.5 2.5 Mabsadd m
.46508 .30111 2.5 2.5 Mabsadd L
.46508 .30111 2.5 -2.5 Mabsadd L
.46508 .30111 -2.5 -2.5 Mabsadd L
.46508 .30111 -2.5 2.5 Mabsadd L closepath F
.46825 .30015 -2.5 2.5 Mabsadd m
.46825 .30015 2.5 2.5 Mabsadd L
.46825 .30015 2.5 -2.5 Mabsadd L
.46825 .30015 -2.5 -2.5 Mabsadd L
.46825 .30015 -2.5 2.5 Mabsadd L closepath F
.47143 .29921 -2.5 2.5 Mabsadd m
.47143 .29921 2.5 2.5 Mabsadd L
.47143 .29921 2.5 -2.5 Mabsadd L
.47143 .29921 -2.5 -2.5 Mabsadd L
.47143 .29921 -2.5 2.5 Mabsadd L closepath F
.4746 .29827 -2.5 2.5 Mabsadd m
.4746 .29827 2.5 2.5 Mabsadd L
.4746 .29827 2.5 -2.5 Mabsadd L
.4746 .29827 -2.5 -2.5 Mabsadd L
.4746 .29827 -2.5 2.5 Mabsadd L closepath F
.47778 .29735 -2.5 2.5 Mabsadd m
.47778 .29735 2.5 2.5 Mabsadd L
.47778 .29735 2.5 -2.5 Mabsadd L
.47778 .29735 -2.5 -2.5 Mabsadd L
.47778 .29735 -2.5 2.5 Mabsadd L closepath F
.48095 .29643 -2.5 2.5 Mabsadd m
.48095 .29643 2.5 2.5 Mabsadd L
.48095 .29643 2.5 -2.5 Mabsadd L
.48095 .29643 -2.5 -2.5 Mabsadd L
.48095 .29643 -2.5 2.5 Mabsadd L closepath F
.48413 .29552 -2.5 2.5 Mabsadd m
.48413 .29552 2.5 2.5 Mabsadd L
.48413 .29552 2.5 -2.5 Mabsadd L
.48413 .29552 -2.5 -2.5 Mabsadd L
.48413 .29552 -2.5 2.5 Mabsadd L closepath F
.4873 .29463 -2.5 2.5 Mabsadd m
.4873 .29463 2.5 2.5 Mabsadd L
.4873 .29463 2.5 -2.5 Mabsadd L
.4873 .29463 -2.5 -2.5 Mabsadd L
.4873 .29463 -2.5 2.5 Mabsadd L closepath F
.49048 .29374 -2.5 2.5 Mabsadd m
.49048 .29374 2.5 2.5 Mabsadd L
.49048 .29374 2.5 -2.5 Mabsadd L
.49048 .29374 -2.5 -2.5 Mabsadd L
.49048 .29374 -2.5 2.5 Mabsadd L closepath F
.49365 .29286 -2.5 2.5 Mabsadd m
.49365 .29286 2.5 2.5 Mabsadd L
.49365 .29286 2.5 -2.5 Mabsadd L
.49365 .29286 -2.5 -2.5 Mabsadd L
.49365 .29286 -2.5 2.5 Mabsadd L closepath F
.49683 .29198 -2.5 2.5 Mabsadd m
.49683 .29198 2.5 2.5 Mabsadd L
.49683 .29198 2.5 -2.5 Mabsadd L
.49683 .29198 -2.5 -2.5 Mabsadd L
.49683 .29198 -2.5 2.5 Mabsadd L closepath F
.5 .29112 -2.5 2.5 Mabsadd m
.5 .29112 2.5 2.5 Mabsadd L
.5 .29112 2.5 -2.5 Mabsadd L
.5 .29112 -2.5 -2.5 Mabsadd L
.5 .29112 -2.5 2.5 Mabsadd L closepath F
.50317 .29027 -2.5 2.5 Mabsadd m
.50317 .29027 2.5 2.5 Mabsadd L
.50317 .29027 2.5 -2.5 Mabsadd L
.50317 .29027 -2.5 -2.5 Mabsadd L
.50317 .29027 -2.5 2.5 Mabsadd L closepath F
.50635 .28942 -2.5 2.5 Mabsadd m
.50635 .28942 2.5 2.5 Mabsadd L
.50635 .28942 2.5 -2.5 Mabsadd L
.50635 .28942 -2.5 -2.5 Mabsadd L
.50635 .28942 -2.5 2.5 Mabsadd L closepath F
.50952 .28858 -2.5 2.5 Mabsadd m
.50952 .28858 2.5 2.5 Mabsadd L
.50952 .28858 2.5 -2.5 Mabsadd L
.50952 .28858 -2.5 -2.5 Mabsadd L
.50952 .28858 -2.5 2.5 Mabsadd L closepath F
.5127 .28775 -2.5 2.5 Mabsadd m
.5127 .28775 2.5 2.5 Mabsadd L
.5127 .28775 2.5 -2.5 Mabsadd L
.5127 .28775 -2.5 -2.5 Mabsadd L
.5127 .28775 -2.5 2.5 Mabsadd L closepath F
.51587 .28693 -2.5 2.5 Mabsadd m
.51587 .28693 2.5 2.5 Mabsadd L
.51587 .28693 2.5 -2.5 Mabsadd L
.51587 .28693 -2.5 -2.5 Mabsadd L
.51587 .28693 -2.5 2.5 Mabsadd L closepath F
.51905 .28612 -2.5 2.5 Mabsadd m
.51905 .28612 2.5 2.5 Mabsadd L
.51905 .28612 2.5 -2.5 Mabsadd L
.51905 .28612 -2.5 -2.5 Mabsadd L
.51905 .28612 -2.5 2.5 Mabsadd L closepath F
.52222 .28532 -2.5 2.5 Mabsadd m
.52222 .28532 2.5 2.5 Mabsadd L
.52222 .28532 2.5 -2.5 Mabsadd L
.52222 .28532 -2.5 -2.5 Mabsadd L
.52222 .28532 -2.5 2.5 Mabsadd L closepath F
.5254 .28452 -2.5 2.5 Mabsadd m
.5254 .28452 2.5 2.5 Mabsadd L
.5254 .28452 2.5 -2.5 Mabsadd L
.5254 .28452 -2.5 -2.5 Mabsadd L
.5254 .28452 -2.5 2.5 Mabsadd L closepath F
.52857 .28373 -2.5 2.5 Mabsadd m
.52857 .28373 2.5 2.5 Mabsadd L
.52857 .28373 2.5 -2.5 Mabsadd L
.52857 .28373 -2.5 -2.5 Mabsadd L
.52857 .28373 -2.5 2.5 Mabsadd L closepath F
.53175 .28295 -2.5 2.5 Mabsadd m
.53175 .28295 2.5 2.5 Mabsadd L
.53175 .28295 2.5 -2.5 Mabsadd L
.53175 .28295 -2.5 -2.5 Mabsadd L
.53175 .28295 -2.5 2.5 Mabsadd L closepath F
.53492 .28218 -2.5 2.5 Mabsadd m
.53492 .28218 2.5 2.5 Mabsadd L
.53492 .28218 2.5 -2.5 Mabsadd L
.53492 .28218 -2.5 -2.5 Mabsadd L
.53492 .28218 -2.5 2.5 Mabsadd L closepath F
.5381 .28141 -2.5 2.5 Mabsadd m
.5381 .28141 2.5 2.5 Mabsadd L
.5381 .28141 2.5 -2.5 Mabsadd L
.5381 .28141 -2.5 -2.5 Mabsadd L
.5381 .28141 -2.5 2.5 Mabsadd L closepath F
.54127 .28066 -2.5 2.5 Mabsadd m
.54127 .28066 2.5 2.5 Mabsadd L
.54127 .28066 2.5 -2.5 Mabsadd L
.54127 .28066 -2.5 -2.5 Mabsadd L
.54127 .28066 -2.5 2.5 Mabsadd L closepath F
.54444 .27991 -2.5 2.5 Mabsadd m
.54444 .27991 2.5 2.5 Mabsadd L
.54444 .27991 2.5 -2.5 Mabsadd L
.54444 .27991 -2.5 -2.5 Mabsadd L
.54444 .27991 -2.5 2.5 Mabsadd L closepath F
.54762 .27917 -2.5 2.5 Mabsadd m
.54762 .27917 2.5 2.5 Mabsadd L
.54762 .27917 2.5 -2.5 Mabsadd L
.54762 .27917 -2.5 -2.5 Mabsadd L
.54762 .27917 -2.5 2.5 Mabsadd L closepath F
.55079 .27843 -2.5 2.5 Mabsadd m
.55079 .27843 2.5 2.5 Mabsadd L
.55079 .27843 2.5 -2.5 Mabsadd L
.55079 .27843 -2.5 -2.5 Mabsadd L
.55079 .27843 -2.5 2.5 Mabsadd L closepath F
.55397 .2777 -2.5 2.5 Mabsadd m
.55397 .2777 2.5 2.5 Mabsadd L
.55397 .2777 2.5 -2.5 Mabsadd L
.55397 .2777 -2.5 -2.5 Mabsadd L
.55397 .2777 -2.5 2.5 Mabsadd L closepath F
.55714 .27698 -2.5 2.5 Mabsadd m
.55714 .27698 2.5 2.5 Mabsadd L
.55714 .27698 2.5 -2.5 Mabsadd L
.55714 .27698 -2.5 -2.5 Mabsadd L
.55714 .27698 -2.5 2.5 Mabsadd L closepath F
.56032 .27627 -2.5 2.5 Mabsadd m
.56032 .27627 2.5 2.5 Mabsadd L
.56032 .27627 2.5 -2.5 Mabsadd L
.56032 .27627 -2.5 -2.5 Mabsadd L
.56032 .27627 -2.5 2.5 Mabsadd L closepath F
.56349 .27556 -2.5 2.5 Mabsadd m
.56349 .27556 2.5 2.5 Mabsadd L
.56349 .27556 2.5 -2.5 Mabsadd L
.56349 .27556 -2.5 -2.5 Mabsadd L
.56349 .27556 -2.5 2.5 Mabsadd L closepath F
.56667 .27487 -2.5 2.5 Mabsadd m
.56667 .27487 2.5 2.5 Mabsadd L
.56667 .27487 2.5 -2.5 Mabsadd L
.56667 .27487 -2.5 -2.5 Mabsadd L
.56667 .27487 -2.5 2.5 Mabsadd L closepath F
.56984 .27417 -2.5 2.5 Mabsadd m
.56984 .27417 2.5 2.5 Mabsadd L
.56984 .27417 2.5 -2.5 Mabsadd L
.56984 .27417 -2.5 -2.5 Mabsadd L
.56984 .27417 -2.5 2.5 Mabsadd L closepath F
.57302 .27349 -2.5 2.5 Mabsadd m
.57302 .27349 2.5 2.5 Mabsadd L
.57302 .27349 2.5 -2.5 Mabsadd L
.57302 .27349 -2.5 -2.5 Mabsadd L
.57302 .27349 -2.5 2.5 Mabsadd L closepath F
.57619 .27281 -2.5 2.5 Mabsadd m
.57619 .27281 2.5 2.5 Mabsadd L
.57619 .27281 2.5 -2.5 Mabsadd L
.57619 .27281 -2.5 -2.5 Mabsadd L
.57619 .27281 -2.5 2.5 Mabsadd L closepath F
.57937 .27214 -2.5 2.5 Mabsadd m
.57937 .27214 2.5 2.5 Mabsadd L
.57937 .27214 2.5 -2.5 Mabsadd L
.57937 .27214 -2.5 -2.5 Mabsadd L
.57937 .27214 -2.5 2.5 Mabsadd L closepath F
.58254 .27147 -2.5 2.5 Mabsadd m
.58254 .27147 2.5 2.5 Mabsadd L
.58254 .27147 2.5 -2.5 Mabsadd L
.58254 .27147 -2.5 -2.5 Mabsadd L
.58254 .27147 -2.5 2.5 Mabsadd L closepath F
.58571 .27082 -2.5 2.5 Mabsadd m
.58571 .27082 2.5 2.5 Mabsadd L
.58571 .27082 2.5 -2.5 Mabsadd L
.58571 .27082 -2.5 -2.5 Mabsadd L
.58571 .27082 -2.5 2.5 Mabsadd L closepath F
.58889 .27017 -2.5 2.5 Mabsadd m
.58889 .27017 2.5 2.5 Mabsadd L
.58889 .27017 2.5 -2.5 Mabsadd L
.58889 .27017 -2.5 -2.5 Mabsadd L
.58889 .27017 -2.5 2.5 Mabsadd L closepath F
.59206 .26952 -2.5 2.5 Mabsadd m
.59206 .26952 2.5 2.5 Mabsadd L
.59206 .26952 2.5 -2.5 Mabsadd L
.59206 .26952 -2.5 -2.5 Mabsadd L
.59206 .26952 -2.5 2.5 Mabsadd L closepath F
.59524 .26888 -2.5 2.5 Mabsadd m
.59524 .26888 2.5 2.5 Mabsadd L
.59524 .26888 2.5 -2.5 Mabsadd L
.59524 .26888 -2.5 -2.5 Mabsadd L
.59524 .26888 -2.5 2.5 Mabsadd L closepath F
.59841 .26825 -2.5 2.5 Mabsadd m
.59841 .26825 2.5 2.5 Mabsadd L
.59841 .26825 2.5 -2.5 Mabsadd L
.59841 .26825 -2.5 -2.5 Mabsadd L
.59841 .26825 -2.5 2.5 Mabsadd L closepath F
.60159 .26762 -2.5 2.5 Mabsadd m
.60159 .26762 2.5 2.5 Mabsadd L
.60159 .26762 2.5 -2.5 Mabsadd L
.60159 .26762 -2.5 -2.5 Mabsadd L
.60159 .26762 -2.5 2.5 Mabsadd L closepath F
.60476 .26701 -2.5 2.5 Mabsadd m
.60476 .26701 2.5 2.5 Mabsadd L
.60476 .26701 2.5 -2.5 Mabsadd L
.60476 .26701 -2.5 -2.5 Mabsadd L
.60476 .26701 -2.5 2.5 Mabsadd L closepath F
.60794 .26639 -2.5 2.5 Mabsadd m
.60794 .26639 2.5 2.5 Mabsadd L
.60794 .26639 2.5 -2.5 Mabsadd L
.60794 .26639 -2.5 -2.5 Mabsadd L
.60794 .26639 -2.5 2.5 Mabsadd L closepath F
.61111 .26579 -2.5 2.5 Mabsadd m
.61111 .26579 2.5 2.5 Mabsadd L
.61111 .26579 2.5 -2.5 Mabsadd L
.61111 .26579 -2.5 -2.5 Mabsadd L
.61111 .26579 -2.5 2.5 Mabsadd L closepath F
.61429 .26518 -2.5 2.5 Mabsadd m
.61429 .26518 2.5 2.5 Mabsadd L
.61429 .26518 2.5 -2.5 Mabsadd L
.61429 .26518 -2.5 -2.5 Mabsadd L
.61429 .26518 -2.5 2.5 Mabsadd L closepath F
.61746 .26459 -2.5 2.5 Mabsadd m
.61746 .26459 2.5 2.5 Mabsadd L
.61746 .26459 2.5 -2.5 Mabsadd L
.61746 .26459 -2.5 -2.5 Mabsadd L
.61746 .26459 -2.5 2.5 Mabsadd L closepath F
.62063 .264 -2.5 2.5 Mabsadd m
.62063 .264 2.5 2.5 Mabsadd L
.62063 .264 2.5 -2.5 Mabsadd L
.62063 .264 -2.5 -2.5 Mabsadd L
.62063 .264 -2.5 2.5 Mabsadd L closepath F
.62381 .26342 -2.5 2.5 Mabsadd m
.62381 .26342 2.5 2.5 Mabsadd L
.62381 .26342 2.5 -2.5 Mabsadd L
.62381 .26342 -2.5 -2.5 Mabsadd L
.62381 .26342 -2.5 2.5 Mabsadd L closepath F
.62698 .26284 -2.5 2.5 Mabsadd m
.62698 .26284 2.5 2.5 Mabsadd L
.62698 .26284 2.5 -2.5 Mabsadd L
.62698 .26284 -2.5 -2.5 Mabsadd L
.62698 .26284 -2.5 2.5 Mabsadd L closepath F
.63016 .26227 -2.5 2.5 Mabsadd m
.63016 .26227 2.5 2.5 Mabsadd L
.63016 .26227 2.5 -2.5 Mabsadd L
.63016 .26227 -2.5 -2.5 Mabsadd L
.63016 .26227 -2.5 2.5 Mabsadd L closepath F
.63333 .2617 -2.5 2.5 Mabsadd m
.63333 .2617 2.5 2.5 Mabsadd L
.63333 .2617 2.5 -2.5 Mabsadd L
.63333 .2617 -2.5 -2.5 Mabsadd L
.63333 .2617 -2.5 2.5 Mabsadd L closepath F
.63651 .26114 -2.5 2.5 Mabsadd m
.63651 .26114 2.5 2.5 Mabsadd L
.63651 .26114 2.5 -2.5 Mabsadd L
.63651 .26114 -2.5 -2.5 Mabsadd L
.63651 .26114 -2.5 2.5 Mabsadd L closepath F
.63968 .26059 -2.5 2.5 Mabsadd m
.63968 .26059 2.5 2.5 Mabsadd L
.63968 .26059 2.5 -2.5 Mabsadd L
.63968 .26059 -2.5 -2.5 Mabsadd L
.63968 .26059 -2.5 2.5 Mabsadd L closepath F
.64286 .26004 -2.5 2.5 Mabsadd m
.64286 .26004 2.5 2.5 Mabsadd L
.64286 .26004 2.5 -2.5 Mabsadd L
.64286 .26004 -2.5 -2.5 Mabsadd L
.64286 .26004 -2.5 2.5 Mabsadd L closepath F
.64603 .2595 -2.5 2.5 Mabsadd m
.64603 .2595 2.5 2.5 Mabsadd L
.64603 .2595 2.5 -2.5 Mabsadd L
.64603 .2595 -2.5 -2.5 Mabsadd L
.64603 .2595 -2.5 2.5 Mabsadd L closepath F
.64921 .25896 -2.5 2.5 Mabsadd m
.64921 .25896 2.5 2.5 Mabsadd L
.64921 .25896 2.5 -2.5 Mabsadd L
.64921 .25896 -2.5 -2.5 Mabsadd L
.64921 .25896 -2.5 2.5 Mabsadd L closepath F
.65238 .25842 -2.5 2.5 Mabsadd m
.65238 .25842 2.5 2.5 Mabsadd L
.65238 .25842 2.5 -2.5 Mabsadd L
.65238 .25842 -2.5 -2.5 Mabsadd L
.65238 .25842 -2.5 2.5 Mabsadd L closepath F
.65556 .2579 -2.5 2.5 Mabsadd m
.65556 .2579 2.5 2.5 Mabsadd L
.65556 .2579 2.5 -2.5 Mabsadd L
.65556 .2579 -2.5 -2.5 Mabsadd L
.65556 .2579 -2.5 2.5 Mabsadd L closepath F
.65873 .25737 -2.5 2.5 Mabsadd m
.65873 .25737 2.5 2.5 Mabsadd L
.65873 .25737 2.5 -2.5 Mabsadd L
.65873 .25737 -2.5 -2.5 Mabsadd L
.65873 .25737 -2.5 2.5 Mabsadd L closepath F
.6619 .25686 -2.5 2.5 Mabsadd m
.6619 .25686 2.5 2.5 Mabsadd L
.6619 .25686 2.5 -2.5 Mabsadd L
.6619 .25686 -2.5 -2.5 Mabsadd L
.6619 .25686 -2.5 2.5 Mabsadd L closepath F
.66508 .25635 -2.5 2.5 Mabsadd m
.66508 .25635 2.5 2.5 Mabsadd L
.66508 .25635 2.5 -2.5 Mabsadd L
.66508 .25635 -2.5 -2.5 Mabsadd L
.66508 .25635 -2.5 2.5 Mabsadd L closepath F
.66825 .25584 -2.5 2.5 Mabsadd m
.66825 .25584 2.5 2.5 Mabsadd L
.66825 .25584 2.5 -2.5 Mabsadd L
.66825 .25584 -2.5 -2.5 Mabsadd L
.66825 .25584 -2.5 2.5 Mabsadd L closepath F
.67143 .25534 -2.5 2.5 Mabsadd m
.67143 .25534 2.5 2.5 Mabsadd L
.67143 .25534 2.5 -2.5 Mabsadd L
.67143 .25534 -2.5 -2.5 Mabsadd L
.67143 .25534 -2.5 2.5 Mabsadd L closepath F
.6746 .25484 -2.5 2.5 Mabsadd m
.6746 .25484 2.5 2.5 Mabsadd L
.6746 .25484 2.5 -2.5 Mabsadd L
.6746 .25484 -2.5 -2.5 Mabsadd L
.6746 .25484 -2.5 2.5 Mabsadd L closepath F
.67778 .25435 -2.5 2.5 Mabsadd m
.67778 .25435 2.5 2.5 Mabsadd L
.67778 .25435 2.5 -2.5 Mabsadd L
.67778 .25435 -2.5 -2.5 Mabsadd L
.67778 .25435 -2.5 2.5 Mabsadd L closepath F
.68095 .25386 -2.5 2.5 Mabsadd m
.68095 .25386 2.5 2.5 Mabsadd L
.68095 .25386 2.5 -2.5 Mabsadd L
.68095 .25386 -2.5 -2.5 Mabsadd L
.68095 .25386 -2.5 2.5 Mabsadd L closepath F
.68413 .25338 -2.5 2.5 Mabsadd m
.68413 .25338 2.5 2.5 Mabsadd L
.68413 .25338 2.5 -2.5 Mabsadd L
.68413 .25338 -2.5 -2.5 Mabsadd L
.68413 .25338 -2.5 2.5 Mabsadd L closepath F
.6873 .2529 -2.5 2.5 Mabsadd m
.6873 .2529 2.5 2.5 Mabsadd L
.6873 .2529 2.5 -2.5 Mabsadd L
.6873 .2529 -2.5 -2.5 Mabsadd L
.6873 .2529 -2.5 2.5 Mabsadd L closepath F
.69048 .25243 -2.5 2.5 Mabsadd m
.69048 .25243 2.5 2.5 Mabsadd L
.69048 .25243 2.5 -2.5 Mabsadd L
.69048 .25243 -2.5 -2.5 Mabsadd L
.69048 .25243 -2.5 2.5 Mabsadd L closepath F
.69365 .25196 -2.5 2.5 Mabsadd m
.69365 .25196 2.5 2.5 Mabsadd L
.69365 .25196 2.5 -2.5 Mabsadd L
.69365 .25196 -2.5 -2.5 Mabsadd L
.69365 .25196 -2.5 2.5 Mabsadd L closepath F
.69683 .2515 -2.5 2.5 Mabsadd m
.69683 .2515 2.5 2.5 Mabsadd L
.69683 .2515 2.5 -2.5 Mabsadd L
.69683 .2515 -2.5 -2.5 Mabsadd L
.69683 .2515 -2.5 2.5 Mabsadd L closepath F
.7 .25104 -2.5 2.5 Mabsadd m
.7 .25104 2.5 2.5 Mabsadd L
.7 .25104 2.5 -2.5 Mabsadd L
.7 .25104 -2.5 -2.5 Mabsadd L
.7 .25104 -2.5 2.5 Mabsadd L closepath F
.70317 .25059 -2.5 2.5 Mabsadd m
.70317 .25059 2.5 2.5 Mabsadd L
.70317 .25059 2.5 -2.5 Mabsadd L
.70317 .25059 -2.5 -2.5 Mabsadd L
.70317 .25059 -2.5 2.5 Mabsadd L closepath F
.70635 .25014 -2.5 2.5 Mabsadd m
.70635 .25014 2.5 2.5 Mabsadd L
.70635 .25014 2.5 -2.5 Mabsadd L
.70635 .25014 -2.5 -2.5 Mabsadd L
.70635 .25014 -2.5 2.5 Mabsadd L closepath F
.70952 .2497 -2.5 2.5 Mabsadd m
.70952 .2497 2.5 2.5 Mabsadd L
.70952 .2497 2.5 -2.5 Mabsadd L
.70952 .2497 -2.5 -2.5 Mabsadd L
.70952 .2497 -2.5 2.5 Mabsadd L closepath F
.7127 .24926 -2.5 2.5 Mabsadd m
.7127 .24926 2.5 2.5 Mabsadd L
.7127 .24926 2.5 -2.5 Mabsadd L
.7127 .24926 -2.5 -2.5 Mabsadd L
.7127 .24926 -2.5 2.5 Mabsadd L closepath F
.71587 .24882 -2.5 2.5 Mabsadd m
.71587 .24882 2.5 2.5 Mabsadd L
.71587 .24882 2.5 -2.5 Mabsadd L
.71587 .24882 -2.5 -2.5 Mabsadd L
.71587 .24882 -2.5 2.5 Mabsadd L closepath F
.71905 .24839 -2.5 2.5 Mabsadd m
.71905 .24839 2.5 2.5 Mabsadd L
.71905 .24839 2.5 -2.5 Mabsadd L
.71905 .24839 -2.5 -2.5 Mabsadd L
.71905 .24839 -2.5 2.5 Mabsadd L closepath F
.72222 .24796 -2.5 2.5 Mabsadd m
.72222 .24796 2.5 2.5 Mabsadd L
.72222 .24796 2.5 -2.5 Mabsadd L
.72222 .24796 -2.5 -2.5 Mabsadd L
.72222 .24796 -2.5 2.5 Mabsadd L closepath F
.7254 .24754 -2.5 2.5 Mabsadd m
.7254 .24754 2.5 2.5 Mabsadd L
.7254 .24754 2.5 -2.5 Mabsadd L
.7254 .24754 -2.5 -2.5 Mabsadd L
.7254 .24754 -2.5 2.5 Mabsadd L closepath F
.72857 .24712 -2.5 2.5 Mabsadd m
.72857 .24712 2.5 2.5 Mabsadd L
.72857 .24712 2.5 -2.5 Mabsadd L
.72857 .24712 -2.5 -2.5 Mabsadd L
.72857 .24712 -2.5 2.5 Mabsadd L closepath F
.73175 .24671 -2.5 2.5 Mabsadd m
.73175 .24671 2.5 2.5 Mabsadd L
.73175 .24671 2.5 -2.5 Mabsadd L
.73175 .24671 -2.5 -2.5 Mabsadd L
.73175 .24671 -2.5 2.5 Mabsadd L closepath F
.73492 .2463 -2.5 2.5 Mabsadd m
.73492 .2463 2.5 2.5 Mabsadd L
.73492 .2463 2.5 -2.5 Mabsadd L
.73492 .2463 -2.5 -2.5 Mabsadd L
.73492 .2463 -2.5 2.5 Mabsadd L closepath F
.7381 .24589 -2.5 2.5 Mabsadd m
.7381 .24589 2.5 2.5 Mabsadd L
.7381 .24589 2.5 -2.5 Mabsadd L
.7381 .24589 -2.5 -2.5 Mabsadd L
.7381 .24589 -2.5 2.5 Mabsadd L closepath F
.74127 .24549 -2.5 2.5 Mabsadd m
.74127 .24549 2.5 2.5 Mabsadd L
.74127 .24549 2.5 -2.5 Mabsadd L
.74127 .24549 -2.5 -2.5 Mabsadd L
.74127 .24549 -2.5 2.5 Mabsadd L closepath F
.74444 .24509 -2.5 2.5 Mabsadd m
.74444 .24509 2.5 2.5 Mabsadd L
.74444 .24509 2.5 -2.5 Mabsadd L
.74444 .24509 -2.5 -2.5 Mabsadd L
.74444 .24509 -2.5 2.5 Mabsadd L closepath F
.74762 .2447 -2.5 2.5 Mabsadd m
.74762 .2447 2.5 2.5 Mabsadd L
.74762 .2447 2.5 -2.5 Mabsadd L
.74762 .2447 -2.5 -2.5 Mabsadd L
.74762 .2447 -2.5 2.5 Mabsadd L closepath F
.75079 .24431 -2.5 2.5 Mabsadd m
.75079 .24431 2.5 2.5 Mabsadd L
.75079 .24431 2.5 -2.5 Mabsadd L
.75079 .24431 -2.5 -2.5 Mabsadd L
.75079 .24431 -2.5 2.5 Mabsadd L closepath F
.75397 .24392 -2.5 2.5 Mabsadd m
.75397 .24392 2.5 2.5 Mabsadd L
.75397 .24392 2.5 -2.5 Mabsadd L
.75397 .24392 -2.5 -2.5 Mabsadd L
.75397 .24392 -2.5 2.5 Mabsadd L closepath F
.75714 .24354 -2.5 2.5 Mabsadd m
.75714 .24354 2.5 2.5 Mabsadd L
.75714 .24354 2.5 -2.5 Mabsadd L
.75714 .24354 -2.5 -2.5 Mabsadd L
.75714 .24354 -2.5 2.5 Mabsadd L closepath F
.76032 .24316 -2.5 2.5 Mabsadd m
.76032 .24316 2.5 2.5 Mabsadd L
.76032 .24316 2.5 -2.5 Mabsadd L
.76032 .24316 -2.5 -2.5 Mabsadd L
.76032 .24316 -2.5 2.5 Mabsadd L closepath F
.76349 .24278 -2.5 2.5 Mabsadd m
.76349 .24278 2.5 2.5 Mabsadd L
.76349 .24278 2.5 -2.5 Mabsadd L
.76349 .24278 -2.5 -2.5 Mabsadd L
.76349 .24278 -2.5 2.5 Mabsadd L closepath F
.76667 .24241 -2.5 2.5 Mabsadd m
.76667 .24241 2.5 2.5 Mabsadd L
.76667 .24241 2.5 -2.5 Mabsadd L
.76667 .24241 -2.5 -2.5 Mabsadd L
.76667 .24241 -2.5 2.5 Mabsadd L closepath F
.76984 .24205 -2.5 2.5 Mabsadd m
.76984 .24205 2.5 2.5 Mabsadd L
.76984 .24205 2.5 -2.5 Mabsadd L
.76984 .24205 -2.5 -2.5 Mabsadd L
.76984 .24205 -2.5 2.5 Mabsadd L closepath F
.77302 .24168 -2.5 2.5 Mabsadd m
.77302 .24168 2.5 2.5 Mabsadd L
.77302 .24168 2.5 -2.5 Mabsadd L
.77302 .24168 -2.5 -2.5 Mabsadd L
.77302 .24168 -2.5 2.5 Mabsadd L closepath F
.77619 .24132 -2.5 2.5 Mabsadd m
.77619 .24132 2.5 2.5 Mabsadd L
.77619 .24132 2.5 -2.5 Mabsadd L
.77619 .24132 -2.5 -2.5 Mabsadd L
.77619 .24132 -2.5 2.5 Mabsadd L closepath F
.77937 .24097 -2.5 2.5 Mabsadd m
.77937 .24097 2.5 2.5 Mabsadd L
.77937 .24097 2.5 -2.5 Mabsadd L
.77937 .24097 -2.5 -2.5 Mabsadd L
.77937 .24097 -2.5 2.5 Mabsadd L closepath F
.78254 .24061 -2.5 2.5 Mabsadd m
.78254 .24061 2.5 2.5 Mabsadd L
.78254 .24061 2.5 -2.5 Mabsadd L
.78254 .24061 -2.5 -2.5 Mabsadd L
.78254 .24061 -2.5 2.5 Mabsadd L closepath F
.78571 .24026 -2.5 2.5 Mabsadd m
.78571 .24026 2.5 2.5 Mabsadd L
.78571 .24026 2.5 -2.5 Mabsadd L
.78571 .24026 -2.5 -2.5 Mabsadd L
.78571 .24026 -2.5 2.5 Mabsadd L closepath F
.78889 .23992 -2.5 2.5 Mabsadd m
.78889 .23992 2.5 2.5 Mabsadd L
.78889 .23992 2.5 -2.5 Mabsadd L
.78889 .23992 -2.5 -2.5 Mabsadd L
.78889 .23992 -2.5 2.5 Mabsadd L closepath F
.79206 .23958 -2.5 2.5 Mabsadd m
.79206 .23958 2.5 2.5 Mabsadd L
.79206 .23958 2.5 -2.5 Mabsadd L
.79206 .23958 -2.5 -2.5 Mabsadd L
.79206 .23958 -2.5 2.5 Mabsadd L closepath F
.79524 .23924 -2.5 2.5 Mabsadd m
.79524 .23924 2.5 2.5 Mabsadd L
.79524 .23924 2.5 -2.5 Mabsadd L
.79524 .23924 -2.5 -2.5 Mabsadd L
.79524 .23924 -2.5 2.5 Mabsadd L closepath F
.79841 .2389 -2.5 2.5 Mabsadd m
.79841 .2389 2.5 2.5 Mabsadd L
.79841 .2389 2.5 -2.5 Mabsadd L
.79841 .2389 -2.5 -2.5 Mabsadd L
.79841 .2389 -2.5 2.5 Mabsadd L closepath F
.80159 .23857 -2.5 2.5 Mabsadd m
.80159 .23857 2.5 2.5 Mabsadd L
.80159 .23857 2.5 -2.5 Mabsadd L
.80159 .23857 -2.5 -2.5 Mabsadd L
.80159 .23857 -2.5 2.5 Mabsadd L closepath F
.80476 .23824 -2.5 2.5 Mabsadd m
.80476 .23824 2.5 2.5 Mabsadd L
.80476 .23824 2.5 -2.5 Mabsadd L
.80476 .23824 -2.5 -2.5 Mabsadd L
.80476 .23824 -2.5 2.5 Mabsadd L closepath F
.80794 .23792 -2.5 2.5 Mabsadd m
.80794 .23792 2.5 2.5 Mabsadd L
.80794 .23792 2.5 -2.5 Mabsadd L
.80794 .23792 -2.5 -2.5 Mabsadd L
.80794 .23792 -2.5 2.5 Mabsadd L closepath F
.81111 .23759 -2.5 2.5 Mabsadd m
.81111 .23759 2.5 2.5 Mabsadd L
.81111 .23759 2.5 -2.5 Mabsadd L
.81111 .23759 -2.5 -2.5 Mabsadd L
.81111 .23759 -2.5 2.5 Mabsadd L closepath F
.81429 .23727 -2.5 2.5 Mabsadd m
.81429 .23727 2.5 2.5 Mabsadd L
.81429 .23727 2.5 -2.5 Mabsadd L
.81429 .23727 -2.5 -2.5 Mabsadd L
.81429 .23727 -2.5 2.5 Mabsadd L closepath F
.81746 .23696 -2.5 2.5 Mabsadd m
.81746 .23696 2.5 2.5 Mabsadd L
.81746 .23696 2.5 -2.5 Mabsadd L
.81746 .23696 -2.5 -2.5 Mabsadd L
.81746 .23696 -2.5 2.5 Mabsadd L closepath F
.82063 .23665 -2.5 2.5 Mabsadd m
.82063 .23665 2.5 2.5 Mabsadd L
.82063 .23665 2.5 -2.5 Mabsadd L
.82063 .23665 -2.5 -2.5 Mabsadd L
.82063 .23665 -2.5 2.5 Mabsadd L closepath F
.82381 .23634 -2.5 2.5 Mabsadd m
.82381 .23634 2.5 2.5 Mabsadd L
.82381 .23634 2.5 -2.5 Mabsadd L
.82381 .23634 -2.5 -2.5 Mabsadd L
.82381 .23634 -2.5 2.5 Mabsadd L closepath F
.82698 .23603 -2.5 2.5 Mabsadd m
.82698 .23603 2.5 2.5 Mabsadd L
.82698 .23603 2.5 -2.5 Mabsadd L
.82698 .23603 -2.5 -2.5 Mabsadd L
.82698 .23603 -2.5 2.5 Mabsadd L closepath F
.83016 .23573 -2.5 2.5 Mabsadd m
.83016 .23573 2.5 2.5 Mabsadd L
.83016 .23573 2.5 -2.5 Mabsadd L
.83016 .23573 -2.5 -2.5 Mabsadd L
.83016 .23573 -2.5 2.5 Mabsadd L closepath F
.83333 .23543 -2.5 2.5 Mabsadd m
.83333 .23543 2.5 2.5 Mabsadd L
.83333 .23543 2.5 -2.5 Mabsadd L
.83333 .23543 -2.5 -2.5 Mabsadd L
.83333 .23543 -2.5 2.5 Mabsadd L closepath F
.83651 .23513 -2.5 2.5 Mabsadd m
.83651 .23513 2.5 2.5 Mabsadd L
.83651 .23513 2.5 -2.5 Mabsadd L
.83651 .23513 -2.5 -2.5 Mabsadd L
.83651 .23513 -2.5 2.5 Mabsadd L closepath F
.83968 .23483 -2.5 2.5 Mabsadd m
.83968 .23483 2.5 2.5 Mabsadd L
.83968 .23483 2.5 -2.5 Mabsadd L
.83968 .23483 -2.5 -2.5 Mabsadd L
.83968 .23483 -2.5 2.5 Mabsadd L closepath F
.84286 .23454 -2.5 2.5 Mabsadd m
.84286 .23454 2.5 2.5 Mabsadd L
.84286 .23454 2.5 -2.5 Mabsadd L
.84286 .23454 -2.5 -2.5 Mabsadd L
.84286 .23454 -2.5 2.5 Mabsadd L closepath F
.84603 .23425 -2.5 2.5 Mabsadd m
.84603 .23425 2.5 2.5 Mabsadd L
.84603 .23425 2.5 -2.5 Mabsadd L
.84603 .23425 -2.5 -2.5 Mabsadd L
.84603 .23425 -2.5 2.5 Mabsadd L closepath F
.84921 .23397 -2.5 2.5 Mabsadd m
.84921 .23397 2.5 2.5 Mabsadd L
.84921 .23397 2.5 -2.5 Mabsadd L
.84921 .23397 -2.5 -2.5 Mabsadd L
.84921 .23397 -2.5 2.5 Mabsadd L closepath F
.85238 .23368 -2.5 2.5 Mabsadd m
.85238 .23368 2.5 2.5 Mabsadd L
.85238 .23368 2.5 -2.5 Mabsadd L
.85238 .23368 -2.5 -2.5 Mabsadd L
.85238 .23368 -2.5 2.5 Mabsadd L closepath F
.85556 .2334 -2.5 2.5 Mabsadd m
.85556 .2334 2.5 2.5 Mabsadd L
.85556 .2334 2.5 -2.5 Mabsadd L
.85556 .2334 -2.5 -2.5 Mabsadd L
.85556 .2334 -2.5 2.5 Mabsadd L closepath F
.85873 .23313 -2.5 2.5 Mabsadd m
.85873 .23313 2.5 2.5 Mabsadd L
.85873 .23313 2.5 -2.5 Mabsadd L
.85873 .23313 -2.5 -2.5 Mabsadd L
.85873 .23313 -2.5 2.5 Mabsadd L closepath F
.8619 .23285 -2.5 2.5 Mabsadd m
.8619 .23285 2.5 2.5 Mabsadd L
.8619 .23285 2.5 -2.5 Mabsadd L
.8619 .23285 -2.5 -2.5 Mabsadd L
.8619 .23285 -2.5 2.5 Mabsadd L closepath F
.86508 .23258 -2.5 2.5 Mabsadd m
.86508 .23258 2.5 2.5 Mabsadd L
.86508 .23258 2.5 -2.5 Mabsadd L
.86508 .23258 -2.5 -2.5 Mabsadd L
.86508 .23258 -2.5 2.5 Mabsadd L closepath F
.86825 .23231 -2.5 2.5 Mabsadd m
.86825 .23231 2.5 2.5 Mabsadd L
.86825 .23231 2.5 -2.5 Mabsadd L
.86825 .23231 -2.5 -2.5 Mabsadd L
.86825 .23231 -2.5 2.5 Mabsadd L closepath F
.87143 .23205 -2.5 2.5 Mabsadd m
.87143 .23205 2.5 2.5 Mabsadd L
.87143 .23205 2.5 -2.5 Mabsadd L
.87143 .23205 -2.5 -2.5 Mabsadd L
.87143 .23205 -2.5 2.5 Mabsadd L closepath F
.8746 .23178 -2.5 2.5 Mabsadd m
.8746 .23178 2.5 2.5 Mabsadd L
.8746 .23178 2.5 -2.5 Mabsadd L
.8746 .23178 -2.5 -2.5 Mabsadd L
.8746 .23178 -2.5 2.5 Mabsadd L closepath F
.87778 .23152 -2.5 2.5 Mabsadd m
.87778 .23152 2.5 2.5 Mabsadd L
.87778 .23152 2.5 -2.5 Mabsadd L
.87778 .23152 -2.5 -2.5 Mabsadd L
.87778 .23152 -2.5 2.5 Mabsadd L closepath F
.88095 .23126 -2.5 2.5 Mabsadd m
.88095 .23126 2.5 2.5 Mabsadd L
.88095 .23126 2.5 -2.5 Mabsadd L
.88095 .23126 -2.5 -2.5 Mabsadd L
.88095 .23126 -2.5 2.5 Mabsadd L closepath F
.88413 .23101 -2.5 2.5 Mabsadd m
.88413 .23101 2.5 2.5 Mabsadd L
.88413 .23101 2.5 -2.5 Mabsadd L
.88413 .23101 -2.5 -2.5 Mabsadd L
.88413 .23101 -2.5 2.5 Mabsadd L closepath F
.8873 .23075 -2.5 2.5 Mabsadd m
.8873 .23075 2.5 2.5 Mabsadd L
.8873 .23075 2.5 -2.5 Mabsadd L
.8873 .23075 -2.5 -2.5 Mabsadd L
.8873 .23075 -2.5 2.5 Mabsadd L closepath F
.89048 .2305 -2.5 2.5 Mabsadd m
.89048 .2305 2.5 2.5 Mabsadd L
.89048 .2305 2.5 -2.5 Mabsadd L
.89048 .2305 -2.5 -2.5 Mabsadd L
.89048 .2305 -2.5 2.5 Mabsadd L closepath F
.89365 .23026 -2.5 2.5 Mabsadd m
.89365 .23026 2.5 2.5 Mabsadd L
.89365 .23026 2.5 -2.5 Mabsadd L
.89365 .23026 -2.5 -2.5 Mabsadd L
.89365 .23026 -2.5 2.5 Mabsadd L closepath F
.89683 .23001 -2.5 2.5 Mabsadd m
.89683 .23001 2.5 2.5 Mabsadd L
.89683 .23001 2.5 -2.5 Mabsadd L
.89683 .23001 -2.5 -2.5 Mabsadd L
.89683 .23001 -2.5 2.5 Mabsadd L closepath F
.9 .22977 -2.5 2.5 Mabsadd m
.9 .22977 2.5 2.5 Mabsadd L
.9 .22977 2.5 -2.5 Mabsadd L
.9 .22977 -2.5 -2.5 Mabsadd L
.9 .22977 -2.5 2.5 Mabsadd L closepath F
.90317 .22953 -2.5 2.5 Mabsadd m
.90317 .22953 2.5 2.5 Mabsadd L
.90317 .22953 2.5 -2.5 Mabsadd L
.90317 .22953 -2.5 -2.5 Mabsadd L
.90317 .22953 -2.5 2.5 Mabsadd L closepath F
.90635 .22929 -2.5 2.5 Mabsadd m
.90635 .22929 2.5 2.5 Mabsadd L
.90635 .22929 2.5 -2.5 Mabsadd L
.90635 .22929 -2.5 -2.5 Mabsadd L
.90635 .22929 -2.5 2.5 Mabsadd L closepath F
.90952 .22905 -2.5 2.5 Mabsadd m
.90952 .22905 2.5 2.5 Mabsadd L
.90952 .22905 2.5 -2.5 Mabsadd L
.90952 .22905 -2.5 -2.5 Mabsadd L
.90952 .22905 -2.5 2.5 Mabsadd L closepath F
.9127 .22882 -2.5 2.5 Mabsadd m
.9127 .22882 2.5 2.5 Mabsadd L
.9127 .22882 2.5 -2.5 Mabsadd L
.9127 .22882 -2.5 -2.5 Mabsadd L
.9127 .22882 -2.5 2.5 Mabsadd L closepath F
.91587 .22859 -2.5 2.5 Mabsadd m
.91587 .22859 2.5 2.5 Mabsadd L
.91587 .22859 2.5 -2.5 Mabsadd L
.91587 .22859 -2.5 -2.5 Mabsadd L
.91587 .22859 -2.5 2.5 Mabsadd L closepath F
.91905 .22836 -2.5 2.5 Mabsadd m
.91905 .22836 2.5 2.5 Mabsadd L
.91905 .22836 2.5 -2.5 Mabsadd L
.91905 .22836 -2.5 -2.5 Mabsadd L
.91905 .22836 -2.5 2.5 Mabsadd L closepath F
.92222 .22813 -2.5 2.5 Mabsadd m
.92222 .22813 2.5 2.5 Mabsadd L
.92222 .22813 2.5 -2.5 Mabsadd L
.92222 .22813 -2.5 -2.5 Mabsadd L
.92222 .22813 -2.5 2.5 Mabsadd L closepath F
.9254 .22791 -2.5 2.5 Mabsadd m
.9254 .22791 2.5 2.5 Mabsadd L
.9254 .22791 2.5 -2.5 Mabsadd L
.9254 .22791 -2.5 -2.5 Mabsadd L
.9254 .22791 -2.5 2.5 Mabsadd L closepath F
.92857 .22768 -2.5 2.5 Mabsadd m
.92857 .22768 2.5 2.5 Mabsadd L
.92857 .22768 2.5 -2.5 Mabsadd L
.92857 .22768 -2.5 -2.5 Mabsadd L
.92857 .22768 -2.5 2.5 Mabsadd L closepath F
.93175 .22746 -2.5 2.5 Mabsadd m
.93175 .22746 2.5 2.5 Mabsadd L
.93175 .22746 2.5 -2.5 Mabsadd L
.93175 .22746 -2.5 -2.5 Mabsadd L
.93175 .22746 -2.5 2.5 Mabsadd L closepath F
.93492 .22725 -2.5 2.5 Mabsadd m
.93492 .22725 2.5 2.5 Mabsadd L
.93492 .22725 2.5 -2.5 Mabsadd L
.93492 .22725 -2.5 -2.5 Mabsadd L
.93492 .22725 -2.5 2.5 Mabsadd L closepath F
.9381 .22703 -2.5 2.5 Mabsadd m
.9381 .22703 2.5 2.5 Mabsadd L
.9381 .22703 2.5 -2.5 Mabsadd L
.9381 .22703 -2.5 -2.5 Mabsadd L
.9381 .22703 -2.5 2.5 Mabsadd L closepath F
.94127 .22682 -2.5 2.5 Mabsadd m
.94127 .22682 2.5 2.5 Mabsadd L
.94127 .22682 2.5 -2.5 Mabsadd L
.94127 .22682 -2.5 -2.5 Mabsadd L
.94127 .22682 -2.5 2.5 Mabsadd L closepath F
.94444 .22661 -2.5 2.5 Mabsadd m
.94444 .22661 2.5 2.5 Mabsadd L
.94444 .22661 2.5 -2.5 Mabsadd L
.94444 .22661 -2.5 -2.5 Mabsadd L
.94444 .22661 -2.5 2.5 Mabsadd L closepath F
.94762 .2264 -2.5 2.5 Mabsadd m
.94762 .2264 2.5 2.5 Mabsadd L
.94762 .2264 2.5 -2.5 Mabsadd L
.94762 .2264 -2.5 -2.5 Mabsadd L
.94762 .2264 -2.5 2.5 Mabsadd L closepath F
.95079 .22619 -2.5 2.5 Mabsadd m
.95079 .22619 2.5 2.5 Mabsadd L
.95079 .22619 2.5 -2.5 Mabsadd L
.95079 .22619 -2.5 -2.5 Mabsadd L
.95079 .22619 -2.5 2.5 Mabsadd L closepath F
.95397 .22598 -2.5 2.5 Mabsadd m
.95397 .22598 2.5 2.5 Mabsadd L
.95397 .22598 2.5 -2.5 Mabsadd L
.95397 .22598 -2.5 -2.5 Mabsadd L
.95397 .22598 -2.5 2.5 Mabsadd L closepath F
.95714 .22578 -2.5 2.5 Mabsadd m
.95714 .22578 2.5 2.5 Mabsadd L
.95714 .22578 2.5 -2.5 Mabsadd L
.95714 .22578 -2.5 -2.5 Mabsadd L
.95714 .22578 -2.5 2.5 Mabsadd L closepath F
.96032 .22558 -2.5 2.5 Mabsadd m
.96032 .22558 2.5 2.5 Mabsadd L
.96032 .22558 2.5 -2.5 Mabsadd L
.96032 .22558 -2.5 -2.5 Mabsadd L
.96032 .22558 -2.5 2.5 Mabsadd L closepath F
.96349 .22538 -2.5 2.5 Mabsadd m
.96349 .22538 2.5 2.5 Mabsadd L
.96349 .22538 2.5 -2.5 Mabsadd L
.96349 .22538 -2.5 -2.5 Mabsadd L
.96349 .22538 -2.5 2.5 Mabsadd L closepath F
.96667 .22518 -2.5 2.5 Mabsadd m
.96667 .22518 2.5 2.5 Mabsadd L
.96667 .22518 2.5 -2.5 Mabsadd L
.96667 .22518 -2.5 -2.5 Mabsadd L
.96667 .22518 -2.5 2.5 Mabsadd L closepath F
.96984 .22499 -2.5 2.5 Mabsadd m
.96984 .22499 2.5 2.5 Mabsadd L
.96984 .22499 2.5 -2.5 Mabsadd L
.96984 .22499 -2.5 -2.5 Mabsadd L
.96984 .22499 -2.5 2.5 Mabsadd L closepath F
.97302 .2248 -2.5 2.5 Mabsadd m
.97302 .2248 2.5 2.5 Mabsadd L
.97302 .2248 2.5 -2.5 Mabsadd L
.97302 .2248 -2.5 -2.5 Mabsadd L
.97302 .2248 -2.5 2.5 Mabsadd L closepath F
.97619 .22461 -2.5 2.5 Mabsadd m
.97619 .22461 2.5 2.5 Mabsadd L
.97619 .22461 2.5 -2.5 Mabsadd L
.97619 .22461 -2.5 -2.5 Mabsadd L
.97619 .22461 -2.5 2.5 Mabsadd L closepath F
.0075 w
.13087 .61803 m
.13175 .61688 L
.13492 .61277 L
.1381 .6087 L
.14127 .60467 L
.14444 .60068 L
.14762 .59673 L
.15079 .59282 L
.15397 .58895 L
.15714 .58511 L
.16032 .58132 L
.16349 .57756 L
.16667 .57385 L
.16984 .57016 L
.17302 .56652 L
.17619 .56291 L
.17937 .55934 L
.18254 .5558 L
.18571 .5523 L
.18889 .54883 L
.19206 .5454 L
.19524 .54201 L
.19841 .53864 L
.20159 .53531 L
.20476 .53202 L
.20794 .52875 L
.21111 .52552 L
.21429 .52232 L
.21746 .51916 L
.22063 .51602 L
.22381 .51292 L
.22698 .50985 L
.23016 .50681 L
.23333 .50379 L
.23651 .50081 L
.23968 .49786 L
.24286 .49494 L
.24603 .49205 L
.24921 .48918 L
.25238 .48635 L
.25556 .48354 L
.25873 .48076 L
.2619 .47801 L
.26508 .47529 L
.26825 .47259 L
.27143 .46992 L
.2746 .46728 L
.27778 .46467 L
.28095 .46208 L
.28413 .45951 L
Mistroke
.2873 .45697 L
.29048 .45446 L
.29365 .45197 L
.29683 .44951 L
.3 .44707 L
.30317 .44466 L
.30635 .44227 L
.30952 .4399 L
.3127 .43756 L
.31587 .43524 L
.31905 .43295 L
.32222 .43067 L
.3254 .42842 L
.32857 .4262 L
.33175 .42399 L
.33492 .42181 L
.3381 .41965 L
.34127 .41751 L
.34444 .41539 L
.34762 .41329 L
.35079 .41122 L
.35397 .40916 L
.35714 .40713 L
.36032 .40511 L
.36349 .40312 L
.36667 .40114 L
.36984 .39919 L
.37302 .39725 L
.37619 .39534 L
.37937 .39344 L
.38254 .39156 L
.38571 .38971 L
.38889 .38787 L
.39206 .38604 L
.39524 .38424 L
.39841 .38245 L
.40159 .38069 L
.40476 .37894 L
.40794 .3772 L
.41111 .37549 L
.41429 .37379 L
.41746 .37211 L
.42063 .37045 L
.42381 .3688 L
.42698 .36717 L
.43016 .36555 L
.43333 .36395 L
.43651 .36237 L
.43968 .3608 L
.44286 .35925 L
Mistroke
.44603 .35772 L
.44921 .3562 L
.45238 .35469 L
.45556 .3532 L
.45873 .35173 L
.4619 .35027 L
.46508 .34882 L
.46825 .34739 L
.47143 .34597 L
.4746 .34457 L
.47778 .34318 L
.48095 .34181 L
.48413 .34044 L
.4873 .3391 L
.49048 .33776 L
.49365 .33644 L
.49683 .33513 L
.5 .33384 L
.50317 .33256 L
.50635 .33129 L
.50952 .33003 L
.5127 .32879 L
.51587 .32756 L
.51905 .32634 L
.52222 .32513 L
.5254 .32394 L
.52857 .32276 L
.53175 .32159 L
.53492 .32043 L
.5381 .31928 L
.54127 .31814 L
.54444 .31702 L
.54762 .31591 L
.55079 .3148 L
.55397 .31371 L
.55714 .31263 L
.56032 .31156 L
.56349 .3105 L
.56667 .30946 L
.56984 .30842 L
.57302 .30739 L
.57619 .30637 L
.57937 .30537 L
.58254 .30437 L
.58571 .30338 L
.58889 .30241 L
.59206 .30144 L
.59524 .30048 L
.59841 .29953 L
.60159 .29859 L
Mistroke
.60476 .29767 L
.60794 .29675 L
.61111 .29584 L
.61429 .29493 L
.61746 .29404 L
.62063 .29316 L
.62381 .29228 L
.62698 .29142 L
.63016 .29056 L
.63333 .28971 L
.63651 .28887 L
.63968 .28804 L
.64286 .28722 L
.64603 .2864 L
.64921 .28559 L
.65238 .28479 L
.65556 .284 L
.65873 .28322 L
.6619 .28244 L
.66508 .28168 L
.66825 .28092 L
.67143 .28016 L
.6746 .27942 L
.67778 .27868 L
.68095 .27795 L
.68413 .27723 L
.6873 .27651 L
.69048 .27581 L
.69365 .2751 L
.69683 .27441 L
.7 .27372 L
.70317 .27304 L
.70635 .27237 L
.70952 .2717 L
.7127 .27104 L
.71587 .27039 L
.71905 .26974 L
.72222 .2691 L
.7254 .26847 L
.72857 .26784 L
.73175 .26722 L
.73492 .2666 L
.7381 .26599 L
.74127 .26539 L
.74444 .26479 L
.74762 .2642 L
.75079 .26362 L
.75397 .26304 L
.75714 .26246 L
.76032 .2619 L
Mistroke
.76349 .26133 L
.76667 .26078 L
.76984 .26023 L
.77302 .25968 L
.77619 .25914 L
.77937 .25861 L
.78254 .25808 L
.78571 .25755 L
.78889 .25703 L
.79206 .25652 L
.79524 .25601 L
.79841 .25551 L
.80159 .25501 L
.80476 .25452 L
.80794 .25403 L
.81111 .25355 L
.81429 .25307 L
.81746 .25259 L
.82063 .25212 L
.82381 .25166 L
.82698 .2512 L
.83016 .25075 L
.83333 .2503 L
.83651 .24985 L
.83968 .24941 L
.84286 .24897 L
.84603 .24854 L
.84921 .24811 L
.85238 .24768 L
.85556 .24726 L
.85873 .24685 L
.8619 .24644 L
.86508 .24603 L
.86825 .24563 L
.87143 .24523 L
.8746 .24483 L
.87778 .24444 L
.88095 .24405 L
.88413 .24367 L
.8873 .24329 L
.89048 .24291 L
.89365 .24254 L
.89683 .24217 L
.9 .24181 L
.90317 .24145 L
.90635 .24109 L
.90952 .24073 L
.9127 .24038 L
.91587 .24004 L
.91905 .23969 L
Mistroke
.92222 .23935 L
.9254 .23902 L
.92857 .23868 L
.93175 .23835 L
.93492 .23803 L
.9381 .2377 L
.94127 .23738 L
.94444 .23707 L
.94762 .23675 L
.95079 .23644 L
.95397 .23613 L
.95714 .23583 L
.96032 .23553 L
.96349 .23523 L
.96667 .23493 L
.96984 .23464 L
.97302 .23435 L
.97619 .23407 L
Mfstroke
.0001 w
.02698 .7786 0 2.5 Mabsadd m
.02698 .7786 -2.165 -1.25 Mabsadd L
.02698 .7786 2.165 -1.25 Mabsadd L
.02698 .7786 0 2.5 Mabsadd L closepath F
.03016 .77287 0 2.5 Mabsadd m
.03016 .77287 -2.165 -1.25 Mabsadd L
.03016 .77287 2.165 -1.25 Mabsadd L
.03016 .77287 0 2.5 Mabsadd L closepath F
.03333 .7672 0 2.5 Mabsadd m
.03333 .7672 -2.165 -1.25 Mabsadd L
.03333 .7672 2.165 -1.25 Mabsadd L
.03333 .7672 0 2.5 Mabsadd L closepath F
.03651 .76158 0 2.5 Mabsadd m
.03651 .76158 -2.165 -1.25 Mabsadd L
.03651 .76158 2.165 -1.25 Mabsadd L
.03651 .76158 0 2.5 Mabsadd L closepath F
.03968 .75602 0 2.5 Mabsadd m
.03968 .75602 -2.165 -1.25 Mabsadd L
.03968 .75602 2.165 -1.25 Mabsadd L
.03968 .75602 0 2.5 Mabsadd L closepath F
.04286 .75052 0 2.5 Mabsadd m
.04286 .75052 -2.165 -1.25 Mabsadd L
.04286 .75052 2.165 -1.25 Mabsadd L
.04286 .75052 0 2.5 Mabsadd L closepath F
.04603 .74507 0 2.5 Mabsadd m
.04603 .74507 -2.165 -1.25 Mabsadd L
.04603 .74507 2.165 -1.25 Mabsadd L
.04603 .74507 0 2.5 Mabsadd L closepath F
.04921 .73968 0 2.5 Mabsadd m
.04921 .73968 -2.165 -1.25 Mabsadd L
.04921 .73968 2.165 -1.25 Mabsadd L
.04921 .73968 0 2.5 Mabsadd L closepath F
.05238 .73434 0 2.5 Mabsadd m
.05238 .73434 -2.165 -1.25 Mabsadd L
.05238 .73434 2.165 -1.25 Mabsadd L
.05238 .73434 0 2.5 Mabsadd L closepath F
.05556 .72905 0 2.5 Mabsadd m
.05556 .72905 -2.165 -1.25 Mabsadd L
.05556 .72905 2.165 -1.25 Mabsadd L
.05556 .72905 0 2.5 Mabsadd L closepath F
.05873 .72382 0 2.5 Mabsadd m
.05873 .72382 -2.165 -1.25 Mabsadd L
.05873 .72382 2.165 -1.25 Mabsadd L
.05873 .72382 0 2.5 Mabsadd L closepath F
.0619 .71864 0 2.5 Mabsadd m
.0619 .71864 -2.165 -1.25 Mabsadd L
.0619 .71864 2.165 -1.25 Mabsadd L
.0619 .71864 0 2.5 Mabsadd L closepath F
.06508 .71351 0 2.5 Mabsadd m
.06508 .71351 -2.165 -1.25 Mabsadd L
.06508 .71351 2.165 -1.25 Mabsadd L
.06508 .71351 0 2.5 Mabsadd L closepath F
.06825 .70843 0 2.5 Mabsadd m
.06825 .70843 -2.165 -1.25 Mabsadd L
.06825 .70843 2.165 -1.25 Mabsadd L
.06825 .70843 0 2.5 Mabsadd L closepath F
.07143 .7034 0 2.5 Mabsadd m
.07143 .7034 -2.165 -1.25 Mabsadd L
.07143 .7034 2.165 -1.25 Mabsadd L
.07143 .7034 0 2.5 Mabsadd L closepath F
.0746 .69842 0 2.5 Mabsadd m
.0746 .69842 -2.165 -1.25 Mabsadd L
.0746 .69842 2.165 -1.25 Mabsadd L
.0746 .69842 0 2.5 Mabsadd L closepath F
.07778 .6935 0 2.5 Mabsadd m
.07778 .6935 -2.165 -1.25 Mabsadd L
.07778 .6935 2.165 -1.25 Mabsadd L
.07778 .6935 0 2.5 Mabsadd L closepath F
.08095 .68862 0 2.5 Mabsadd m
.08095 .68862 -2.165 -1.25 Mabsadd L
.08095 .68862 2.165 -1.25 Mabsadd L
.08095 .68862 0 2.5 Mabsadd L closepath F
.08413 .68379 0 2.5 Mabsadd m
.08413 .68379 -2.165 -1.25 Mabsadd L
.08413 .68379 2.165 -1.25 Mabsadd L
.08413 .68379 0 2.5 Mabsadd L closepath F
.0873 .67901 0 2.5 Mabsadd m
.0873 .67901 -2.165 -1.25 Mabsadd L
.0873 .67901 2.165 -1.25 Mabsadd L
.0873 .67901 0 2.5 Mabsadd L closepath F
.09048 .67427 0 2.5 Mabsadd m
.09048 .67427 -2.165 -1.25 Mabsadd L
.09048 .67427 2.165 -1.25 Mabsadd L
.09048 .67427 0 2.5 Mabsadd L closepath F
.09365 .66959 0 2.5 Mabsadd m
.09365 .66959 -2.165 -1.25 Mabsadd L
.09365 .66959 2.165 -1.25 Mabsadd L
.09365 .66959 0 2.5 Mabsadd L closepath F
.09683 .66495 0 2.5 Mabsadd m
.09683 .66495 -2.165 -1.25 Mabsadd L
.09683 .66495 2.165 -1.25 Mabsadd L
.09683 .66495 0 2.5 Mabsadd L closepath F
.1 .66036 0 2.5 Mabsadd m
.1 .66036 -2.165 -1.25 Mabsadd L
.1 .66036 2.165 -1.25 Mabsadd L
.1 .66036 0 2.5 Mabsadd L closepath F
.10317 .65581 0 2.5 Mabsadd m
.10317 .65581 -2.165 -1.25 Mabsadd L
.10317 .65581 2.165 -1.25 Mabsadd L
.10317 .65581 0 2.5 Mabsadd L closepath F
.10635 .65131 0 2.5 Mabsadd m
.10635 .65131 -2.165 -1.25 Mabsadd L
.10635 .65131 2.165 -1.25 Mabsadd L
.10635 .65131 0 2.5 Mabsadd L closepath F
.10952 .64685 0 2.5 Mabsadd m
.10952 .64685 -2.165 -1.25 Mabsadd L
.10952 .64685 2.165 -1.25 Mabsadd L
.10952 .64685 0 2.5 Mabsadd L closepath F
.1127 .64244 0 2.5 Mabsadd m
.1127 .64244 -2.165 -1.25 Mabsadd L
.1127 .64244 2.165 -1.25 Mabsadd L
.1127 .64244 0 2.5 Mabsadd L closepath F
.11587 .63807 0 2.5 Mabsadd m
.11587 .63807 -2.165 -1.25 Mabsadd L
.11587 .63807 2.165 -1.25 Mabsadd L
.11587 .63807 0 2.5 Mabsadd L closepath F
.11905 .63375 0 2.5 Mabsadd m
.11905 .63375 -2.165 -1.25 Mabsadd L
.11905 .63375 2.165 -1.25 Mabsadd L
.11905 .63375 0 2.5 Mabsadd L closepath F
.12222 .62947 0 2.5 Mabsadd m
.12222 .62947 -2.165 -1.25 Mabsadd L
.12222 .62947 2.165 -1.25 Mabsadd L
.12222 .62947 0 2.5 Mabsadd L closepath F
.1254 .62523 0 2.5 Mabsadd m
.1254 .62523 -2.165 -1.25 Mabsadd L
.1254 .62523 2.165 -1.25 Mabsadd L
.1254 .62523 0 2.5 Mabsadd L closepath F
.12857 .62104 0 2.5 Mabsadd m
.12857 .62104 -2.165 -1.25 Mabsadd L
.12857 .62104 2.165 -1.25 Mabsadd L
.12857 .62104 0 2.5 Mabsadd L closepath F
.13175 .61688 0 2.5 Mabsadd m
.13175 .61688 -2.165 -1.25 Mabsadd L
.13175 .61688 2.165 -1.25 Mabsadd L
.13175 .61688 0 2.5 Mabsadd L closepath F
.13492 .61277 0 2.5 Mabsadd m
.13492 .61277 -2.165 -1.25 Mabsadd L
.13492 .61277 2.165 -1.25 Mabsadd L
.13492 .61277 0 2.5 Mabsadd L closepath F
.1381 .6087 0 2.5 Mabsadd m
.1381 .6087 -2.165 -1.25 Mabsadd L
.1381 .6087 2.165 -1.25 Mabsadd L
.1381 .6087 0 2.5 Mabsadd L closepath F
.14127 .60467 0 2.5 Mabsadd m
.14127 .60467 -2.165 -1.25 Mabsadd L
.14127 .60467 2.165 -1.25 Mabsadd L
.14127 .60467 0 2.5 Mabsadd L closepath F
.14444 .60068 0 2.5 Mabsadd m
.14444 .60068 -2.165 -1.25 Mabsadd L
.14444 .60068 2.165 -1.25 Mabsadd L
.14444 .60068 0 2.5 Mabsadd L closepath F
.14762 .59673 0 2.5 Mabsadd m
.14762 .59673 -2.165 -1.25 Mabsadd L
.14762 .59673 2.165 -1.25 Mabsadd L
.14762 .59673 0 2.5 Mabsadd L closepath F
.15079 .59282 0 2.5 Mabsadd m
.15079 .59282 -2.165 -1.25 Mabsadd L
.15079 .59282 2.165 -1.25 Mabsadd L
.15079 .59282 0 2.5 Mabsadd L closepath F
.15397 .58895 0 2.5 Mabsadd m
.15397 .58895 -2.165 -1.25 Mabsadd L
.15397 .58895 2.165 -1.25 Mabsadd L
.15397 .58895 0 2.5 Mabsadd L closepath F
.15714 .58511 0 2.5 Mabsadd m
.15714 .58511 -2.165 -1.25 Mabsadd L
.15714 .58511 2.165 -1.25 Mabsadd L
.15714 .58511 0 2.5 Mabsadd L closepath F
.16032 .58132 0 2.5 Mabsadd m
.16032 .58132 -2.165 -1.25 Mabsadd L
.16032 .58132 2.165 -1.25 Mabsadd L
.16032 .58132 0 2.5 Mabsadd L closepath F
.16349 .57756 0 2.5 Mabsadd m
.16349 .57756 -2.165 -1.25 Mabsadd L
.16349 .57756 2.165 -1.25 Mabsadd L
.16349 .57756 0 2.5 Mabsadd L closepath F
.16667 .57385 0 2.5 Mabsadd m
.16667 .57385 -2.165 -1.25 Mabsadd L
.16667 .57385 2.165 -1.25 Mabsadd L
.16667 .57385 0 2.5 Mabsadd L closepath F
.16984 .57016 0 2.5 Mabsadd m
.16984 .57016 -2.165 -1.25 Mabsadd L
.16984 .57016 2.165 -1.25 Mabsadd L
.16984 .57016 0 2.5 Mabsadd L closepath F
.17302 .56652 0 2.5 Mabsadd m
.17302 .56652 -2.165 -1.25 Mabsadd L
.17302 .56652 2.165 -1.25 Mabsadd L
.17302 .56652 0 2.5 Mabsadd L closepath F
.17619 .56291 0 2.5 Mabsadd m
.17619 .56291 -2.165 -1.25 Mabsadd L
.17619 .56291 2.165 -1.25 Mabsadd L
.17619 .56291 0 2.5 Mabsadd L closepath F
.17937 .55934 0 2.5 Mabsadd m
.17937 .55934 -2.165 -1.25 Mabsadd L
.17937 .55934 2.165 -1.25 Mabsadd L
.17937 .55934 0 2.5 Mabsadd L closepath F
.18254 .5558 0 2.5 Mabsadd m
.18254 .5558 -2.165 -1.25 Mabsadd L
.18254 .5558 2.165 -1.25 Mabsadd L
.18254 .5558 0 2.5 Mabsadd L closepath F
.18571 .5523 0 2.5 Mabsadd m
.18571 .5523 -2.165 -1.25 Mabsadd L
.18571 .5523 2.165 -1.25 Mabsadd L
.18571 .5523 0 2.5 Mabsadd L closepath F
.18889 .54883 0 2.5 Mabsadd m
.18889 .54883 -2.165 -1.25 Mabsadd L
.18889 .54883 2.165 -1.25 Mabsadd L
.18889 .54883 0 2.5 Mabsadd L closepath F
.19206 .5454 0 2.5 Mabsadd m
.19206 .5454 -2.165 -1.25 Mabsadd L
.19206 .5454 2.165 -1.25 Mabsadd L
.19206 .5454 0 2.5 Mabsadd L closepath F
.19524 .54201 0 2.5 Mabsadd m
.19524 .54201 -2.165 -1.25 Mabsadd L
.19524 .54201 2.165 -1.25 Mabsadd L
.19524 .54201 0 2.5 Mabsadd L closepath F
.19841 .53864 0 2.5 Mabsadd m
.19841 .53864 -2.165 -1.25 Mabsadd L
.19841 .53864 2.165 -1.25 Mabsadd L
.19841 .53864 0 2.5 Mabsadd L closepath F
.20159 .53531 0 2.5 Mabsadd m
.20159 .53531 -2.165 -1.25 Mabsadd L
.20159 .53531 2.165 -1.25 Mabsadd L
.20159 .53531 0 2.5 Mabsadd L closepath F
.20476 .53202 0 2.5 Mabsadd m
.20476 .53202 -2.165 -1.25 Mabsadd L
.20476 .53202 2.165 -1.25 Mabsadd L
.20476 .53202 0 2.5 Mabsadd L closepath F
.20794 .52875 0 2.5 Mabsadd m
.20794 .52875 -2.165 -1.25 Mabsadd L
.20794 .52875 2.165 -1.25 Mabsadd L
.20794 .52875 0 2.5 Mabsadd L closepath F
.21111 .52552 0 2.5 Mabsadd m
.21111 .52552 -2.165 -1.25 Mabsadd L
.21111 .52552 2.165 -1.25 Mabsadd L
.21111 .52552 0 2.5 Mabsadd L closepath F
.21429 .52232 0 2.5 Mabsadd m
.21429 .52232 -2.165 -1.25 Mabsadd L
.21429 .52232 2.165 -1.25 Mabsadd L
.21429 .52232 0 2.5 Mabsadd L closepath F
.21746 .51916 0 2.5 Mabsadd m
.21746 .51916 -2.165 -1.25 Mabsadd L
.21746 .51916 2.165 -1.25 Mabsadd L
.21746 .51916 0 2.5 Mabsadd L closepath F
.22063 .51602 0 2.5 Mabsadd m
.22063 .51602 -2.165 -1.25 Mabsadd L
.22063 .51602 2.165 -1.25 Mabsadd L
.22063 .51602 0 2.5 Mabsadd L closepath F
.22381 .51292 0 2.5 Mabsadd m
.22381 .51292 -2.165 -1.25 Mabsadd L
.22381 .51292 2.165 -1.25 Mabsadd L
.22381 .51292 0 2.5 Mabsadd L closepath F
.22698 .50985 0 2.5 Mabsadd m
.22698 .50985 -2.165 -1.25 Mabsadd L
.22698 .50985 2.165 -1.25 Mabsadd L
.22698 .50985 0 2.5 Mabsadd L closepath F
.23016 .50681 0 2.5 Mabsadd m
.23016 .50681 -2.165 -1.25 Mabsadd L
.23016 .50681 2.165 -1.25 Mabsadd L
.23016 .50681 0 2.5 Mabsadd L closepath F
.23333 .50379 0 2.5 Mabsadd m
.23333 .50379 -2.165 -1.25 Mabsadd L
.23333 .50379 2.165 -1.25 Mabsadd L
.23333 .50379 0 2.5 Mabsadd L closepath F
.23651 .50081 0 2.5 Mabsadd m
.23651 .50081 -2.165 -1.25 Mabsadd L
.23651 .50081 2.165 -1.25 Mabsadd L
.23651 .50081 0 2.5 Mabsadd L closepath F
.23968 .49786 0 2.5 Mabsadd m
.23968 .49786 -2.165 -1.25 Mabsadd L
.23968 .49786 2.165 -1.25 Mabsadd L
.23968 .49786 0 2.5 Mabsadd L closepath F
.24286 .49494 0 2.5 Mabsadd m
.24286 .49494 -2.165 -1.25 Mabsadd L
.24286 .49494 2.165 -1.25 Mabsadd L
.24286 .49494 0 2.5 Mabsadd L closepath F
.24603 .49205 0 2.5 Mabsadd m
.24603 .49205 -2.165 -1.25 Mabsadd L
.24603 .49205 2.165 -1.25 Mabsadd L
.24603 .49205 0 2.5 Mabsadd L closepath F
.24921 .48918 0 2.5 Mabsadd m
.24921 .48918 -2.165 -1.25 Mabsadd L
.24921 .48918 2.165 -1.25 Mabsadd L
.24921 .48918 0 2.5 Mabsadd L closepath F
.25238 .48635 0 2.5 Mabsadd m
.25238 .48635 -2.165 -1.25 Mabsadd L
.25238 .48635 2.165 -1.25 Mabsadd L
.25238 .48635 0 2.5 Mabsadd L closepath F
.25556 .48354 0 2.5 Mabsadd m
.25556 .48354 -2.165 -1.25 Mabsadd L
.25556 .48354 2.165 -1.25 Mabsadd L
.25556 .48354 0 2.5 Mabsadd L closepath F
.25873 .48076 0 2.5 Mabsadd m
.25873 .48076 -2.165 -1.25 Mabsadd L
.25873 .48076 2.165 -1.25 Mabsadd L
.25873 .48076 0 2.5 Mabsadd L closepath F
.2619 .47801 0 2.5 Mabsadd m
.2619 .47801 -2.165 -1.25 Mabsadd L
.2619 .47801 2.165 -1.25 Mabsadd L
.2619 .47801 0 2.5 Mabsadd L closepath F
.26508 .47529 0 2.5 Mabsadd m
.26508 .47529 -2.165 -1.25 Mabsadd L
.26508 .47529 2.165 -1.25 Mabsadd L
.26508 .47529 0 2.5 Mabsadd L closepath F
.26825 .47259 0 2.5 Mabsadd m
.26825 .47259 -2.165 -1.25 Mabsadd L
.26825 .47259 2.165 -1.25 Mabsadd L
.26825 .47259 0 2.5 Mabsadd L closepath F
.27143 .46992 0 2.5 Mabsadd m
.27143 .46992 -2.165 -1.25 Mabsadd L
.27143 .46992 2.165 -1.25 Mabsadd L
.27143 .46992 0 2.5 Mabsadd L closepath F
.2746 .46728 0 2.5 Mabsadd m
.2746 .46728 -2.165 -1.25 Mabsadd L
.2746 .46728 2.165 -1.25 Mabsadd L
.2746 .46728 0 2.5 Mabsadd L closepath F
.27778 .46467 0 2.5 Mabsadd m
.27778 .46467 -2.165 -1.25 Mabsadd L
.27778 .46467 2.165 -1.25 Mabsadd L
.27778 .46467 0 2.5 Mabsadd L closepath F
.28095 .46208 0 2.5 Mabsadd m
.28095 .46208 -2.165 -1.25 Mabsadd L
.28095 .46208 2.165 -1.25 Mabsadd L
.28095 .46208 0 2.5 Mabsadd L closepath F
.28413 .45951 0 2.5 Mabsadd m
.28413 .45951 -2.165 -1.25 Mabsadd L
.28413 .45951 2.165 -1.25 Mabsadd L
.28413 .45951 0 2.5 Mabsadd L closepath F
.2873 .45697 0 2.5 Mabsadd m
.2873 .45697 -2.165 -1.25 Mabsadd L
.2873 .45697 2.165 -1.25 Mabsadd L
.2873 .45697 0 2.5 Mabsadd L closepath F
.29048 .45446 0 2.5 Mabsadd m
.29048 .45446 -2.165 -1.25 Mabsadd L
.29048 .45446 2.165 -1.25 Mabsadd L
.29048 .45446 0 2.5 Mabsadd L closepath F
.29365 .45197 0 2.5 Mabsadd m
.29365 .45197 -2.165 -1.25 Mabsadd L
.29365 .45197 2.165 -1.25 Mabsadd L
.29365 .45197 0 2.5 Mabsadd L closepath F
.29683 .44951 0 2.5 Mabsadd m
.29683 .44951 -2.165 -1.25 Mabsadd L
.29683 .44951 2.165 -1.25 Mabsadd L
.29683 .44951 0 2.5 Mabsadd L closepath F
.3 .44707 0 2.5 Mabsadd m
.3 .44707 -2.165 -1.25 Mabsadd L
.3 .44707 2.165 -1.25 Mabsadd L
.3 .44707 0 2.5 Mabsadd L closepath F
.30317 .44466 0 2.5 Mabsadd m
.30317 .44466 -2.165 -1.25 Mabsadd L
.30317 .44466 2.165 -1.25 Mabsadd L
.30317 .44466 0 2.5 Mabsadd L closepath F
.30635 .44227 0 2.5 Mabsadd m
.30635 .44227 -2.165 -1.25 Mabsadd L
.30635 .44227 2.165 -1.25 Mabsadd L
.30635 .44227 0 2.5 Mabsadd L closepath F
.30952 .4399 0 2.5 Mabsadd m
.30952 .4399 -2.165 -1.25 Mabsadd L
.30952 .4399 2.165 -1.25 Mabsadd L
.30952 .4399 0 2.5 Mabsadd L closepath F
.3127 .43756 0 2.5 Mabsadd m
.3127 .43756 -2.165 -1.25 Mabsadd L
.3127 .43756 2.165 -1.25 Mabsadd L
.3127 .43756 0 2.5 Mabsadd L closepath F
.31587 .43524 0 2.5 Mabsadd m
.31587 .43524 -2.165 -1.25 Mabsadd L
.31587 .43524 2.165 -1.25 Mabsadd L
.31587 .43524 0 2.5 Mabsadd L closepath F
.31905 .43295 0 2.5 Mabsadd m
.31905 .43295 -2.165 -1.25 Mabsadd L
.31905 .43295 2.165 -1.25 Mabsadd L
.31905 .43295 0 2.5 Mabsadd L closepath F
.32222 .43067 0 2.5 Mabsadd m
.32222 .43067 -2.165 -1.25 Mabsadd L
.32222 .43067 2.165 -1.25 Mabsadd L
.32222 .43067 0 2.5 Mabsadd L closepath F
.3254 .42842 0 2.5 Mabsadd m
.3254 .42842 -2.165 -1.25 Mabsadd L
.3254 .42842 2.165 -1.25 Mabsadd L
.3254 .42842 0 2.5 Mabsadd L closepath F
.32857 .4262 0 2.5 Mabsadd m
.32857 .4262 -2.165 -1.25 Mabsadd L
.32857 .4262 2.165 -1.25 Mabsadd L
.32857 .4262 0 2.5 Mabsadd L closepath F
.33175 .42399 0 2.5 Mabsadd m
.33175 .42399 -2.165 -1.25 Mabsadd L
.33175 .42399 2.165 -1.25 Mabsadd L
.33175 .42399 0 2.5 Mabsadd L closepath F
.33492 .42181 0 2.5 Mabsadd m
.33492 .42181 -2.165 -1.25 Mabsadd L
.33492 .42181 2.165 -1.25 Mabsadd L
.33492 .42181 0 2.5 Mabsadd L closepath F
.3381 .41965 0 2.5 Mabsadd m
.3381 .41965 -2.165 -1.25 Mabsadd L
.3381 .41965 2.165 -1.25 Mabsadd L
.3381 .41965 0 2.5 Mabsadd L closepath F
.34127 .41751 0 2.5 Mabsadd m
.34127 .41751 -2.165 -1.25 Mabsadd L
.34127 .41751 2.165 -1.25 Mabsadd L
.34127 .41751 0 2.5 Mabsadd L closepath F
.34444 .41539 0 2.5 Mabsadd m
.34444 .41539 -2.165 -1.25 Mabsadd L
.34444 .41539 2.165 -1.25 Mabsadd L
.34444 .41539 0 2.5 Mabsadd L closepath F
.34762 .41329 0 2.5 Mabsadd m
.34762 .41329 -2.165 -1.25 Mabsadd L
.34762 .41329 2.165 -1.25 Mabsadd L
.34762 .41329 0 2.5 Mabsadd L closepath F
.35079 .41122 0 2.5 Mabsadd m
.35079 .41122 -2.165 -1.25 Mabsadd L
.35079 .41122 2.165 -1.25 Mabsadd L
.35079 .41122 0 2.5 Mabsadd L closepath F
.35397 .40916 0 2.5 Mabsadd m
.35397 .40916 -2.165 -1.25 Mabsadd L
.35397 .40916 2.165 -1.25 Mabsadd L
.35397 .40916 0 2.5 Mabsadd L closepath F
.35714 .40713 0 2.5 Mabsadd m
.35714 .40713 -2.165 -1.25 Mabsadd L
.35714 .40713 2.165 -1.25 Mabsadd L
.35714 .40713 0 2.5 Mabsadd L closepath F
.36032 .40511 0 2.5 Mabsadd m
.36032 .40511 -2.165 -1.25 Mabsadd L
.36032 .40511 2.165 -1.25 Mabsadd L
.36032 .40511 0 2.5 Mabsadd L closepath F
.36349 .40312 0 2.5 Mabsadd m
.36349 .40312 -2.165 -1.25 Mabsadd L
.36349 .40312 2.165 -1.25 Mabsadd L
.36349 .40312 0 2.5 Mabsadd L closepath F
.36667 .40114 0 2.5 Mabsadd m
.36667 .40114 -2.165 -1.25 Mabsadd L
.36667 .40114 2.165 -1.25 Mabsadd L
.36667 .40114 0 2.5 Mabsadd L closepath F
.36984 .39919 0 2.5 Mabsadd m
.36984 .39919 -2.165 -1.25 Mabsadd L
.36984 .39919 2.165 -1.25 Mabsadd L
.36984 .39919 0 2.5 Mabsadd L closepath F
.37302 .39725 0 2.5 Mabsadd m
.37302 .39725 -2.165 -1.25 Mabsadd L
.37302 .39725 2.165 -1.25 Mabsadd L
.37302 .39725 0 2.5 Mabsadd L closepath F
.37619 .39534 0 2.5 Mabsadd m
.37619 .39534 -2.165 -1.25 Mabsadd L
.37619 .39534 2.165 -1.25 Mabsadd L
.37619 .39534 0 2.5 Mabsadd L closepath F
.37937 .39344 0 2.5 Mabsadd m
.37937 .39344 -2.165 -1.25 Mabsadd L
.37937 .39344 2.165 -1.25 Mabsadd L
.37937 .39344 0 2.5 Mabsadd L closepath F
.38254 .39156 0 2.5 Mabsadd m
.38254 .39156 -2.165 -1.25 Mabsadd L
.38254 .39156 2.165 -1.25 Mabsadd L
.38254 .39156 0 2.5 Mabsadd L closepath F
.38571 .38971 0 2.5 Mabsadd m
.38571 .38971 -2.165 -1.25 Mabsadd L
.38571 .38971 2.165 -1.25 Mabsadd L
.38571 .38971 0 2.5 Mabsadd L closepath F
.38889 .38787 0 2.5 Mabsadd m
.38889 .38787 -2.165 -1.25 Mabsadd L
.38889 .38787 2.165 -1.25 Mabsadd L
.38889 .38787 0 2.5 Mabsadd L closepath F
.39206 .38604 0 2.5 Mabsadd m
.39206 .38604 -2.165 -1.25 Mabsadd L
.39206 .38604 2.165 -1.25 Mabsadd L
.39206 .38604 0 2.5 Mabsadd L closepath F
.39524 .38424 0 2.5 Mabsadd m
.39524 .38424 -2.165 -1.25 Mabsadd L
.39524 .38424 2.165 -1.25 Mabsadd L
.39524 .38424 0 2.5 Mabsadd L closepath F
.39841 .38245 0 2.5 Mabsadd m
.39841 .38245 -2.165 -1.25 Mabsadd L
.39841 .38245 2.165 -1.25 Mabsadd L
.39841 .38245 0 2.5 Mabsadd L closepath F
.40159 .38069 0 2.5 Mabsadd m
.40159 .38069 -2.165 -1.25 Mabsadd L
.40159 .38069 2.165 -1.25 Mabsadd L
.40159 .38069 0 2.5 Mabsadd L closepath F
.40476 .37894 0 2.5 Mabsadd m
.40476 .37894 -2.165 -1.25 Mabsadd L
.40476 .37894 2.165 -1.25 Mabsadd L
.40476 .37894 0 2.5 Mabsadd L closepath F
.40794 .3772 0 2.5 Mabsadd m
.40794 .3772 -2.165 -1.25 Mabsadd L
.40794 .3772 2.165 -1.25 Mabsadd L
.40794 .3772 0 2.5 Mabsadd L closepath F
.41111 .37549 0 2.5 Mabsadd m
.41111 .37549 -2.165 -1.25 Mabsadd L
.41111 .37549 2.165 -1.25 Mabsadd L
.41111 .37549 0 2.5 Mabsadd L closepath F
.41429 .37379 0 2.5 Mabsadd m
.41429 .37379 -2.165 -1.25 Mabsadd L
.41429 .37379 2.165 -1.25 Mabsadd L
.41429 .37379 0 2.5 Mabsadd L closepath F
.41746 .37211 0 2.5 Mabsadd m
.41746 .37211 -2.165 -1.25 Mabsadd L
.41746 .37211 2.165 -1.25 Mabsadd L
.41746 .37211 0 2.5 Mabsadd L closepath F
.42063 .37045 0 2.5 Mabsadd m
.42063 .37045 -2.165 -1.25 Mabsadd L
.42063 .37045 2.165 -1.25 Mabsadd L
.42063 .37045 0 2.5 Mabsadd L closepath F
.42381 .3688 0 2.5 Mabsadd m
.42381 .3688 -2.165 -1.25 Mabsadd L
.42381 .3688 2.165 -1.25 Mabsadd L
.42381 .3688 0 2.5 Mabsadd L closepath F
.42698 .36717 0 2.5 Mabsadd m
.42698 .36717 -2.165 -1.25 Mabsadd L
.42698 .36717 2.165 -1.25 Mabsadd L
.42698 .36717 0 2.5 Mabsadd L closepath F
.43016 .36555 0 2.5 Mabsadd m
.43016 .36555 -2.165 -1.25 Mabsadd L
.43016 .36555 2.165 -1.25 Mabsadd L
.43016 .36555 0 2.5 Mabsadd L closepath F
.43333 .36395 0 2.5 Mabsadd m
.43333 .36395 -2.165 -1.25 Mabsadd L
.43333 .36395 2.165 -1.25 Mabsadd L
.43333 .36395 0 2.5 Mabsadd L closepath F
.43651 .36237 0 2.5 Mabsadd m
.43651 .36237 -2.165 -1.25 Mabsadd L
.43651 .36237 2.165 -1.25 Mabsadd L
.43651 .36237 0 2.5 Mabsadd L closepath F
.43968 .3608 0 2.5 Mabsadd m
.43968 .3608 -2.165 -1.25 Mabsadd L
.43968 .3608 2.165 -1.25 Mabsadd L
.43968 .3608 0 2.5 Mabsadd L closepath F
.44286 .35925 0 2.5 Mabsadd m
.44286 .35925 -2.165 -1.25 Mabsadd L
.44286 .35925 2.165 -1.25 Mabsadd L
.44286 .35925 0 2.5 Mabsadd L closepath F
.44603 .35772 0 2.5 Mabsadd m
.44603 .35772 -2.165 -1.25 Mabsadd L
.44603 .35772 2.165 -1.25 Mabsadd L
.44603 .35772 0 2.5 Mabsadd L closepath F
.44921 .3562 0 2.5 Mabsadd m
.44921 .3562 -2.165 -1.25 Mabsadd L
.44921 .3562 2.165 -1.25 Mabsadd L
.44921 .3562 0 2.5 Mabsadd L closepath F
.45238 .35469 0 2.5 Mabsadd m
.45238 .35469 -2.165 -1.25 Mabsadd L
.45238 .35469 2.165 -1.25 Mabsadd L
.45238 .35469 0 2.5 Mabsadd L closepath F
.45556 .3532 0 2.5 Mabsadd m
.45556 .3532 -2.165 -1.25 Mabsadd L
.45556 .3532 2.165 -1.25 Mabsadd L
.45556 .3532 0 2.5 Mabsadd L closepath F
.45873 .35173 0 2.5 Mabsadd m
.45873 .35173 -2.165 -1.25 Mabsadd L
.45873 .35173 2.165 -1.25 Mabsadd L
.45873 .35173 0 2.5 Mabsadd L closepath F
.4619 .35027 0 2.5 Mabsadd m
.4619 .35027 -2.165 -1.25 Mabsadd L
.4619 .35027 2.165 -1.25 Mabsadd L
.4619 .35027 0 2.5 Mabsadd L closepath F
.46508 .34882 0 2.5 Mabsadd m
.46508 .34882 -2.165 -1.25 Mabsadd L
.46508 .34882 2.165 -1.25 Mabsadd L
.46508 .34882 0 2.5 Mabsadd L closepath F
.46825 .34739 0 2.5 Mabsadd m
.46825 .34739 -2.165 -1.25 Mabsadd L
.46825 .34739 2.165 -1.25 Mabsadd L
.46825 .34739 0 2.5 Mabsadd L closepath F
.47143 .34597 0 2.5 Mabsadd m
.47143 .34597 -2.165 -1.25 Mabsadd L
.47143 .34597 2.165 -1.25 Mabsadd L
.47143 .34597 0 2.5 Mabsadd L closepath F
.4746 .34457 0 2.5 Mabsadd m
.4746 .34457 -2.165 -1.25 Mabsadd L
.4746 .34457 2.165 -1.25 Mabsadd L
.4746 .34457 0 2.5 Mabsadd L closepath F
.47778 .34318 0 2.5 Mabsadd m
.47778 .34318 -2.165 -1.25 Mabsadd L
.47778 .34318 2.165 -1.25 Mabsadd L
.47778 .34318 0 2.5 Mabsadd L closepath F
.48095 .34181 0 2.5 Mabsadd m
.48095 .34181 -2.165 -1.25 Mabsadd L
.48095 .34181 2.165 -1.25 Mabsadd L
.48095 .34181 0 2.5 Mabsadd L closepath F
.48413 .34044 0 2.5 Mabsadd m
.48413 .34044 -2.165 -1.25 Mabsadd L
.48413 .34044 2.165 -1.25 Mabsadd L
.48413 .34044 0 2.5 Mabsadd L closepath F
.4873 .3391 0 2.5 Mabsadd m
.4873 .3391 -2.165 -1.25 Mabsadd L
.4873 .3391 2.165 -1.25 Mabsadd L
.4873 .3391 0 2.5 Mabsadd L closepath F
.49048 .33776 0 2.5 Mabsadd m
.49048 .33776 -2.165 -1.25 Mabsadd L
.49048 .33776 2.165 -1.25 Mabsadd L
.49048 .33776 0 2.5 Mabsadd L closepath F
.49365 .33644 0 2.5 Mabsadd m
.49365 .33644 -2.165 -1.25 Mabsadd L
.49365 .33644 2.165 -1.25 Mabsadd L
.49365 .33644 0 2.5 Mabsadd L closepath F
.49683 .33513 0 2.5 Mabsadd m
.49683 .33513 -2.165 -1.25 Mabsadd L
.49683 .33513 2.165 -1.25 Mabsadd L
.49683 .33513 0 2.5 Mabsadd L closepath F
.5 .33384 0 2.5 Mabsadd m
.5 .33384 -2.165 -1.25 Mabsadd L
.5 .33384 2.165 -1.25 Mabsadd L
.5 .33384 0 2.5 Mabsadd L closepath F
.50317 .33256 0 2.5 Mabsadd m
.50317 .33256 -2.165 -1.25 Mabsadd L
.50317 .33256 2.165 -1.25 Mabsadd L
.50317 .33256 0 2.5 Mabsadd L closepath F
.50635 .33129 0 2.5 Mabsadd m
.50635 .33129 -2.165 -1.25 Mabsadd L
.50635 .33129 2.165 -1.25 Mabsadd L
.50635 .33129 0 2.5 Mabsadd L closepath F
.50952 .33003 0 2.5 Mabsadd m
.50952 .33003 -2.165 -1.25 Mabsadd L
.50952 .33003 2.165 -1.25 Mabsadd L
.50952 .33003 0 2.5 Mabsadd L closepath F
.5127 .32879 0 2.5 Mabsadd m
.5127 .32879 -2.165 -1.25 Mabsadd L
.5127 .32879 2.165 -1.25 Mabsadd L
.5127 .32879 0 2.5 Mabsadd L closepath F
.51587 .32756 0 2.5 Mabsadd m
.51587 .32756 -2.165 -1.25 Mabsadd L
.51587 .32756 2.165 -1.25 Mabsadd L
.51587 .32756 0 2.5 Mabsadd L closepath F
.51905 .32634 0 2.5 Mabsadd m
.51905 .32634 -2.165 -1.25 Mabsadd L
.51905 .32634 2.165 -1.25 Mabsadd L
.51905 .32634 0 2.5 Mabsadd L closepath F
.52222 .32513 0 2.5 Mabsadd m
.52222 .32513 -2.165 -1.25 Mabsadd L
.52222 .32513 2.165 -1.25 Mabsadd L
.52222 .32513 0 2.5 Mabsadd L closepath F
.5254 .32394 0 2.5 Mabsadd m
.5254 .32394 -2.165 -1.25 Mabsadd L
.5254 .32394 2.165 -1.25 Mabsadd L
.5254 .32394 0 2.5 Mabsadd L closepath F
.52857 .32276 0 2.5 Mabsadd m
.52857 .32276 -2.165 -1.25 Mabsadd L
.52857 .32276 2.165 -1.25 Mabsadd L
.52857 .32276 0 2.5 Mabsadd L closepath F
.53175 .32159 0 2.5 Mabsadd m
.53175 .32159 -2.165 -1.25 Mabsadd L
.53175 .32159 2.165 -1.25 Mabsadd L
.53175 .32159 0 2.5 Mabsadd L closepath F
.53492 .32043 0 2.5 Mabsadd m
.53492 .32043 -2.165 -1.25 Mabsadd L
.53492 .32043 2.165 -1.25 Mabsadd L
.53492 .32043 0 2.5 Mabsadd L closepath F
.5381 .31928 0 2.5 Mabsadd m
.5381 .31928 -2.165 -1.25 Mabsadd L
.5381 .31928 2.165 -1.25 Mabsadd L
.5381 .31928 0 2.5 Mabsadd L closepath F
.54127 .31814 0 2.5 Mabsadd m
.54127 .31814 -2.165 -1.25 Mabsadd L
.54127 .31814 2.165 -1.25 Mabsadd L
.54127 .31814 0 2.5 Mabsadd L closepath F
.54444 .31702 0 2.5 Mabsadd m
.54444 .31702 -2.165 -1.25 Mabsadd L
.54444 .31702 2.165 -1.25 Mabsadd L
.54444 .31702 0 2.5 Mabsadd L closepath F
.54762 .31591 0 2.5 Mabsadd m
.54762 .31591 -2.165 -1.25 Mabsadd L
.54762 .31591 2.165 -1.25 Mabsadd L
.54762 .31591 0 2.5 Mabsadd L closepath F
.55079 .3148 0 2.5 Mabsadd m
.55079 .3148 -2.165 -1.25 Mabsadd L
.55079 .3148 2.165 -1.25 Mabsadd L
.55079 .3148 0 2.5 Mabsadd L closepath F
.55397 .31371 0 2.5 Mabsadd m
.55397 .31371 -2.165 -1.25 Mabsadd L
.55397 .31371 2.165 -1.25 Mabsadd L
.55397 .31371 0 2.5 Mabsadd L closepath F
.55714 .31263 0 2.5 Mabsadd m
.55714 .31263 -2.165 -1.25 Mabsadd L
.55714 .31263 2.165 -1.25 Mabsadd L
.55714 .31263 0 2.5 Mabsadd L closepath F
.56032 .31156 0 2.5 Mabsadd m
.56032 .31156 -2.165 -1.25 Mabsadd L
.56032 .31156 2.165 -1.25 Mabsadd L
.56032 .31156 0 2.5 Mabsadd L closepath F
.56349 .3105 0 2.5 Mabsadd m
.56349 .3105 -2.165 -1.25 Mabsadd L
.56349 .3105 2.165 -1.25 Mabsadd L
.56349 .3105 0 2.5 Mabsadd L closepath F
.56667 .30946 0 2.5 Mabsadd m
.56667 .30946 -2.165 -1.25 Mabsadd L
.56667 .30946 2.165 -1.25 Mabsadd L
.56667 .30946 0 2.5 Mabsadd L closepath F
.56984 .30842 0 2.5 Mabsadd m
.56984 .30842 -2.165 -1.25 Mabsadd L
.56984 .30842 2.165 -1.25 Mabsadd L
.56984 .30842 0 2.5 Mabsadd L closepath F
.57302 .30739 0 2.5 Mabsadd m
.57302 .30739 -2.165 -1.25 Mabsadd L
.57302 .30739 2.165 -1.25 Mabsadd L
.57302 .30739 0 2.5 Mabsadd L closepath F
.57619 .30637 0 2.5 Mabsadd m
.57619 .30637 -2.165 -1.25 Mabsadd L
.57619 .30637 2.165 -1.25 Mabsadd L
.57619 .30637 0 2.5 Mabsadd L closepath F
.57937 .30537 0 2.5 Mabsadd m
.57937 .30537 -2.165 -1.25 Mabsadd L
.57937 .30537 2.165 -1.25 Mabsadd L
.57937 .30537 0 2.5 Mabsadd L closepath F
.58254 .30437 0 2.5 Mabsadd m
.58254 .30437 -2.165 -1.25 Mabsadd L
.58254 .30437 2.165 -1.25 Mabsadd L
.58254 .30437 0 2.5 Mabsadd L closepath F
.58571 .30338 0 2.5 Mabsadd m
.58571 .30338 -2.165 -1.25 Mabsadd L
.58571 .30338 2.165 -1.25 Mabsadd L
.58571 .30338 0 2.5 Mabsadd L closepath F
.58889 .30241 0 2.5 Mabsadd m
.58889 .30241 -2.165 -1.25 Mabsadd L
.58889 .30241 2.165 -1.25 Mabsadd L
.58889 .30241 0 2.5 Mabsadd L closepath F
.59206 .30144 0 2.5 Mabsadd m
.59206 .30144 -2.165 -1.25 Mabsadd L
.59206 .30144 2.165 -1.25 Mabsadd L
.59206 .30144 0 2.5 Mabsadd L closepath F
.59524 .30048 0 2.5 Mabsadd m
.59524 .30048 -2.165 -1.25 Mabsadd L
.59524 .30048 2.165 -1.25 Mabsadd L
.59524 .30048 0 2.5 Mabsadd L closepath F
.59841 .29953 0 2.5 Mabsadd m
.59841 .29953 -2.165 -1.25 Mabsadd L
.59841 .29953 2.165 -1.25 Mabsadd L
.59841 .29953 0 2.5 Mabsadd L closepath F
.60159 .29859 0 2.5 Mabsadd m
.60159 .29859 -2.165 -1.25 Mabsadd L
.60159 .29859 2.165 -1.25 Mabsadd L
.60159 .29859 0 2.5 Mabsadd L closepath F
.60476 .29767 0 2.5 Mabsadd m
.60476 .29767 -2.165 -1.25 Mabsadd L
.60476 .29767 2.165 -1.25 Mabsadd L
.60476 .29767 0 2.5 Mabsadd L closepath F
.60794 .29675 0 2.5 Mabsadd m
.60794 .29675 -2.165 -1.25 Mabsadd L
.60794 .29675 2.165 -1.25 Mabsadd L
.60794 .29675 0 2.5 Mabsadd L closepath F
.61111 .29584 0 2.5 Mabsadd m
.61111 .29584 -2.165 -1.25 Mabsadd L
.61111 .29584 2.165 -1.25 Mabsadd L
.61111 .29584 0 2.5 Mabsadd L closepath F
.61429 .29493 0 2.5 Mabsadd m
.61429 .29493 -2.165 -1.25 Mabsadd L
.61429 .29493 2.165 -1.25 Mabsadd L
.61429 .29493 0 2.5 Mabsadd L closepath F
.61746 .29404 0 2.5 Mabsadd m
.61746 .29404 -2.165 -1.25 Mabsadd L
.61746 .29404 2.165 -1.25 Mabsadd L
.61746 .29404 0 2.5 Mabsadd L closepath F
.62063 .29316 0 2.5 Mabsadd m
.62063 .29316 -2.165 -1.25 Mabsadd L
.62063 .29316 2.165 -1.25 Mabsadd L
.62063 .29316 0 2.5 Mabsadd L closepath F
.62381 .29228 0 2.5 Mabsadd m
.62381 .29228 -2.165 -1.25 Mabsadd L
.62381 .29228 2.165 -1.25 Mabsadd L
.62381 .29228 0 2.5 Mabsadd L closepath F
.62698 .29142 0 2.5 Mabsadd m
.62698 .29142 -2.165 -1.25 Mabsadd L
.62698 .29142 2.165 -1.25 Mabsadd L
.62698 .29142 0 2.5 Mabsadd L closepath F
.63016 .29056 0 2.5 Mabsadd m
.63016 .29056 -2.165 -1.25 Mabsadd L
.63016 .29056 2.165 -1.25 Mabsadd L
.63016 .29056 0 2.5 Mabsadd L closepath F
.63333 .28971 0 2.5 Mabsadd m
.63333 .28971 -2.165 -1.25 Mabsadd L
.63333 .28971 2.165 -1.25 Mabsadd L
.63333 .28971 0 2.5 Mabsadd L closepath F
.63651 .28887 0 2.5 Mabsadd m
.63651 .28887 -2.165 -1.25 Mabsadd L
.63651 .28887 2.165 -1.25 Mabsadd L
.63651 .28887 0 2.5 Mabsadd L closepath F
.63968 .28804 0 2.5 Mabsadd m
.63968 .28804 -2.165 -1.25 Mabsadd L
.63968 .28804 2.165 -1.25 Mabsadd L
.63968 .28804 0 2.5 Mabsadd L closepath F
.64286 .28722 0 2.5 Mabsadd m
.64286 .28722 -2.165 -1.25 Mabsadd L
.64286 .28722 2.165 -1.25 Mabsadd L
.64286 .28722 0 2.5 Mabsadd L closepath F
.64603 .2864 0 2.5 Mabsadd m
.64603 .2864 -2.165 -1.25 Mabsadd L
.64603 .2864 2.165 -1.25 Mabsadd L
.64603 .2864 0 2.5 Mabsadd L closepath F
.64921 .28559 0 2.5 Mabsadd m
.64921 .28559 -2.165 -1.25 Mabsadd L
.64921 .28559 2.165 -1.25 Mabsadd L
.64921 .28559 0 2.5 Mabsadd L closepath F
.65238 .28479 0 2.5 Mabsadd m
.65238 .28479 -2.165 -1.25 Mabsadd L
.65238 .28479 2.165 -1.25 Mabsadd L
.65238 .28479 0 2.5 Mabsadd L closepath F
.65556 .284 0 2.5 Mabsadd m
.65556 .284 -2.165 -1.25 Mabsadd L
.65556 .284 2.165 -1.25 Mabsadd L
.65556 .284 0 2.5 Mabsadd L closepath F
.65873 .28322 0 2.5 Mabsadd m
.65873 .28322 -2.165 -1.25 Mabsadd L
.65873 .28322 2.165 -1.25 Mabsadd L
.65873 .28322 0 2.5 Mabsadd L closepath F
.6619 .28244 0 2.5 Mabsadd m
.6619 .28244 -2.165 -1.25 Mabsadd L
.6619 .28244 2.165 -1.25 Mabsadd L
.6619 .28244 0 2.5 Mabsadd L closepath F
.66508 .28168 0 2.5 Mabsadd m
.66508 .28168 -2.165 -1.25 Mabsadd L
.66508 .28168 2.165 -1.25 Mabsadd L
.66508 .28168 0 2.5 Mabsadd L closepath F
.66825 .28092 0 2.5 Mabsadd m
.66825 .28092 -2.165 -1.25 Mabsadd L
.66825 .28092 2.165 -1.25 Mabsadd L
.66825 .28092 0 2.5 Mabsadd L closepath F
.67143 .28016 0 2.5 Mabsadd m
.67143 .28016 -2.165 -1.25 Mabsadd L
.67143 .28016 2.165 -1.25 Mabsadd L
.67143 .28016 0 2.5 Mabsadd L closepath F
.6746 .27942 0 2.5 Mabsadd m
.6746 .27942 -2.165 -1.25 Mabsadd L
.6746 .27942 2.165 -1.25 Mabsadd L
.6746 .27942 0 2.5 Mabsadd L closepath F
.67778 .27868 0 2.5 Mabsadd m
.67778 .27868 -2.165 -1.25 Mabsadd L
.67778 .27868 2.165 -1.25 Mabsadd L
.67778 .27868 0 2.5 Mabsadd L closepath F
.68095 .27795 0 2.5 Mabsadd m
.68095 .27795 -2.165 -1.25 Mabsadd L
.68095 .27795 2.165 -1.25 Mabsadd L
.68095 .27795 0 2.5 Mabsadd L closepath F
.68413 .27723 0 2.5 Mabsadd m
.68413 .27723 -2.165 -1.25 Mabsadd L
.68413 .27723 2.165 -1.25 Mabsadd L
.68413 .27723 0 2.5 Mabsadd L closepath F
.6873 .27651 0 2.5 Mabsadd m
.6873 .27651 -2.165 -1.25 Mabsadd L
.6873 .27651 2.165 -1.25 Mabsadd L
.6873 .27651 0 2.5 Mabsadd L closepath F
.69048 .27581 0 2.5 Mabsadd m
.69048 .27581 -2.165 -1.25 Mabsadd L
.69048 .27581 2.165 -1.25 Mabsadd L
.69048 .27581 0 2.5 Mabsadd L closepath F
.69365 .2751 0 2.5 Mabsadd m
.69365 .2751 -2.165 -1.25 Mabsadd L
.69365 .2751 2.165 -1.25 Mabsadd L
.69365 .2751 0 2.5 Mabsadd L closepath F
.69683 .27441 0 2.5 Mabsadd m
.69683 .27441 -2.165 -1.25 Mabsadd L
.69683 .27441 2.165 -1.25 Mabsadd L
.69683 .27441 0 2.5 Mabsadd L closepath F
.7 .27372 0 2.5 Mabsadd m
.7 .27372 -2.165 -1.25 Mabsadd L
.7 .27372 2.165 -1.25 Mabsadd L
.7 .27372 0 2.5 Mabsadd L closepath F
.70317 .27304 0 2.5 Mabsadd m
.70317 .27304 -2.165 -1.25 Mabsadd L
.70317 .27304 2.165 -1.25 Mabsadd L
.70317 .27304 0 2.5 Mabsadd L closepath F
.70635 .27237 0 2.5 Mabsadd m
.70635 .27237 -2.165 -1.25 Mabsadd L
.70635 .27237 2.165 -1.25 Mabsadd L
.70635 .27237 0 2.5 Mabsadd L closepath F
.70952 .2717 0 2.5 Mabsadd m
.70952 .2717 -2.165 -1.25 Mabsadd L
.70952 .2717 2.165 -1.25 Mabsadd L
.70952 .2717 0 2.5 Mabsadd L closepath F
.7127 .27104 0 2.5 Mabsadd m
.7127 .27104 -2.165 -1.25 Mabsadd L
.7127 .27104 2.165 -1.25 Mabsadd L
.7127 .27104 0 2.5 Mabsadd L closepath F
.71587 .27039 0 2.5 Mabsadd m
.71587 .27039 -2.165 -1.25 Mabsadd L
.71587 .27039 2.165 -1.25 Mabsadd L
.71587 .27039 0 2.5 Mabsadd L closepath F
.71905 .26974 0 2.5 Mabsadd m
.71905 .26974 -2.165 -1.25 Mabsadd L
.71905 .26974 2.165 -1.25 Mabsadd L
.71905 .26974 0 2.5 Mabsadd L closepath F
.72222 .2691 0 2.5 Mabsadd m
.72222 .2691 -2.165 -1.25 Mabsadd L
.72222 .2691 2.165 -1.25 Mabsadd L
.72222 .2691 0 2.5 Mabsadd L closepath F
.7254 .26847 0 2.5 Mabsadd m
.7254 .26847 -2.165 -1.25 Mabsadd L
.7254 .26847 2.165 -1.25 Mabsadd L
.7254 .26847 0 2.5 Mabsadd L closepath F
.72857 .26784 0 2.5 Mabsadd m
.72857 .26784 -2.165 -1.25 Mabsadd L
.72857 .26784 2.165 -1.25 Mabsadd L
.72857 .26784 0 2.5 Mabsadd L closepath F
.73175 .26722 0 2.5 Mabsadd m
.73175 .26722 -2.165 -1.25 Mabsadd L
.73175 .26722 2.165 -1.25 Mabsadd L
.73175 .26722 0 2.5 Mabsadd L closepath F
.73492 .2666 0 2.5 Mabsadd m
.73492 .2666 -2.165 -1.25 Mabsadd L
.73492 .2666 2.165 -1.25 Mabsadd L
.73492 .2666 0 2.5 Mabsadd L closepath F
.7381 .26599 0 2.5 Mabsadd m
.7381 .26599 -2.165 -1.25 Mabsadd L
.7381 .26599 2.165 -1.25 Mabsadd L
.7381 .26599 0 2.5 Mabsadd L closepath F
.74127 .26539 0 2.5 Mabsadd m
.74127 .26539 -2.165 -1.25 Mabsadd L
.74127 .26539 2.165 -1.25 Mabsadd L
.74127 .26539 0 2.5 Mabsadd L closepath F
.74444 .26479 0 2.5 Mabsadd m
.74444 .26479 -2.165 -1.25 Mabsadd L
.74444 .26479 2.165 -1.25 Mabsadd L
.74444 .26479 0 2.5 Mabsadd L closepath F
.74762 .2642 0 2.5 Mabsadd m
.74762 .2642 -2.165 -1.25 Mabsadd L
.74762 .2642 2.165 -1.25 Mabsadd L
.74762 .2642 0 2.5 Mabsadd L closepath F
.75079 .26362 0 2.5 Mabsadd m
.75079 .26362 -2.165 -1.25 Mabsadd L
.75079 .26362 2.165 -1.25 Mabsadd L
.75079 .26362 0 2.5 Mabsadd L closepath F
.75397 .26304 0 2.5 Mabsadd m
.75397 .26304 -2.165 -1.25 Mabsadd L
.75397 .26304 2.165 -1.25 Mabsadd L
.75397 .26304 0 2.5 Mabsadd L closepath F
.75714 .26246 0 2.5 Mabsadd m
.75714 .26246 -2.165 -1.25 Mabsadd L
.75714 .26246 2.165 -1.25 Mabsadd L
.75714 .26246 0 2.5 Mabsadd L closepath F
.76032 .2619 0 2.5 Mabsadd m
.76032 .2619 -2.165 -1.25 Mabsadd L
.76032 .2619 2.165 -1.25 Mabsadd L
.76032 .2619 0 2.5 Mabsadd L closepath F
.76349 .26133 0 2.5 Mabsadd m
.76349 .26133 -2.165 -1.25 Mabsadd L
.76349 .26133 2.165 -1.25 Mabsadd L
.76349 .26133 0 2.5 Mabsadd L closepath F
.76667 .26078 0 2.5 Mabsadd m
.76667 .26078 -2.165 -1.25 Mabsadd L
.76667 .26078 2.165 -1.25 Mabsadd L
.76667 .26078 0 2.5 Mabsadd L closepath F
.76984 .26023 0 2.5 Mabsadd m
.76984 .26023 -2.165 -1.25 Mabsadd L
.76984 .26023 2.165 -1.25 Mabsadd L
.76984 .26023 0 2.5 Mabsadd L closepath F
.77302 .25968 0 2.5 Mabsadd m
.77302 .25968 -2.165 -1.25 Mabsadd L
.77302 .25968 2.165 -1.25 Mabsadd L
.77302 .25968 0 2.5 Mabsadd L closepath F
.77619 .25914 0 2.5 Mabsadd m
.77619 .25914 -2.165 -1.25 Mabsadd L
.77619 .25914 2.165 -1.25 Mabsadd L
.77619 .25914 0 2.5 Mabsadd L closepath F
.77937 .25861 0 2.5 Mabsadd m
.77937 .25861 -2.165 -1.25 Mabsadd L
.77937 .25861 2.165 -1.25 Mabsadd L
.77937 .25861 0 2.5 Mabsadd L closepath F
.78254 .25808 0 2.5 Mabsadd m
.78254 .25808 -2.165 -1.25 Mabsadd L
.78254 .25808 2.165 -1.25 Mabsadd L
.78254 .25808 0 2.5 Mabsadd L closepath F
.78571 .25755 0 2.5 Mabsadd m
.78571 .25755 -2.165 -1.25 Mabsadd L
.78571 .25755 2.165 -1.25 Mabsadd L
.78571 .25755 0 2.5 Mabsadd L closepath F
.78889 .25703 0 2.5 Mabsadd m
.78889 .25703 -2.165 -1.25 Mabsadd L
.78889 .25703 2.165 -1.25 Mabsadd L
.78889 .25703 0 2.5 Mabsadd L closepath F
.79206 .25652 0 2.5 Mabsadd m
.79206 .25652 -2.165 -1.25 Mabsadd L
.79206 .25652 2.165 -1.25 Mabsadd L
.79206 .25652 0 2.5 Mabsadd L closepath F
.79524 .25601 0 2.5 Mabsadd m
.79524 .25601 -2.165 -1.25 Mabsadd L
.79524 .25601 2.165 -1.25 Mabsadd L
.79524 .25601 0 2.5 Mabsadd L closepath F
.79841 .25551 0 2.5 Mabsadd m
.79841 .25551 -2.165 -1.25 Mabsadd L
.79841 .25551 2.165 -1.25 Mabsadd L
.79841 .25551 0 2.5 Mabsadd L closepath F
.80159 .25501 0 2.5 Mabsadd m
.80159 .25501 -2.165 -1.25 Mabsadd L
.80159 .25501 2.165 -1.25 Mabsadd L
.80159 .25501 0 2.5 Mabsadd L closepath F
.80476 .25452 0 2.5 Mabsadd m
.80476 .25452 -2.165 -1.25 Mabsadd L
.80476 .25452 2.165 -1.25 Mabsadd L
.80476 .25452 0 2.5 Mabsadd L closepath F
.80794 .25403 0 2.5 Mabsadd m
.80794 .25403 -2.165 -1.25 Mabsadd L
.80794 .25403 2.165 -1.25 Mabsadd L
.80794 .25403 0 2.5 Mabsadd L closepath F
.81111 .25355 0 2.5 Mabsadd m
.81111 .25355 -2.165 -1.25 Mabsadd L
.81111 .25355 2.165 -1.25 Mabsadd L
.81111 .25355 0 2.5 Mabsadd L closepath F
.81429 .25307 0 2.5 Mabsadd m
.81429 .25307 -2.165 -1.25 Mabsadd L
.81429 .25307 2.165 -1.25 Mabsadd L
.81429 .25307 0 2.5 Mabsadd L closepath F
.81746 .25259 0 2.5 Mabsadd m
.81746 .25259 -2.165 -1.25 Mabsadd L
.81746 .25259 2.165 -1.25 Mabsadd L
.81746 .25259 0 2.5 Mabsadd L closepath F
.82063 .25212 0 2.5 Mabsadd m
.82063 .25212 -2.165 -1.25 Mabsadd L
.82063 .25212 2.165 -1.25 Mabsadd L
.82063 .25212 0 2.5 Mabsadd L closepath F
.82381 .25166 0 2.5 Mabsadd m
.82381 .25166 -2.165 -1.25 Mabsadd L
.82381 .25166 2.165 -1.25 Mabsadd L
.82381 .25166 0 2.5 Mabsadd L closepath F
.82698 .2512 0 2.5 Mabsadd m
.82698 .2512 -2.165 -1.25 Mabsadd L
.82698 .2512 2.165 -1.25 Mabsadd L
.82698 .2512 0 2.5 Mabsadd L closepath F
.83016 .25075 0 2.5 Mabsadd m
.83016 .25075 -2.165 -1.25 Mabsadd L
.83016 .25075 2.165 -1.25 Mabsadd L
.83016 .25075 0 2.5 Mabsadd L closepath F
.83333 .2503 0 2.5 Mabsadd m
.83333 .2503 -2.165 -1.25 Mabsadd L
.83333 .2503 2.165 -1.25 Mabsadd L
.83333 .2503 0 2.5 Mabsadd L closepath F
.83651 .24985 0 2.5 Mabsadd m
.83651 .24985 -2.165 -1.25 Mabsadd L
.83651 .24985 2.165 -1.25 Mabsadd L
.83651 .24985 0 2.5 Mabsadd L closepath F
.83968 .24941 0 2.5 Mabsadd m
.83968 .24941 -2.165 -1.25 Mabsadd L
.83968 .24941 2.165 -1.25 Mabsadd L
.83968 .24941 0 2.5 Mabsadd L closepath F
.84286 .24897 0 2.5 Mabsadd m
.84286 .24897 -2.165 -1.25 Mabsadd L
.84286 .24897 2.165 -1.25 Mabsadd L
.84286 .24897 0 2.5 Mabsadd L closepath F
.84603 .24854 0 2.5 Mabsadd m
.84603 .24854 -2.165 -1.25 Mabsadd L
.84603 .24854 2.165 -1.25 Mabsadd L
.84603 .24854 0 2.5 Mabsadd L closepath F
.84921 .24811 0 2.5 Mabsadd m
.84921 .24811 -2.165 -1.25 Mabsadd L
.84921 .24811 2.165 -1.25 Mabsadd L
.84921 .24811 0 2.5 Mabsadd L closepath F
.85238 .24768 0 2.5 Mabsadd m
.85238 .24768 -2.165 -1.25 Mabsadd L
.85238 .24768 2.165 -1.25 Mabsadd L
.85238 .24768 0 2.5 Mabsadd L closepath F
.85556 .24726 0 2.5 Mabsadd m
.85556 .24726 -2.165 -1.25 Mabsadd L
.85556 .24726 2.165 -1.25 Mabsadd L
.85556 .24726 0 2.5 Mabsadd L closepath F
.85873 .24685 0 2.5 Mabsadd m
.85873 .24685 -2.165 -1.25 Mabsadd L
.85873 .24685 2.165 -1.25 Mabsadd L
.85873 .24685 0 2.5 Mabsadd L closepath F
.8619 .24644 0 2.5 Mabsadd m
.8619 .24644 -2.165 -1.25 Mabsadd L
.8619 .24644 2.165 -1.25 Mabsadd L
.8619 .24644 0 2.5 Mabsadd L closepath F
.86508 .24603 0 2.5 Mabsadd m
.86508 .24603 -2.165 -1.25 Mabsadd L
.86508 .24603 2.165 -1.25 Mabsadd L
.86508 .24603 0 2.5 Mabsadd L closepath F
.86825 .24563 0 2.5 Mabsadd m
.86825 .24563 -2.165 -1.25 Mabsadd L
.86825 .24563 2.165 -1.25 Mabsadd L
.86825 .24563 0 2.5 Mabsadd L closepath F
.87143 .24523 0 2.5 Mabsadd m
.87143 .24523 -2.165 -1.25 Mabsadd L
.87143 .24523 2.165 -1.25 Mabsadd L
.87143 .24523 0 2.5 Mabsadd L closepath F
.8746 .24483 0 2.5 Mabsadd m
.8746 .24483 -2.165 -1.25 Mabsadd L
.8746 .24483 2.165 -1.25 Mabsadd L
.8746 .24483 0 2.5 Mabsadd L closepath F
.87778 .24444 0 2.5 Mabsadd m
.87778 .24444 -2.165 -1.25 Mabsadd L
.87778 .24444 2.165 -1.25 Mabsadd L
.87778 .24444 0 2.5 Mabsadd L closepath F
.88095 .24405 0 2.5 Mabsadd m
.88095 .24405 -2.165 -1.25 Mabsadd L
.88095 .24405 2.165 -1.25 Mabsadd L
.88095 .24405 0 2.5 Mabsadd L closepath F
.88413 .24367 0 2.5 Mabsadd m
.88413 .24367 -2.165 -1.25 Mabsadd L
.88413 .24367 2.165 -1.25 Mabsadd L
.88413 .24367 0 2.5 Mabsadd L closepath F
.8873 .24329 0 2.5 Mabsadd m
.8873 .24329 -2.165 -1.25 Mabsadd L
.8873 .24329 2.165 -1.25 Mabsadd L
.8873 .24329 0 2.5 Mabsadd L closepath F
.89048 .24291 0 2.5 Mabsadd m
.89048 .24291 -2.165 -1.25 Mabsadd L
.89048 .24291 2.165 -1.25 Mabsadd L
.89048 .24291 0 2.5 Mabsadd L closepath F
.89365 .24254 0 2.5 Mabsadd m
.89365 .24254 -2.165 -1.25 Mabsadd L
.89365 .24254 2.165 -1.25 Mabsadd L
.89365 .24254 0 2.5 Mabsadd L closepath F
.89683 .24217 0 2.5 Mabsadd m
.89683 .24217 -2.165 -1.25 Mabsadd L
.89683 .24217 2.165 -1.25 Mabsadd L
.89683 .24217 0 2.5 Mabsadd L closepath F
.9 .24181 0 2.5 Mabsadd m
.9 .24181 -2.165 -1.25 Mabsadd L
.9 .24181 2.165 -1.25 Mabsadd L
.9 .24181 0 2.5 Mabsadd L closepath F
.90317 .24145 0 2.5 Mabsadd m
.90317 .24145 -2.165 -1.25 Mabsadd L
.90317 .24145 2.165 -1.25 Mabsadd L
.90317 .24145 0 2.5 Mabsadd L closepath F
.90635 .24109 0 2.5 Mabsadd m
.90635 .24109 -2.165 -1.25 Mabsadd L
.90635 .24109 2.165 -1.25 Mabsadd L
.90635 .24109 0 2.5 Mabsadd L closepath F
.90952 .24073 0 2.5 Mabsadd m
.90952 .24073 -2.165 -1.25 Mabsadd L
.90952 .24073 2.165 -1.25 Mabsadd L
.90952 .24073 0 2.5 Mabsadd L closepath F
.9127 .24038 0 2.5 Mabsadd m
.9127 .24038 -2.165 -1.25 Mabsadd L
.9127 .24038 2.165 -1.25 Mabsadd L
.9127 .24038 0 2.5 Mabsadd L closepath F
.91587 .24004 0 2.5 Mabsadd m
.91587 .24004 -2.165 -1.25 Mabsadd L
.91587 .24004 2.165 -1.25 Mabsadd L
.91587 .24004 0 2.5 Mabsadd L closepath F
.91905 .23969 0 2.5 Mabsadd m
.91905 .23969 -2.165 -1.25 Mabsadd L
.91905 .23969 2.165 -1.25 Mabsadd L
.91905 .23969 0 2.5 Mabsadd L closepath F
.92222 .23935 0 2.5 Mabsadd m
.92222 .23935 -2.165 -1.25 Mabsadd L
.92222 .23935 2.165 -1.25 Mabsadd L
.92222 .23935 0 2.5 Mabsadd L closepath F
.9254 .23902 0 2.5 Mabsadd m
.9254 .23902 -2.165 -1.25 Mabsadd L
.9254 .23902 2.165 -1.25 Mabsadd L
.9254 .23902 0 2.5 Mabsadd L closepath F
.92857 .23868 0 2.5 Mabsadd m
.92857 .23868 -2.165 -1.25 Mabsadd L
.92857 .23868 2.165 -1.25 Mabsadd L
.92857 .23868 0 2.5 Mabsadd L closepath F
.93175 .23835 0 2.5 Mabsadd m
.93175 .23835 -2.165 -1.25 Mabsadd L
.93175 .23835 2.165 -1.25 Mabsadd L
.93175 .23835 0 2.5 Mabsadd L closepath F
.93492 .23803 0 2.5 Mabsadd m
.93492 .23803 -2.165 -1.25 Mabsadd L
.93492 .23803 2.165 -1.25 Mabsadd L
.93492 .23803 0 2.5 Mabsadd L closepath F
.9381 .2377 0 2.5 Mabsadd m
.9381 .2377 -2.165 -1.25 Mabsadd L
.9381 .2377 2.165 -1.25 Mabsadd L
.9381 .2377 0 2.5 Mabsadd L closepath F
.94127 .23738 0 2.5 Mabsadd m
.94127 .23738 -2.165 -1.25 Mabsadd L
.94127 .23738 2.165 -1.25 Mabsadd L
.94127 .23738 0 2.5 Mabsadd L closepath F
.94444 .23707 0 2.5 Mabsadd m
.94444 .23707 -2.165 -1.25 Mabsadd L
.94444 .23707 2.165 -1.25 Mabsadd L
.94444 .23707 0 2.5 Mabsadd L closepath F
.94762 .23675 0 2.5 Mabsadd m
.94762 .23675 -2.165 -1.25 Mabsadd L
.94762 .23675 2.165 -1.25 Mabsadd L
.94762 .23675 0 2.5 Mabsadd L closepath F
.95079 .23644 0 2.5 Mabsadd m
.95079 .23644 -2.165 -1.25 Mabsadd L
.95079 .23644 2.165 -1.25 Mabsadd L
.95079 .23644 0 2.5 Mabsadd L closepath F
.95397 .23613 0 2.5 Mabsadd m
.95397 .23613 -2.165 -1.25 Mabsadd L
.95397 .23613 2.165 -1.25 Mabsadd L
.95397 .23613 0 2.5 Mabsadd L closepath F
.95714 .23583 0 2.5 Mabsadd m
.95714 .23583 -2.165 -1.25 Mabsadd L
.95714 .23583 2.165 -1.25 Mabsadd L
.95714 .23583 0 2.5 Mabsadd L closepath F
.96032 .23553 0 2.5 Mabsadd m
.96032 .23553 -2.165 -1.25 Mabsadd L
.96032 .23553 2.165 -1.25 Mabsadd L
.96032 .23553 0 2.5 Mabsadd L closepath F
.96349 .23523 0 2.5 Mabsadd m
.96349 .23523 -2.165 -1.25 Mabsadd L
.96349 .23523 2.165 -1.25 Mabsadd L
.96349 .23523 0 2.5 Mabsadd L closepath F
.96667 .23493 0 2.5 Mabsadd m
.96667 .23493 -2.165 -1.25 Mabsadd L
.96667 .23493 2.165 -1.25 Mabsadd L
.96667 .23493 0 2.5 Mabsadd L closepath F
.96984 .23464 0 2.5 Mabsadd m
.96984 .23464 -2.165 -1.25 Mabsadd L
.96984 .23464 2.165 -1.25 Mabsadd L
.96984 .23464 0 2.5 Mabsadd L closepath F
.97302 .23435 0 2.5 Mabsadd m
.97302 .23435 -2.165 -1.25 Mabsadd L
.97302 .23435 2.165 -1.25 Mabsadd L
.97302 .23435 0 2.5 Mabsadd L closepath F
.97619 .23407 0 2.5 Mabsadd m
.97619 .23407 -2.165 -1.25 Mabsadd L
.97619 .23407 2.165 -1.25 Mabsadd L
.97619 .23407 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z
000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoook
JPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000KoookJPGo001o
1?oonfX3o`00O`?ooo]Z1Ol007l9oookJPGo0000oooonf[ooookJPGooo]Z000JoookJPOo001o0ooo
nfX3o`00O`;ooo]Z1ol007l8oookJPGo0000oooonf[ooookJPGooo]Z000JoookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool007oo001o
2?oonfX5o`000?oooo]ZoooonfX5oookJP003OoonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPGooo]Z000=oookJP[o001o0_oonfX3
o`00O`?ooo]Z0ol007l<oookJP?o001o1ooonfX6o`000?oooo]ZoooonfX4oookJP006OoonfX3o`00
O`?ooo]Z0ol007l<oookJP?o001o1ooonfX8o`000?oooo]ZoooonfX2oookJP006OoonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX4o`00O`Oooo]Z2_l0003ooookJ_oooo]Z000IoookJP?o001o
0ooonfX3o`00O`Oooo]Z1ol007l8oookJP_o0000oooonf[noookJP006OoonfX3o`00O`?ooo]Z0ol0
07l7oookJPKo001o2OoonfX=o`000?oooo]Zo?oonfX001Wooo]Z0ol007l3oookJP?o001o1ooonfX2
o`00O`gooo]Z3ol0003ooookJ_[ooo]Z000JoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2
o`00O`gooo]Z1Ol00002oookJP03o`000?oonf[o000000Ko0000oooonf[ioookJP006_oonfX7o`00
O`Wooo]Z1ol007l7oookJPGo00001OoonfX8o`000?oooo]ZmooonfX001_ooo]Z1Ol007l:oookJPOo
001o1ooonfX5o`0000Oooo]Z2?l0003ooookJ_Gooo]Z000hoookJPGo00002OoonfX7o`000?oooo]Z
m?oonfX003Sooo]Z1Ol0000:oookJP[o0000oooonf[`oookJP00>?oonfX5o`0000cooo]Z2Ol0003o
oookJ^oooo]Z000hoookJPGo00003_oonfX9o`000?oooo]ZkOoonfX003Sooo]Z1Ol0000?oookJP[o
0000oooonf[[oookJP00>?oonfX5o`00017ooo]Z2Ol0003ooookJ^[ooo]Z000hoookJPGo00004ooo
nfX9o`000?oooo]Zj?oonfX003Sooo]Z1Ol0000DoookJP[o0000oooonf[VoookJP00>?oonfX5o`00
01Kooo]Z2ol0003ooookJ^?ooo]Z000hoookJPGo00006?oonfX;o`000?oooo]ZhOoonfX003Sooo]Z
1Ol0000KoookJPWo0000oooonf[PoookJP00>?oonfX5o`0001gooo]Z2Ol0003ooookJ]kooo]Z000h
oookJPGo00007_oonfX;o`000?oooo]ZfooonfX003Sooo]Z1Ol0000PoookJP_o0000oooonf[Ioook
JP00>?oonfX5o`0002;ooo]Z2ol0003ooookJ]Oooo]Z000hoookJPGo00009OoonfX9o`000?oooo]Z
e_oonfX003Sooo]Z1Ol0000WoookJP_o0000oooonf[BoookJP00>?oonfX5o`0002Sooo]Z2ol0003o
oookJ]7ooo]Z000hoookJPGo0000:_oonfX00ol0003ooo]Zo`000008o`000?oooo]ZcooonfX003So
oo]Z1Ol0000]oookJP_o0000oooonf[<oookJP00>?oonfX5o`0002oooo]Z2ol0003ooookJ/[ooo]Z
000hoookJPGo0000<_oonfX;o`000?oooo]ZaooonfX003Sooo]Z1Ol0000doookJP_o0000oooonf[5
oookJP00>?oonfX5o`0003Kooo]Z3?l0003ooookJ/;ooo]Z000hoookJPGo0000=ooonfX00ol0003o
oo]Zo`00000:o`000?oooo]Z`?oonfX003Sooo]Z1Ol0000koookJPco0000oooonfZmoookJP00>?oo
nfX5o`0003cooo]Z00?o0000oookJ_l000002_l0003ooookJ[_ooo]Z000hoookJPGo0000@?oonfX<
o`000?oooo]Z^?oonfX003Sooo]Z1Ol00011oookJP03o`000?oonf[o000000[o0000oooonfZfoook
JP00>?oonfX5o`0004Gooo]Z3?l0003ooookJ[?ooo]Z000hoookJPGo0000A_oonfX00ol0003ooo]Z
o`00000:o`000?oooo]Z/OoonfX003Sooo]Z1Ol0001:oookJPco0000oooonfZ^oookJP00>?oonfX5
o`0004_ooo]Z00?o0000oookJ_l000003?l0003ooookJZ[ooo]Z000hoookJPGo0000D?oonfX;o`00
0?oooo]ZZOoonfX003Sooo]Z1Ol0001BoookJPgo0000oooonfZUoookJP00>?oonfX5o`0005Gooo]Z
3Ol0003ooookJZ;ooo]Z000hoookJPGo0000EooonfX00ol0003ooo]Zo`00000;o`000?oooo]ZWooo
nfX003Sooo]Z1Ol0001JoookJPoo0000oooonfZKoookJP004OoonfX5o`00O`Cooo]Z0ol007l00ooo
nf[o001oo`00O`07o`00O`?ooo]Z1Ol007l9oookJPGo0000G?oonfX00ol0003ooo]Zo`00000;o`00
0?oooo]ZV_oonfX0013ooo]Z1ol007l3oookJP?o001o00?ooo]Zo`00Ool007l01ol007l2oookJPOo
001o2?oonfX5o`0005oooo]Z00?o0000oookJ_l000003?l0003ooookJYKooo]Z000@oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o1_oonfX4o`00O`04
oookJ_l007oo001oo`00O`Sooo]Z1Ol0001ToookJPgo0000oooonfZCoookJP000ooonfX:o`00O`;o
oo]Z0ol007l3oookJP?o001o1ooonfX4o`00O`Gooo]Z0ol007l3oookJP?o001o1ooonfX5o`0006Ko
oo]Z00?o0000oookJ_l000002ol0003ooookJY3ooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l8oookJPGo001o2OoonfX3o`00O`Oooo]Z1_l0001XoookJPoo0000oooonfZ<oookJP003ooo
nfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX3o`00O`Oooo]Z1Ol0001[oookJP03o`000?oo
nf[o000000go0000oooonfZ9oookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2
o`00O`;ooo]Z1?l007l7oookJPGo0000K_oonfX00ol0003ooo]Zo`00000=o`000?oooo]ZQ_oonfX0
00oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000LooonfX@o`00
0?oooo]ZPOoonfX000oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJPKo
001o2OoonfX5o`0007Gooo]Z00?o0000oookJ_l000003ol0003ooookJWgooo]Z000?oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o0_oonfX2o`00O`gooo]Z1Ol0001hoookJP03o`00
0?oonf[o000000oo0000oooonfYjoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z
1?l007l2oookJP?o001o0_oonfX2o`00O`gooo]Z1Ol0001moookJP03o`000?oonf[o000000go0000
oooonfYgoookJP004?oonfX7o`00O`Sooo]Z1ol007l4oookJPOo001o1ooonfX5o`0008;ooo]Z4?l0
003ooookJW;ooo]Z000AoookJPGo001o2_oonfX5o`00O`Gooo]Z1ol007l7oookJPGo0000Q?oonfX0
0ol0003ooo]Zo`00000?o`000?oooo]ZK_oonfX003Sooo]Z1Ol00027oookJP03o`000?oonf[o0000
017o0000oooonfYYoookJP00>?oonfX5o`0008cooo]Z00?o0000oookJ_l000003ol0003ooookJVKo
oo]Z000hoookJPGo0000TOoonfXBo`000?oooo]ZHOoonfX003Sooo]Z1Ol0002CoookJP03o`000?oo
nf[o0000013o0000oooonfYNoookJP00>?oonfX5o`0009Kooo]Z00Co0000oookJ_l0003ooo]Z4Ol0
003ooookJUWooo]Z000hoookJPGo0000VooonfX00ol0003ooo]Zo`00000Bo`000?oooo]ZE?oonfX0
03Sooo]Z1Ol0002PoookJP03o`000?oonf[o000001;o0000oooonfY?oookJP00>?oonfX5o`000:?o
oo]Z00Co0000oookJ_l0003ooo]Z4ol0003ooookJT[ooo]Z000hoookJPGo0000Z?oonfX01?l0003o
oo]Zo`000?oonfXCo`000?oooo]ZAOoonfX003Sooo]Z1Ol0002]oookJP04o`000?oonf[o0000oook
JQ?o0000oooonfY0oookJP00>?oonfX5o`000;;ooo]Z00?o0000oookJ_l000005_l0003ooookJSWo
oo]Z000hoookJPGo0000]_oonfX2o`000003oookJ_l0003o000001Go0000oooonfXdoookJP00>?oo
nfX5o`000;_ooo]Z0_l000000ooonf[o0000oookJP0Eo`000?oooo]Z;ooonfX003Sooo]Z1Ol00031
oookJP04o`000?oonf[o0000oookJQKo0000oooonfXYoookJP00>?oonfX5o`000<Kooo]Z00Co0000
oookJ_l0003ooo]Z6?l0003ooookJR;ooo]Z000hoookJPGo0000booonfX01?l0003ooo]Zo`000?oo
nfXJo`000?oooo]Z6ooonfX003Sooo]Z1Ol0003BoookJP03o`000?oonf[o000001[o0000oooonfXE
oookJP00>?oonfX5o`000=Oooo]Z00Go0000oookJ_l0003o0000oookJP0Jo`000?oooo]Z3_oonfX0
03Sooo]Z1Ol0003NoookJP;o000000?ooo]Zo`000?oonfX06ol0003ooookJPKooo]Z000hoookJPGo
0000i?oonfX01?l0003ooo]Zo`000?oonfXOo`000?cooo]Z000hoookJPGo0000jooonfX01Ol0003o
oo]Zo`000?l0003ooo]Z01go0000m_oonfX003Sooo]Z1Ol00018oookJPGo001o1OoonfX5o`00Od7o
oo]Z0ol007l5oookJPGo001o1OoonfX5o`00Ocgooo]Z0ol007l3oookJP;o000000?o001oo`000?l0
07l08?l0000ToookJPWo001o0ooonfX5o`00O`Gooo]Z1Ol007lhoookJPWo001o0ooonfX5o`00O`Go
oo]Z1Ol007ljoookJPGo001o1OoonfX5o`00O`Gooo]Z1Ol007l7oookJP00>?oonfX5o`0004Oooo]Z
1ol007l3oookJPOo001o@?oonfX3o`00O`Cooo]Z1ol007l3oookJPOo001o??oonfX3o`00O`Cooo]Z
1ol007l01Ol0003ooo]Zo`000?l0003o001o027o00006ooonfX9o`00O`;ooo]Z1ol007l3oookJPOo
001o=ooonfX9o`00O`;ooo]Z1ol007l3oookJPOo001o>?oonfX7o`00O`?ooo]Z1ol007l3oookJPOo
001o1_oonfX003Sooo]Z1Ol00016oookJPCo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04
oookJ_l007oo001oo`00Od3ooo]Z0ol007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00Occooo]Z0ol007l3oookJPCo001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`06oookJ_l0003o0000o`00Ool0003ooo]Z9?l0000AoookJPCo001o1ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lgoookJPCo001o1_oo
nfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lgoookJP?o
001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o1_oonfX003Sooo]Z1Ol00016oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007looookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o>ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`Cooo]Z00Oo0000oookJ_l0003o0000oookJ_l0003ooo]Z02Co00002?oonfX4o`00
O`Gooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00OcOooo]Z1?l007l5
oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lfoookJP?o001o0ooo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1OoonfX003Sooo]Z1Ol0001<oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Ocoo
oo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007lkoook
JP?o001o2OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l<oookJP04o`000?oonf[o
0000oookJP;o000000?ooo]Zo`000?l000009Ol00003o`00O`?ooo]Z0ol007l3oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00OcSooo]Z1Ol007l9oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00Occooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Gooo]Z000hoookJPGo0000C?oonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007looookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o>ooonfX3o`00O`Wooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
5OoonfX2o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l000009ol00003o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007ljoookJPCo001o2?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007lloookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z0ol007l5oookJP00>?oonfX5o`0004Oooo]Z0_l007l2oookJPCo001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00Ocoooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007lkoookJP?o001o1?oonfX2o`00O`;ooo]Z1?l007l01?oonf[o001o
o`00Ool007l3oookJP?o001o7ooonfX2o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?l0
0000:Ol000000ol007oooo]ZoookJP0ioookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l01?oonf[o
001oo`00Ool007l3oookJP?o001o>_oonfX4o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00
Ool007oo001o0ooonfX3o`00O`Gooo]Z000hoookJPGo0000AooonfX7o`00O`;ooo]Z0ol007l3oook
JP?o001o?ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3
o`00Oc_ooo]Z0ol007l4oookJPOo001o0_oonfX3o`00O`?ooo]Z0ol007lYoookJP;o000000?ooo]Z
o`000?oonfX00_l000000ooonf[o0000o`00000/o`00033ooo]Z0ol007l2oookJPOo001o0_oonfX3
o`00O`?ooo]Z0ol007ljoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o1OoonfX003Sooo]Z1Ol00017oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007lo
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o>ooo
nfX3o`00O`Cooo]Z1_l007l3oookJP?o001o0ooonfX3o`00Oc?ooo]Z0_l000000ooonf[o0000o`00
O`02o`000003oookJ_l0003o001o037o00006ooonfX3o`00O`?ooo]Z0ol007l2oookJPKo001o0ooo
nfX3o`00O`?ooo]Z0ol007lloookJP;o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1OoonfX003Sooo]Z1Ol00017oookJP;o001o1ooonfX3o`00O`?ooo]Z0ol0
07lloookJPKo001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
>?oonfX6o`00O`Cooo]Z0_l007l7oookJP?o001o0ooonfX3o`00OcKooo]Z0ol007l3oookJP;o001o
00Co0000oookJ_l0003o001o0_l000000ooonf[o0000o`00O`0ho`0000[ooo]Z0ol007l3oookJP?o
001o0_oonfX2o`00O`Oooo]Z0ol007l3oookJP?o001o=_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Gooo]Z000hoook
JPGo0000AooonfX2o`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007lmoookJPKo001o1?oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lioookJPKo001o
1?oonfX2o`00O`Sooo]Z0ol007l01?oonf[o001oo`00Ool007lgoookJPCo001o0_oonfX3o`00O`;o
oo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJP07o`000?l007oo0000o`000?oonf[o0000o`00
O`02o`000003oookJ_l0003ooo]Z03_o000000?o001ooookJ_oonfX00_l007l8oookJP?o001o00Co
oo]Zo`00Ool007oo001o=ooonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Kooo]Z000hoookJPGo0000B?oonfX7o`00O`;o
oo]Z1ol007looookJPCo001o1?oonfX7o`00O`?ooo]Z1ol007lkoookJPCo001o1OoonfX7o`00O`;o
oo]Z1ol007lhoookJPOo001o0ooonfX7o`00O`?ooo]Z1ol007l5oookJP04o`000?oonf[o0000oook
JP;o000000?ooo]Zo`000?oonfX00_l000000ooonf[o0000oookJP10o`0003Sooo]Z1ol007l3oook
JPOo001o0ooonfX7o`00O`Kooo]Z000hoookJPGo0000B?oonfX7o`00O`?ooo]Z1Ol007m1oookJP?o
001o1OoonfX5o`00O`Gooo]Z1Ol007lmoookJP?o001o1OoonfX7o`00O`?ooo]Z1Ol007ljoookJPGo
001o1OoonfX5o`00O`Gooo]Z1Ol007lEoookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`00
0?oonfX00_l000000ooonf[o0000oookJP18o`0002;ooo]Z1Ol007l5oookJPGo001o1OoonfX5o`00
O`Oooo]Z000hoookJPGo0000oooonfYkoookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0
003ooo]Z0_l000000ooonf[o0000oookJP1Do`0002Oooo]Z000hoookJPGo0000oooonfZ<oookJP06
o`000?oonf[ooo]Zo`000?oonf[o00000_oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0
003ooo]Z05Ko00004OoonfX003Sooo]Z1Ol0003ooookJZ3ooo]Z00Ko0000oookJ_oonf[o0000oook
J_l00002oookJP04o`000?oonf[o0000oookJP;o000000?ooo]Zo`000?oonfX00_l000000ooonf[o
0000o`00000mo`00017ooo]Z000hoookJPGo0000oooonfZgoookJP03o`000?oonf[o000000;ooo]Z
00?o0000oookJ_l000000_oonfX01?l0003ooo]Zo`000?oonfX2o`000003oookJ_l0003ooo]Z00;o
000000?ooo]Zo`000?l000009?l0000AoookJP00>?oonfX5o`000?oooo]Zd?oonfX00ol0003ooo]Z
o`000002oookJP03o`000?oonf[o000000;ooo]Z00Co0000oookJ_l0003ooo]Z0_l000000ooonf[o
0000oookJP02o`000003oookJ_l0003ooo]Z00_o00004OoonfX002cooo]Zool0003oo`0001?o0000
0ooonfX002cooo]Zool0003oo`0001?o00000ooonfX002cooo]Zool0003oo`0001?o00000ooonfX0
02cooo]Zool0003oo`0001?o00000ooonfX002cooo]Zool0003oo`0001?o00000ooonfX003Sooo]Z
1Ol0001@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0DOoonfX00ol0003ooo]Z
oookJP1@oookJP03o`000?oonf[ooo]Z053ooo]Z00?o0000oookJ_oonfX0D?oonfX00ol0003ooo]Z
oookJP0@oookJP00>?oonfX5o`000?oooo]Zi?oonfX?o`00017ooo]Z000hoookJPGo0000oooonf[8
oookJR_o00004OoonfX003Sooo]Z1Ol0003ooookJZoooo]Z00?o0000oookJ_l00000@_l0000@oook
JP00>?oonfX5o`000?oooo]ZVooonfY;o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oo
nfX00_l000000ooonf[o0000oookJP0AoookJP00>?oonfX5o`000?oooo]ZQooonfX00ol0003ooo]Z
o`000010o`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l000001?oonf[o0000oookJ_l00004
oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02
oookJP03o`000?oonf[ooo]Z00;ooo]Z00Co0000oookJ_oonf[o00004_oonfX003Sooo]Z1Ol0003o
oookJWKooo]Z00?o0000oookJ_l00000>ol000000ooonf[o0000oookJP02o`000004oookJ_l0003o
oo]Zo`0000Cooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oo
nf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]ZoookJP0:oookJQ;o00004?oo
nfX003Sooo]Z1Ol0003ooookJVOooo]Z=_l000001_oonf[o0000o`000?oonf[o0000oookJP;o0000
0ooonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX0
0_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z01Cooo]Z8Ol0000@oookJP00>?oo
nfX5o`000?oooo]ZF_oonfXbo`000003oookJ_l0003ooo]Z00;o00000ooonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003ooo]Zoook
JP0OoookJRoo00004?oonfX003Sooo]Z1Ol0003ooookJTgooo]Z;Ol000000ooonf[o0000o`000002
o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zoook
JP02oookJP03o`000?oonf[ooo]Z02Kooo]Z??l0000@oookJP00>?oonfX5o`000?oooo]Z@OoonfXZ
o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[o0000033ooo]ZA_l0000@oookJP00>?oonfX5o`000?oooo]Z=OoonfXW
o`000003oookJ_l0003o000000;o000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[o000003?ooo]Z@ol00008oookJPKo00004OoonfX003Sooo]Z1Ol0003o
oookJR_ooo]Z9ol000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[o000000;ooo]Z00?o
0000oookJ_l00000>?oonfXno`0000_ooo]Z4ol0000@oookJP00>?oonfX5o`000?oooo]Z8OoonfXR
o`000004oookJ_l0003o0000o`0000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`00
0002oookJP03o`000?oonf[ooo]Z03Sooo]Z>ol0000>oookJQgo00004?oonfX003Sooo]Z1Ol0003o
oookJQOooo]Z8_l000001?oonf[o0000o`000?l00002oookJP03o`000?oonf[o000000;ooo]Z00?o
0000oookJ_l00000?ooonfXeo`0001Cooo]Z9?l0000AoookJP00>?oonfX5o`000?oooo]Z3ooonfXP
o`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]Zo`00
0011oookJS?o00005?oonfXRo`000006oookJ_l0003o0000oookJ_l0003ooo]Z0_l000000ooonf[o
0000o`00000BoookJP00>?oonfX5o`000?oooo]Z1ooonfXNo`000004oookJ_l0003ooo]Zo`0000;o
oo]Z00?o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP12oookJS7o00005_oonfXQo`000006
oookJ_l0003o0000oookJ_l0003ooo]Z0_l000000ooonf[o0000oookJP0LoookJP00>?oonfX5o`00
0?gooo]Z7Ol000001?oonf[o0000oookJ_l00002oookJP03o`000?oonf[o000000;ooo]Z00?o0000
oookJ_oonfX0A?oonfX_o`0001[ooo]Z8?l000000ooonf[o0000oookJP02o`000003oookJ_l0003o
oo]Z02Kooo]Z000hoookJPGo0000mooonfXIo`000004oookJ_l0003o0000o`0000;ooo]Z00?o0000
oookJ_l000000_oonfX00ol0003ooo]ZoookJP17oookJRco00006ooonfXOo`000003oookJ_l0003o
oo]Z00;o000000Cooo]Zo`000?oonf[o0000;ooonfX003Sooo]Z1Ol0003^oookJQgo000000Cooo]Z
o`000?oonf[o00000_oonfX00ol0003ooo]Zo`000019oookJR_o00007_oonfXKo`000003oookJ_l0
003ooo]Z00;o000000Cooo]Zo`000?oonf[o0000>OoonfX003Sooo]Z1Ol0003XoookJQWo000000Co
oo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`00001<oookJR[o00007ooonfXJo`000006oook
J_l0003o0000oookJ_l0003ooo]Z0_l00012oookJP00>?oonfX5o`000>7ooo]Z6?l000001ooonf[o
0000oookJ_oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP1;oookJRSo00008?oonfXJ
o`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX0BOoonfX003Sooo]Z1Ol0003Joook
JQSo000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`00001@oookJRCo00008ooonfXH
o`000007oookJ_l0003o0000oookJ_l0003ooo]Zo`00001BoookJP00>?oonfX5o`000=Gooo]Z5Ol0
00001ooonf[o0000oookJ_oonf[o0000oookJ_l000000_oonfX00ol0003ooo]ZoookJP1>oookJRGo
00008_oonfXHo`000003oookJ_l0003ooo]Z00;o000000?ooo]Zo`000?oonfX0F?oonfX003Sooo]Z
1Ol0003?oookJQCo000000Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]Zo`00001BoookJR;o
00009?oonfXJo`000003oookJ_l0003ooo]Z00;o0000H?oonfX003Sooo]Z1Ol0003:oookJQCo0000
00Cooo]Zo`000?oonf[o00000_oonfX00ol0003ooo]ZoookJP1BoookJR7o00009OoonfXGo`000007
oookJ_l0003o0000oookJ_l0003ooo]Zo`00001VoookJP00>?oonfX5o`000<?ooo]Z5_l000001?oo
nf[o0000oookJ_l0001GoookJQoo00009ooonfXEo`000003oookJ_l0003ooo]Z00;o000000?ooo]Z
o`000?oonfX0K?oonfX003Sooo]Z1Ol0002noookJQ?o000000Oooo]Zo`000?oonf[ooo]Zo`000?oo
nf[o000005Oooo]Z7ol0000VoookJQKo000000?ooo]Zo`000?oonfX00_l0001doookJP00>?oonfX5
o`000;Wooo]Z4ol000001ooonf[o0000oookJ_oonf[o0000oookJ_l00000EOoonfXPo`0002Oooo]Z
5_l000001?oonf[o0000oookJ_l0001joookJP00>?oonfX5o`000;Cooo]Z4ol000001Ooonf[o0000
oookJ_oonf[o000005Oooo]Z7_l0000YoookJQ?o000000Oooo]Zo`000?l0003ooo]Zo`000?oonf[o
000007oooo]Z000hoookJPGo0000[ooonfXAo`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000
oookJ_oonfX0EooonfXLo`0002Wooo]Z4ol000001Ooonf[o0000o`000?oonf[o000008Kooo]Z000h
oookJPGo0000Z_oonfXAo`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0Eooo
nfXLo`0002Wooo]Z4ol000001Ooonf[o0000o`000?oonf[o000008_ooo]Z000hoookJPGo0000YOoo
nfXAo`000004oookJ_l0003ooo]Zo`0000;ooo]Z00?o0000oookJ_oonfX0EooonfXLo`0002[ooo]Z
4_l000001Ooonf[o0000o`000?oonf[o0000093ooo]Z000hoookJPGo0000X_oonfX?o`000004oook
J_l0003ooo]Zo`0005cooo]Z6_l0000/oookJQ;o000000Gooo]Zo`000?l0003ooo]Zo`00002Eoook
JP00>?oonfX5o`0009gooo]Z4Ol000001Ooonf[o0000oookJ_oonf[o000005[ooo]Z6Ol0000/oook
JQ;o000000Gooo]Zo`000?l0003ooo]Zo`00002JoookJP00>?oonfX5o`0009Sooo]Z00?o0000oook
J_l000003_l000001Ooonf[o0000oookJ_oonf[o000005[ooo]Z6ol0000/oookJQ3o000000Gooo]Z
o`000?l0003ooo]Zo`00002OoookJP00>?oonfX5o`0009Gooo]Z3ol000001Ooonf[o0000oookJ_oo
nf[o000005cooo]Z6Ol0000/oookJQ3o000000Gooo]Zo`000?l0003ooo]Zo`00002ToookJP00>?oo
nfX5o`00097ooo]Z3_l000001Ooonf[o0000oookJ_oonf[o000005cooo]Z6Ol0000^oookJQ7o0000
00?ooo]Zo`000?oonfX0Z?oonfX003Sooo]Z1Ol0002<oookJQ3o0000HOoonfXGo`0002oooo]Z4?l0
00001?oonf[o0000oookJ_l0002/oookJP00>?oonfX5o`0008Wooo]Z3_l00004oookJP03o`000?oo
nf[ooo]Z05_ooo]Z6?l0000]oookJQ3o000000Cooo]Zo`000?oonf[o0000/OoonfX003Sooo]Z1Ol0
0026oookJPgo00000ooonfX00ol0003ooo]ZoookJP1KoookJQSo0000;ooonfX@o`000003oookJ_l0
003o00000;Gooo]Z000hoookJPGo0000POoonfX>o`0000;ooo]Z00?o0000oookJ_oonfX0GOoonfXG
o`00033ooo]Z3_l000000ooonf[o0000o`00002joookJP00>?oonfX5o`0007gooo]Z3_l000000ooo
nf[o0000oookJP1PoookJQGo0000<OoonfX=o`000005oookJ_l0003o0000oookJ_l00000_OoonfX0
03Sooo]Z1Ol0001joookJPko0000H_oonfXFo`0002oooo]Z4?l000000ooonf[o0000oookJP31oook
JP004OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`?ooo]Z1Ol007l9oookJPGo
0000MooonfX<o`0000Cooo]Z00?o0000oookJ_oonfX0GOoonfXFo`0002oooo]Z4?l000000ooonf[o
0000oookJP34oookJP004?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`;ooo]Z
1ol007l8oookJPGo0000LooonfX=o`0000;ooo]Z00?o0000oookJ_oonfX0GooonfXDo`00037ooo]Z
3_l000000ooonf[o0000o`000039oookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
0ol007l00ooonf[o001oo`00O`02o`00O`Kooo]Z1?l007l01?oonf[o001oo`00Ool007l8oookJPGo
0000L?oonfX<o`000003oookJ_l0003ooo]Z067ooo]Z5?l0000aoookJPgo000000Gooo]Zo`000?l0
003ooo]Zo`00003<oookJP003ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o1OoonfX3o`00O`?o
oo]Z0ol007l7oookJPGo0000KOoonfX<o`0006Cooo]Z5?l0000aoookJPko000000?ooo]Zo`000?oo
nfX0d?oonfX000oooo]Z0ol007l3oookJP?o001o2?oonfX5o`00O`Wooo]Z0ol007l7oookJPKo0000
J?oonfX=o`0000;ooo]Z00?o0000oookJ_oonfX0GooonfXDo`00037ooo]Z3_l000000ooonf[o0000
oookJP3CoookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX3o`00O`Oooo]Z1Ol0
001VoookJPco000000?ooo]Zo`000?oonfX0HOoonfXDo`0003?ooo]Z2ol000000ooonf[o0000o`00
003HoookJP003ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o0ooonfX2o`00O`;ooo]Z1?l007l7
oookJPGo0000HooonfX<o`0006Cooo]Z5?l0000coookJPco000000?ooo]Zo`000?oonfX0f_oonfX0
00oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`;ooo]Z1ol007l8oookJPGo0000HOoonfX;o`00
00;ooo]Z00?o0000oookJ_oonfX0H?oonfXCo`0003;ooo]Z3Ol000000ooonf[o0000oookJP3Moook
JP003ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`;ooo]Z1_l007l9oookJPGo
0000G_oonfX:o`000003oookJ_l0003ooo]Z06?ooo]Z4_l0000coookJPko0000h_oonfX000oooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l2oookJP;o001o3OoonfX5o`0005[ooo]Z
2ol0001VoookJQ;o0000<ooonfX>o`000>Gooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o
1ooonfX4o`00O`;ooo]Z0ol007l2oookJP;o001o3OoonfX5o`0005Oooo]Z3?l000000ooonf[o0000
oookJP1QoookJQ?o0000=?oonfX;o`000003oookJ_l0003o00000>Oooo]Z000@oookJPOo001o2?oo
nfX7o`00O`Cooo]Z1ol007l7oookJPGo0000EOoonfX;o`0006Kooo]Z4?l0000eoookJPco000000?o
oo]Zo`000?oonfX0jOoonfX0017ooo]Z1Ol007l:oookJPGo001o1OoonfX7o`00O`Oooo]Z1Ol0001B
oookJP_o00000_oonfX00ol0003ooo]ZoookJP1PoookJQ?o0000<_oonfX=o`000003oookJ_l0003o
oo]Z0>cooo]Z000hoookJPGo0000CooonfX:o`000003oookJ_l0003ooo]Z06?ooo]Z4_l0000eoook
JPco0000lOoonfX003Sooo]Z1Ol0001=oookJP[o0000I_oonfXAo`0003Cooo]Z3Ol0003doookJP00
>?oonfX5o`0004[ooo]Z2_l000000ooonf[o0000oookJP1SoookJQ7o0000=?oonfX;o`000003oook
J_l0003o00000?Kooo]Z000hoookJPGo0000B?oonfX9o`0006Oooo]Z4Ol0000doookJP_o000000?o
oo]Zo`000?oonfX0n?oonfX003Sooo]Z1Ol00015oookJP[o000000?ooo]Zo`000?oonfX0HooonfXA
o`0003Cooo]Z2ol000000ooonf[o0000oookJP3koookJP00>?oonfX5o`00047ooo]Z00?o0000oook
J_l000002?l0001WoookJPoo0000=_oonfX;o`000003oookJ_l0003ooo]Z0?gooo]Z000hoookJPGo
0000@?oonfX:o`000003oookJ_l0003ooo]Z06?ooo]Z4Ol0000doookJP_o000000?ooo]Zo`000?oo
nfX0oooonfX1oookJP00>?oonfX5o`0003kooo]Z2Ol0001WoookJPoo0000=_oonfX;o`000003oook
J_l0003ooo]Z0?oooo]Z0ooonfX003Sooo]Z1Ol0000koookJP[o000000?ooo]Zo`000?oonfX0Hooo
nfXAo`0003Cooo]Z2ol000000ooonf[o0000oookJP3ooookJPKooo]Z000hoookJPGo0000>OoonfX9
o`0006Oooo]Z3ol0000foookJP_o000000?ooo]Zo`000?oonfX0oooonfX8oookJP00>?oonfX5o`00
03Kooo]Z2_l000000ooonf[o0000oookJP1UoookJPoo0000=_oonfX9o`000003oookJ_l0003ooo]Z
0?oooo]Z2ooonfX003Sooo]Z1Ol0000doookJPWo0000IooonfX?o`0003Kooo]Z2ol000000ooonf[o
0000oookJP3ooookJPgooo]Z000hoookJPGo0000<_oonfX9o`000003oookJ_l0003ooo]Z06Gooo]Z
3ol0000foookJPWo000000?ooo]Zo`000?oonfX0oooonfX@oookJP00>?oonfX5o`0002oooo]Z2Ol0
00000ooonf[o0000oookJP1ToookJPoo0000=_oonfX;o`000003oookJ_l0003ooo]Z0?oooo]Z4_oo
nfX003Sooo]Z1Ol0000]oookJPWo000000?ooo]Zo`000?oonfX0IOoonfX?o`0003Kooo]Z2Ol00000
0ooonf[o0000oookJP3ooookJQGooo]Z000hoookJPGo0000;?oonfX9o`0006Oooo]Z3ol0000foook
JP_o0000oooonfXHoookJP00>?oonfX5o`0002Sooo]Z2Ol000000ooonf[o0000oookJP1VoookJPko
0000=ooonfX8o`000003oookJ_l0003o00000?oooo]Z6_oonfX003Sooo]Z1Ol0000WoookJPWo0000
IooonfX?o`0003Kooo]Z2ol0003ooookJQgooo]Z000hoookJPGo00009OoonfX9o`000003oookJ_l0
003ooo]Z06Cooo]Z3_l0000goookJP_o0000oooonfXOoookJP00>?oonfX5o`0002;ooo]Z2Ol0001Y
oookJPgo0000>?oonfX9o`000003oookJ_l0003ooo]Z0?oooo]Z7ooonfX003Sooo]Z1Ol0000Poook
JPWo000000?ooo]Zo`000?oonfX0I_oonfX=o`0003Sooo]Z2Ol0003ooookJRCooo]Z000hoookJPGo
00007_oonfX9o`000003oookJ_l0003ooo]Z06Gooo]Z3ol0000foookJPWo000000?ooo]Zo`000?oo
nfX0oooonfXToookJP00>?oonfX5o`0001gooo]Z1ol000000ooonf[o0000oookJP1VoookJPgo0000
>?oonfX9o`000003oookJ_l0003ooo]Z0?oooo]Z9_oonfX003Sooo]Z1Ol0000KoookJPOo000000?o
oo]Zo`000?oonfX0I_oonfX>o`0003Oooo]Z2_l0003ooookJR[ooo]Z000hoookJPGo00006?oonfX9
o`0006Wooo]Z3Ol0000hoookJPWo0000oooonfX/oookJP00>?oonfX5o`0001Kooo]Z2Ol000000ooo
nf[o0000oookJP1VoookJPgo0000>?oonfX9o`000?oooo]Z;_oonfX003Sooo]Z1Ol0000DoookJPWo
0000JOoonfX<o`0003Sooo]Z2Ol000000ooonf[o0000oookJP3ooookJRkooo]Z000hoookJPGo0000
4ooonfX7o`000003oookJ_l0003ooo]Z06Kooo]Z3Ol0000hoookJPWo000000?ooo]Zo`000?oonfX0
oooonfX`oookJP00>?oonfX5o`00017ooo]Z1ol000000ooonf[o0000oookJP1VoookJPko0000=ooo
nfX:o`000?oooo]Z=?oonfX003Sooo]Z1Ol0000?oookJPSo0000JOoonfX=o`0003Sooo]Z2Ol0003o
oookJSKooo]Z000hoookJPGo00003_oonfX7o`000003oookJ_l0003ooo]Z06Kooo]Z3Ol0000hoook
JPWo0000oooonfXhoookJP00>?oonfX5o`0000cooo]Z1ol000000ooonf[o0000oookJP1VoookJPko
0000=ooonfX8o`000003oookJ_l0003ooo]Z0?oooo]Z>?oonfX003Sooo]Z1Ol0000:oookJPSo0000
JOoonfX;o`0003[ooo]Z2Ol0003ooookJS_ooo]Z000hoookJPGo00001ooonfX9o`0006Wooo]Z3?l0
000ioookJPWo0000oooonfXmoookJP00>?oonfX5o`0000Gooo]Z2Ol0001YoookJPco0000>OoonfX8
o`000003oookJ_l0003ooo]Z0?oooo]Z?OoonfX003Sooo]Z1Ol00004oookJPWo0000JOoonfX;o`00
03Wooo]Z2?l0003ooookJT;ooo]Z000hoookJPGo00000_oonfX7o`000003oookJ_l0003ooo]Z06So
oo]Z3?l0000ioookJPSo0000oooonfY3oookJP006ooonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o
2OoonfX=o`0006[ooo]Z3?l0000ioookJPSo0000oooonfY5oookJP006_oonfX7o`00O`?ooo]Z0ol0
07l2oookJPOo001o2?oonfX;o`000003oookJ_l0003ooo]Z06Sooo]Z2ol0000ioookJPSo0000oooo
nfY7oookJP006_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00
O`02o`00O`04oookJ_l007oo001oo`00O`Sooo]Z2Ol000000ooonf[o0000oookJP1XoookJPco0000
>OoonfX8o`000?oooo]ZB?oonfX001Wooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol0
07l7oookJPSo0000J_oonfX<o`0003Wooo]Z2?l0003ooookJT[ooo]Z000IoookJP?o001o0ooonfX3
o`00O`cooo]Z0ol007l7oookJPKo000000?ooo]Zo`000?oonfX0J?oonfX;o`0003Wooo]Z2?l0003o
oookJTcooo]Z000IoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPKo0000JOoonfX<o`00
03Wooo]Z2?l0003ooookJTgooo]Z000IoookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJPCo
001o1ooonfX5o`0006Sooo]Z3?l0000ioookJPSo0000oooonfY?oookJP006OoonfX3o`00O`?ooo]Z
0ol007l7oookJPOo001o2?oonfX5o`0006Oooo]Z2ol0000joookJPOo0000oooonfYAoookJP006Ooo
nfX3o`00O`?ooo]Z0ol007l7oookJPKo001o2OoonfX5o`0006Gooo]Z3?l0000ioookJPSo0000oooo
nfYBoookJP006OoonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o3OoonfX5o`0006?ooo]Z3?l0000i
oookJPSo0000oooonfYDoookJP006_oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0_l007l=
oookJPGo0000H_oonfX;o`0003[ooo]Z1ol0003ooookJUKooo]Z000JoookJPOo001o2OoonfX7o`00
O`Oooo]Z1Ol0001PoookJPco0000>OoonfX8o`000?oooo]ZEooonfX001_ooo]Z1Ol007l:oookJPOo
001o1ooonfX5o`0005kooo]Z3?l0000ioookJPSo0000oooonfYIoookJP00>?oonfX5o`0005kooo]Z
2_l0000joookJPOo0000oooonfYKoookJP00>?oonfX5o`0005gooo]Z2_l0000joookJPOo0000oooo
nfYLoookJP00>?oonfX5o`0005_ooo]Z2_l0000koookJPKo000000?ooo]Zo`000?oonfX0oooonfYK
oookJP00>?oonfX5o`0005Wooo]Z2_l0000koookJPSo0000oooonfYNoookJP00>?oonfX5o`0005So
oo]Z2_l0000joookJPSo0000oooonfYPoookJP00>?oonfX5o`0005Kooo]Z3?l0000ioookJPSo0000
oooonfYQoookJP00>?oonfX5o`0005Cooo]Z3?l0000joookJPOo0000oooonfYSoookJP00>?oonfX5
o`0005?ooo]Z2ol0000joookJPSo0000oooonfYToookJP00>?oonfX5o`0005?ooo]Z2_l0000joook
JPOo0000oooonfYVoookJP00>?oonfX5o`00057ooo]Z2_l0000koookJPKo0000oooonfYXoookJP00
>?oonfX5o`0004oooo]Z2_l0000koookJPOo0000oooonfYYoookJP00>?oonfX5o`0004kooo]Z2_l0
000koookJPKo000000?ooo]Zo`000?oonfX0oooonfYXoookJP00>?oonfX5o`0004cooo]Z2_l0000k
oookJPSo0000oooonfY[oookJP00>?oonfX5o`0004cooo]Z2_l0000joookJPOo0000oooonfY]oook
JP00>?oonfX5o`0004[ooo]Z2_l0000koookJPOo0000oooonfY^oookJP00>?oonfX5o`0004Wooo]Z
2_l0000joookJPOo0000oooonfY`oookJP00>?oonfX5o`0004Oooo]Z2_l0000koookJPSo0000oooo
nfY`oookJP00>?oonfX5o`0004Gooo]Z2_l0000loookJPOo0000oooonfYboookJP00>?oonfX5o`00
04Gooo]Z2_l0000koookJPOo0000oooonfYcoookJP00>?oonfX5o`0004Cooo]Z2_l0000joookJPOo
0000oooonfYeoookJP00>?oonfX5o`0004;ooo]Z2_l0000koookJPKo0000oooonfYgoookJP00>?oo
nfX5o`00043ooo]Z2_l0000loookJPOo0000oooonfYgoookJP00>?oonfX5o`00043ooo]Z2Ol0000l
oookJPOo0000oooonfYhoookJP00>?oonfX5o`0003oooo]Z2_l0000joookJPOo0000oooonfYjoook
JP00>?oonfX5o`0003gooo]Z2_l0000koookJPKo0000oooonfYloookJP00>?oonfX5o`0003_ooo]Z
2_l0000loookJPKo0000oooonfYmoookJP00>?oonfX5o`0003_ooo]Z2Ol0000loookJPOo0000oooo
nfYmoookJP00>?oonfX5o`0003[ooo]Z2_l0000joookJPOo0000oooonfYooookJP00>?oonfX5o`00
03Sooo]Z2_l0000koookJPKo0000oooonfZ1oookJP00>?oonfX5o`0003Sooo]Z2?l0000loookJPOo
0000oooonfZ1oookJP00>?oonfX5o`0003Kooo]Z2Ol0000loookJPOo0000oooonfZ2oookJP00>?oo
nfX5o`0003Gooo]Z2_l0000joookJPOo0000oooonfZ4oookJP00>?oonfX5o`0003?ooo]Z2_l0000k
oookJPOo0000oooonfZ5oookJP00>?oonfX5o`0003?ooo]Z2?l0000loookJPOo0000oooonfZ6oook
JP00>?oonfX5o`00037ooo]Z2_l0000koookJPOo0000oooonfZ7oookJP00>?oonfX5o`00033ooo]Z
2_l0000koookJPKo0000oooonfZ9oookJP00>?oonfX5o`00033ooo]Z2?l0000loookJPKo0000oooo
nfZ:oookJP00>?oonfX5o`0002kooo]Z2?l0000moookJPKo0000oooonfZ;oookJP004OoonfX5o`00
O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5o`00O`Wooo]Z1Ol0000/oookJP[o0000??oonfX6o`00
0?oooo]ZS?oonfX0013ooo]Z1ol007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1ol007l8oookJPGo
0000;?oonfX9o`0003cooo]Z1Ol0003ooookJXkooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJPCo001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`00
02_ooo]Z2?l0000loookJPOo0000oooonfZ>oookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP;o
001o1OoonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000:OoonfX:o`0003_ooo]Z1_l0003ooookJY3o
oo]Z000?oookJP?o001o0ooonfX3o`00O`Wooo]Z0ol007l:oookJP?o001o1ooonfX6o`0002Sooo]Z
2?l0000loookJPKo0000oooonfZAoookJP003ooonfX3o`00O`?ooo]Z0ol007l9oookJP?o001o2_oo
nfX3o`00O`Oooo]Z1Ol0000WoookJPWo0000??oonfX7o`000?oooo]ZTOoonfX000oooo]Z0ol007l3
oookJP?o001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o1ooonfX5o`0002Kooo]Z2_l0000l
oookJPGo0000oooonfZCoookJP003ooonfX3o`00O`?ooo]Z0ol007l:oookJP?o001o1?oonfX7o`00
O`Sooo]Z1Ol0000VoookJPSo0000?OoonfX5o`000?oooo]ZU?oonfX000oooo]Z0ol007l3oookJP?o
001o2ooonfX2o`00O`Cooo]Z1_l007l9oookJPGo00009?oonfX8o`0003gooo]Z1_l0003ooookJYGo
oo]Z000?oookJP?o001o0ooonfX3o`00O`cooo]Z0_l007l3oookJP;o001o3OoonfX5o`0002Cooo]Z
2?l0000loookJPKo0000oooonfZFoookJP004?oonfX3o`00O`04oookJ_l007oo001oo`00O`gooo]Z
0_l007l3oookJP;o001o3OoonfX5o`0002;ooo]Z2Ol0000loookJPKo0000oooonfZGoookJP004?oo
nfX7o`00O`Oooo]Z2Ol007l3oookJPOo001o1ooonfX5o`00027ooo]Z2?l0000loookJPOo0000oooo
nfZHoookJP004OoonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o1ooonfX5o`00027ooo]Z2?l0000l
oookJPKo0000oooonfZIoookJP00>?oonfX5o`0001oooo]Z2?l0000moookJPKo0000oooonfZJoook
JP00>?oonfX5o`0001oooo]Z2?l0000loookJPKo0000oooonfZKoookJP00>?oonfX5o`0001gooo]Z
2Ol0000loookJPGo0000oooonfZMoookJP00>?oonfX5o`0001cooo]Z2?l0000loookJPOo0000oooo
nfZMoookJP00>?oonfX5o`0001cooo]Z2?l0000loookJPKo0000oooonfZNoookJP00>?oonfX5o`00
01[ooo]Z2?l0000moookJPKo0000oooonfZOoookJP00>?oonfX5o`0001[ooo]Z2?l0000loookJPKo
0000oooonfZPoookJP00>?oonfX5o`0001Sooo]Z2Ol0000loookJPGo0000oooonfZRoookJP00>?oo
nfX5o`0001Oooo]Z2?l0000loookJPOo0000oooonfZRoookJP00>?oonfX5o`0001Oooo]Z2?l0000l
oookJPKo0000oooonfZSoookJP00>?oonfX5o`0001Gooo]Z2?l0000moookJPKo0000oooonfZToook
JP00>?oonfX5o`0001Gooo]Z2?l0000loookJPKo0000oooonfZUoookJP00>?oonfX5o`0001?ooo]Z
2Ol0000loookJPGo0000oooonfZWoookJP00>?oonfX5o`0001;ooo]Z2?l0000noookJPGo0000oooo
nfZWoookJP00>?oonfX5o`0001;ooo]Z2?l0000moookJPGo0000oooonfZXoookJP00>?oonfX5o`00
013ooo]Z2?l0000moookJPKo0000oooonfZYoookJP00>?oonfX5o`00013ooo]Z2?l0000loookJPKo
0000oooonfZZoookJP00>?oonfX5o`0000kooo]Z2Ol0000loookJPKo0000oooonfZ[oookJP00>?oo
nfX5o`0000kooo]Z1ol0000noookJPGo0000oooonfZ/oookJP00>?oonfX5o`0000gooo]Z2?l0000l
oookJPKo0000oooonfZ]oookJP00>?oonfX5o`0000gooo]Z1_l0000noookJPGo0000oooonfZ^oook
JP00>?oonfX5o`0000_ooo]Z2?l0000moookJPGo0000oooonfZ_oookJP00>?oonfX5o`0000_ooo]Z
1ol0000moookJPKo0000oooonfZ_oookJP00>?oonfX5o`0000Wooo]Z2Ol0000loookJPGo0000oooo
nfZaoookJP00>?oonfX5o`0000Sooo]Z2?l0000loookJPKo0000oooonfZboookJP00>?oonfX5o`00
00Sooo]Z2?l0000moookJPGo0000oooonfZboookJP00>?oonfX5o`0000Kooo]Z2?l0000moookJPKo
0000oooonfZcoookJP00>?oonfX5o`0000Kooo]Z2?l0000loookJPKo0000oooonfZdoookJP00>?oo
nfX5o`0000Cooo]Z2Ol0000loookJPKo0000oooonfZeoookJP00>?oonfX5o`0000Cooo]Z1ol0000n
oookJPGo0000oooonfZfoookJP00>?oonfX5o`0000?ooo]Z2?l0000loookJPKo0000oooonfZgoook
JP00>?oonfX5o`0000?ooo]Z1_l0000noookJPGo0000oooonfZhoookJP00>?oonfX5o`000003oook
J_l0003o000000Ko0000?OoonfX5o`000?oooo]Z^OoonfX003Sooo]Z1Ol000000ooonf[o0000o`00
0005o`0003gooo]Z1_l0003ooookJ[Wooo]Z000hoookJPgo0000??oonfX5o`000?oooo]Z^ooonfX0
03Sooo]Z2ol0000noookJPGo0000oooonfZkoookJP00>?oonfX;o`0003cooo]Z1_l0003ooookJ[co
oo]Z000hoookJPWo0000?_oonfX5o`000?oooo]Z_OoonfX002cooo]Z0ol007l9oookJPWo0000?Ooo
nfX5o`000?oooo]Z__oonfX002cooo]Z0ol007l9oookJPSo0000?OoonfX6o`000?oooo]Z__oonfX0
02cooo]Z0ol007l9oookJPSo0000??oonfX5o`000?oooo]Z`?oonfX002cooo]Z0ol007l9oookJPKo
0000?_oonfX5o`000?oooo]Z`?oonfX002cooo]Z0ol007l9oookJPKo0000??oonfX6o`000?oooo]Z
`OoonfX002cooo]Z0ol007l9oookJPGo0000?OoonfX5o`000?oooo]Z`_oonfX002cooo]Z0ol007l9
oookJPGo0000??oonfX5o`000?oooo]Z`ooonfX002cooo]Z0ol007l9oookJPGo0000>ooonfX6o`00
0?oooo]Z`ooonfX002cooo]Z0ol007l9oookJPGo0000>_oonfX5o`000?oooo]ZaOoonfX002Wooo]Z
1_l007l9oookJPGo0000>_oonfX5o`000?oooo]ZaOoonfX002Wooo]Z1_l007l9oookJPGo0000>?oo
nfX6o`000?oooo]Za_oonfX002_ooo]Z1?l007l9oookJPGo0000>OoonfX4o`000?oooo]ZaooonfX0
02cooo]Z0ol007l9oookJPGo0000=ooonfX6o`000?oooo]ZaooonfX003Sooo]Z1Ol0000goookJPGo
0000oooonf[8oookJP00>?oonfX5o`0003Gooo]Z1_l0003ooookJ/Wooo]Z000hoookJPGo0000=_oo
nfX4o`000?oooo]Zb_oonfX003Sooo]Z1Ol0000doookJPGo0000oooonf[;oookJP00>?oonfX5o`00
03Cooo]Z1Ol0003ooookJ/_ooo]Z000hoookJPGo0000oooonf[ooookJPGooo]Z000hoookJPGo0000
oooonf[ooookJPGooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-35.1325, -0.610893, \
0.600599, 0.00494211}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Background- Forward Differencing", "Subtitle"],

Cell[TextData[{
  "Create a function to return a list of values by forward differencing with \
a function (these examples were modified from those found in ``Computer \
Science with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'' by Roman E. Maeder, Cambridge University Press, (2000).)"
}], "Text",
  CellTags->"mmtag:19:Roman_Maeder__Computer_Science_with_Mathematica"],

Cell[TextData[{
  "The ",
  StyleBox["Module",
    FontWeight->"Bold"],
  " function makes the variables inside local variables. "
}], "Subsubsection"],

Cell[BoxData[
    \(ForwardDifferenceListV1[AFunction_\ , \ InitialValue_\ , \ delta_, \ 
        ListLength_Integer]\  := \[IndentingNewLine]Module[{TheResultList\  = \
\ {InitialValue}, TheValue = InitialValue}, \[IndentingNewLine]Do[
          TheValue\  = \ TheValue\  + \ delta\ AFunction[TheValue]; \ 
          AppendTo[TheResultList, TheValue], {ListLength}]; 
        TheResultList]\)], "Input",
  CellTags->"mmtag:19:Module[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(exampleFunction[x_]\  := \ 0.1\ x\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(exampleFunction\\)\\\" is similar to \
existing symbol \\\"\\!\\(ExampleFunction\\)\\\". \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[BoxData[
    \(\(result\  = \ 
        ForwardDifferenceListV1[exampleFunction, \ 1, \ 0.01, \ 
          500];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result // Short\)], "Input"],

Cell[BoxData[
    TagBox[\({1, 1.001`, 1.002001`, \[LeftSkeleton]496\[RightSkeleton], 
        1.6466627536593788`, 1.648309416413038`}\),
      Short]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[result, PlotJoined \[Rule] True]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190096 -0.893191 0.907906 [
[.21391 .00222 -17 -20 ]
[.21391 .00222 17 0 ]
[.404 .00222 -17 -20 ]
[.404 .00222 17 0 ]
[.5941 .00222 -17 -20 ]
[.5941 .00222 17 0 ]
[.78419 .00222 -17 -20 ]
[.78419 .00222 17 0 ]
[.97429 .00222 -17 -20 ]
[.97429 .00222 17 0 ]
[.01131 .10551 -29 -10 ]
[.01131 .10551 0 10 ]
[.01131 .1963 -29 -10 ]
[.01131 .1963 0 10 ]
[.01131 .28709 -29 -10 ]
[.01131 .28709 0 10 ]
[.01131 .37788 -29 -10 ]
[.01131 .37788 0 10 ]
[.01131 .46867 -29 -10 ]
[.01131 .46867 0 10 ]
[.01131 .55946 -29 -10 ]
[.01131 .55946 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21391 .01472 m
.21391 .02097 L
s
gsave
.21391 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.404 .01472 m
.404 .02097 L
s
gsave
.404 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.5941 .01472 m
.5941 .02097 L
s
gsave
.5941 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.78419 .01472 m
.78419 .02097 L
s
gsave
.78419 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(400) show
1.000 setlinewidth
grestore
.97429 .01472 m
.97429 .02097 L
s
gsave
.97429 .00222 -78 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(500) show
1.000 setlinewidth
grestore
.125 Mabswid
.06183 .01472 m
.06183 .01847 L
s
.09985 .01472 m
.09985 .01847 L
s
.13787 .01472 m
.13787 .01847 L
s
.17589 .01472 m
.17589 .01847 L
s
.25192 .01472 m
.25192 .01847 L
s
.28994 .01472 m
.28994 .01847 L
s
.32796 .01472 m
.32796 .01847 L
s
.36598 .01472 m
.36598 .01847 L
s
.44202 .01472 m
.44202 .01847 L
s
.48004 .01472 m
.48004 .01847 L
s
.51806 .01472 m
.51806 .01847 L
s
.55608 .01472 m
.55608 .01847 L
s
.63212 .01472 m
.63212 .01847 L
s
.67014 .01472 m
.67014 .01847 L
s
.70816 .01472 m
.70816 .01847 L
s
.74617 .01472 m
.74617 .01847 L
s
.82221 .01472 m
.82221 .01847 L
s
.86023 .01472 m
.86023 .01847 L
s
.89825 .01472 m
.89825 .01847 L
s
.93627 .01472 m
.93627 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .10551 m
.03006 .10551 L
s
gsave
.01131 .10551 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .1963 m
.03006 .1963 L
s
gsave
.01131 .1963 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .28709 m
.03006 .28709 L
s
gsave
.01131 .28709 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .37788 m
.03006 .37788 L
s
gsave
.01131 .37788 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .46867 m
.03006 .46867 L
s
gsave
.01131 .46867 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.02381 .55946 m
.03006 .55946 L
s
gsave
.01131 .55946 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03287 m
.02756 .03287 L
s
.02381 .05103 m
.02756 .05103 L
s
.02381 .06919 m
.02756 .06919 L
s
.02381 .08735 m
.02756 .08735 L
s
.02381 .12366 m
.02756 .12366 L
s
.02381 .14182 m
.02756 .14182 L
s
.02381 .15998 m
.02756 .15998 L
s
.02381 .17814 m
.02756 .17814 L
s
.02381 .21445 m
.02756 .21445 L
s
.02381 .23261 m
.02756 .23261 L
s
.02381 .25077 m
.02756 .25077 L
s
.02381 .26893 m
.02756 .26893 L
s
.02381 .30524 m
.02756 .30524 L
s
.02381 .3234 m
.02756 .3234 L
s
.02381 .34156 m
.02756 .34156 L
s
.02381 .35972 m
.02756 .35972 L
s
.02381 .39604 m
.02756 .39604 L
s
.02381 .41419 m
.02756 .41419 L
s
.02381 .43235 m
.02756 .43235 L
s
.02381 .45051 m
.02756 .45051 L
s
.02381 .48683 m
.02756 .48683 L
s
.02381 .50498 m
.02756 .50498 L
s
.02381 .52314 m
.02756 .52314 L
s
.02381 .5413 m
.02756 .5413 L
s
.02381 .57762 m
.02756 .57762 L
s
.02381 .59577 m
.02756 .59577 L
s
.02381 .61393 m
.02756 .61393 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02571 .01472 m
.02761 .01562 L
.02951 .01653 L
.03141 .01744 L
.03331 .01835 L
.03522 .01926 L
.03712 .02018 L
.03902 .02109 L
.04092 .022 L
.04282 .02292 L
.04472 .02384 L
.04662 .02475 L
.04852 .02567 L
.05042 .02659 L
.05232 .02751 L
.05422 .02843 L
.05613 .02935 L
.05803 .03027 L
.05993 .0312 L
.06183 .03212 L
.06373 .03305 L
.06563 .03397 L
.06753 .0349 L
.06943 .03583 L
.07133 .03676 L
.07323 .03769 L
.07514 .03862 L
.07704 .03955 L
.07894 .04048 L
.08084 .04142 L
.08274 .04235 L
.08464 .04329 L
.08654 .04422 L
.08844 .04516 L
.09034 .0461 L
.09224 .04704 L
.09415 .04798 L
.09605 .04892 L
.09795 .04986 L
.09985 .0508 L
.10175 .05175 L
.10365 .05269 L
.10555 .05364 L
.10745 .05459 L
.10935 .05553 L
.11125 .05648 L
.11315 .05743 L
.11506 .05838 L
.11696 .05933 L
.11886 .06029 L
Mistroke
.12076 .06124 L
.12266 .0622 L
.12456 .06315 L
.12646 .06411 L
.12836 .06506 L
.13026 .06602 L
.13216 .06698 L
.13407 .06794 L
.13597 .0689 L
.13787 .06986 L
.13977 .07083 L
.14167 .07179 L
.14357 .07276 L
.14547 .07372 L
.14737 .07469 L
.14927 .07566 L
.15117 .07663 L
.15307 .0776 L
.15498 .07857 L
.15688 .07954 L
.15878 .08051 L
.16068 .08149 L
.16258 .08246 L
.16448 .08344 L
.16638 .08441 L
.16828 .08539 L
.17018 .08637 L
.17208 .08735 L
.17399 .08833 L
.17589 .08931 L
.17779 .09029 L
.17969 .09128 L
.18159 .09226 L
.18349 .09325 L
.18539 .09423 L
.18729 .09522 L
.18919 .09621 L
.19109 .0972 L
.19299 .09819 L
.1949 .09918 L
.1968 .10017 L
.1987 .10117 L
.2006 .10216 L
.2025 .10315 L
.2044 .10415 L
.2063 .10515 L
.2082 .10615 L
.2101 .10715 L
.212 .10815 L
.21391 .10915 L
Mistroke
.21581 .11015 L
.21771 .11115 L
.21961 .11216 L
.22151 .11316 L
.22341 .11417 L
.22531 .11518 L
.22721 .11619 L
.22911 .11719 L
.23101 .11821 L
.23292 .11922 L
.23482 .12023 L
.23672 .12124 L
.23862 .12226 L
.24052 .12327 L
.24242 .12429 L
.24432 .12531 L
.24622 .12632 L
.24812 .12734 L
.25002 .12836 L
.25192 .12939 L
.25383 .13041 L
.25573 .13143 L
.25763 .13246 L
.25953 .13348 L
.26143 .13451 L
.26333 .13554 L
.26523 .13657 L
.26713 .1376 L
.26903 .13863 L
.27093 .13966 L
.27284 .14069 L
.27474 .14172 L
.27664 .14276 L
.27854 .1438 L
.28044 .14483 L
.28234 .14587 L
.28424 .14691 L
.28614 .14795 L
.28804 .14899 L
.28994 .15003 L
.29184 .15108 L
.29375 .15212 L
.29565 .15317 L
.29755 .15421 L
.29945 .15526 L
.30135 .15631 L
.30325 .15736 L
.30515 .15841 L
.30705 .15946 L
.30895 .16051 L
Mistroke
.31085 .16157 L
.31276 .16262 L
.31466 .16368 L
.31656 .16473 L
.31846 .16579 L
.32036 .16685 L
.32226 .16791 L
.32416 .16897 L
.32606 .17003 L
.32796 .1711 L
.32986 .17216 L
.33177 .17323 L
.33367 .17429 L
.33557 .17536 L
.33747 .17643 L
.33937 .1775 L
.34127 .17857 L
.34317 .17964 L
.34507 .18071 L
.34697 .18179 L
.34887 .18286 L
.35077 .18394 L
.35268 .18502 L
.35458 .18609 L
.35648 .18717 L
.35838 .18825 L
.36028 .18934 L
.36218 .19042 L
.36408 .1915 L
.36598 .19259 L
.36788 .19367 L
.36978 .19476 L
.37169 .19585 L
.37359 .19694 L
.37549 .19803 L
.37739 .19912 L
.37929 .20021 L
.38119 .2013 L
.38309 .2024 L
.38499 .20349 L
.38689 .20459 L
.38879 .20569 L
.39069 .20679 L
.3926 .20789 L
.3945 .20899 L
.3964 .21009 L
.3983 .21119 L
.4002 .2123 L
.4021 .2134 L
.404 .21451 L
Mistroke
.4059 .21562 L
.4078 .21673 L
.4097 .21784 L
.41161 .21895 L
.41351 .22006 L
.41541 .22117 L
.41731 .22229 L
.41921 .2234 L
.42111 .22452 L
.42301 .22564 L
.42491 .22676 L
.42681 .22788 L
.42871 .229 L
.43061 .23012 L
.43252 .23124 L
.43442 .23237 L
.43632 .23349 L
.43822 .23462 L
.44012 .23575 L
.44202 .23688 L
.44392 .23801 L
.44582 .23914 L
.44772 .24027 L
.44962 .2414 L
.45153 .24254 L
.45343 .24367 L
.45533 .24481 L
.45723 .24595 L
.45913 .24709 L
.46103 .24823 L
.46293 .24937 L
.46483 .25051 L
.46673 .25165 L
.46863 .2528 L
.47054 .25395 L
.47244 .25509 L
.47434 .25624 L
.47624 .25739 L
.47814 .25854 L
.48004 .25969 L
.48194 .26085 L
.48384 .262 L
.48574 .26315 L
.48764 .26431 L
.48954 .26547 L
.49145 .26663 L
.49335 .26779 L
.49525 .26895 L
.49715 .27011 L
.49905 .27127 L
Mistroke
.50095 .27244 L
.50285 .2736 L
.50475 .27477 L
.50665 .27594 L
.50855 .27711 L
.51046 .27828 L
.51236 .27945 L
.51426 .28062 L
.51616 .2818 L
.51806 .28297 L
.51996 .28415 L
.52186 .28532 L
.52376 .2865 L
.52566 .28768 L
.52756 .28886 L
.52946 .29005 L
.53137 .29123 L
.53327 .29241 L
.53517 .2936 L
.53707 .29479 L
.53897 .29597 L
.54087 .29716 L
.54277 .29835 L
.54467 .29954 L
.54657 .30074 L
.54847 .30193 L
.55038 .30313 L
.55228 .30432 L
.55418 .30552 L
.55608 .30672 L
.55798 .30792 L
.55988 .30912 L
.56178 .31032 L
.56368 .31153 L
.56558 .31273 L
.56748 .31394 L
.56939 .31514 L
.57129 .31635 L
.57319 .31756 L
.57509 .31877 L
.57699 .31998 L
.57889 .3212 L
.58079 .32241 L
.58269 .32363 L
.58459 .32484 L
.58649 .32606 L
.58839 .32728 L
.5903 .3285 L
.5922 .32972 L
.5941 .33095 L
Mistroke
.596 .33217 L
.5979 .3334 L
.5998 .33462 L
.6017 .33585 L
.6036 .33708 L
.6055 .33831 L
.6074 .33954 L
.60931 .34077 L
.61121 .34201 L
.61311 .34324 L
.61501 .34448 L
.61691 .34572 L
.61881 .34696 L
.62071 .3482 L
.62261 .34944 L
.62451 .35068 L
.62641 .35192 L
.62831 .35317 L
.63022 .35442 L
.63212 .35566 L
.63402 .35691 L
.63592 .35816 L
.63782 .35941 L
.63972 .36067 L
.64162 .36192 L
.64352 .36317 L
.64542 .36443 L
.64732 .36569 L
.64923 .36695 L
.65113 .36821 L
.65303 .36947 L
.65493 .37073 L
.65683 .372 L
.65873 .37326 L
.66063 .37453 L
.66253 .37579 L
.66443 .37706 L
.66633 .37833 L
.66823 .37961 L
.67014 .38088 L
.67204 .38215 L
.67394 .38343 L
.67584 .3847 L
.67774 .38598 L
.67964 .38726 L
.68154 .38854 L
.68344 .38982 L
.68534 .39111 L
.68724 .39239 L
.68915 .39368 L
Mistroke
.69105 .39496 L
.69295 .39625 L
.69485 .39754 L
.69675 .39883 L
.69865 .40012 L
.70055 .40142 L
.70245 .40271 L
.70435 .40401 L
.70625 .4053 L
.70816 .4066 L
.71006 .4079 L
.71196 .4092 L
.71386 .41051 L
.71576 .41181 L
.71766 .41312 L
.71956 .41442 L
.72146 .41573 L
.72336 .41704 L
.72526 .41835 L
.72716 .41966 L
.72907 .42097 L
.73097 .42229 L
.73287 .4236 L
.73477 .42492 L
.73667 .42624 L
.73857 .42756 L
.74047 .42888 L
.74237 .4302 L
.74427 .43152 L
.74617 .43285 L
.74808 .43417 L
.74998 .4355 L
.75188 .43683 L
.75378 .43816 L
.75568 .43949 L
.75758 .44082 L
.75948 .44216 L
.76138 .44349 L
.76328 .44483 L
.76518 .44617 L
.76708 .44751 L
.76899 .44885 L
.77089 .45019 L
.77279 .45153 L
.77469 .45288 L
.77659 .45422 L
.77849 .45557 L
.78039 .45692 L
.78229 .45827 L
.78419 .45962 L
Mistroke
.78609 .46097 L
.788 .46233 L
.7899 .46368 L
.7918 .46504 L
.7937 .4664 L
.7956 .46776 L
.7975 .46912 L
.7994 .47048 L
.8013 .47185 L
.8032 .47321 L
.8051 .47458 L
.80701 .47595 L
.80891 .47731 L
.81081 .47869 L
.81271 .48006 L
.81461 .48143 L
.81651 .4828 L
.81841 .48418 L
.82031 .48556 L
.82221 .48694 L
.82411 .48832 L
.82601 .4897 L
.82792 .49108 L
.82982 .49247 L
.83172 .49385 L
.83362 .49524 L
.83552 .49663 L
.83742 .49802 L
.83932 .49941 L
.84122 .5008 L
.84312 .50219 L
.84502 .50359 L
.84693 .50499 L
.84883 .50638 L
.85073 .50778 L
.85263 .50919 L
.85453 .51059 L
.85643 .51199 L
.85833 .5134 L
.86023 .5148 L
.86213 .51621 L
.86403 .51762 L
.86593 .51903 L
.86784 .52044 L
.86974 .52186 L
.87164 .52327 L
.87354 .52469 L
.87544 .52611 L
.87734 .52753 L
.87924 .52895 L
Mistroke
.88114 .53037 L
.88304 .53179 L
.88494 .53322 L
.88685 .53464 L
.88875 .53607 L
.89065 .5375 L
.89255 .53893 L
.89445 .54036 L
.89635 .5418 L
.89825 .54323 L
.90015 .54467 L
.90205 .54611 L
.90395 .54755 L
.90585 .54899 L
.90776 .55043 L
.90966 .55187 L
.91156 .55332 L
.91346 .55476 L
.91536 .55621 L
.91726 .55766 L
.91916 .55911 L
.92106 .56056 L
.92296 .56202 L
.92486 .56347 L
.92677 .56493 L
.92867 .56639 L
.93057 .56785 L
.93247 .56931 L
.93437 .57077 L
.93627 .57224 L
.93817 .5737 L
.94007 .57517 L
.94197 .57664 L
.94387 .57811 L
.94578 .57958 L
.94768 .58105 L
.94958 .58252 L
.95148 .584 L
.95338 .58548 L
.95528 .58696 L
.95718 .58844 L
.95908 .58992 L
.96098 .5914 L
.96288 .59289 L
.96478 .59437 L
.96669 .59586 L
.96859 .59735 L
.97049 .59884 L
.97239 .60033 L
.97429 .60182 L
Mistroke
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00Q?oonfX3o`00O`Gooo]Z1Ol007l5oook
JPGo001oBooonfX9o`00O`?ooo]Z1Ol007l5oookJPGo001oC_oonfX5o`00O`Gooo]Z1Ol007l5oook
JPGo001oD?oonfX3o`00O`Cooo]Z1Ol007l5oookJPGo001oC_oonfX5o`00O`Gooo]Z1Ol007l5oook
JPGo001o2ooonfX008Cooo]Z0ol007l4oookJPOo001o0ooonfX7o`00Od[ooo]Z2Ol007l2oookJPOo
001o0ooonfX7o`00Odcooo]Z1ol007l3oookJPOo001o0ooonfX7o`00Odoooo]Z0ol007l3oookJPOo
001o0ooonfX7o`00Odcooo]Z1ol007l3oookJPOo001o0ooonfX7o`00O`[ooo]Z0024oookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007m:oook
JPCo001o1ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07m;oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o
00Cooo]Zo`00Ool007oo001oCooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001oBooonfX4o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX008Cooo]Z
0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m:oookJPCo
001o1OoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001oB_oonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00OdWooo]Z2Ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00Od[ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l9oookJP00Q?oonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Od_ooo]Z1Ol007l3oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m@oookJP?o001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m9oookJPWo001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m@oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l9oookJP00Q?oo
nfX3o`00O`?ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Odgooo]Z
1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m@oookJP?o
001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m9
oookJP;o001o0ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00Oe3ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`Wooo]Z0024oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007l3oookJP?o001oC_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool0
07oo001o0ooonfX3o`00Odkooo]Z1?l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007m:oookJP;o001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00Od_ooo]Z0_l007l2oookJPCo001o00Cooo]Zo`00Ool007oo001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l9oookJP00Q?oonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Odoooo]Z0ol007l01?oonf[o
001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Odkooo]Z0ol007l3
oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007m:oookJP?o001o00Co
oo]Zo`00Ool007oo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001oBooonfX7o`00O`;ooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00
O`Wooo]Z0024oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oook
JP?o001oBOoonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00Oe3ooo]Z0_l007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`?ooo]Z0ol007m;oookJP;o001o00Cooo]Zo`00Ool007oo001o0_oonfX3o`00O`?o
oo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001oBooonfX6o`00O`?ooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Wooo]Z0021oookJPKo001o0ooonfX3o`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001oBOoonfX3o`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00Od[ooo]Z
0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007m<oookJPGo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001oBooonfX2o`00O`Oooo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooo
nfX3o`00O`Wooo]Z000VoookJPGo0000E_oonfX6o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool0
07l3oookJP?o001o00Cooo]Zo`00Ool007oo001oB_oonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00Od_ooo]Z0ol007l3oook
JP?o001o0_oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool0
07m=oookJPGo001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001o
o`00Ool007m<oookJP;o001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l:oookJP009_oonfX5o`0005Sooo]Z1?l007l4oookJPOo001o0ooonfX7o`00
Od_ooo]Z1ol007l3oookJPOo001o0ooonfX7o`00Odcooo]Z1ol007l3oookJPOo001o0ooonfX7o`00
Odkooo]Z1?l007l3oookJPOo001o0ooonfX7o`00Odgooo]Z1ol007l2oookJPOo001o0ooonfX7o`00
O`[ooo]Z000VoookJPGo0000FOoonfX3o`00O`Gooo]Z1Ol007l5oookJPGo001oCOoonfX5o`00O`Go
oo]Z1Ol007l5oookJPGo001oC_oonfX5o`00O`Gooo]Z1Ol007l5oookJPGo001oD?oonfX3o`00O`Co
oo]Z1Ol007l5oookJPGo001oC_oonfX7o`00O`?ooo]Z1Ol007l5oookJPGo001o2ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oo
oo]Z5ooonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o00001_oo
nfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wo
oo]Zool0003oo`0002?o00001_oonfX002Kooo]Z1Ol00003oookJP;o0000GooonfX00ol0003ooo]Z
oookJP1SoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]Z
oookJP1ToookJP03o`000?oonf[ooo]Z01Cooo]Z000VoookJPGo00001OoonfX2o`0005gooo]Z00?o
0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z06?ooo]Z00?o
0000oookJ_oonfX0I?oonfX00ol0003ooo]ZoookJP0DoookJP009_oonfX5o`0000Oooo]Z0_l0003o
oookJ_oooo]Z3_oonfX002Kooo]Z1Ol00009oookJP;o0000oooonf[ooookJPcooo]Z000VoookJPGo
00002ooonfX2o`000?oooo]ZoooonfX:oookJP009_oonfX5o`0000gooo]Z0_l0003ooookJ_oooo]Z
2?oonfX002Kooo]Z1Ol0000?oookJP;o0000oooonf[ooookJPKooo]Z000VoookJPGo00004OoonfX3
o`000?oooo]ZoooonfX3oookJP009_oonfX5o`0001Cooo]Z0_l0003ooookJ_oooo]Z0OoonfX002Ko
oo]Z1Ol0000FoookJP;o0000oooonf[noookJP009_oonfX5o`0001Sooo]Z0_l0003ooookJ_cooo]Z
000VoookJPGo00006_oonfX2o`000?oooo]Zn_oonfX002Kooo]Z1Ol0000LoookJP;o0000oooonf[h
oookJP009_oonfX5o`0001kooo]Z0_l0003ooookJ_Kooo]Z000VoookJPGo00008?oonfX2o`000?oo
oo]Zm?oonfX002Kooo]Z1Ol0000RoookJP;o0000oooonf[boookJP009_oonfX5o`0002Cooo]Z0_l0
003ooookJ_3ooo]Z000VoookJPGo00009_oonfX2o`000?oooo]Zk_oonfX002Kooo]Z1Ol0000Xoook
JP;o0000oooonf[/oookJP009_oonfX5o`0002[ooo]Z0_l0003ooookJ^[ooo]Z000VoookJPGo0000
;?oonfX2o`000?oooo]Zj?oonfX002Kooo]Z1Ol0000^oookJP;o0000oooonf[VoookJP009_oonfX5
o`00033ooo]Z0_l0003ooookJ^Cooo]Z000VoookJPGo0000<_oonfX2o`000?oooo]Zh_oonfX002Ko
oo]Z1Ol0000doookJP;o0000oooonf[PoookJP009_oonfX5o`0003Kooo]Z00?o0000oookJ_oonfX0
oooonf[MoookJP009_oonfX5o`0003Oooo]Z0_l0003ooookJ]gooo]Z000VoookJPGo0000>OoonfX3
o`000?oooo]Zf_oonfX002Kooo]Z1Ol0000loookJP;o0000oooonf[HoookJP009_oonfX5o`0003ko
oo]Z0_l0003ooookJ]Kooo]Z000VoookJPGo0000@?oonfX2o`000?oooo]Ze?oonfX002Kooo]Z1Ol0
0012oookJP;o0000oooonf[BoookJP009_oonfX5o`0004Cooo]Z0_l0003ooookJ]3ooo]Z000Voook
JPGo0000A_oonfX2o`000?oooo]Zc_oonfX002Kooo]Z1Ol00018oookJP;o0000oooonf[<oookJP00
9_oonfX5o`0004[ooo]Z0_l0003ooookJ/[ooo]Z000VoookJPGo0000C?oonfX2o`000?oooo]Zb?oo
nfX002Kooo]Z1Ol0001>oookJP03o`000?oonf[ooo]Z0?oooo]ZaOoonfX002Kooo]Z1Ol0001?oook
JP;o0000oooonf[5oookJP009_oonfX5o`00057ooo]Z0_l0003ooookJ/?ooo]Z000VoookJPGo0000
DooonfX2o`000?oooo]Z`OoonfX002Kooo]Z1Ol0001EoookJP;o0000oooonfZooookJP002_oonfX3
o`00O`Cooo]Z0ol007l5oookJP?o001o2_oonfX5o`0005Oooo]Z0_l0003ooookJ[gooo]Z000:oook
JP?o001o1?oonfX3o`00O`Gooo]Z0ol007l:oookJPGo0000FOoonfX2o`000?oooo]Z^ooonfX000[o
oo]Z0ol007l4oookJP?o001o1OoonfX3o`00O`[ooo]Z1Ol0001KoookJP;o0000oooonfZioookJP00
2_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000GOoonfX00ol0003ooo]ZoookJP3ooookJ[Kooo]Z
000:oookJP?o001o3?oonfX3o`00O`[ooo]Z1_l0001MoookJP;o0000oooonfZfoookJP002_oonfX3
o`00O`cooo]Z0ol007l:oookJPGo0000H?oonfX3o`000?oooo]Z/ooonfX000[ooo]Z0ol007l<oook
JP?o001o2_oonfX5o`0006?ooo]Z0_l0003ooookJ[7ooo]Z000:oookJP?o001o3?oonfX3o`00O`[o
oo]Z1Ol0001UoookJP;o0000oooonfZ_oookJP002_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000
IooonfX2o`000?oooo]Z[OoonfX000Oooo]Z1_l007l9oookJPKo001o2_oonfX5o`0006Wooo]Z00?o
0000oookJ_oonfX0oooonfZZoookJP001ooonfX6o`00O`Wooo]Z1_l007l:oookJPGo0000J_oonfX2
o`000?oooo]ZZ_oonfX000Wooo]Z1?l007l;oookJPCo001o2_oonfX5o`0006cooo]Z0_l0003ooook
JZSooo]Z000:oookJP?o001o3?oonfX3o`00O`[ooo]Z1Ol0001^oookJP;o0000oooonfZVoookJP00
9_oonfX5o`00073ooo]Z0_l0003ooookJZCooo]Z000VoookJPGo0000L_oonfX2o`000?oooo]ZX_oo
nfX002Kooo]Z1Ol0001doookJP03o`000?oonf[ooo]Z0?oooo]ZWooonfX002Kooo]Z1Ol0001eoook
JP;o0000oooonfZOoookJP009_oonfX5o`0007Oooo]Z0_l0003ooookJYgooo]Z000VoookJPGo0000
NOoonfX2o`000?oooo]ZVooonfX002Kooo]Z1Ol0001koookJP;o0000oooonfZIoookJP009_oonfX5
o`0007gooo]Z0_l0003ooookJYOooo]Z000VoookJPGo0000OooonfX00ol0003ooo]ZoookJP3ooook
JYCooo]Z000VoookJPGo0000P?oonfX2o`000?oooo]ZU?oonfX002Kooo]Z1Ol00022oookJP;o0000
oooonfZBoookJP009_oonfX5o`0008Cooo]Z0_l0003ooookJY3ooo]Z000VoookJPGo0000Q_oonfX0
0ol0003ooo]ZoookJP3ooookJXgooo]Z000VoookJPGo0000QooonfX2o`000?oooo]ZSOoonfX002Ko
oo]Z1Ol00029oookJP?o0000oooonfZ:oookJP009_oonfX5o`0008cooo]Z0_l0003ooookJXSooo]Z
000VoookJPGo0000S_oonfX2o`000?oooo]ZQ_oonfX002Kooo]Z1Ol0002@oookJP03o`000?oonf[o
oo]Z0?oooo]ZPooonfX002Kooo]Z1Ol0002AoookJP;o0000oooonfZ3oookJP009_oonfX5o`0009?o
oo]Z0_l0003ooookJX7ooo]Z000VoookJPGo0000UOoonfX2o`000?oooo]ZOooonfX002Kooo]Z1Ol0
002GoookJP03o`000?oonf[ooo]Z0?oooo]ZO?oonfX002Kooo]Z1Ol0002HoookJP;o0000oooonfYl
oookJP009_oonfX5o`0009[ooo]Z0_l0003ooookJW[ooo]Z000VoookJPGo0000W?oonfX2o`000?oo
oo]ZN?oonfX002Kooo]Z1Ol0002NoookJP03o`000?oonf[ooo]Z0?oooo]ZMOoonfX002Kooo]Z1Ol0
002OoookJP;o0000oooonfYeoookJP009_oonfX5o`000:7ooo]Z0_l0003ooookJW?ooo]Z000Voook
JPGo0000XooonfX2o`000?oooo]ZLOoonfX002Kooo]Z1Ol0002UoookJP03o`000?oonf[ooo]Z0?oo
oo]ZK_oonfX002Kooo]Z1Ol0002VoookJP;o0000oooonfY^oookJP009_oonfX5o`000:Sooo]Z0_l0
003ooookJVcooo]Z000VoookJPGo0000Z_oonfX2o`000?oooo]ZJ_oonfX002Kooo]Z1Ol0002/oook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX002Kooo]Z1Ol0002]oookJP;o0000oooonfYWoookJP00
9_oonfX5o`000:oooo]Z0_l0003ooookJVGooo]Z000:oookJP?o001o1?oonfX3o`00O`03oookJ_l0
07oo001o00Oo001o2?oonfX5o`000;7ooo]Z0_l0003ooookJV?ooo]Z000:oookJP?o001o1?oonfX3
o`00O`03oookJ_l007oo001o00Oo001o2?oonfX5o`000;?ooo]Z0_l0003ooookJV7ooo]Z000:oook
JP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00;o001o3OoonfX5o`000;Gooo]Z0_l0003ooook
JUoooo]Z000:oookJP?o001o2OoonfX4o`00O`cooo]Z1Ol0002goookJP;o0000oooonfYMoookJP00
2_oonfX3o`00O`[ooo]Z1Ol007l:oookJPKo0000^?oonfX00ol0003ooo]ZoookJP3ooookJU[ooo]Z
000:oookJP?o001o3?oonfX4o`00O`Wooo]Z1Ol0002joookJP;o0000oooonfYJoookJP002_oonfX3
o`00O`gooo]Z0ol007l9oookJPGo0000_?oonfX2o`000?oooo]ZF?oonfX000[ooo]Z0ol007l>oook
JP?o001o2?oonfX5o`000;kooo]Z00?o0000oookJ_oonfX0oooonfYEoookJP002_oonfX3o`00O`So
oo]Z0ol007l3oookJP?o001o2?oonfX5o`000;oooo]Z0_l0003ooookJUGooo]Z0007oookJPKo001o
2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo0000`OoonfX2o`000?oooo]ZDooonfX000Oooo]Z1_l0
07l8oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol00033oookJP03o`000?oonf[ooo]Z0?oooo]ZD?oo
nfX000Wooo]Z1?l007l9oookJPOo001o2OoonfX5o`000<Cooo]Z0_l0003ooookJU3ooo]Z000:oook
JP?o001o2_oonfX5o`00O`[ooo]Z1Ol00036oookJP;o0000oooonfY>oookJP009_oonfX5o`000<So
oo]Z0_l0003ooookJTcooo]Z000VoookJPGo0000b_oonfX00ol0003ooo]ZoookJP3ooookJTWooo]Z
000VoookJPGo0000booonfX2o`000?oooo]ZBOoonfX002Kooo]Z1Ol0003=oookJP;o0000oooonfY7
oookJP009_oonfX5o`000<oooo]Z00?o0000oookJ_oonfX0oooonfY4oookJP009_oonfX5o`000=3o
oo]Z0_l0003ooookJTCooo]Z000VoookJPGo0000d_oonfX2o`000?oooo]Z@_oonfX002Kooo]Z1Ol0
003DoookJP03o`000?oonf[ooo]Z0?oooo]Z?ooonfX002Kooo]Z1Ol0003EoookJP;o0000oooonfXo
oookJP009_oonfX5o`000=Oooo]Z00?o0000oookJ_oonfX0oooonfXloookJP009_oonfX5o`000=So
oo]Z0ol0003ooookJS_ooo]Z000VoookJPGo0000fooonfX2o`000?oooo]Z>OoonfX002Kooo]Z1Ol0
003MoookJP03o`000?oonf[ooo]Z0?oooo]Z=_oonfX002Kooo]Z1Ol0003NoookJP;o0000oooonfXf
oookJP009_oonfX5o`000>3ooo]Z0_l0003ooookJSCooo]Z000VoookJPGo0000h_oonfX00ol0003o
oo]ZoookJP3ooookJS7ooo]Z000VoookJPGo0000hooonfX2o`000?oooo]Z<OoonfX002Kooo]Z1Ol0
003UoookJP;o0000oooonfX_oookJP009_oonfX5o`000>Oooo]Z00?o0000oookJ_oonfX0oooonfX/
oookJP009_oonfX5o`000>Sooo]Z0_l0003ooookJRcooo]Z000VoookJPGo0000j_oonfX00ol0003o
oo]ZoookJP3ooookJRWooo]Z000VoookJPGo0000jooonfX2o`000?oooo]Z:OoonfX002Kooo]Z1Ol0
003]oookJP;o0000oooonfXWoookJP009_oonfX5o`000>oooo]Z00?o0000oookJ_oonfX0oooonfXT
oookJP009_oonfX5o`000?3ooo]Z0_l0003ooookJRCooo]Z000VoookJPGo0000l_oonfX2o`000?oo
oo]Z8_oonfX002Kooo]Z1Ol0003doookJP03o`000?oonf[ooo]Z0?oooo]Z7ooonfX002Kooo]Z1Ol0
003eoookJP;o0000oooonfXOoookJP009_oonfX5o`000?Oooo]Z00?o0000oookJ_oonfX0oooonfXL
oookJP009_oonfX5o`000?Sooo]Z0_l0003ooookJQcooo]Z000VoookJPGo0000n_oonfX2o`000?oo
oo]Z6_oonfX002Kooo]Z1Ol0003loookJP03o`000?oonf[ooo]Z0?oooo]Z5ooonfX002Kooo]Z1Ol0
003moookJP;o0000oooonfXGoookJP009_oonfX5o`000?oooo]Z00?o0000oookJ_oonfX0oooonfXD
oookJP009_oonfX5o`000?oooo]Z0OoonfX2o`000?oooo]Z5?oonfX002Kooo]Z1Ol0003ooookJP?o
oo]Z0ol0003ooookJQ7ooo]Z000:oookJP?o001o1?oonfX3o`00O`?ooo]Z1Ol007l:oookJPGo0000
oooonfX6oookJP03o`000?oonf[ooo]Z0?oooo]Z3_oonfX000[ooo]Z0ol007l4oookJP?o001o0_oo
nfX7o`00O`Wooo]Z1Ol0003ooookJPOooo]Z0_l0003ooookJPkooo]Z000:oookJP?o001o1?oonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfX9oookJP03o`000?oo
nf[ooo]Z0?oooo]Z2ooonfX000[ooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003o
oookJP[ooo]Z0_l0003ooookJP_ooo]Z000:oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooook
JP_ooo]Z00?o0000oookJ_oonfX0oooonfX8oookJP002_oonfX3o`00O`kooo]Z0ol007l8oookJPGo
0000oooonfX=oookJP;o0000oooonfX8oookJP002_oonfX3o`00O`cooo]Z1?l007l9oookJPGo0000
oooonfX?oookJP;o0000oooonfX6oookJP002_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000oooo
nfXAoookJP03o`000?oonf[ooo]Z0?oooo]Z0ooonfX000[ooo]Z0ol007l>oookJP;o001o2OoonfX5
o`000?oooo]Z4_oonfX2o`000?oooo]Z0ooonfX000Oooo]Z1_l007l8oookJP?o001o0ooonfX3o`00
O`Sooo]Z1Ol0003ooookJQCooo]Z00?o0000oookJ_oonfX0oooonfX000Oooo]Z1_l007l8oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJQGooo]Z0_l0003ooookJP002OoonfX4o`00O`Wooo]Z
1ol007l9oookJPGo0000oooonfXGoookJP03o`000?oonf[ooo]Z0?cooo]Z000:oookJP?o001o2_oo
nfX5o`00O`[ooo]Z1Ol0003ooookJQSooo]Z0_l0003loookJP009_oonfX5o`000?oooo]Z6_oonfX0
0ol0003ooo]ZoookJP3ioookJP009_oonfX5o`000?oooo]Z6ooonfX2o`000?Wooo]Z000VoookJPGo
0000oooonfXMoookJP;o0000mooonfX002Kooo]Z1Ol0003ooookJQoooo]Z00?o0000oookJ_oonfX0
m?oonfX002Kooo]Z1Ol0003ooookJR3ooo]Z0_l0003doookJP009_oonfX5o`000?oooo]Z8_oonfX0
0ol0003ooo]ZoookJP3aoookJP009_oonfX5o`000?oooo]Z8ooonfX2o`000?7ooo]Z000VoookJPGo
0000oooonfXUoookJP03o`000?oonf[ooo]Z0>kooo]Z000VoookJPGo0000oooonfXVoookJP;o0000
k_oonfX002Kooo]Z1Ol0003ooookJRSooo]Z00?o0000oookJ_oonfX0jooonfX002Kooo]Z1Ol0003o
oookJRWooo]Z0_l0003[oookJP009_oonfX5o`000?oooo]Z:ooonfX2o`000>Wooo]Z000VoookJPGo
0000oooonfX]oookJP;o0000iooonfX002Kooo]Z1Ol0003ooookJRoooo]Z00?o0000oookJ_oonfX0
i?oonfX002Kooo]Z1Ol0003ooookJS3ooo]Z0_l0003ToookJP009_oonfX5o`000?oooo]Z<_oonfX0
0ol0003ooo]ZoookJP3QoookJP009_oonfX5o`000?oooo]Z<ooonfX2o`000>7ooo]Z000VoookJPGo
0000oooonfXeoookJP03o`000?oonf[ooo]Z0=kooo]Z000VoookJPGo0000oooonfXfoookJP;o0000
g_oonfX002Kooo]Z1Ol0003ooookJSSooo]Z00?o0000oookJ_oonfX0fooonfX002Kooo]Z1Ol0003o
oookJSWooo]Z0_l0003KoookJP009_oonfX5o`000?oooo]Z>ooonfX00ol0003ooo]ZoookJP3Hoook
JP009_oonfX5o`000?oooo]Z??oonfX2o`000=Sooo]Z000VoookJPGo0000oooonfXnoookJP03o`00
0?oonf[ooo]Z0=Gooo]Z000VoookJPGo0000oooonfXooookJP;o0000eOoonfX002Kooo]Z1Ol0003o
oookJT7ooo]Z00?o0000oookJ_oonfX0d_oonfX002Kooo]Z1Ol0003ooookJT;ooo]Z0_l0003Boook
JP009_oonfX5o`000?oooo]ZA?oonfX00ol0003ooo]ZoookJP3?oookJP009_oonfX5o`000?oooo]Z
AOoonfX2o`000<oooo]Z000VoookJPGo0000oooonfY7oookJP03o`000?oonf[ooo]Z0<cooo]Z000V
oookJPGo0000oooonfY8oookJP;o0000c?oonfX002Kooo]Z1Ol0003ooookJT[ooo]Z00?o0000oook
J_oonfX0bOoonfX002Kooo]Z1Ol0003ooookJT_ooo]Z0_l00039oookJP009_oonfX5o`000?oooo]Z
COoonfX00ol0003ooo]ZoookJP36oookJP009_oonfX5o`000?oooo]ZC_oonfX2o`000<Kooo]Z000V
oookJPGo0000oooonfY@oookJP03o`000?oonf[ooo]Z0<?ooo]Z000:oookJP?o001o1?oonfX3o`00
O`Kooo]Z0ol007l9oookJPGo0000oooonfYAoookJP;o0000`ooonfX000[ooo]Z0ol007l4oookJP?o
001o1_oonfX3o`00O`Wooo]Z1Ol0003ooookJU?ooo]Z0_l00031oookJP002_oonfX3o`00O`Cooo]Z
0ol007l6oookJP?o001o2OoonfX5o`000?oooo]ZEOoonfX2o`000;oooo]Z000:oookJP?o001o2?oo
nfX9o`00O`Sooo]Z1Ol0003ooookJUOooo]Z00?o0000oookJ_oonfX0_?oonfX000[ooo]Z0ol007l8
oookJPWo001o2?oonfX6o`000?oooo]ZEooonfX2o`000;cooo]Z000:oookJP?o001o2?oonfX2o`00
O`?ooo]Z0ol007l9oookJPGo0000oooonfYJoookJP03o`000?oonf[ooo]Z0;Wooo]Z000:oookJP?o
001o2OoonfX2o`00O`;ooo]Z0ol007l9oookJPGo0000oooonfYKoookJP03o`000?oonf[ooo]Z0;So
oo]Z000:oookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJUco
oo]Z0_l0002hoookJP002_oonfX3o`00O`[ooo]Z0_l007l01?oonf[o001oo`00Ool007l9oookJPGo
0000oooonfYNoookJP03o`000?oonf[ooo]Z0;Gooo]Z0007oookJPKo001o2ooonfX5o`00O`Wooo]Z
1Ol0003ooookJUoooo]Z0_l0002eoookJP001ooonfX6o`00O`_ooo]Z1Ol007l9oookJPGo0000oooo
nfYQoookJP03o`000?oonf[ooo]Z0;;ooo]Z0009oookJPCo001o3?oonfX4o`00O`Wooo]Z1Ol0003o
oookJV;ooo]Z0_l0002boookJP002_oonfX3o`00O`gooo]Z0ol007l9oookJPGo0000oooonfYToook
JP03o`000?oonf[ooo]Z0:oooo]Z000VoookJPGo0000oooonfYUoookJP;o0000[ooonfX002Kooo]Z
1Ol0003ooookJVOooo]Z00?o0000oookJ_oonfX0[?oonfX002Kooo]Z1Ol0003ooookJVSooo]Z00?o
0000oookJ_oonfX0ZooonfX002Kooo]Z1Ol0003ooookJVWooo]Z0_l0002[oookJP009_oonfX5o`00
0?oooo]ZJooonfX00ol0003ooo]ZoookJP2XoookJP009_oonfX5o`000?oooo]ZK?oonfX2o`000:So
oo]Z000VoookJPGo0000oooonfY^oookJP03o`000?oonf[ooo]Z0:Gooo]Z000VoookJPGo0000oooo
nfY_oookJP;o0000YOoonfX002Kooo]Z1Ol0003ooookJW7ooo]Z00?o0000oookJ_oonfX0X_oonfX0
02Kooo]Z1Ol0003ooookJW;ooo]Z00?o0000oookJ_oonfX0XOoonfX002Kooo]Z1Ol0003ooookJW?o
oo]Z0_l0002QoookJP009_oonfX5o`000?oooo]ZMOoonfX00ol0003ooo]ZoookJP2NoookJP009_oo
nfX5o`000?oooo]ZM_oonfX2o`0009kooo]Z000VoookJPGo0000oooonfYhoookJP03o`000?oonf[o
oo]Z09_ooo]Z000VoookJPGo0000oooonfYioookJP;o0000VooonfX002Kooo]Z1Ol0003ooookJW_o
oo]Z0_l0002IoookJP009_oonfX5o`000?oooo]ZOOoonfX00ol0003ooo]ZoookJP2FoookJP009_oo
nfX5o`000?oooo]ZO_oonfX2o`0009Kooo]Z000VoookJPGo0000oooonfZ0oookJP03o`000?oonf[o
oo]Z09?ooo]Z000VoookJPGo0000oooonfZ1oookJP;o0000TooonfX002Kooo]Z1Ol0003ooookJX?o
oo]Z00?o0000oookJ_oonfX0T?oonfX002Kooo]Z1Ol0003ooookJXCooo]Z00?o0000oookJ_oonfX0
SooonfX002Kooo]Z1Ol0003ooookJXGooo]Z0_l0002?oookJP009_oonfX5o`000?oooo]ZQooonfX0
0ol0003ooo]ZoookJP2<oookJP009_oonfX5o`000?oooo]ZR?oonfX2o`0008cooo]Z000VoookJPGo
0000oooonfZ:oookJP03o`000?oonf[ooo]Z08Wooo]Z000VoookJPGo0000oooonfZ;oookJP03o`00
0?oonf[ooo]Z08Sooo]Z000VoookJPGo0000oooonfZ<oookJP;o0000R?oonfX002Kooo]Z1Ol0003o
oookJXkooo]Z00?o0000oookJ_oonfX0QOoonfX002Kooo]Z1Ol0003ooookJXoooo]Z00?o0000oook
J_oonfX0Q?oonfX002Kooo]Z1Ol0003ooookJY3ooo]Z0_l00024oookJP009_oonfX5o`000?oooo]Z
T_oonfX00ol0003ooo]ZoookJP21oookJP009_oonfX5o`000?oooo]ZTooonfX2o`00087ooo]Z000V
oookJPGo0000oooonfZEoookJP03o`000?oonf[ooo]Z07kooo]Z000VoookJPGo0000oooonfZFoook
JP03o`000?oonf[ooo]Z07gooo]Z000VoookJPGo0000oooonfZGoookJP;o0000OOoonfX000[ooo]Z
0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJYWooo]Z00?o0000oookJ_oonfX0
N_oonfX000[ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJY[ooo]Z00?o
0000oookJ_oonfX0NOoonfX000[ooo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l0
1?oonf[o001oo`00Ool007l9oookJPGo0000oooonfZKoookJP;o0000NOoonfX000[ooo]Z0ol007l8
oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJYgooo]Z00?o0000oookJ_oonfX0M_oonfX0
00[ooo]Z0ol007l>oookJP?o001o2?oonfX6o`000?oooo]ZWOoonfX2o`0007Kooo]Z000:oookJP?o
001o3_oonfX3o`00O`Sooo]Z1Ol0003ooookJZ3ooo]Z00?o0000oookJ_oonfX0LooonfX000[ooo]Z
0ol007l9oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0003ooookJZ7ooo]Z00?o0000oookJ_oonfX0
L_oonfX000[ooo]Z0ol007l9oookJPOo001o2OoonfX5o`000?oooo]ZX_oonfX3o`00077ooo]Z000:
oookJP?o001o2OoonfX6o`00O`[ooo]Z1Ol0003ooookJZGooo]Z00?o0000oookJ_oonfX0K_oonfX0
00Oooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]ZY_oonfX00ol0003ooo]ZoookJP1]oook
JP001ooonfX6o`00O`Wooo]Z0_l007l>oookJPGo0000oooonfZWoookJP;o0000KOoonfX000Wooo]Z
1?l007l:oookJPOo001o2?oonfX5o`000?oooo]ZZOoonfX00ol0003ooo]ZoookJP1ZoookJP002_oo
nfX3o`00O`[ooo]Z1ol007l8oookJPGo0000oooonfZZoookJP03o`000?oonf[ooo]Z06Wooo]Z000V
oookJPGo0000oooonfZ[oookJP;o0000JOoonfX002Kooo]Z1Ol0003ooookJZgooo]Z00?o0000oook
J_oonfX0I_oonfX002Kooo]Z1Ol0003ooookJZkooo]Z00?o0000oookJ_oonfX0IOoonfX002Kooo]Z
1Ol0003ooookJZoooo]Z0_l0001UoookJP009_oonfX5o`000?oooo]Z/OoonfX00ol0003ooo]Zoook
JP1RoookJP009_oonfX5o`000?oooo]Z/_oonfX00ol0003ooo]ZoookJP1QoookJP009_oonfX5o`00
0?oooo]Z/ooonfX2o`00067ooo]Z000VoookJPGo0000oooonfZeoookJP03o`000?oonf[ooo]Z05ko
oo]Z000VoookJPGo0000oooonfZfoookJP03o`000?oonf[ooo]Z05gooo]Z000VoookJPGo0000oooo
nfZgoookJP;o0000GOoonfX002Kooo]Z1Ol0003ooookJ[Wooo]Z00?o0000oookJ_oonfX0F_oonfX0
02Kooo]Z1Ol0003ooookJ[[ooo]Z00?o0000oookJ_oonfX0FOoonfX002Kooo]Z1Ol0003ooookJ[_o
oo]Z0_l0001IoookJP009_oonfX5o`000?oooo]Z_OoonfX00ol0003ooo]ZoookJP1FoookJP009_oo
nfX5o`000?oooo]Z__oonfX00ol0003ooo]ZoookJP1EoookJP009_oonfX5o`000?oooo]Z_ooonfX2
o`0005Gooo]Z000VoookJPGo0000oooonf[1oookJP03o`000?oonf[ooo]Z05;ooo]Z000VoookJPGo
0000oooonf[2oookJP03o`000?oonf[ooo]Z057ooo]Z000VoookJPGo0000oooonf[3oookJP;o0000
DOoonfX002Kooo]Z1Ol0003ooookJ/Gooo]Z00?o0000oookJ_oonfX0C_oonfX002Kooo]Z1Ol0003o
oookJ/Kooo]Z00?o0000oookJ_oonfX0COoonfX002Kooo]Z1Ol0003ooookJ/Oooo]Z0_l0001=oook
JP009_oonfX5o`000?oooo]ZbOoonfX00ol0003ooo]ZoookJP1:oookJP009_oonfX5o`000?oooo]Z
b_oonfX00ol0003ooo]ZoookJP19oookJP009_oonfX5o`000?oooo]ZbooonfX2o`0004Wooo]Z000V
oookJPGo0000oooonf[=oookJP;o0000AooonfX002Kooo]Z1Ol0003ooookJ/oooo]Z00?o0000oook
J_oonfX0A?oonfX002Kooo]Z1Ol0003ooookJ]3ooo]Z00?o0000oookJ_oonfX0@ooonfX002Kooo]Z
1Ol0003ooookJ]7ooo]Z0_l00013oookJP009_oonfX5o`000?oooo]ZdooonfX00ol0003ooo]Zoook
JP10oookJP009_oonfX5o`000?oooo]Ze?oonfX00ol0003ooo]ZoookJP0ooookJP009_oonfX5o`00
0?oooo]ZeOoonfX2o`0003oooo]Z000VoookJPGo0000oooonf[GoookJP03o`000?oonf[ooo]Z03co
oo]Z000VoookJPGo0000oooonf[HoookJP03o`000?oonf[ooo]Z03_ooo]Z000VoookJPGo0000oooo
nf[IoookJP03o`000?oonf[ooo]Z03[ooo]Z000VoookJPGo0000oooonf[JoookJP;o0000>_oonfX0
00[ooo]Z0ol007l4oookJP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJ]cooo]Z00?o0000oook
J_oonfX0=ooonfX000[ooo]Z0ol007l4oookJP?o001o0_oonfX7o`00O`Wooo]Z1Ol0003ooookJ]go
oo]Z00?o0000oookJ_oonfX0=_oonfX000[ooo]Z0ol007l4oookJP?o001o0_oonfX3o`00O`;ooo]Z
0ol007l8oookJPGo0000oooonf[NoookJP;o0000=_oonfX000[ooo]Z0ol007l8oookJP?o001o0ooo
nfX3o`00O`Sooo]Z1Ol0003ooookJ^3ooo]Z00?o0000oookJ_oonfX0<ooonfX000[ooo]Z0ol007l8
oookJP?o001o0ooonfX3o`00O`Sooo]Z1_l0003ooookJ^3ooo]Z00?o0000oookJ_oonfX0<_oonfX0
00[ooo]Z0ol007l8oookJPCo001o0_oonfX3o`00O`Sooo]Z1Ol0003ooookJ^;ooo]Z00?o0000oook
J_oonfX0<OoonfX000[ooo]Z0ol007l8oookJPSo001o2OoonfX5o`000?oooo]ZhooonfX2o`00037o
oo]Z000:oookJP?o001o2?oonfX3o`00O`04oookJ_l007oo001oo`00O`[ooo]Z1Ol0003ooookJ^Go
oo]Z00?o0000oookJ_oonfX0;_oonfX000[ooo]Z0ol007l8oookJP?o001o3_oonfX5o`000?oooo]Z
i_oonfX00ol0003ooo]ZoookJP0]oookJP001ooonfX6o`00O`Sooo]Z0ol007l>oookJPGo0000oooo
nf[WoookJP03o`000?oonf[ooo]Z02cooo]Z0007oookJPKo001o2OoonfX3o`00O`;ooo]Z0ol007l8
oookJPGo0000oooonf[XoookJP;o0000;?oonfX000Wooo]Z1?l007l9oookJPOo001o2OoonfX5o`00
0?oooo]Zj_oonfX00ol0003ooo]ZoookJP0YoookJP002_oonfX3o`00O`_ooo]Z1?l007l:oookJPGo
0000oooonf[[oookJP03o`000?oonf[ooo]Z02Sooo]Z000VoookJPGo0000oooonf[/oookJP;o0000
:?oonfX002Kooo]Z1Ol0003ooookJ^kooo]Z00?o0000oookJ_oonfX09OoonfX002Kooo]Z1Ol0003o
oookJ^oooo]Z00?o0000oookJ_oonfX09?oonfX002Kooo]Z1Ol0003ooookJ_3ooo]Z00?o0000oook
J_oonfX08ooonfX002Kooo]Z1Ol0003ooookJ_7ooo]Z0_l0000SoookJP009_oonfX5o`000?oooo]Z
looonfX2o`00027ooo]Z000VoookJPGo0000oooonf[eoookJP03o`000?oonf[ooo]Z01kooo]Z000V
oookJPGo0000oooonf[foookJP03o`000?oonf[ooo]Z01gooo]Z000VoookJPGo0000oooonf[goook
JP;o00007OoonfX002Kooo]Z1Ol0003ooookJ_Wooo]Z00?o0000oookJ_oonfX06_oonfX002Kooo]Z
1Ol0003ooookJ_[ooo]Z00?o0000oookJ_oonfX06OoonfX002Kooo]Z1Ol0003ooookJ__ooo]Z00?o
0000oookJ_oonfX06?oonfX002Kooo]Z1Ol0003ooookJ_cooo]Z0_l0000HoookJP009_oonfX5o`00
0?oooo]Zo_oonfX00ol0003ooo]ZoookJP0EoookJP009_oonfX5o`000?oooo]ZoooonfX00ol0003o
oo]ZoookJP0DoookJP009_oonfX5o`000?oooo]ZoooonfX1oookJP03o`000?oonf[ooo]Z01?ooo]Z
000VoookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z000Voook
JPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000
oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[o
oookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOo
oo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-39.4643, 0.945403, \
0.975049, 0.00204154}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Write another version of this forward difference function that returns a \
list of values\nand the \"x\" value for subsequent use in ListPlot, this one \
will take ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  " and y(",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ") as an argument in a list"
}], "Text"],

Cell[BoxData[
    \(Clear[ForwardDifferenceListV2]\)], "Input"],

Cell[BoxData[
    \(ForwardDifferenceListV2[AFunction_\ , x0_\ , \ fx0_\ , \ delta_, \ 
        Xlast_]\  := \[IndentingNewLine]Module[{TheResultList\  = \ {{x0, 
                fx0}}, TheValue = fx0, 
          CurrentX\ \  = \ x0}, \[IndentingNewLine]While[
          CurrentX\  < \ Xlast, \[IndentingNewLine]CurrentX\  = 
            CurrentX\  + \ delta; \[IndentingNewLine]\ 
          TheValue = \ TheValue\  + \ delta\ AFunction[TheValue]; \ 
          AppendTo[
            TheResultList, {CurrentX, 
              TheValue}]]; \[IndentingNewLine]TheResultList]\)], "Input"],

Cell[BoxData[
    \(\(result\  = \ 
        ForwardDifferenceListV2[exampleFunction, 0, 1, \ 0.01, 
          4];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result // Short\)], "Input"],

Cell[BoxData[
    TagBox[\({{0, 
          1}, \[LeftSkeleton]399\[RightSkeleton], {3.9999999999999587`, 
          1.4915265612574076`}}\),
      Short]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[result]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 -1.18279 1.1975 [
[.2619 .00222 -7 -20 ]
[.2619 .00222 7 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.7381 .00222 -7 -20 ]
[.7381 .00222 7 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.01131 .13447 -29 -10 ]
[.01131 .13447 0 10 ]
[.01131 .25422 -29 -10 ]
[.01131 .25422 0 10 ]
[.01131 .37397 -29 -10 ]
[.01131 .37397 0 10 ]
[.01131 .49372 -29 -10 ]
[.01131 .49372 0 10 ]
[.01131 .61347 -29 -10 ]
[.01131 .61347 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13447 m
.03006 .13447 L
s
gsave
.01131 .13447 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .25422 m
.03006 .25422 L
s
gsave
.01131 .25422 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .37397 m
.03006 .37397 L
s
gsave
.01131 .37397 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .49372 m
.03006 .49372 L
s
gsave
.01131 .49372 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .61347 m
.03006 .61347 L
s
gsave
.01131 .61347 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03867 m
.02756 .03867 L
s
.02381 .06262 m
.02756 .06262 L
s
.02381 .08657 m
.02756 .08657 L
s
.02381 .11052 m
.02756 .11052 L
s
.02381 .15842 m
.02756 .15842 L
s
.02381 .18237 m
.02756 .18237 L
s
.02381 .20632 m
.02756 .20632 L
s
.02381 .23027 m
.02756 .23027 L
s
.02381 .27817 m
.02756 .27817 L
s
.02381 .30212 m
.02756 .30212 L
s
.02381 .32607 m
.02756 .32607 L
s
.02381 .35002 m
.02756 .35002 L
s
.02381 .39792 m
.02756 .39792 L
s
.02381 .42187 m
.02756 .42187 L
s
.02381 .44582 m
.02756 .44582 L
s
.02381 .46977 m
.02756 .46977 L
s
.02381 .51767 m
.02756 .51767 L
s
.02381 .54162 m
.02756 .54162 L
s
.02381 .56557 m
.02756 .56557 L
s
.02381 .58952 m
.02756 .58952 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.02619 .01591 Mdot
.02857 .01711 Mdot
.03095 .01831 Mdot
.03333 .01951 Mdot
.03571 .02071 Mdot
.0381 .02192 Mdot
.04048 .02312 Mdot
.04286 .02433 Mdot
.04524 .02554 Mdot
.04762 .02674 Mdot
.05 .02795 Mdot
.05238 .02916 Mdot
.05476 .03038 Mdot
.05714 .03159 Mdot
.05952 .0328 Mdot
.0619 .03402 Mdot
.06429 .03524 Mdot
.06667 .03645 Mdot
.06905 .03767 Mdot
.07143 .03889 Mdot
.07381 .04012 Mdot
.07619 .04134 Mdot
.07857 .04256 Mdot
.08095 .04379 Mdot
.08333 .04501 Mdot
.08571 .04624 Mdot
.0881 .04747 Mdot
.09048 .0487 Mdot
.09286 .04993 Mdot
.09524 .05117 Mdot
.09762 .0524 Mdot
.1 .05364 Mdot
.10238 .05487 Mdot
.10476 .05611 Mdot
.10714 .05735 Mdot
.10952 .05859 Mdot
.1119 .05983 Mdot
.11429 .06107 Mdot
.11667 .06232 Mdot
.11905 .06356 Mdot
.12143 .06481 Mdot
.12381 .06606 Mdot
.12619 .0673 Mdot
.12857 .06855 Mdot
.13095 .06981 Mdot
.13333 .07106 Mdot
.13571 .07231 Mdot
.1381 .07357 Mdot
.14048 .07482 Mdot
.14286 .07608 Mdot
.14524 .07734 Mdot
.14762 .0786 Mdot
.15 .07986 Mdot
.15238 .08112 Mdot
.15476 .08239 Mdot
.15714 .08365 Mdot
.15952 .08492 Mdot
.1619 .08619 Mdot
.16429 .08746 Mdot
.16667 .08873 Mdot
.16905 .09 Mdot
.17143 .09127 Mdot
.17381 .09254 Mdot
.17619 .09382 Mdot
.17857 .0951 Mdot
.18095 .09637 Mdot
.18333 .09765 Mdot
.18571 .09893 Mdot
.1881 .10022 Mdot
.19048 .1015 Mdot
.19286 .10278 Mdot
.19524 .10407 Mdot
.19762 .10536 Mdot
.2 .10664 Mdot
.20238 .10793 Mdot
.20476 .10922 Mdot
.20714 .11052 Mdot
.20952 .11181 Mdot
.2119 .1131 Mdot
.21429 .1144 Mdot
.21667 .1157 Mdot
.21905 .117 Mdot
.22143 .1183 Mdot
.22381 .1196 Mdot
.22619 .1209 Mdot
.22857 .1222 Mdot
.23095 .12351 Mdot
.23333 .12481 Mdot
.23571 .12612 Mdot
.2381 .12743 Mdot
.24048 .12874 Mdot
.24286 .13005 Mdot
.24524 .13136 Mdot
.24762 .13268 Mdot
.25 .13399 Mdot
.25238 .13531 Mdot
.25476 .13663 Mdot
.25714 .13795 Mdot
.25952 .13927 Mdot
.2619 .14059 Mdot
.26429 .14191 Mdot
.26667 .14324 Mdot
.26905 .14457 Mdot
.27143 .14589 Mdot
.27381 .14722 Mdot
.27619 .14855 Mdot
.27857 .14988 Mdot
.28095 .15122 Mdot
.28333 .15255 Mdot
.28571 .15388 Mdot
.2881 .15522 Mdot
.29048 .15656 Mdot
.29286 .1579 Mdot
.29524 .15924 Mdot
.29762 .16058 Mdot
.3 .16192 Mdot
.30238 .16327 Mdot
.30476 .16462 Mdot
.30714 .16596 Mdot
.30952 .16731 Mdot
.3119 .16866 Mdot
.31429 .17001 Mdot
.31667 .17137 Mdot
.31905 .17272 Mdot
.32143 .17408 Mdot
.32381 .17543 Mdot
.32619 .17679 Mdot
.32857 .17815 Mdot
.33095 .17951 Mdot
.33333 .18087 Mdot
.33571 .18224 Mdot
.3381 .1836 Mdot
.34048 .18497 Mdot
.34286 .18634 Mdot
.34524 .18771 Mdot
.34762 .18908 Mdot
.35 .19045 Mdot
.35238 .19182 Mdot
.35476 .1932 Mdot
.35714 .19457 Mdot
.35952 .19595 Mdot
.3619 .19733 Mdot
.36429 .19871 Mdot
.36667 .20009 Mdot
.36905 .20147 Mdot
.37143 .20286 Mdot
.37381 .20424 Mdot
.37619 .20563 Mdot
.37857 .20702 Mdot
.38095 .20841 Mdot
.38333 .2098 Mdot
.38571 .21119 Mdot
.3881 .21259 Mdot
.39048 .21398 Mdot
.39286 .21538 Mdot
.39524 .21678 Mdot
.39762 .21818 Mdot
.4 .21958 Mdot
.40238 .22098 Mdot
.40476 .22238 Mdot
.40714 .22379 Mdot
.40952 .22519 Mdot
.4119 .2266 Mdot
.41429 .22801 Mdot
.41667 .22942 Mdot
.41905 .23083 Mdot
.42143 .23225 Mdot
.42381 .23366 Mdot
.42619 .23508 Mdot
.42857 .2365 Mdot
.43095 .23792 Mdot
.43333 .23934 Mdot
.43571 .24076 Mdot
.4381 .24218 Mdot
.44048 .24361 Mdot
.44286 .24503 Mdot
.44524 .24646 Mdot
.44762 .24789 Mdot
.45 .24932 Mdot
.45238 .25075 Mdot
.45476 .25219 Mdot
.45714 .25362 Mdot
.45952 .25506 Mdot
.4619 .2565 Mdot
.46429 .25794 Mdot
.46667 .25938 Mdot
.46905 .26082 Mdot
.47143 .26226 Mdot
.47381 .26371 Mdot
.47619 .26515 Mdot
.47857 .2666 Mdot
.48095 .26805 Mdot
.48333 .2695 Mdot
.48571 .27095 Mdot
.4881 .27241 Mdot
.49048 .27386 Mdot
.49286 .27532 Mdot
.49524 .27678 Mdot
.49762 .27824 Mdot
.5 .2797 Mdot
.50238 .28116 Mdot
.50476 .28263 Mdot
.50714 .28409 Mdot
.50952 .28556 Mdot
.5119 .28703 Mdot
.51429 .2885 Mdot
.51667 .28997 Mdot
.51905 .29144 Mdot
.52143 .29291 Mdot
.52381 .29439 Mdot
.52619 .29587 Mdot
.52857 .29735 Mdot
.53095 .29883 Mdot
.53333 .30031 Mdot
.53571 .30179 Mdot
.5381 .30328 Mdot
.54048 .30476 Mdot
.54286 .30625 Mdot
.54524 .30774 Mdot
.54762 .30923 Mdot
.55 .31072 Mdot
.55238 .31221 Mdot
.55476 .31371 Mdot
.55714 .31521 Mdot
.55952 .3167 Mdot
.5619 .3182 Mdot
.56429 .3197 Mdot
.56667 .32121 Mdot
.56905 .32271 Mdot
.57143 .32422 Mdot
.57381 .32572 Mdot
.57619 .32723 Mdot
.57857 .32874 Mdot
.58095 .33025 Mdot
.58333 .33177 Mdot
.58571 .33328 Mdot
.5881 .3348 Mdot
.59048 .33631 Mdot
.59286 .33783 Mdot
.59524 .33935 Mdot
.59762 .34088 Mdot
.6 .3424 Mdot
.60238 .34392 Mdot
.60476 .34545 Mdot
.60714 .34698 Mdot
.60952 .34851 Mdot
.6119 .35004 Mdot
.61429 .35157 Mdot
.61667 .35311 Mdot
.61905 .35464 Mdot
.62143 .35618 Mdot
.62381 .35772 Mdot
.62619 .35926 Mdot
.62857 .3608 Mdot
.63095 .36235 Mdot
.63333 .36389 Mdot
.63571 .36544 Mdot
.6381 .36699 Mdot
.64048 .36854 Mdot
.64286 .37009 Mdot
.64524 .37164 Mdot
.64762 .37319 Mdot
.65 .37475 Mdot
.65238 .37631 Mdot
.65476 .37787 Mdot
.65714 .37943 Mdot
.65952 .38099 Mdot
.6619 .38255 Mdot
.66429 .38412 Mdot
.66667 .38569 Mdot
.66905 .38725 Mdot
.67143 .38882 Mdot
.67381 .3904 Mdot
.67619 .39197 Mdot
.67857 .39354 Mdot
.68095 .39512 Mdot
.68333 .3967 Mdot
.68571 .39828 Mdot
.6881 .39986 Mdot
.69048 .40144 Mdot
.69286 .40303 Mdot
.69524 .40461 Mdot
.69762 .4062 Mdot
.7 .40779 Mdot
.70238 .40938 Mdot
.70476 .41097 Mdot
.70714 .41256 Mdot
.70952 .41416 Mdot
.7119 .41576 Mdot
.71429 .41736 Mdot
.71667 .41896 Mdot
.71905 .42056 Mdot
.72143 .42216 Mdot
.72381 .42377 Mdot
.72619 .42537 Mdot
.72857 .42698 Mdot
.73095 .42859 Mdot
.73333 .4302 Mdot
.73571 .43181 Mdot
.7381 .43343 Mdot
.74048 .43505 Mdot
.74286 .43666 Mdot
.74524 .43828 Mdot
.74762 .4399 Mdot
.75 .44153 Mdot
.75238 .44315 Mdot
.75476 .44478 Mdot
.75714 .4464 Mdot
.75952 .44803 Mdot
.7619 .44966 Mdot
.76429 .4513 Mdot
.76667 .45293 Mdot
.76905 .45457 Mdot
.77143 .4562 Mdot
.77381 .45784 Mdot
.77619 .45948 Mdot
.77857 .46113 Mdot
.78095 .46277 Mdot
.78333 .46442 Mdot
.78571 .46606 Mdot
.7881 .46771 Mdot
.79048 .46936 Mdot
.79286 .47101 Mdot
.79524 .47267 Mdot
.79762 .47432 Mdot
.8 .47598 Mdot
.80238 .47764 Mdot
.80476 .4793 Mdot
.80714 .48096 Mdot
.80952 .48263 Mdot
.8119 .48429 Mdot
.81429 .48596 Mdot
.81667 .48763 Mdot
.81905 .4893 Mdot
.82143 .49097 Mdot
.82381 .49264 Mdot
.82619 .49432 Mdot
.82857 .496 Mdot
.83095 .49767 Mdot
.83333 .49935 Mdot
.83571 .50104 Mdot
.8381 .50272 Mdot
.84048 .50441 Mdot
.84286 .50609 Mdot
.84524 .50778 Mdot
.84762 .50947 Mdot
.85 .51117 Mdot
.85238 .51286 Mdot
.85476 .51455 Mdot
.85714 .51625 Mdot
.85952 .51795 Mdot
.8619 .51965 Mdot
.86429 .52135 Mdot
.86667 .52306 Mdot
.86905 .52476 Mdot
.87143 .52647 Mdot
.87381 .52818 Mdot
.87619 .52989 Mdot
.87857 .5316 Mdot
.88095 .53332 Mdot
.88333 .53504 Mdot
.88571 .53675 Mdot
.8881 .53847 Mdot
.89048 .54019 Mdot
.89286 .54192 Mdot
.89524 .54364 Mdot
.89762 .54537 Mdot
.9 .5471 Mdot
.90238 .54883 Mdot
.90476 .55056 Mdot
.90714 .55229 Mdot
.90952 .55403 Mdot
.9119 .55576 Mdot
.91429 .5575 Mdot
.91667 .55924 Mdot
.91905 .56098 Mdot
.92143 .56273 Mdot
.92381 .56447 Mdot
.92619 .56622 Mdot
.92857 .56797 Mdot
.93095 .56972 Mdot
.93333 .57147 Mdot
.93571 .57323 Mdot
.9381 .57498 Mdot
.94048 .57674 Mdot
.94286 .5785 Mdot
.94524 .58026 Mdot
.94762 .58202 Mdot
.95 .58379 Mdot
.95238 .58556 Mdot
.95476 .58732 Mdot
.95714 .58909 Mdot
.95952 .59087 Mdot
.9619 .59264 Mdot
.96429 .59442 Mdot
.96667 .59619 Mdot
.96905 .59797 Mdot
.97143 .59975 Mdot
.97381 .60153 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00Z_oonfX3o`00OgOooo]Z2Ol007mhoook
JPGo001oO?oonfX3o`00OaOooo]Z002ZoookJP?o001oMooonfX9o`00OgOooo]Z1ol007mkoookJP?o
001o5ooonfX00:[ooo]Z0ol007mgoookJPCo001oNooonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o
5ooonfX00:[ooo]Z0ol007mhoookJPCo001oN_oonfX3o`00O`?ooo]Z0ol007meoookJPWo001o5_oo
nfX00:[ooo]Z0ol007mioookJPGo001oO_oonfX3o`00OgGooo]Z2Ol007lFoookJP00Z_oonfX3o`00
Og_ooo]Z1?l007mmoookJP?o001oMOoonfX2o`00O`?ooo]Z0ol007lGoookJP00Z_oonfX3o`00Ogco
oo]Z0ol007mkoookJPCo001oMooonfX2o`00O`;ooo]Z0ol007lGoookJP00Z_oonfX3o`00Oggooo]Z
0ol007mjoookJP?o001oN?oonfX3o`00O`04oookJ_l007oo001oo`00OaOooo]Z002ZoookJP?o001o
MooonfX3o`00O`?ooo]Z0ol007mloookJP;o001oN?oonfX2o`00O`04oookJ_l007oo001oo`00OaOo
oo]Z002WoookJPKo001oMooonfX3o`00O`?ooo]Z0ol007mfoookJP?o001o0ooonfX3o`00OgSooo]Z
1Ol007lGoookJP00:_oonfX5o`0007Sooo]Z1_l007mgoookJPCo001o0_oonfX3o`00OgKooo]Z0ol0
07l3oookJP?o001oN?oonfX5o`00OaOooo]Z000ZoookJPGo0000N_oonfX4o`00OgSooo]Z1ol007mh
oookJPOo001oN_oonfX4o`00OaOooo]Z000ZoookJPGo0000NooonfX3o`00OgWooo]Z1Ol007mjoook
JPGo001oO?oonfX3o`00OaOooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000
oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[o
oookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000MoookJ_oo0000ool0000Ko`0000[o
oo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000M
oookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000ZoookJPco
0000MOoonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oo
nfX0NooonfX00ol0003ooo]ZoookJP0GoookJP00:_oonfX>o`0007?ooo]Z00?o0000oookJ_oonfX0
NooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0
5ooonfX002[ooo]Z1Ol00003oookJPSo0000oooonf[ooookJPSooo]Z000ZoookJPGo00001?oonfX8
o`000?oooo]ZoooonfX7oookJP00:_oonfX5o`0000Oooo]Z2?l0003ooookJ_oooo]Z1?oonfX002[o
oo]Z1Ol00008oookJPWo0000oooonf[ooookJP;ooo]Z000ZoookJPGo00002_oonfX9o`000?oooo]Z
oooonfX002[ooo]Z1Ol0000<oookJPWo0000oooonf[moookJP00:_oonfX5o`0000kooo]Z2?l0003o
oookJ_cooo]Z000ZoookJPGo00004OoonfX8o`000?oooo]ZnOoonfX002[ooo]Z1Ol0000BoookJPSo
0000oooonf[hoookJP00:_oonfX5o`0001Cooo]Z2Ol0003ooookJ_Gooo]Z000ZoookJPGo00005_oo
nfX8o`000?oooo]Zm?oonfX002[ooo]Z1Ol0000HoookJPWo0000oooonf[aoookJP00:_oonfX5o`00
01[ooo]Z2?l0003ooookJ_3ooo]Z000ZoookJPGo00007?oonfX8o`000?oooo]Zk_oonfX002[ooo]Z
1Ol0000MoookJPWo0000oooonf[/oookJP00:_oonfX5o`00023ooo]Z2?l0003ooookJ^[ooo]Z000Z
oookJPGo00008OoonfX:o`000?oooo]ZiooonfX002[ooo]Z1Ol0000ToookJPSo0000oooonf[Voook
JP00:_oonfX5o`0002Gooo]Z2_l0003ooookJ^?ooo]Z000ZoookJPGo00009ooonfX9o`000?oooo]Z
h_oonfX002[ooo]Z1Ol0000ZoookJPSo0000oooonf[PoookJP00:_oonfX5o`0002_ooo]Z2Ol0003o
oookJ]kooo]Z000ZoookJPGo0000;_oonfX8o`000?oooo]Zg?oonfX002[ooo]Z1Ol0000_oookJPSo
0000oooonf[KoookJP00:_oonfX5o`0003;ooo]Z2?l0003ooookJ]Sooo]Z000ZoookJPGo0000<ooo
nfX8o`000?oooo]ZeooonfX002[ooo]Z1Ol0000eoookJPWo0000oooonf[DoookJP00:_oonfX5o`00
03Oooo]Z2?l0003ooookJ]?ooo]Z000ZoookJPGo0000>OoonfX8o`000?oooo]ZdOoonfX002[ooo]Z
1Ol0000joookJPWo0000oooonf[?oookJP00:_oonfX5o`0003gooo]Z2?l0003ooookJ/gooo]Z000Z
oookJPGo0000?_oonfX9o`000?oooo]ZbooonfX002[ooo]Z1Ol00011oookJPSo0000oooonf[9oook
JP00:_oonfX5o`0004;ooo]Z2?l0003ooookJ/Sooo]Z000ZoookJPGo0000AOoonfX7o`000?oooo]Z
a_oonfX002[ooo]Z1Ol00016oookJPSo0000oooonf[4oookJP00:_oonfX5o`0004Sooo]Z1ol0003o
oookJ/?ooo]Z000ZoookJPGo0000B_oonfX8o`000?oooo]Z`?oonfX002[ooo]Z1Ol0001;oookJPSo
0000oooonfZooookJP00:_oonfX5o`0004gooo]Z2Ol0003ooookJ[cooo]Z000ZoookJPGo0000Cooo
nfX8o`000?oooo]Z^ooonfX002[ooo]Z1Ol0001AoookJPWo0000oooonfZhoookJP00:_oonfX5o`00
05;ooo]Z2Ol0003ooookJ[Oooo]Z000ZoookJPGo0000EOoonfX8o`000?oooo]Z]OoonfX002[ooo]Z
1Ol0001FoookJPWo0000oooonfZcoookJP00:_oonfX5o`0005Wooo]Z2?l0003ooookJ[7ooo]Z000Z
oookJPGo0000F_oonfX8o`000?oooo]Z/?oonfX002[ooo]Z1Ol0001MoookJPOo0000oooonfZ^oook
JP00:_oonfX5o`0005kooo]Z2?l0003ooookJZcooo]Z000ZoookJPGo0000H?oonfX7o`000?oooo]Z
ZooonfX002[ooo]Z1Ol0001RoookJPSo0000oooonfZXoookJP00:_oonfX5o`0006?ooo]Z2?l0003o
oookJZOooo]Z000ZoookJPGo0000IOoonfX9o`000?oooo]ZY?oonfX002[ooo]Z1Ol0001WoookJPSo
0000oooonfZSoookJP00:_oonfX5o`0006Wooo]Z2Ol0003ooookJZ3ooo]Z000>oookJP?o001o1?oo
nfX3o`00O`Gooo]Z0ol007l:oookJPGo0000JooonfX8o`000?oooo]ZWooonfX000kooo]Z0ol007l4
oookJP?o001o1OoonfX3o`00O`[ooo]Z1Ol0001]oookJPOo0000oooonfZNoookJP003_oonfX3o`00
O`Cooo]Z0ol007l5oookJP?o001o2_oonfX5o`0006kooo]Z2Ol0003ooookJY_ooo]Z000>oookJP?o
001o3?oonfX3o`00O`[ooo]Z1Ol0001aoookJPOo0000oooonfZJoookJP003_oonfX3o`00O`cooo]Z
0ol007l:oookJPKo0000LOoonfX8o`000?oooo]ZV?oonfX000kooo]Z0ol007l<oookJP?o001o2_oo
nfX5o`0007?ooo]Z2Ol0003ooookJYKooo]Z000>oookJP?o001o3?oonfX3o`00O`[ooo]Z1Ol0001f
oookJPSo0000oooonfZDoookJP003_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000MooonfX9o`00
0?oooo]ZT_oonfX000kooo]Z0ol007l<oookJP?o001o2_oonfX5o`0007[ooo]Z1ol0003ooookJY7o
oo]Z000;oookJPKo001o2OoonfX6o`00O`[ooo]Z1Ol0001koookJPSo0000oooonfZ?oookJP002ooo
nfX6o`00O`Wooo]Z1_l007l:oookJPGo0000O_oonfX7o`000?oooo]ZSOoonfX000gooo]Z1?l007l;
oookJPCo001o2_oonfX5o`0007oooo]Z2?l0003ooookJX_ooo]Z000>oookJP?o001o3?oonfX3o`00
O`[ooo]Z1Ol00020oookJPSo0000oooonfZ:oookJP00:_oonfX5o`0008?ooo]Z1ol0003ooookJXSo
oo]Z000ZoookJPGo0000Q?oonfX8o`000?oooo]ZQ_oonfX002[ooo]Z1Ol00026oookJPOo0000oooo
nfZ5oookJP00:_oonfX5o`0008Sooo]Z2?l0003ooookJX;ooo]Z000ZoookJPGo0000ROoonfX8o`00
0?oooo]ZPOoonfX002[ooo]Z1Ol0002;oookJPOo0000oooonfZ0oookJP00:_oonfX5o`0008gooo]Z
2?l0003ooookJWgooo]Z000ZoookJPGo0000SooonfX7o`000?oooo]ZO?oonfX002[ooo]Z1Ol0002@
oookJPWo0000oooonfYioookJP00:_oonfX5o`0009;ooo]Z2?l0003ooookJWSooo]Z000ZoookJPGo
0000U?oonfX7o`000?oooo]ZMooonfX002[ooo]Z1Ol0002FoookJPSo0000oooonfYdoookJP00:_oo
nfX5o`0009Sooo]Z1ol0003ooookJW?ooo]Z000ZoookJPGo0000VOoonfX9o`000?oooo]ZL?oonfX0
02[ooo]Z1Ol0002KoookJPSo0000oooonfY_oookJP00:_oonfX5o`0009gooo]Z1ol0003ooookJVko
oo]Z000ZoookJPGo0000W_oonfX9o`000?oooo]ZJooonfX002[ooo]Z1Ol0002QoookJPOo0000oooo
nfYZoookJP00:_oonfX5o`000:;ooo]Z1ol0003ooookJVWooo]Z000ZoookJPGo0000XooonfX9o`00
0?oooo]ZI_oonfX002[ooo]Z1Ol0002VoookJPOo0000oooonfYUoookJP00:_oonfX5o`000:Oooo]Z
2Ol0003ooookJV;ooo]Z000ZoookJPGo0000ZOoonfX8o`000?oooo]ZHOoonfX002[ooo]Z1Ol0002[
oookJPOo0000oooonfYPoookJP00:_oonfX5o`000:cooo]Z2Ol0003ooookJUgooo]Z000ZoookJPGo
0000[ooonfX7o`000?oooo]ZG?oonfX002[ooo]Z1Ol0002`oookJPOo0000oooonfYKoookJP00:_oo
nfX5o`000;7ooo]Z2Ol0003ooookJUSooo]Z000ZoookJPGo0000]?oonfX7o`000?oooo]ZEooonfX0
02[ooo]Z1Ol0002eoookJPOo0000oooonfYFoookJP00:_oonfX5o`000;Kooo]Z2Ol0003ooookJU?o
oo]Z000ZoookJPGo0000^OoonfX7o`000?oooo]ZD_oonfX002[ooo]Z1Ol0002joookJPOo0000oooo
nfYAoookJP00:_oonfX5o`000;cooo]Z2?l0003ooookJTkooo]Z000ZoookJPGo0000__oonfX7o`00
0?oooo]ZCOoonfX002[ooo]Z1Ol0002ooookJPWo0000oooonfY:oookJP00:_oonfX5o`000<7ooo]Z
2?l0003ooookJTWooo]Z000ZoookJPGo0000`ooonfX7o`000?oooo]ZB?oonfX002[ooo]Z1Ol00034
oookJPWo0000oooonfY5oookJP00:_oonfX5o`000<Oooo]Z1ol0003ooookJTCooo]Z000ZoookJPGo
0000b?oonfX7o`000?oooo]Z@ooonfX002[ooo]Z1Ol00039oookJPWo0000oooonfY0oookJP00:_oo
nfX5o`000<cooo]Z1ol0003ooookJSoooo]Z000ZoookJPGo0000cOoonfX7o`000?oooo]Z?_oonfX0
02[ooo]Z1Ol0003?oookJPSo0000oooonfXkoookJP00:_oonfX5o`000=7ooo]Z1ol0003ooookJS[o
oo]Z000ZoookJPGo0000d_oonfX7o`000?oooo]Z>OoonfX002[ooo]Z1Ol0003DoookJPOo0000oooo
nfXgoookJP00:_oonfX5o`000=Kooo]Z1ol0003ooookJSGooo]Z000ZoookJPGo0000eooonfX7o`00
0?oooo]Z=?oonfX002[ooo]Z1Ol0003IoookJPOo0000oooonfXboookJP003_oonfX3o`00O`Cooo]Z
0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003JoookJPSo0000oooonfX`oookJP003_oo
nfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003LoookJPOo0000oooo
nfX_oookJP003_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`gooo]Z1Ol0003N
oookJPOo0000oooonfX]oookJP003_oonfX3o`00O`Wooo]Z1?l007l<oookJPGo0000gooonfX8o`00
0?oooo]Z:ooonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX6o`000>3ooo]Z2?l0003ooookJRWo
oo]Z000>oookJP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003SoookJPOo0000oooonfXXoookJP003_oo
nfX3o`00O`gooo]Z0ol007l9oookJPGo0000i?oonfX8o`000?oooo]Z9_oonfX000kooo]Z0ol007l>
oookJP?o001o2?oonfX5o`000>Oooo]Z1ol0003ooookJRCooo]Z000>oookJP?o001o2?oonfX3o`00
O`?ooo]Z0ol007l8oookJPGo0000j?oonfX7o`000?oooo]Z8ooonfX000_ooo]Z1_l007l8oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003YoookJPSo0000oooonfXQoookJP002ooonfX6o`00O`Sooo]Z
1?l007l2oookJP?o001o2?oonfX5o`000>cooo]Z1ol0003ooookJQoooo]Z000=oookJPCo001o2Ooo
nfX7o`00O`Wooo]Z1Ol0003]oookJPOo0000oooonfXNoookJP003_oonfX3o`00O`[ooo]Z1Ol007l:
oookJPGo0000k_oonfX7o`000?oooo]Z7OoonfX002[ooo]Z1Ol0003aoookJPOo0000oooonfXJoook
JP00:_oonfX5o`000?;ooo]Z1ol0003ooookJQWooo]Z000ZoookJPGo0000looonfX7o`000?oooo]Z
6?oonfX002[ooo]Z1Ol0003doookJPWo0000oooonfXEoookJP00:_oonfX5o`000?Oooo]Z1ol0003o
oookJQCooo]Z000ZoookJPGo0000n?oonfX7o`000?oooo]Z4ooonfX002[ooo]Z1Ol0003joookJPOo
0000oooonfXAoookJP00:_oonfX5o`000?cooo]Z1ol0003ooookJPoooo]Z000ZoookJPGo0000oOoo
nfX7o`000?oooo]Z3_oonfX002[ooo]Z1Ol0003ooookJPOo0000oooonfX<oookJP00:_oonfX5o`00
0?oooo]Z0OoonfX7o`000?oooo]Z2ooonfX002[ooo]Z1Ol0003ooookJP?ooo]Z1ol0003ooookJPWo
oo]Z000ZoookJPGo0000oooonfX5oookJPOo0000oooonfX7oookJP00:_oonfX5o`000?oooo]Z1_oo
nfX7o`000?oooo]Z1_oonfX002[ooo]Z1Ol0003ooookJPOooo]Z2Ol0003ooookJP?ooo]Z000Zoook
JPGo0000oooonfX:oookJPOo0000oooonfX2oookJP00:_oonfX5o`000?oooo]Z2ooonfX7o`000?oo
oo]Z0OoonfX002[ooo]Z1Ol0003ooookJPcooo]Z1ol0003ooookJP00:_oonfX5o`000?oooo]Z3ooo
nfX7o`000?cooo]Z000ZoookJPGo0000oooonfX@oookJPOo0000nooonfX002[ooo]Z1Ol0003ooook
JQ7ooo]Z1ol0003joookJP00:_oonfX5o`000?oooo]Z4ooonfX7o`000?Sooo]Z000ZoookJPGo0000
oooonfXEoookJPOo0000m_oonfX002[ooo]Z1Ol0003ooookJQKooo]Z1ol0003eoookJP00:_oonfX5
o`000?oooo]Z6?oonfX7o`000??ooo]Z000ZoookJPGo0000oooonfXIoookJPOo0000l_oonfX002[o
oo]Z1Ol0003ooookJQ_ooo]Z2?l0003_oookJP00:_oonfX5o`000?oooo]Z7OoonfX7o`000>kooo]Z
000ZoookJPGo0000oooonfXNoookJPOo0000kOoonfX002[ooo]Z1Ol0003ooookJQoooo]Z1ol0003/
oookJP00:_oonfX5o`000?oooo]Z8_oonfX7o`000>Wooo]Z000ZoookJPGo0000oooonfXSoookJPOo
0000j?oonfX002[ooo]Z1Ol0003ooookJRCooo]Z1ol0003WoookJP00:_oonfX5o`000?oooo]Z9_oo
nfX7o`000>Gooo]Z000ZoookJPGo0000oooonfXXoookJPOo0000hooonfX002[ooo]Z1Ol0003ooook
JRWooo]Z1ol0003RoookJP00:_oonfX5o`000?oooo]Z:ooonfX7o`000>3ooo]Z000ZoookJPGo0000
oooonfX/oookJPOo0000gooonfX002[ooo]Z1Ol0003ooookJRkooo]Z1ol0003MoookJP00:_oonfX5
o`000?oooo]Z<?oonfX7o`000=_ooo]Z000ZoookJPGo0000oooonfXaoookJPOo0000f_oonfX002[o
oo]Z1Ol0003ooookJS;ooo]Z1ol0003IoookJP00:_oonfX5o`000?oooo]Z=OoonfX6o`000=Oooo]Z
000ZoookJPGo0000oooonfXfoookJPOo0000eOoonfX002[ooo]Z1Ol0003ooookJSOooo]Z1ol0003D
oookJP00:_oonfX5o`000?oooo]Z>OoonfX7o`000=;ooo]Z000ZoookJPGo0000oooonfXjoookJPOo
0000dOoonfX002[ooo]Z1Ol0003ooookJScooo]Z1ol0003?oookJP00:_oonfX5o`000?oooo]Z?_oo
nfX7o`000<gooo]Z000ZoookJPGo0000oooonfXooookJPOo0000c?oonfX000kooo]Z0ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJT3ooo]Z1ol0003;oookJP003_oonfX3o`00O`Co
oo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z@ooonfX5o`000<[ooo]Z000>oookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfY4oookJPOo
0000aooonfX000kooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJTGooo]Z
1ol00036oookJP003_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfY5oookJPSo0000a?oo
nfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZB?oonfX7o`000<?ooo]Z000>oook
JP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003ooookJT[ooo]Z1_l00032oookJP003_oonfX3o`00O`co
oo]Z0ol007l:oookJPGo0000oooonfY<oookJPOo0000_ooonfX000kooo]Z0ol007l>oookJP;o001o
2OoonfX5o`000?oooo]ZCOoonfX7o`000;kooo]Z000;oookJPKo001o2?oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonfY>oookJPOo0000_OoonfX000_ooo]Z1_l007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJToooo]Z1ol0002loookJP003OoonfX4o`00O`Wooo]Z1ol007l9oook
JPGo0000oooonfYBoookJPKo0000^_oonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX5o`000?oo
oo]ZDooonfX7o`000;Sooo]Z000ZoookJPGo0000oooonfYDoookJPOo0000]ooonfX002[ooo]Z1Ol0
003ooookJUKooo]Z1ol0002eoookJP00:_oonfX5o`000?oooo]ZEooonfX7o`000;Cooo]Z000Zoook
JPGo0000oooonfYIoookJPKo0000/ooonfX002[ooo]Z1Ol0003ooookJU_ooo]Z1ol0002`oookJP00
:_oonfX5o`000?oooo]ZG?oonfX7o`000:oooo]Z000ZoookJPGo0000oooonfYMoookJPOo0000[_oo
nfX002[ooo]Z1Ol0003ooookJUoooo]Z1ol0002/oookJP00:_oonfX5o`000?oooo]ZHOoonfX6o`00
0:_ooo]Z000ZoookJPGo0000oooonfYRoookJPOo0000ZOoonfX002[ooo]Z1Ol0003ooookJVCooo]Z
1ol0002WoookJP00:_oonfX5o`000?oooo]ZIOoonfX7o`000:Kooo]Z000ZoookJPGo0000oooonfYV
oookJPOo0000YOoonfX002[ooo]Z1Ol0003ooookJVWooo]Z1Ol0002ToookJP00:_oonfX5o`000?oo
oo]ZJ_oonfX6o`000:;ooo]Z000ZoookJPGo0000oooonfY[oookJPOo0000X?oonfX002[ooo]Z1Ol0
003ooookJVcooo]Z2?l0002NoookJP00:_oonfX5o`000?oooo]ZK_oonfX7o`0009gooo]Z000Zoook
JPGo0000oooonfY_oookJPOo0000W?oonfX002[ooo]Z1Ol0003ooookJW;ooo]Z1Ol0002KoookJP00
:_oonfX5o`000?oooo]ZLooonfX6o`0009Wooo]Z000ZoookJPGo0000oooonfYdoookJPOo0000Uooo
nfX002[ooo]Z1Ol0003ooookJWGooo]Z1ol0002FoookJP00:_oonfX5o`000?oooo]ZMooonfX7o`00
09Cooo]Z000ZoookJPGo0000oooonfYhoookJPOo0000TooonfX002[ooo]Z1Ol0003ooookJW[ooo]Z
1_l0002BoookJP00:_oonfX5o`000?oooo]ZO?oonfX5o`00097ooo]Z000ZoookJPGo0000oooonfYm
oookJPOo0000S_oonfX002[ooo]Z1Ol0003ooookJWkooo]Z1ol0002=oookJP00:_oonfX5o`000?oo
oo]ZOooonfX8o`0008_ooo]Z000ZoookJPGo0000oooonfZ1oookJPOo0000R_oonfX002[ooo]Z1Ol0
003ooookJX?ooo]Z1_l00029oookJP00:_oonfX5o`000?oooo]ZQOoonfX5o`0008Sooo]Z000Zoook
JPGo0000oooonfZ6oookJPKo0000Q_oonfX002[ooo]Z1Ol0003ooookJXOooo]Z1ol00024oookJP00
:_oonfX5o`000?oooo]ZR?oonfX7o`0008?ooo]Z000ZoookJPGo0000oooonfZ:oookJPOo0000POoo
nfX002[ooo]Z1Ol0003ooookJX_ooo]Z1ol00020oookJP00:_oonfX5o`000?oooo]ZSOoonfX6o`00
07oooo]Z000ZoookJPGo0000oooonfZ?oookJPGo0000O_oonfX002[ooo]Z1Ol0003ooookJY3ooo]Z
1_l0001loookJP00:_oonfX5o`000?oooo]ZTOoonfX7o`0007[ooo]Z000ZoookJPGo0000oooonfZB
oookJPOo0000NOoonfX002[ooo]Z1Ol0003ooookJYCooo]Z1ol0001goookJP00:_oonfX5o`000?oo
oo]ZUOoonfX7o`0007Kooo]Z000ZoookJPGo0000oooonfZGoookJPKo0000MOoonfX002[ooo]Z1Ol0
003ooookJYWooo]Z1_l0001coookJP00:_oonfX5o`000?oooo]ZV_oonfX6o`0007;ooo]Z000Zoook
JPGo0000oooonfZKoookJPOo0000L?oonfX002[ooo]Z1Ol0003ooookJYgooo]Z1ol0001^oookJP00
:_oonfX5o`000?oooo]ZW_oonfX7o`0006gooo]Z000>oookJP?o001o1?oonfX3o`00O`Kooo]Z0ol0
07l9oookJPGo0000oooonfZOoookJPOo0000K?oonfX000kooo]Z0ol007l4oookJP?o001o1_oonfX3
o`00O`Wooo]Z1Ol0003ooookJZ;ooo]Z1Ol0001[oookJP003_oonfX3o`00O`Cooo]Z0ol007l6oook
JP?o001o2OoonfX5o`000?oooo]ZXooonfX6o`0006Wooo]Z000>oookJP?o001o2?oonfX9o`00O`So
oo]Z1Ol0003ooookJZCooo]Z1_l0001XoookJP003_oonfX3o`00O`Sooo]Z2Ol007l8oookJPKo0000
oooonfZToookJPKo0000IooonfX000kooo]Z0ol007l8oookJP;o001o0ooonfX3o`00O`Wooo]Z1Ol0
003ooookJZOooo]Z1ol0001ToookJP003_oonfX3o`00O`Wooo]Z0_l007l2oookJP?o001o2OoonfX5
o`000?oooo]ZZ?oonfX7o`0006?ooo]Z000>oookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0003ooookJZWooo]Z1ol0001RoookJP003_oonfX3o`00O`[ooo]Z0_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000oooonfZZoookJPSo0000H?oonfX000_ooo]Z1_l007l;oook
JPGo001o2OoonfX5o`000?oooo]Z[OoonfX6o`0005oooo]Z000;oookJPKo001o2ooonfX5o`00O`Wo
oo]Z1Ol0003ooookJZkooo]Z1_l0001NoookJP003OoonfX4o`00O`cooo]Z1?l007l9oookJPGo0000
oooonfZ`oookJPGo0000GOoonfX000kooo]Z0ol007l=oookJP?o001o2OoonfX5o`000?oooo]Z/Ooo
nfX6o`0005_ooo]Z000ZoookJPGo0000oooonfZboookJPKo0000F_oonfX002[ooo]Z1Ol0003ooook
J[?ooo]Z1ol0001HoookJP00:_oonfX5o`000?oooo]Z]OoonfX7o`0005Kooo]Z000ZoookJPGo0000
oooonfZfoookJPOo0000EOoonfX002[ooo]Z1Ol0003ooookJ[Oooo]Z1ol0001DoookJP00:_oonfX5
o`000?oooo]Z^_oonfX5o`0005?ooo]Z000ZoookJPGo0000oooonfZkoookJPKo0000DOoonfX002[o
oo]Z1Ol0003ooookJ[cooo]Z1_l0001@oookJP00:_oonfX5o`000?oooo]Z_OoonfX6o`0004oooo]Z
000ZoookJPGo0000oooonfZooookJPKo0000COoonfX002[ooo]Z1Ol0003ooookJ/3ooo]Z1_l0001<
oookJP00:_oonfX5o`000?oooo]Z`OoonfX7o`0004[ooo]Z000ZoookJPGo0000oooonf[3oookJPOo
0000B?oonfX002[ooo]Z1Ol0003ooookJ/Cooo]Z1ol00017oookJP00:_oonfX5o`000?oooo]ZaOoo
nfX7o`0004Kooo]Z000ZoookJPGo0000oooonf[8oookJPGo0000AOoonfX002[ooo]Z1Ol0003ooook
J/Wooo]Z1_l00013oookJP00:_oonfX5o`000?oooo]Zb_oonfX6o`0004;ooo]Z000ZoookJPGo0000
oooonf[;oookJPKo0000@OoonfX002[ooo]Z1Ol0003ooookJ/gooo]Z1Ol00010oookJP00:_oonfX5
o`000?oooo]Zc_oonfX6o`0003kooo]Z000ZoookJPGo0000oooonf[?oookJPKo0000?OoonfX002[o
oo]Z1Ol0003ooookJ]3ooo]Z2?l0000joookJP00:_oonfX5o`000?oooo]Zd_oonfX7o`0003Wooo]Z
000ZoookJPGo0000oooonf[CoookJPOo0000>?oonfX002[ooo]Z1Ol0003ooookJ]Cooo]Z1ol0000g
oookJP00:_oonfX5o`000?oooo]ZeooonfX6o`0003Gooo]Z000ZoookJPGo0000oooonf[HoookJPKo
0000=?oonfX002[ooo]Z1Ol0003ooookJ]Wooo]Z1_l0000coookJP00:_oonfX5o`000?oooo]Zfooo
nfX5o`0003;ooo]Z000ZoookJPGo0000oooonf[LoookJPKo0000<?oonfX002[ooo]Z1Ol0003ooook
J]gooo]Z1_l0000_oookJP00:_oonfX5o`000?oooo]Zg_oonfX6o`0002kooo]Z000ZoookJPGo0000
oooonf[PoookJPGo0000;OoonfX002[ooo]Z1Ol0003ooookJ^7ooo]Z1_l0000[oookJP00:_oonfX5
o`000?oooo]Zh_oonfX7o`0002Wooo]Z000ZoookJPGo0000oooonf[SoookJPOo0000:?oonfX002[o
oo]Z1Ol0003ooookJ^Gooo]Z1ol0000VoookJP00:_oonfX5o`000?oooo]Zi_oonfX7o`0002Gooo]Z
000ZoookJPGo0000oooonf[XoookJPKo00009?oonfX002[ooo]Z1Ol0003ooookJ^[ooo]Z1_l0000R
oookJP00:_oonfX5o`000?oooo]ZjooonfX6o`00027ooo]Z000ZoookJPGo0000oooonf[/oookJPKo
00008?oonfX002[ooo]Z1Ol0003ooookJ^kooo]Z1Ol0000OoookJP00:_oonfX5o`000?oooo]Zkooo
nfX6o`0001gooo]Z000ZoookJPGo0000oooonf[`oookJPKo00007?oonfX002[ooo]Z1Ol0003ooook
J_7ooo]Z1_l0000KoookJP00:_oonfX5o`000?oooo]ZlooonfX5o`0001[ooo]Z000ZoookJPGo0000
oooonf[doookJPKo00006?oonfX002[ooo]Z1Ol0003ooookJ_Gooo]Z1_l0000GoookJP003_oonfX3
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Zm_oonfX5o`0001Oooo]Z000>oook
JP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonf[hoookJP;o00006?oonfX000ko
oo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJ_oooo]Z
4_oonfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3
o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3o`00
O`Wooo]Z1ol007l9oookJPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2OoonfX6o`00O`[o
oo]Z1Ol0003ooookJ_oooo]Z4ooonfX000_ooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z
oooonfXCoookJP002ooonfX6o`00O`Wooo]Z0_l007oooookJ_oooo]Z9_oonfX000gooo]Z1?l007l:
oookJPOo001ooooonf[ooookJR3ooo]Z000>oookJP?o001o2_oonfX7o`00Oooooo]ZoooonfXPoook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.3518, 0.958149, \
0.00790084, 0.0015709}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["Background-Repeated Operations on a Function", "Subtitle"],

Cell[TextData[{
  "Because each iteration is the same, the iteration can be considered a \
functional operation, for the case considered above,\n{",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(i + 1\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_\(i + 1\)\)]],
  "} = {",
  Cell[BoxData[
      \(TraditionalForm\`x\_i\)]],
  "+ \[Delta], ",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  "+ \[Delta] f(",
  Cell[BoxData[
      \(TraditionalForm\`y\_i\)]],
  ")}.  Therefore a \"Incrementing Operator\" can be obtained that updates \
the values:"
}], "Text",
  CellTags->"mmtag:19:increment_operator"],

Cell[BoxData[
    \(StepOnce[{x_, y_}, \ AFunction_, \ delta_]\  := \ {x + \ delta, \ 
        y\  + \ delta\ AFunction[y]}\)], "Input"],

Cell[TextData[{
  "Then, the trajectory should be obtained from:\n    \
{{xo,yo},StepOnce[{xo,yo}], StepOnce[StepOnce[{xo,yo}]], \[TripleDot]\
\[TripleDot]\[TripleDot]}\n    This is what the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["NestList",
    FontWeight->"Bold"],
  "[function, initialvalue,depth] does:"
}], "Text"],

Cell[BoxData[
    \(OurStepOnce[{x_\ , \ y_}]\  := \ 
      StepOnce[{x, y}, exampleFunction, \ 0.01]\)], "Input"],

Cell[BoxData[
    \(\(result\  = \ NestList[OurStepOnce, {0, 1}, 400];\)\)], "Input",
  CellTags->"mmtag:19:NestList[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[result]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 -1.18279 1.1975 [
[.2619 .00222 -7 -20 ]
[.2619 .00222 7 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.7381 .00222 -7 -20 ]
[.7381 .00222 7 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.01131 .13447 -29 -10 ]
[.01131 .13447 0 10 ]
[.01131 .25422 -29 -10 ]
[.01131 .25422 0 10 ]
[.01131 .37397 -29 -10 ]
[.01131 .37397 0 10 ]
[.01131 .49372 -29 -10 ]
[.01131 .49372 0 10 ]
[.01131 .61347 -29 -10 ]
[.01131 .61347 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13447 m
.03006 .13447 L
s
gsave
.01131 .13447 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .25422 m
.03006 .25422 L
s
gsave
.01131 .25422 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .37397 m
.03006 .37397 L
s
gsave
.01131 .37397 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .49372 m
.03006 .49372 L
s
gsave
.01131 .49372 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .61347 m
.03006 .61347 L
s
gsave
.01131 .61347 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03867 m
.02756 .03867 L
s
.02381 .06262 m
.02756 .06262 L
s
.02381 .08657 m
.02756 .08657 L
s
.02381 .11052 m
.02756 .11052 L
s
.02381 .15842 m
.02756 .15842 L
s
.02381 .18237 m
.02756 .18237 L
s
.02381 .20632 m
.02756 .20632 L
s
.02381 .23027 m
.02756 .23027 L
s
.02381 .27817 m
.02756 .27817 L
s
.02381 .30212 m
.02756 .30212 L
s
.02381 .32607 m
.02756 .32607 L
s
.02381 .35002 m
.02756 .35002 L
s
.02381 .39792 m
.02756 .39792 L
s
.02381 .42187 m
.02756 .42187 L
s
.02381 .44582 m
.02756 .44582 L
s
.02381 .46977 m
.02756 .46977 L
s
.02381 .51767 m
.02756 .51767 L
s
.02381 .54162 m
.02756 .54162 L
s
.02381 .56557 m
.02756 .56557 L
s
.02381 .58952 m
.02756 .58952 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.02619 .01591 Mdot
.02857 .01711 Mdot
.03095 .01831 Mdot
.03333 .01951 Mdot
.03571 .02071 Mdot
.0381 .02192 Mdot
.04048 .02312 Mdot
.04286 .02433 Mdot
.04524 .02554 Mdot
.04762 .02674 Mdot
.05 .02795 Mdot
.05238 .02916 Mdot
.05476 .03038 Mdot
.05714 .03159 Mdot
.05952 .0328 Mdot
.0619 .03402 Mdot
.06429 .03524 Mdot
.06667 .03645 Mdot
.06905 .03767 Mdot
.07143 .03889 Mdot
.07381 .04012 Mdot
.07619 .04134 Mdot
.07857 .04256 Mdot
.08095 .04379 Mdot
.08333 .04501 Mdot
.08571 .04624 Mdot
.0881 .04747 Mdot
.09048 .0487 Mdot
.09286 .04993 Mdot
.09524 .05117 Mdot
.09762 .0524 Mdot
.1 .05364 Mdot
.10238 .05487 Mdot
.10476 .05611 Mdot
.10714 .05735 Mdot
.10952 .05859 Mdot
.1119 .05983 Mdot
.11429 .06107 Mdot
.11667 .06232 Mdot
.11905 .06356 Mdot
.12143 .06481 Mdot
.12381 .06606 Mdot
.12619 .0673 Mdot
.12857 .06855 Mdot
.13095 .06981 Mdot
.13333 .07106 Mdot
.13571 .07231 Mdot
.1381 .07357 Mdot
.14048 .07482 Mdot
.14286 .07608 Mdot
.14524 .07734 Mdot
.14762 .0786 Mdot
.15 .07986 Mdot
.15238 .08112 Mdot
.15476 .08239 Mdot
.15714 .08365 Mdot
.15952 .08492 Mdot
.1619 .08619 Mdot
.16429 .08746 Mdot
.16667 .08873 Mdot
.16905 .09 Mdot
.17143 .09127 Mdot
.17381 .09254 Mdot
.17619 .09382 Mdot
.17857 .0951 Mdot
.18095 .09637 Mdot
.18333 .09765 Mdot
.18571 .09893 Mdot
.1881 .10022 Mdot
.19048 .1015 Mdot
.19286 .10278 Mdot
.19524 .10407 Mdot
.19762 .10536 Mdot
.2 .10664 Mdot
.20238 .10793 Mdot
.20476 .10922 Mdot
.20714 .11052 Mdot
.20952 .11181 Mdot
.2119 .1131 Mdot
.21429 .1144 Mdot
.21667 .1157 Mdot
.21905 .117 Mdot
.22143 .1183 Mdot
.22381 .1196 Mdot
.22619 .1209 Mdot
.22857 .1222 Mdot
.23095 .12351 Mdot
.23333 .12481 Mdot
.23571 .12612 Mdot
.2381 .12743 Mdot
.24048 .12874 Mdot
.24286 .13005 Mdot
.24524 .13136 Mdot
.24762 .13268 Mdot
.25 .13399 Mdot
.25238 .13531 Mdot
.25476 .13663 Mdot
.25714 .13795 Mdot
.25952 .13927 Mdot
.2619 .14059 Mdot
.26429 .14191 Mdot
.26667 .14324 Mdot
.26905 .14457 Mdot
.27143 .14589 Mdot
.27381 .14722 Mdot
.27619 .14855 Mdot
.27857 .14988 Mdot
.28095 .15122 Mdot
.28333 .15255 Mdot
.28571 .15388 Mdot
.2881 .15522 Mdot
.29048 .15656 Mdot
.29286 .1579 Mdot
.29524 .15924 Mdot
.29762 .16058 Mdot
.3 .16192 Mdot
.30238 .16327 Mdot
.30476 .16462 Mdot
.30714 .16596 Mdot
.30952 .16731 Mdot
.3119 .16866 Mdot
.31429 .17001 Mdot
.31667 .17137 Mdot
.31905 .17272 Mdot
.32143 .17408 Mdot
.32381 .17543 Mdot
.32619 .17679 Mdot
.32857 .17815 Mdot
.33095 .17951 Mdot
.33333 .18087 Mdot
.33571 .18224 Mdot
.3381 .1836 Mdot
.34048 .18497 Mdot
.34286 .18634 Mdot
.34524 .18771 Mdot
.34762 .18908 Mdot
.35 .19045 Mdot
.35238 .19182 Mdot
.35476 .1932 Mdot
.35714 .19457 Mdot
.35952 .19595 Mdot
.3619 .19733 Mdot
.36429 .19871 Mdot
.36667 .20009 Mdot
.36905 .20147 Mdot
.37143 .20286 Mdot
.37381 .20424 Mdot
.37619 .20563 Mdot
.37857 .20702 Mdot
.38095 .20841 Mdot
.38333 .2098 Mdot
.38571 .21119 Mdot
.3881 .21259 Mdot
.39048 .21398 Mdot
.39286 .21538 Mdot
.39524 .21678 Mdot
.39762 .21818 Mdot
.4 .21958 Mdot
.40238 .22098 Mdot
.40476 .22238 Mdot
.40714 .22379 Mdot
.40952 .22519 Mdot
.4119 .2266 Mdot
.41429 .22801 Mdot
.41667 .22942 Mdot
.41905 .23083 Mdot
.42143 .23225 Mdot
.42381 .23366 Mdot
.42619 .23508 Mdot
.42857 .2365 Mdot
.43095 .23792 Mdot
.43333 .23934 Mdot
.43571 .24076 Mdot
.4381 .24218 Mdot
.44048 .24361 Mdot
.44286 .24503 Mdot
.44524 .24646 Mdot
.44762 .24789 Mdot
.45 .24932 Mdot
.45238 .25075 Mdot
.45476 .25219 Mdot
.45714 .25362 Mdot
.45952 .25506 Mdot
.4619 .2565 Mdot
.46429 .25794 Mdot
.46667 .25938 Mdot
.46905 .26082 Mdot
.47143 .26226 Mdot
.47381 .26371 Mdot
.47619 .26515 Mdot
.47857 .2666 Mdot
.48095 .26805 Mdot
.48333 .2695 Mdot
.48571 .27095 Mdot
.4881 .27241 Mdot
.49048 .27386 Mdot
.49286 .27532 Mdot
.49524 .27678 Mdot
.49762 .27824 Mdot
.5 .2797 Mdot
.50238 .28116 Mdot
.50476 .28263 Mdot
.50714 .28409 Mdot
.50952 .28556 Mdot
.5119 .28703 Mdot
.51429 .2885 Mdot
.51667 .28997 Mdot
.51905 .29144 Mdot
.52143 .29291 Mdot
.52381 .29439 Mdot
.52619 .29587 Mdot
.52857 .29735 Mdot
.53095 .29883 Mdot
.53333 .30031 Mdot
.53571 .30179 Mdot
.5381 .30328 Mdot
.54048 .30476 Mdot
.54286 .30625 Mdot
.54524 .30774 Mdot
.54762 .30923 Mdot
.55 .31072 Mdot
.55238 .31221 Mdot
.55476 .31371 Mdot
.55714 .31521 Mdot
.55952 .3167 Mdot
.5619 .3182 Mdot
.56429 .3197 Mdot
.56667 .32121 Mdot
.56905 .32271 Mdot
.57143 .32422 Mdot
.57381 .32572 Mdot
.57619 .32723 Mdot
.57857 .32874 Mdot
.58095 .33025 Mdot
.58333 .33177 Mdot
.58571 .33328 Mdot
.5881 .3348 Mdot
.59048 .33631 Mdot
.59286 .33783 Mdot
.59524 .33935 Mdot
.59762 .34088 Mdot
.6 .3424 Mdot
.60238 .34392 Mdot
.60476 .34545 Mdot
.60714 .34698 Mdot
.60952 .34851 Mdot
.6119 .35004 Mdot
.61429 .35157 Mdot
.61667 .35311 Mdot
.61905 .35464 Mdot
.62143 .35618 Mdot
.62381 .35772 Mdot
.62619 .35926 Mdot
.62857 .3608 Mdot
.63095 .36235 Mdot
.63333 .36389 Mdot
.63571 .36544 Mdot
.6381 .36699 Mdot
.64048 .36854 Mdot
.64286 .37009 Mdot
.64524 .37164 Mdot
.64762 .37319 Mdot
.65 .37475 Mdot
.65238 .37631 Mdot
.65476 .37787 Mdot
.65714 .37943 Mdot
.65952 .38099 Mdot
.6619 .38255 Mdot
.66429 .38412 Mdot
.66667 .38569 Mdot
.66905 .38725 Mdot
.67143 .38882 Mdot
.67381 .3904 Mdot
.67619 .39197 Mdot
.67857 .39354 Mdot
.68095 .39512 Mdot
.68333 .3967 Mdot
.68571 .39828 Mdot
.6881 .39986 Mdot
.69048 .40144 Mdot
.69286 .40303 Mdot
.69524 .40461 Mdot
.69762 .4062 Mdot
.7 .40779 Mdot
.70238 .40938 Mdot
.70476 .41097 Mdot
.70714 .41256 Mdot
.70952 .41416 Mdot
.7119 .41576 Mdot
.71429 .41736 Mdot
.71667 .41896 Mdot
.71905 .42056 Mdot
.72143 .42216 Mdot
.72381 .42377 Mdot
.72619 .42537 Mdot
.72857 .42698 Mdot
.73095 .42859 Mdot
.73333 .4302 Mdot
.73571 .43181 Mdot
.7381 .43343 Mdot
.74048 .43505 Mdot
.74286 .43666 Mdot
.74524 .43828 Mdot
.74762 .4399 Mdot
.75 .44153 Mdot
.75238 .44315 Mdot
.75476 .44478 Mdot
.75714 .4464 Mdot
.75952 .44803 Mdot
.7619 .44966 Mdot
.76429 .4513 Mdot
.76667 .45293 Mdot
.76905 .45457 Mdot
.77143 .4562 Mdot
.77381 .45784 Mdot
.77619 .45948 Mdot
.77857 .46113 Mdot
.78095 .46277 Mdot
.78333 .46442 Mdot
.78571 .46606 Mdot
.7881 .46771 Mdot
.79048 .46936 Mdot
.79286 .47101 Mdot
.79524 .47267 Mdot
.79762 .47432 Mdot
.8 .47598 Mdot
.80238 .47764 Mdot
.80476 .4793 Mdot
.80714 .48096 Mdot
.80952 .48263 Mdot
.8119 .48429 Mdot
.81429 .48596 Mdot
.81667 .48763 Mdot
.81905 .4893 Mdot
.82143 .49097 Mdot
.82381 .49264 Mdot
.82619 .49432 Mdot
.82857 .496 Mdot
.83095 .49767 Mdot
.83333 .49935 Mdot
.83571 .50104 Mdot
.8381 .50272 Mdot
.84048 .50441 Mdot
.84286 .50609 Mdot
.84524 .50778 Mdot
.84762 .50947 Mdot
.85 .51117 Mdot
.85238 .51286 Mdot
.85476 .51455 Mdot
.85714 .51625 Mdot
.85952 .51795 Mdot
.8619 .51965 Mdot
.86429 .52135 Mdot
.86667 .52306 Mdot
.86905 .52476 Mdot
.87143 .52647 Mdot
.87381 .52818 Mdot
.87619 .52989 Mdot
.87857 .5316 Mdot
.88095 .53332 Mdot
.88333 .53504 Mdot
.88571 .53675 Mdot
.8881 .53847 Mdot
.89048 .54019 Mdot
.89286 .54192 Mdot
.89524 .54364 Mdot
.89762 .54537 Mdot
.9 .5471 Mdot
.90238 .54883 Mdot
.90476 .55056 Mdot
.90714 .55229 Mdot
.90952 .55403 Mdot
.9119 .55576 Mdot
.91429 .5575 Mdot
.91667 .55924 Mdot
.91905 .56098 Mdot
.92143 .56273 Mdot
.92381 .56447 Mdot
.92619 .56622 Mdot
.92857 .56797 Mdot
.93095 .56972 Mdot
.93333 .57147 Mdot
.93571 .57323 Mdot
.9381 .57498 Mdot
.94048 .57674 Mdot
.94286 .5785 Mdot
.94524 .58026 Mdot
.94762 .58202 Mdot
.95 .58379 Mdot
.95238 .58556 Mdot
.95476 .58732 Mdot
.95714 .58909 Mdot
.95952 .59087 Mdot
.9619 .59264 Mdot
.96429 .59442 Mdot
.96667 .59619 Mdot
.96905 .59797 Mdot
.97143 .59975 Mdot
.97381 .60153 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00Z_oonfX3o`00OgOooo]Z2Ol007mhoook
JPGo001oO?oonfX3o`00OaOooo]Z002ZoookJP?o001oMooonfX9o`00OgOooo]Z1ol007mkoookJP?o
001o5ooonfX00:[ooo]Z0ol007mgoookJPCo001oNooonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o
5ooonfX00:[ooo]Z0ol007mhoookJPCo001oN_oonfX3o`00O`?ooo]Z0ol007meoookJPWo001o5_oo
nfX00:[ooo]Z0ol007mioookJPGo001oO_oonfX3o`00OgGooo]Z2Ol007lFoookJP00Z_oonfX3o`00
Og_ooo]Z1?l007mmoookJP?o001oMOoonfX2o`00O`?ooo]Z0ol007lGoookJP00Z_oonfX3o`00Ogco
oo]Z0ol007mkoookJPCo001oMooonfX2o`00O`;ooo]Z0ol007lGoookJP00Z_oonfX3o`00Oggooo]Z
0ol007mjoookJP?o001oN?oonfX3o`00O`04oookJ_l007oo001oo`00OaOooo]Z002ZoookJP?o001o
MooonfX3o`00O`?ooo]Z0ol007mloookJP;o001oN?oonfX2o`00O`04oookJ_l007oo001oo`00OaOo
oo]Z002WoookJPKo001oMooonfX3o`00O`?ooo]Z0ol007mfoookJP?o001o0ooonfX3o`00OgSooo]Z
1Ol007lGoookJP00:_oonfX5o`0007Sooo]Z1_l007mgoookJPCo001o0_oonfX3o`00OgKooo]Z0ol0
07l3oookJP?o001oN?oonfX5o`00OaOooo]Z000ZoookJPGo0000N_oonfX4o`00OgSooo]Z1ol007mh
oookJPOo001oN_oonfX4o`00OaOooo]Z000ZoookJPGo0000NooonfX3o`00OgWooo]Z1Ol007mjoook
JPGo001oO?oonfX3o`00OaOooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000
oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[o
oookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000MoookJ_oo0000ool0000Ko`0000[o
oo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000M
oookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000ZoookJPco
0000MOoonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oo
nfX0NooonfX00ol0003ooo]ZoookJP0GoookJP00:_oonfX>o`0007?ooo]Z00?o0000oookJ_oonfX0
NooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0
5ooonfX002[ooo]Z1Ol00003oookJPSo0000oooonf[ooookJPSooo]Z000ZoookJPGo00001?oonfX8
o`000?oooo]ZoooonfX7oookJP00:_oonfX5o`0000Oooo]Z2?l0003ooookJ_oooo]Z1?oonfX002[o
oo]Z1Ol00008oookJPWo0000oooonf[ooookJP;ooo]Z000ZoookJPGo00002_oonfX9o`000?oooo]Z
oooonfX002[ooo]Z1Ol0000<oookJPWo0000oooonf[moookJP00:_oonfX5o`0000kooo]Z2?l0003o
oookJ_cooo]Z000ZoookJPGo00004OoonfX8o`000?oooo]ZnOoonfX002[ooo]Z1Ol0000BoookJPSo
0000oooonf[hoookJP00:_oonfX5o`0001Cooo]Z2Ol0003ooookJ_Gooo]Z000ZoookJPGo00005_oo
nfX8o`000?oooo]Zm?oonfX002[ooo]Z1Ol0000HoookJPWo0000oooonf[aoookJP00:_oonfX5o`00
01[ooo]Z2?l0003ooookJ_3ooo]Z000ZoookJPGo00007?oonfX8o`000?oooo]Zk_oonfX002[ooo]Z
1Ol0000MoookJPWo0000oooonf[/oookJP00:_oonfX5o`00023ooo]Z2?l0003ooookJ^[ooo]Z000Z
oookJPGo00008OoonfX:o`000?oooo]ZiooonfX002[ooo]Z1Ol0000ToookJPSo0000oooonf[Voook
JP00:_oonfX5o`0002Gooo]Z2_l0003ooookJ^?ooo]Z000ZoookJPGo00009ooonfX9o`000?oooo]Z
h_oonfX002[ooo]Z1Ol0000ZoookJPSo0000oooonf[PoookJP00:_oonfX5o`0002_ooo]Z2Ol0003o
oookJ]kooo]Z000ZoookJPGo0000;_oonfX8o`000?oooo]Zg?oonfX002[ooo]Z1Ol0000_oookJPSo
0000oooonf[KoookJP00:_oonfX5o`0003;ooo]Z2?l0003ooookJ]Sooo]Z000ZoookJPGo0000<ooo
nfX8o`000?oooo]ZeooonfX002[ooo]Z1Ol0000eoookJPWo0000oooonf[DoookJP00:_oonfX5o`00
03Oooo]Z2?l0003ooookJ]?ooo]Z000ZoookJPGo0000>OoonfX8o`000?oooo]ZdOoonfX002[ooo]Z
1Ol0000joookJPWo0000oooonf[?oookJP00:_oonfX5o`0003gooo]Z2?l0003ooookJ/gooo]Z000Z
oookJPGo0000?_oonfX9o`000?oooo]ZbooonfX002[ooo]Z1Ol00011oookJPSo0000oooonf[9oook
JP00:_oonfX5o`0004;ooo]Z2?l0003ooookJ/Sooo]Z000ZoookJPGo0000AOoonfX7o`000?oooo]Z
a_oonfX002[ooo]Z1Ol00016oookJPSo0000oooonf[4oookJP00:_oonfX5o`0004Sooo]Z1ol0003o
oookJ/?ooo]Z000ZoookJPGo0000B_oonfX8o`000?oooo]Z`?oonfX002[ooo]Z1Ol0001;oookJPSo
0000oooonfZooookJP00:_oonfX5o`0004gooo]Z2Ol0003ooookJ[cooo]Z000ZoookJPGo0000Cooo
nfX8o`000?oooo]Z^ooonfX002[ooo]Z1Ol0001AoookJPWo0000oooonfZhoookJP00:_oonfX5o`00
05;ooo]Z2Ol0003ooookJ[Oooo]Z000ZoookJPGo0000EOoonfX8o`000?oooo]Z]OoonfX002[ooo]Z
1Ol0001FoookJPWo0000oooonfZcoookJP00:_oonfX5o`0005Wooo]Z2?l0003ooookJ[7ooo]Z000Z
oookJPGo0000F_oonfX8o`000?oooo]Z/?oonfX002[ooo]Z1Ol0001MoookJPOo0000oooonfZ^oook
JP00:_oonfX5o`0005kooo]Z2?l0003ooookJZcooo]Z000ZoookJPGo0000H?oonfX7o`000?oooo]Z
ZooonfX002[ooo]Z1Ol0001RoookJPSo0000oooonfZXoookJP00:_oonfX5o`0006?ooo]Z2?l0003o
oookJZOooo]Z000ZoookJPGo0000IOoonfX9o`000?oooo]ZY?oonfX002[ooo]Z1Ol0001WoookJPSo
0000oooonfZSoookJP00:_oonfX5o`0006Wooo]Z2Ol0003ooookJZ3ooo]Z000>oookJP?o001o1?oo
nfX3o`00O`Gooo]Z0ol007l:oookJPGo0000JooonfX8o`000?oooo]ZWooonfX000kooo]Z0ol007l4
oookJP?o001o1OoonfX3o`00O`[ooo]Z1Ol0001]oookJPOo0000oooonfZNoookJP003_oonfX3o`00
O`Cooo]Z0ol007l5oookJP?o001o2_oonfX5o`0006kooo]Z2Ol0003ooookJY_ooo]Z000>oookJP?o
001o3?oonfX3o`00O`[ooo]Z1Ol0001aoookJPOo0000oooonfZJoookJP003_oonfX3o`00O`cooo]Z
0ol007l:oookJPKo0000LOoonfX8o`000?oooo]ZV?oonfX000kooo]Z0ol007l<oookJP?o001o2_oo
nfX5o`0007?ooo]Z2Ol0003ooookJYKooo]Z000>oookJP?o001o3?oonfX3o`00O`[ooo]Z1Ol0001f
oookJPSo0000oooonfZDoookJP003_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000MooonfX9o`00
0?oooo]ZT_oonfX000kooo]Z0ol007l<oookJP?o001o2_oonfX5o`0007[ooo]Z1ol0003ooookJY7o
oo]Z000;oookJPKo001o2OoonfX6o`00O`[ooo]Z1Ol0001koookJPSo0000oooonfZ?oookJP002ooo
nfX6o`00O`Wooo]Z1_l007l:oookJPGo0000O_oonfX7o`000?oooo]ZSOoonfX000gooo]Z1?l007l;
oookJPCo001o2_oonfX5o`0007oooo]Z2?l0003ooookJX_ooo]Z000>oookJP?o001o3?oonfX3o`00
O`[ooo]Z1Ol00020oookJPSo0000oooonfZ:oookJP00:_oonfX5o`0008?ooo]Z1ol0003ooookJXSo
oo]Z000ZoookJPGo0000Q?oonfX8o`000?oooo]ZQ_oonfX002[ooo]Z1Ol00026oookJPOo0000oooo
nfZ5oookJP00:_oonfX5o`0008Sooo]Z2?l0003ooookJX;ooo]Z000ZoookJPGo0000ROoonfX8o`00
0?oooo]ZPOoonfX002[ooo]Z1Ol0002;oookJPOo0000oooonfZ0oookJP00:_oonfX5o`0008gooo]Z
2?l0003ooookJWgooo]Z000ZoookJPGo0000SooonfX7o`000?oooo]ZO?oonfX002[ooo]Z1Ol0002@
oookJPWo0000oooonfYioookJP00:_oonfX5o`0009;ooo]Z2?l0003ooookJWSooo]Z000ZoookJPGo
0000U?oonfX7o`000?oooo]ZMooonfX002[ooo]Z1Ol0002FoookJPSo0000oooonfYdoookJP00:_oo
nfX5o`0009Sooo]Z1ol0003ooookJW?ooo]Z000ZoookJPGo0000VOoonfX9o`000?oooo]ZL?oonfX0
02[ooo]Z1Ol0002KoookJPSo0000oooonfY_oookJP00:_oonfX5o`0009gooo]Z1ol0003ooookJVko
oo]Z000ZoookJPGo0000W_oonfX9o`000?oooo]ZJooonfX002[ooo]Z1Ol0002QoookJPOo0000oooo
nfYZoookJP00:_oonfX5o`000:;ooo]Z1ol0003ooookJVWooo]Z000ZoookJPGo0000XooonfX9o`00
0?oooo]ZI_oonfX002[ooo]Z1Ol0002VoookJPOo0000oooonfYUoookJP00:_oonfX5o`000:Oooo]Z
2Ol0003ooookJV;ooo]Z000ZoookJPGo0000ZOoonfX8o`000?oooo]ZHOoonfX002[ooo]Z1Ol0002[
oookJPOo0000oooonfYPoookJP00:_oonfX5o`000:cooo]Z2Ol0003ooookJUgooo]Z000ZoookJPGo
0000[ooonfX7o`000?oooo]ZG?oonfX002[ooo]Z1Ol0002`oookJPOo0000oooonfYKoookJP00:_oo
nfX5o`000;7ooo]Z2Ol0003ooookJUSooo]Z000ZoookJPGo0000]?oonfX7o`000?oooo]ZEooonfX0
02[ooo]Z1Ol0002eoookJPOo0000oooonfYFoookJP00:_oonfX5o`000;Kooo]Z2Ol0003ooookJU?o
oo]Z000ZoookJPGo0000^OoonfX7o`000?oooo]ZD_oonfX002[ooo]Z1Ol0002joookJPOo0000oooo
nfYAoookJP00:_oonfX5o`000;cooo]Z2?l0003ooookJTkooo]Z000ZoookJPGo0000__oonfX7o`00
0?oooo]ZCOoonfX002[ooo]Z1Ol0002ooookJPWo0000oooonfY:oookJP00:_oonfX5o`000<7ooo]Z
2?l0003ooookJTWooo]Z000ZoookJPGo0000`ooonfX7o`000?oooo]ZB?oonfX002[ooo]Z1Ol00034
oookJPWo0000oooonfY5oookJP00:_oonfX5o`000<Oooo]Z1ol0003ooookJTCooo]Z000ZoookJPGo
0000b?oonfX7o`000?oooo]Z@ooonfX002[ooo]Z1Ol00039oookJPWo0000oooonfY0oookJP00:_oo
nfX5o`000<cooo]Z1ol0003ooookJSoooo]Z000ZoookJPGo0000cOoonfX7o`000?oooo]Z?_oonfX0
02[ooo]Z1Ol0003?oookJPSo0000oooonfXkoookJP00:_oonfX5o`000=7ooo]Z1ol0003ooookJS[o
oo]Z000ZoookJPGo0000d_oonfX7o`000?oooo]Z>OoonfX002[ooo]Z1Ol0003DoookJPOo0000oooo
nfXgoookJP00:_oonfX5o`000=Kooo]Z1ol0003ooookJSGooo]Z000ZoookJPGo0000eooonfX7o`00
0?oooo]Z=?oonfX002[ooo]Z1Ol0003IoookJPOo0000oooonfXboookJP003_oonfX3o`00O`Cooo]Z
0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003JoookJPSo0000oooonfX`oookJP003_oo
nfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003LoookJPOo0000oooo
nfX_oookJP003_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`gooo]Z1Ol0003N
oookJPOo0000oooonfX]oookJP003_oonfX3o`00O`Wooo]Z1?l007l<oookJPGo0000gooonfX8o`00
0?oooo]Z:ooonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX6o`000>3ooo]Z2?l0003ooookJRWo
oo]Z000>oookJP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003SoookJPOo0000oooonfXXoookJP003_oo
nfX3o`00O`gooo]Z0ol007l9oookJPGo0000i?oonfX8o`000?oooo]Z9_oonfX000kooo]Z0ol007l>
oookJP?o001o2?oonfX5o`000>Oooo]Z1ol0003ooookJRCooo]Z000>oookJP?o001o2?oonfX3o`00
O`?ooo]Z0ol007l8oookJPGo0000j?oonfX7o`000?oooo]Z8ooonfX000_ooo]Z1_l007l8oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003YoookJPSo0000oooonfXQoookJP002ooonfX6o`00O`Sooo]Z
1?l007l2oookJP?o001o2?oonfX5o`000>cooo]Z1ol0003ooookJQoooo]Z000=oookJPCo001o2Ooo
nfX7o`00O`Wooo]Z1Ol0003]oookJPOo0000oooonfXNoookJP003_oonfX3o`00O`[ooo]Z1Ol007l:
oookJPGo0000k_oonfX7o`000?oooo]Z7OoonfX002[ooo]Z1Ol0003aoookJPOo0000oooonfXJoook
JP00:_oonfX5o`000?;ooo]Z1ol0003ooookJQWooo]Z000ZoookJPGo0000looonfX7o`000?oooo]Z
6?oonfX002[ooo]Z1Ol0003doookJPWo0000oooonfXEoookJP00:_oonfX5o`000?Oooo]Z1ol0003o
oookJQCooo]Z000ZoookJPGo0000n?oonfX7o`000?oooo]Z4ooonfX002[ooo]Z1Ol0003joookJPOo
0000oooonfXAoookJP00:_oonfX5o`000?cooo]Z1ol0003ooookJPoooo]Z000ZoookJPGo0000oOoo
nfX7o`000?oooo]Z3_oonfX002[ooo]Z1Ol0003ooookJPOo0000oooonfX<oookJP00:_oonfX5o`00
0?oooo]Z0OoonfX7o`000?oooo]Z2ooonfX002[ooo]Z1Ol0003ooookJP?ooo]Z1ol0003ooookJPWo
oo]Z000ZoookJPGo0000oooonfX5oookJPOo0000oooonfX7oookJP00:_oonfX5o`000?oooo]Z1_oo
nfX7o`000?oooo]Z1_oonfX002[ooo]Z1Ol0003ooookJPOooo]Z2Ol0003ooookJP?ooo]Z000Zoook
JPGo0000oooonfX:oookJPOo0000oooonfX2oookJP00:_oonfX5o`000?oooo]Z2ooonfX7o`000?oo
oo]Z0OoonfX002[ooo]Z1Ol0003ooookJPcooo]Z1ol0003ooookJP00:_oonfX5o`000?oooo]Z3ooo
nfX7o`000?cooo]Z000ZoookJPGo0000oooonfX@oookJPOo0000nooonfX002[ooo]Z1Ol0003ooook
JQ7ooo]Z1ol0003joookJP00:_oonfX5o`000?oooo]Z4ooonfX7o`000?Sooo]Z000ZoookJPGo0000
oooonfXEoookJPOo0000m_oonfX002[ooo]Z1Ol0003ooookJQKooo]Z1ol0003eoookJP00:_oonfX5
o`000?oooo]Z6?oonfX7o`000??ooo]Z000ZoookJPGo0000oooonfXIoookJPOo0000l_oonfX002[o
oo]Z1Ol0003ooookJQ_ooo]Z2?l0003_oookJP00:_oonfX5o`000?oooo]Z7OoonfX7o`000>kooo]Z
000ZoookJPGo0000oooonfXNoookJPOo0000kOoonfX002[ooo]Z1Ol0003ooookJQoooo]Z1ol0003/
oookJP00:_oonfX5o`000?oooo]Z8_oonfX7o`000>Wooo]Z000ZoookJPGo0000oooonfXSoookJPOo
0000j?oonfX002[ooo]Z1Ol0003ooookJRCooo]Z1ol0003WoookJP00:_oonfX5o`000?oooo]Z9_oo
nfX7o`000>Gooo]Z000ZoookJPGo0000oooonfXXoookJPOo0000hooonfX002[ooo]Z1Ol0003ooook
JRWooo]Z1ol0003RoookJP00:_oonfX5o`000?oooo]Z:ooonfX7o`000>3ooo]Z000ZoookJPGo0000
oooonfX/oookJPOo0000gooonfX002[ooo]Z1Ol0003ooookJRkooo]Z1ol0003MoookJP00:_oonfX5
o`000?oooo]Z<?oonfX7o`000=_ooo]Z000ZoookJPGo0000oooonfXaoookJPOo0000f_oonfX002[o
oo]Z1Ol0003ooookJS;ooo]Z1ol0003IoookJP00:_oonfX5o`000?oooo]Z=OoonfX6o`000=Oooo]Z
000ZoookJPGo0000oooonfXfoookJPOo0000eOoonfX002[ooo]Z1Ol0003ooookJSOooo]Z1ol0003D
oookJP00:_oonfX5o`000?oooo]Z>OoonfX7o`000=;ooo]Z000ZoookJPGo0000oooonfXjoookJPOo
0000dOoonfX002[ooo]Z1Ol0003ooookJScooo]Z1ol0003?oookJP00:_oonfX5o`000?oooo]Z?_oo
nfX7o`000<gooo]Z000ZoookJPGo0000oooonfXooookJPOo0000c?oonfX000kooo]Z0ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJT3ooo]Z1ol0003;oookJP003_oonfX3o`00O`Co
oo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z@ooonfX5o`000<[ooo]Z000>oookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfY4oookJPOo
0000aooonfX000kooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJTGooo]Z
1ol00036oookJP003_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfY5oookJPSo0000a?oo
nfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZB?oonfX7o`000<?ooo]Z000>oook
JP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003ooookJT[ooo]Z1_l00032oookJP003_oonfX3o`00O`co
oo]Z0ol007l:oookJPGo0000oooonfY<oookJPOo0000_ooonfX000kooo]Z0ol007l>oookJP;o001o
2OoonfX5o`000?oooo]ZCOoonfX7o`000;kooo]Z000;oookJPKo001o2?oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonfY>oookJPOo0000_OoonfX000_ooo]Z1_l007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJToooo]Z1ol0002loookJP003OoonfX4o`00O`Wooo]Z1ol007l9oook
JPGo0000oooonfYBoookJPKo0000^_oonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX5o`000?oo
oo]ZDooonfX7o`000;Sooo]Z000ZoookJPGo0000oooonfYDoookJPOo0000]ooonfX002[ooo]Z1Ol0
003ooookJUKooo]Z1ol0002eoookJP00:_oonfX5o`000?oooo]ZEooonfX7o`000;Cooo]Z000Zoook
JPGo0000oooonfYIoookJPKo0000/ooonfX002[ooo]Z1Ol0003ooookJU_ooo]Z1ol0002`oookJP00
:_oonfX5o`000?oooo]ZG?oonfX7o`000:oooo]Z000ZoookJPGo0000oooonfYMoookJPOo0000[_oo
nfX002[ooo]Z1Ol0003ooookJUoooo]Z1ol0002/oookJP00:_oonfX5o`000?oooo]ZHOoonfX6o`00
0:_ooo]Z000ZoookJPGo0000oooonfYRoookJPOo0000ZOoonfX002[ooo]Z1Ol0003ooookJVCooo]Z
1ol0002WoookJP00:_oonfX5o`000?oooo]ZIOoonfX7o`000:Kooo]Z000ZoookJPGo0000oooonfYV
oookJPOo0000YOoonfX002[ooo]Z1Ol0003ooookJVWooo]Z1Ol0002ToookJP00:_oonfX5o`000?oo
oo]ZJ_oonfX6o`000:;ooo]Z000ZoookJPGo0000oooonfY[oookJPOo0000X?oonfX002[ooo]Z1Ol0
003ooookJVcooo]Z2?l0002NoookJP00:_oonfX5o`000?oooo]ZK_oonfX7o`0009gooo]Z000Zoook
JPGo0000oooonfY_oookJPOo0000W?oonfX002[ooo]Z1Ol0003ooookJW;ooo]Z1Ol0002KoookJP00
:_oonfX5o`000?oooo]ZLooonfX6o`0009Wooo]Z000ZoookJPGo0000oooonfYdoookJPOo0000Uooo
nfX002[ooo]Z1Ol0003ooookJWGooo]Z1ol0002FoookJP00:_oonfX5o`000?oooo]ZMooonfX7o`00
09Cooo]Z000ZoookJPGo0000oooonfYhoookJPOo0000TooonfX002[ooo]Z1Ol0003ooookJW[ooo]Z
1_l0002BoookJP00:_oonfX5o`000?oooo]ZO?oonfX5o`00097ooo]Z000ZoookJPGo0000oooonfYm
oookJPOo0000S_oonfX002[ooo]Z1Ol0003ooookJWkooo]Z1ol0002=oookJP00:_oonfX5o`000?oo
oo]ZOooonfX8o`0008_ooo]Z000ZoookJPGo0000oooonfZ1oookJPOo0000R_oonfX002[ooo]Z1Ol0
003ooookJX?ooo]Z1_l00029oookJP00:_oonfX5o`000?oooo]ZQOoonfX5o`0008Sooo]Z000Zoook
JPGo0000oooonfZ6oookJPKo0000Q_oonfX002[ooo]Z1Ol0003ooookJXOooo]Z1ol00024oookJP00
:_oonfX5o`000?oooo]ZR?oonfX7o`0008?ooo]Z000ZoookJPGo0000oooonfZ:oookJPOo0000POoo
nfX002[ooo]Z1Ol0003ooookJX_ooo]Z1ol00020oookJP00:_oonfX5o`000?oooo]ZSOoonfX6o`00
07oooo]Z000ZoookJPGo0000oooonfZ?oookJPGo0000O_oonfX002[ooo]Z1Ol0003ooookJY3ooo]Z
1_l0001loookJP00:_oonfX5o`000?oooo]ZTOoonfX7o`0007[ooo]Z000ZoookJPGo0000oooonfZB
oookJPOo0000NOoonfX002[ooo]Z1Ol0003ooookJYCooo]Z1ol0001goookJP00:_oonfX5o`000?oo
oo]ZUOoonfX7o`0007Kooo]Z000ZoookJPGo0000oooonfZGoookJPKo0000MOoonfX002[ooo]Z1Ol0
003ooookJYWooo]Z1_l0001coookJP00:_oonfX5o`000?oooo]ZV_oonfX6o`0007;ooo]Z000Zoook
JPGo0000oooonfZKoookJPOo0000L?oonfX002[ooo]Z1Ol0003ooookJYgooo]Z1ol0001^oookJP00
:_oonfX5o`000?oooo]ZW_oonfX7o`0006gooo]Z000>oookJP?o001o1?oonfX3o`00O`Kooo]Z0ol0
07l9oookJPGo0000oooonfZOoookJPOo0000K?oonfX000kooo]Z0ol007l4oookJP?o001o1_oonfX3
o`00O`Wooo]Z1Ol0003ooookJZ;ooo]Z1Ol0001[oookJP003_oonfX3o`00O`Cooo]Z0ol007l6oook
JP?o001o2OoonfX5o`000?oooo]ZXooonfX6o`0006Wooo]Z000>oookJP?o001o2?oonfX9o`00O`So
oo]Z1Ol0003ooookJZCooo]Z1_l0001XoookJP003_oonfX3o`00O`Sooo]Z2Ol007l8oookJPKo0000
oooonfZToookJPKo0000IooonfX000kooo]Z0ol007l8oookJP;o001o0ooonfX3o`00O`Wooo]Z1Ol0
003ooookJZOooo]Z1ol0001ToookJP003_oonfX3o`00O`Wooo]Z0_l007l2oookJP?o001o2OoonfX5
o`000?oooo]ZZ?oonfX7o`0006?ooo]Z000>oookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0003ooookJZWooo]Z1ol0001RoookJP003_oonfX3o`00O`[ooo]Z0_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000oooonfZZoookJPSo0000H?oonfX000_ooo]Z1_l007l;oook
JPGo001o2OoonfX5o`000?oooo]Z[OoonfX6o`0005oooo]Z000;oookJPKo001o2ooonfX5o`00O`Wo
oo]Z1Ol0003ooookJZkooo]Z1_l0001NoookJP003OoonfX4o`00O`cooo]Z1?l007l9oookJPGo0000
oooonfZ`oookJPGo0000GOoonfX000kooo]Z0ol007l=oookJP?o001o2OoonfX5o`000?oooo]Z/Ooo
nfX6o`0005_ooo]Z000ZoookJPGo0000oooonfZboookJPKo0000F_oonfX002[ooo]Z1Ol0003ooook
J[?ooo]Z1ol0001HoookJP00:_oonfX5o`000?oooo]Z]OoonfX7o`0005Kooo]Z000ZoookJPGo0000
oooonfZfoookJPOo0000EOoonfX002[ooo]Z1Ol0003ooookJ[Oooo]Z1ol0001DoookJP00:_oonfX5
o`000?oooo]Z^_oonfX5o`0005?ooo]Z000ZoookJPGo0000oooonfZkoookJPKo0000DOoonfX002[o
oo]Z1Ol0003ooookJ[cooo]Z1_l0001@oookJP00:_oonfX5o`000?oooo]Z_OoonfX6o`0004oooo]Z
000ZoookJPGo0000oooonfZooookJPKo0000COoonfX002[ooo]Z1Ol0003ooookJ/3ooo]Z1_l0001<
oookJP00:_oonfX5o`000?oooo]Z`OoonfX7o`0004[ooo]Z000ZoookJPGo0000oooonf[3oookJPOo
0000B?oonfX002[ooo]Z1Ol0003ooookJ/Cooo]Z1ol00017oookJP00:_oonfX5o`000?oooo]ZaOoo
nfX7o`0004Kooo]Z000ZoookJPGo0000oooonf[8oookJPGo0000AOoonfX002[ooo]Z1Ol0003ooook
J/Wooo]Z1_l00013oookJP00:_oonfX5o`000?oooo]Zb_oonfX6o`0004;ooo]Z000ZoookJPGo0000
oooonf[;oookJPKo0000@OoonfX002[ooo]Z1Ol0003ooookJ/gooo]Z1Ol00010oookJP00:_oonfX5
o`000?oooo]Zc_oonfX6o`0003kooo]Z000ZoookJPGo0000oooonf[?oookJPKo0000?OoonfX002[o
oo]Z1Ol0003ooookJ]3ooo]Z2?l0000joookJP00:_oonfX5o`000?oooo]Zd_oonfX7o`0003Wooo]Z
000ZoookJPGo0000oooonf[CoookJPOo0000>?oonfX002[ooo]Z1Ol0003ooookJ]Cooo]Z1ol0000g
oookJP00:_oonfX5o`000?oooo]ZeooonfX6o`0003Gooo]Z000ZoookJPGo0000oooonf[HoookJPKo
0000=?oonfX002[ooo]Z1Ol0003ooookJ]Wooo]Z1_l0000coookJP00:_oonfX5o`000?oooo]Zfooo
nfX5o`0003;ooo]Z000ZoookJPGo0000oooonf[LoookJPKo0000<?oonfX002[ooo]Z1Ol0003ooook
J]gooo]Z1_l0000_oookJP00:_oonfX5o`000?oooo]Zg_oonfX6o`0002kooo]Z000ZoookJPGo0000
oooonf[PoookJPGo0000;OoonfX002[ooo]Z1Ol0003ooookJ^7ooo]Z1_l0000[oookJP00:_oonfX5
o`000?oooo]Zh_oonfX7o`0002Wooo]Z000ZoookJPGo0000oooonf[SoookJPOo0000:?oonfX002[o
oo]Z1Ol0003ooookJ^Gooo]Z1ol0000VoookJP00:_oonfX5o`000?oooo]Zi_oonfX7o`0002Gooo]Z
000ZoookJPGo0000oooonf[XoookJPKo00009?oonfX002[ooo]Z1Ol0003ooookJ^[ooo]Z1_l0000R
oookJP00:_oonfX5o`000?oooo]ZjooonfX6o`00027ooo]Z000ZoookJPGo0000oooonf[/oookJPKo
00008?oonfX002[ooo]Z1Ol0003ooookJ^kooo]Z1Ol0000OoookJP00:_oonfX5o`000?oooo]Zkooo
nfX6o`0001gooo]Z000ZoookJPGo0000oooonf[`oookJPKo00007?oonfX002[ooo]Z1Ol0003ooook
J_7ooo]Z1_l0000KoookJP00:_oonfX5o`000?oooo]ZlooonfX5o`0001[ooo]Z000ZoookJPGo0000
oooonf[doookJPKo00006?oonfX002[ooo]Z1Ol0003ooookJ_Gooo]Z1_l0000GoookJP003_oonfX3
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Zm_oonfX5o`0001Oooo]Z000>oook
JP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonf[hoookJP;o00006?oonfX000ko
oo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJ_oooo]Z
4_oonfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3
o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3o`00
O`Wooo]Z1ol007l9oookJPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2OoonfX6o`00O`[o
oo]Z1Ol0003ooookJ_oooo]Z4ooonfX000_ooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z
oooonfXCoookJP002ooonfX6o`00O`Wooo]Z0_l007oooookJ_oooo]Z9_oonfX000gooo]Z1?l007l:
oookJPOo001ooooonf[ooookJR3ooo]Z000>oookJP?o001o2_oonfX7o`00Oooooo]ZoooonfXPoook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.3518, 0.958149, \
0.00790084, 0.0015709}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Using a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " trick of a ``pure function'' one can eliminate the intervening function \
(OurStepOnce) definition:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[
      NestList[StepOnce[#, exampleFunction, 0.01] &, {0, 1}, 400]]\)], "Input",\

  CellTags->"mmtag:19:pure_function"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 -1.18279 1.1975 [
[.2619 .00222 -7 -20 ]
[.2619 .00222 7 0 ]
[.5 .00222 -7 -20 ]
[.5 .00222 7 0 ]
[.7381 .00222 -7 -20 ]
[.7381 .00222 7 0 ]
[.97619 .00222 -7 -20 ]
[.97619 .00222 7 0 ]
[.01131 .13447 -29 -10 ]
[.01131 .13447 0 10 ]
[.01131 .25422 -29 -10 ]
[.01131 .25422 0 10 ]
[.01131 .37397 -29 -10 ]
[.01131 .37397 0 10 ]
[.01131 .49372 -29 -10 ]
[.01131 .49372 0 10 ]
[.01131 .61347 -29 -10 ]
[.01131 .61347 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13447 m
.03006 .13447 L
s
gsave
.01131 .13447 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.1) show
1.000 setlinewidth
grestore
.02381 .25422 m
.03006 .25422 L
s
gsave
.01131 .25422 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .37397 m
.03006 .37397 L
s
gsave
.01131 .37397 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.3) show
1.000 setlinewidth
grestore
.02381 .49372 m
.03006 .49372 L
s
gsave
.01131 .49372 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .61347 m
.03006 .61347 L
s
gsave
.01131 .61347 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.5) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03867 m
.02756 .03867 L
s
.02381 .06262 m
.02756 .06262 L
s
.02381 .08657 m
.02756 .08657 L
s
.02381 .11052 m
.02756 .11052 L
s
.02381 .15842 m
.02756 .15842 L
s
.02381 .18237 m
.02756 .18237 L
s
.02381 .20632 m
.02756 .20632 L
s
.02381 .23027 m
.02756 .23027 L
s
.02381 .27817 m
.02756 .27817 L
s
.02381 .30212 m
.02756 .30212 L
s
.02381 .32607 m
.02756 .32607 L
s
.02381 .35002 m
.02756 .35002 L
s
.02381 .39792 m
.02756 .39792 L
s
.02381 .42187 m
.02756 .42187 L
s
.02381 .44582 m
.02756 .44582 L
s
.02381 .46977 m
.02756 .46977 L
s
.02381 .51767 m
.02756 .51767 L
s
.02381 .54162 m
.02756 .54162 L
s
.02381 .56557 m
.02756 .56557 L
s
.02381 .58952 m
.02756 .58952 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.02619 .01591 Mdot
.02857 .01711 Mdot
.03095 .01831 Mdot
.03333 .01951 Mdot
.03571 .02071 Mdot
.0381 .02192 Mdot
.04048 .02312 Mdot
.04286 .02433 Mdot
.04524 .02554 Mdot
.04762 .02674 Mdot
.05 .02795 Mdot
.05238 .02916 Mdot
.05476 .03038 Mdot
.05714 .03159 Mdot
.05952 .0328 Mdot
.0619 .03402 Mdot
.06429 .03524 Mdot
.06667 .03645 Mdot
.06905 .03767 Mdot
.07143 .03889 Mdot
.07381 .04012 Mdot
.07619 .04134 Mdot
.07857 .04256 Mdot
.08095 .04379 Mdot
.08333 .04501 Mdot
.08571 .04624 Mdot
.0881 .04747 Mdot
.09048 .0487 Mdot
.09286 .04993 Mdot
.09524 .05117 Mdot
.09762 .0524 Mdot
.1 .05364 Mdot
.10238 .05487 Mdot
.10476 .05611 Mdot
.10714 .05735 Mdot
.10952 .05859 Mdot
.1119 .05983 Mdot
.11429 .06107 Mdot
.11667 .06232 Mdot
.11905 .06356 Mdot
.12143 .06481 Mdot
.12381 .06606 Mdot
.12619 .0673 Mdot
.12857 .06855 Mdot
.13095 .06981 Mdot
.13333 .07106 Mdot
.13571 .07231 Mdot
.1381 .07357 Mdot
.14048 .07482 Mdot
.14286 .07608 Mdot
.14524 .07734 Mdot
.14762 .0786 Mdot
.15 .07986 Mdot
.15238 .08112 Mdot
.15476 .08239 Mdot
.15714 .08365 Mdot
.15952 .08492 Mdot
.1619 .08619 Mdot
.16429 .08746 Mdot
.16667 .08873 Mdot
.16905 .09 Mdot
.17143 .09127 Mdot
.17381 .09254 Mdot
.17619 .09382 Mdot
.17857 .0951 Mdot
.18095 .09637 Mdot
.18333 .09765 Mdot
.18571 .09893 Mdot
.1881 .10022 Mdot
.19048 .1015 Mdot
.19286 .10278 Mdot
.19524 .10407 Mdot
.19762 .10536 Mdot
.2 .10664 Mdot
.20238 .10793 Mdot
.20476 .10922 Mdot
.20714 .11052 Mdot
.20952 .11181 Mdot
.2119 .1131 Mdot
.21429 .1144 Mdot
.21667 .1157 Mdot
.21905 .117 Mdot
.22143 .1183 Mdot
.22381 .1196 Mdot
.22619 .1209 Mdot
.22857 .1222 Mdot
.23095 .12351 Mdot
.23333 .12481 Mdot
.23571 .12612 Mdot
.2381 .12743 Mdot
.24048 .12874 Mdot
.24286 .13005 Mdot
.24524 .13136 Mdot
.24762 .13268 Mdot
.25 .13399 Mdot
.25238 .13531 Mdot
.25476 .13663 Mdot
.25714 .13795 Mdot
.25952 .13927 Mdot
.2619 .14059 Mdot
.26429 .14191 Mdot
.26667 .14324 Mdot
.26905 .14457 Mdot
.27143 .14589 Mdot
.27381 .14722 Mdot
.27619 .14855 Mdot
.27857 .14988 Mdot
.28095 .15122 Mdot
.28333 .15255 Mdot
.28571 .15388 Mdot
.2881 .15522 Mdot
.29048 .15656 Mdot
.29286 .1579 Mdot
.29524 .15924 Mdot
.29762 .16058 Mdot
.3 .16192 Mdot
.30238 .16327 Mdot
.30476 .16462 Mdot
.30714 .16596 Mdot
.30952 .16731 Mdot
.3119 .16866 Mdot
.31429 .17001 Mdot
.31667 .17137 Mdot
.31905 .17272 Mdot
.32143 .17408 Mdot
.32381 .17543 Mdot
.32619 .17679 Mdot
.32857 .17815 Mdot
.33095 .17951 Mdot
.33333 .18087 Mdot
.33571 .18224 Mdot
.3381 .1836 Mdot
.34048 .18497 Mdot
.34286 .18634 Mdot
.34524 .18771 Mdot
.34762 .18908 Mdot
.35 .19045 Mdot
.35238 .19182 Mdot
.35476 .1932 Mdot
.35714 .19457 Mdot
.35952 .19595 Mdot
.3619 .19733 Mdot
.36429 .19871 Mdot
.36667 .20009 Mdot
.36905 .20147 Mdot
.37143 .20286 Mdot
.37381 .20424 Mdot
.37619 .20563 Mdot
.37857 .20702 Mdot
.38095 .20841 Mdot
.38333 .2098 Mdot
.38571 .21119 Mdot
.3881 .21259 Mdot
.39048 .21398 Mdot
.39286 .21538 Mdot
.39524 .21678 Mdot
.39762 .21818 Mdot
.4 .21958 Mdot
.40238 .22098 Mdot
.40476 .22238 Mdot
.40714 .22379 Mdot
.40952 .22519 Mdot
.4119 .2266 Mdot
.41429 .22801 Mdot
.41667 .22942 Mdot
.41905 .23083 Mdot
.42143 .23225 Mdot
.42381 .23366 Mdot
.42619 .23508 Mdot
.42857 .2365 Mdot
.43095 .23792 Mdot
.43333 .23934 Mdot
.43571 .24076 Mdot
.4381 .24218 Mdot
.44048 .24361 Mdot
.44286 .24503 Mdot
.44524 .24646 Mdot
.44762 .24789 Mdot
.45 .24932 Mdot
.45238 .25075 Mdot
.45476 .25219 Mdot
.45714 .25362 Mdot
.45952 .25506 Mdot
.4619 .2565 Mdot
.46429 .25794 Mdot
.46667 .25938 Mdot
.46905 .26082 Mdot
.47143 .26226 Mdot
.47381 .26371 Mdot
.47619 .26515 Mdot
.47857 .2666 Mdot
.48095 .26805 Mdot
.48333 .2695 Mdot
.48571 .27095 Mdot
.4881 .27241 Mdot
.49048 .27386 Mdot
.49286 .27532 Mdot
.49524 .27678 Mdot
.49762 .27824 Mdot
.5 .2797 Mdot
.50238 .28116 Mdot
.50476 .28263 Mdot
.50714 .28409 Mdot
.50952 .28556 Mdot
.5119 .28703 Mdot
.51429 .2885 Mdot
.51667 .28997 Mdot
.51905 .29144 Mdot
.52143 .29291 Mdot
.52381 .29439 Mdot
.52619 .29587 Mdot
.52857 .29735 Mdot
.53095 .29883 Mdot
.53333 .30031 Mdot
.53571 .30179 Mdot
.5381 .30328 Mdot
.54048 .30476 Mdot
.54286 .30625 Mdot
.54524 .30774 Mdot
.54762 .30923 Mdot
.55 .31072 Mdot
.55238 .31221 Mdot
.55476 .31371 Mdot
.55714 .31521 Mdot
.55952 .3167 Mdot
.5619 .3182 Mdot
.56429 .3197 Mdot
.56667 .32121 Mdot
.56905 .32271 Mdot
.57143 .32422 Mdot
.57381 .32572 Mdot
.57619 .32723 Mdot
.57857 .32874 Mdot
.58095 .33025 Mdot
.58333 .33177 Mdot
.58571 .33328 Mdot
.5881 .3348 Mdot
.59048 .33631 Mdot
.59286 .33783 Mdot
.59524 .33935 Mdot
.59762 .34088 Mdot
.6 .3424 Mdot
.60238 .34392 Mdot
.60476 .34545 Mdot
.60714 .34698 Mdot
.60952 .34851 Mdot
.6119 .35004 Mdot
.61429 .35157 Mdot
.61667 .35311 Mdot
.61905 .35464 Mdot
.62143 .35618 Mdot
.62381 .35772 Mdot
.62619 .35926 Mdot
.62857 .3608 Mdot
.63095 .36235 Mdot
.63333 .36389 Mdot
.63571 .36544 Mdot
.6381 .36699 Mdot
.64048 .36854 Mdot
.64286 .37009 Mdot
.64524 .37164 Mdot
.64762 .37319 Mdot
.65 .37475 Mdot
.65238 .37631 Mdot
.65476 .37787 Mdot
.65714 .37943 Mdot
.65952 .38099 Mdot
.6619 .38255 Mdot
.66429 .38412 Mdot
.66667 .38569 Mdot
.66905 .38725 Mdot
.67143 .38882 Mdot
.67381 .3904 Mdot
.67619 .39197 Mdot
.67857 .39354 Mdot
.68095 .39512 Mdot
.68333 .3967 Mdot
.68571 .39828 Mdot
.6881 .39986 Mdot
.69048 .40144 Mdot
.69286 .40303 Mdot
.69524 .40461 Mdot
.69762 .4062 Mdot
.7 .40779 Mdot
.70238 .40938 Mdot
.70476 .41097 Mdot
.70714 .41256 Mdot
.70952 .41416 Mdot
.7119 .41576 Mdot
.71429 .41736 Mdot
.71667 .41896 Mdot
.71905 .42056 Mdot
.72143 .42216 Mdot
.72381 .42377 Mdot
.72619 .42537 Mdot
.72857 .42698 Mdot
.73095 .42859 Mdot
.73333 .4302 Mdot
.73571 .43181 Mdot
.7381 .43343 Mdot
.74048 .43505 Mdot
.74286 .43666 Mdot
.74524 .43828 Mdot
.74762 .4399 Mdot
.75 .44153 Mdot
.75238 .44315 Mdot
.75476 .44478 Mdot
.75714 .4464 Mdot
.75952 .44803 Mdot
.7619 .44966 Mdot
.76429 .4513 Mdot
.76667 .45293 Mdot
.76905 .45457 Mdot
.77143 .4562 Mdot
.77381 .45784 Mdot
.77619 .45948 Mdot
.77857 .46113 Mdot
.78095 .46277 Mdot
.78333 .46442 Mdot
.78571 .46606 Mdot
.7881 .46771 Mdot
.79048 .46936 Mdot
.79286 .47101 Mdot
.79524 .47267 Mdot
.79762 .47432 Mdot
.8 .47598 Mdot
.80238 .47764 Mdot
.80476 .4793 Mdot
.80714 .48096 Mdot
.80952 .48263 Mdot
.8119 .48429 Mdot
.81429 .48596 Mdot
.81667 .48763 Mdot
.81905 .4893 Mdot
.82143 .49097 Mdot
.82381 .49264 Mdot
.82619 .49432 Mdot
.82857 .496 Mdot
.83095 .49767 Mdot
.83333 .49935 Mdot
.83571 .50104 Mdot
.8381 .50272 Mdot
.84048 .50441 Mdot
.84286 .50609 Mdot
.84524 .50778 Mdot
.84762 .50947 Mdot
.85 .51117 Mdot
.85238 .51286 Mdot
.85476 .51455 Mdot
.85714 .51625 Mdot
.85952 .51795 Mdot
.8619 .51965 Mdot
.86429 .52135 Mdot
.86667 .52306 Mdot
.86905 .52476 Mdot
.87143 .52647 Mdot
.87381 .52818 Mdot
.87619 .52989 Mdot
.87857 .5316 Mdot
.88095 .53332 Mdot
.88333 .53504 Mdot
.88571 .53675 Mdot
.8881 .53847 Mdot
.89048 .54019 Mdot
.89286 .54192 Mdot
.89524 .54364 Mdot
.89762 .54537 Mdot
.9 .5471 Mdot
.90238 .54883 Mdot
.90476 .55056 Mdot
.90714 .55229 Mdot
.90952 .55403 Mdot
.9119 .55576 Mdot
.91429 .5575 Mdot
.91667 .55924 Mdot
.91905 .56098 Mdot
.92143 .56273 Mdot
.92381 .56447 Mdot
.92619 .56622 Mdot
.92857 .56797 Mdot
.93095 .56972 Mdot
.93333 .57147 Mdot
.93571 .57323 Mdot
.9381 .57498 Mdot
.94048 .57674 Mdot
.94286 .5785 Mdot
.94524 .58026 Mdot
.94762 .58202 Mdot
.95 .58379 Mdot
.95238 .58556 Mdot
.95476 .58732 Mdot
.95714 .58909 Mdot
.95952 .59087 Mdot
.9619 .59264 Mdot
.96429 .59442 Mdot
.96667 .59619 Mdot
.96905 .59797 Mdot
.97143 .59975 Mdot
.97381 .60153 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00Z_oonfX3o`00OgOooo]Z2Ol007mhoook
JPGo001oO?oonfX3o`00OaOooo]Z002ZoookJP?o001oMooonfX9o`00OgOooo]Z1ol007mkoookJP?o
001o5ooonfX00:[ooo]Z0ol007mgoookJPCo001oNooonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o
5ooonfX00:[ooo]Z0ol007mhoookJPCo001oN_oonfX3o`00O`?ooo]Z0ol007meoookJPWo001o5_oo
nfX00:[ooo]Z0ol007mioookJPGo001oO_oonfX3o`00OgGooo]Z2Ol007lFoookJP00Z_oonfX3o`00
Og_ooo]Z1?l007mmoookJP?o001oMOoonfX2o`00O`?ooo]Z0ol007lGoookJP00Z_oonfX3o`00Ogco
oo]Z0ol007mkoookJPCo001oMooonfX2o`00O`;ooo]Z0ol007lGoookJP00Z_oonfX3o`00Oggooo]Z
0ol007mjoookJP?o001oN?oonfX3o`00O`04oookJ_l007oo001oo`00OaOooo]Z002ZoookJP?o001o
MooonfX3o`00O`?ooo]Z0ol007mloookJP;o001oN?oonfX2o`00O`04oookJ_l007oo001oo`00OaOo
oo]Z002WoookJPKo001oMooonfX3o`00O`?ooo]Z0ol007mfoookJP?o001o0ooonfX3o`00OgSooo]Z
1Ol007lGoookJP00:_oonfX5o`0007Sooo]Z1_l007mgoookJPCo001o0_oonfX3o`00OgKooo]Z0ol0
07l3oookJP?o001oN?oonfX5o`00OaOooo]Z000ZoookJPGo0000N_oonfX4o`00OgSooo]Z1ol007mh
oookJPOo001oN_oonfX4o`00OaOooo]Z000ZoookJPGo0000NooonfX3o`00OgWooo]Z1Ol007mjoook
JPGo001oO?oonfX3o`00OaOooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000
oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000ZoookJPGo0000oooonf[o
oookJQ?ooo]Z000ZoookJPGo0000oooonf[ooookJQ?ooo]Z000MoookJ_oo0000ool0000Ko`0000[o
oo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000M
oookJ_oo0000ool0000Ko`0000[ooo]Z000MoookJ_oo0000ool0000Ko`0000[ooo]Z000ZoookJPco
0000MOoonfX00ol0003ooo]ZoookJP1koookJP03o`000?oonf[ooo]Z07cooo]Z00?o0000oookJ_oo
nfX0NooonfX00ol0003ooo]ZoookJP0GoookJP00:_oonfX>o`0007?ooo]Z00?o0000oookJ_oonfX0
NooonfX00ol0003ooo]ZoookJP1loookJP03o`000?oonf[ooo]Z07_ooo]Z00?o0000oookJ_oonfX0
5ooonfX002[ooo]Z1Ol00003oookJPSo0000oooonf[ooookJPSooo]Z000ZoookJPGo00001?oonfX8
o`000?oooo]ZoooonfX7oookJP00:_oonfX5o`0000Oooo]Z2?l0003ooookJ_oooo]Z1?oonfX002[o
oo]Z1Ol00008oookJPWo0000oooonf[ooookJP;ooo]Z000ZoookJPGo00002_oonfX9o`000?oooo]Z
oooonfX002[ooo]Z1Ol0000<oookJPWo0000oooonf[moookJP00:_oonfX5o`0000kooo]Z2?l0003o
oookJ_cooo]Z000ZoookJPGo00004OoonfX8o`000?oooo]ZnOoonfX002[ooo]Z1Ol0000BoookJPSo
0000oooonf[hoookJP00:_oonfX5o`0001Cooo]Z2Ol0003ooookJ_Gooo]Z000ZoookJPGo00005_oo
nfX8o`000?oooo]Zm?oonfX002[ooo]Z1Ol0000HoookJPWo0000oooonf[aoookJP00:_oonfX5o`00
01[ooo]Z2?l0003ooookJ_3ooo]Z000ZoookJPGo00007?oonfX8o`000?oooo]Zk_oonfX002[ooo]Z
1Ol0000MoookJPWo0000oooonf[/oookJP00:_oonfX5o`00023ooo]Z2?l0003ooookJ^[ooo]Z000Z
oookJPGo00008OoonfX:o`000?oooo]ZiooonfX002[ooo]Z1Ol0000ToookJPSo0000oooonf[Voook
JP00:_oonfX5o`0002Gooo]Z2_l0003ooookJ^?ooo]Z000ZoookJPGo00009ooonfX9o`000?oooo]Z
h_oonfX002[ooo]Z1Ol0000ZoookJPSo0000oooonf[PoookJP00:_oonfX5o`0002_ooo]Z2Ol0003o
oookJ]kooo]Z000ZoookJPGo0000;_oonfX8o`000?oooo]Zg?oonfX002[ooo]Z1Ol0000_oookJPSo
0000oooonf[KoookJP00:_oonfX5o`0003;ooo]Z2?l0003ooookJ]Sooo]Z000ZoookJPGo0000<ooo
nfX8o`000?oooo]ZeooonfX002[ooo]Z1Ol0000eoookJPWo0000oooonf[DoookJP00:_oonfX5o`00
03Oooo]Z2?l0003ooookJ]?ooo]Z000ZoookJPGo0000>OoonfX8o`000?oooo]ZdOoonfX002[ooo]Z
1Ol0000joookJPWo0000oooonf[?oookJP00:_oonfX5o`0003gooo]Z2?l0003ooookJ/gooo]Z000Z
oookJPGo0000?_oonfX9o`000?oooo]ZbooonfX002[ooo]Z1Ol00011oookJPSo0000oooonf[9oook
JP00:_oonfX5o`0004;ooo]Z2?l0003ooookJ/Sooo]Z000ZoookJPGo0000AOoonfX7o`000?oooo]Z
a_oonfX002[ooo]Z1Ol00016oookJPSo0000oooonf[4oookJP00:_oonfX5o`0004Sooo]Z1ol0003o
oookJ/?ooo]Z000ZoookJPGo0000B_oonfX8o`000?oooo]Z`?oonfX002[ooo]Z1Ol0001;oookJPSo
0000oooonfZooookJP00:_oonfX5o`0004gooo]Z2Ol0003ooookJ[cooo]Z000ZoookJPGo0000Cooo
nfX8o`000?oooo]Z^ooonfX002[ooo]Z1Ol0001AoookJPWo0000oooonfZhoookJP00:_oonfX5o`00
05;ooo]Z2Ol0003ooookJ[Oooo]Z000ZoookJPGo0000EOoonfX8o`000?oooo]Z]OoonfX002[ooo]Z
1Ol0001FoookJPWo0000oooonfZcoookJP00:_oonfX5o`0005Wooo]Z2?l0003ooookJ[7ooo]Z000Z
oookJPGo0000F_oonfX8o`000?oooo]Z/?oonfX002[ooo]Z1Ol0001MoookJPOo0000oooonfZ^oook
JP00:_oonfX5o`0005kooo]Z2?l0003ooookJZcooo]Z000ZoookJPGo0000H?oonfX7o`000?oooo]Z
ZooonfX002[ooo]Z1Ol0001RoookJPSo0000oooonfZXoookJP00:_oonfX5o`0006?ooo]Z2?l0003o
oookJZOooo]Z000ZoookJPGo0000IOoonfX9o`000?oooo]ZY?oonfX002[ooo]Z1Ol0001WoookJPSo
0000oooonfZSoookJP00:_oonfX5o`0006Wooo]Z2Ol0003ooookJZ3ooo]Z000>oookJP?o001o1?oo
nfX3o`00O`Gooo]Z0ol007l:oookJPGo0000JooonfX8o`000?oooo]ZWooonfX000kooo]Z0ol007l4
oookJP?o001o1OoonfX3o`00O`[ooo]Z1Ol0001]oookJPOo0000oooonfZNoookJP003_oonfX3o`00
O`Cooo]Z0ol007l5oookJP?o001o2_oonfX5o`0006kooo]Z2Ol0003ooookJY_ooo]Z000>oookJP?o
001o3?oonfX3o`00O`[ooo]Z1Ol0001aoookJPOo0000oooonfZJoookJP003_oonfX3o`00O`cooo]Z
0ol007l:oookJPKo0000LOoonfX8o`000?oooo]ZV?oonfX000kooo]Z0ol007l<oookJP?o001o2_oo
nfX5o`0007?ooo]Z2Ol0003ooookJYKooo]Z000>oookJP?o001o3?oonfX3o`00O`[ooo]Z1Ol0001f
oookJPSo0000oooonfZDoookJP003_oonfX3o`00O`cooo]Z0ol007l:oookJPGo0000MooonfX9o`00
0?oooo]ZT_oonfX000kooo]Z0ol007l<oookJP?o001o2_oonfX5o`0007[ooo]Z1ol0003ooookJY7o
oo]Z000;oookJPKo001o2OoonfX6o`00O`[ooo]Z1Ol0001koookJPSo0000oooonfZ?oookJP002ooo
nfX6o`00O`Wooo]Z1_l007l:oookJPGo0000O_oonfX7o`000?oooo]ZSOoonfX000gooo]Z1?l007l;
oookJPCo001o2_oonfX5o`0007oooo]Z2?l0003ooookJX_ooo]Z000>oookJP?o001o3?oonfX3o`00
O`[ooo]Z1Ol00020oookJPSo0000oooonfZ:oookJP00:_oonfX5o`0008?ooo]Z1ol0003ooookJXSo
oo]Z000ZoookJPGo0000Q?oonfX8o`000?oooo]ZQ_oonfX002[ooo]Z1Ol00026oookJPOo0000oooo
nfZ5oookJP00:_oonfX5o`0008Sooo]Z2?l0003ooookJX;ooo]Z000ZoookJPGo0000ROoonfX8o`00
0?oooo]ZPOoonfX002[ooo]Z1Ol0002;oookJPOo0000oooonfZ0oookJP00:_oonfX5o`0008gooo]Z
2?l0003ooookJWgooo]Z000ZoookJPGo0000SooonfX7o`000?oooo]ZO?oonfX002[ooo]Z1Ol0002@
oookJPWo0000oooonfYioookJP00:_oonfX5o`0009;ooo]Z2?l0003ooookJWSooo]Z000ZoookJPGo
0000U?oonfX7o`000?oooo]ZMooonfX002[ooo]Z1Ol0002FoookJPSo0000oooonfYdoookJP00:_oo
nfX5o`0009Sooo]Z1ol0003ooookJW?ooo]Z000ZoookJPGo0000VOoonfX9o`000?oooo]ZL?oonfX0
02[ooo]Z1Ol0002KoookJPSo0000oooonfY_oookJP00:_oonfX5o`0009gooo]Z1ol0003ooookJVko
oo]Z000ZoookJPGo0000W_oonfX9o`000?oooo]ZJooonfX002[ooo]Z1Ol0002QoookJPOo0000oooo
nfYZoookJP00:_oonfX5o`000:;ooo]Z1ol0003ooookJVWooo]Z000ZoookJPGo0000XooonfX9o`00
0?oooo]ZI_oonfX002[ooo]Z1Ol0002VoookJPOo0000oooonfYUoookJP00:_oonfX5o`000:Oooo]Z
2Ol0003ooookJV;ooo]Z000ZoookJPGo0000ZOoonfX8o`000?oooo]ZHOoonfX002[ooo]Z1Ol0002[
oookJPOo0000oooonfYPoookJP00:_oonfX5o`000:cooo]Z2Ol0003ooookJUgooo]Z000ZoookJPGo
0000[ooonfX7o`000?oooo]ZG?oonfX002[ooo]Z1Ol0002`oookJPOo0000oooonfYKoookJP00:_oo
nfX5o`000;7ooo]Z2Ol0003ooookJUSooo]Z000ZoookJPGo0000]?oonfX7o`000?oooo]ZEooonfX0
02[ooo]Z1Ol0002eoookJPOo0000oooonfYFoookJP00:_oonfX5o`000;Kooo]Z2Ol0003ooookJU?o
oo]Z000ZoookJPGo0000^OoonfX7o`000?oooo]ZD_oonfX002[ooo]Z1Ol0002joookJPOo0000oooo
nfYAoookJP00:_oonfX5o`000;cooo]Z2?l0003ooookJTkooo]Z000ZoookJPGo0000__oonfX7o`00
0?oooo]ZCOoonfX002[ooo]Z1Ol0002ooookJPWo0000oooonfY:oookJP00:_oonfX5o`000<7ooo]Z
2?l0003ooookJTWooo]Z000ZoookJPGo0000`ooonfX7o`000?oooo]ZB?oonfX002[ooo]Z1Ol00034
oookJPWo0000oooonfY5oookJP00:_oonfX5o`000<Oooo]Z1ol0003ooookJTCooo]Z000ZoookJPGo
0000b?oonfX7o`000?oooo]Z@ooonfX002[ooo]Z1Ol00039oookJPWo0000oooonfY0oookJP00:_oo
nfX5o`000<cooo]Z1ol0003ooookJSoooo]Z000ZoookJPGo0000cOoonfX7o`000?oooo]Z?_oonfX0
02[ooo]Z1Ol0003?oookJPSo0000oooonfXkoookJP00:_oonfX5o`000=7ooo]Z1ol0003ooookJS[o
oo]Z000ZoookJPGo0000d_oonfX7o`000?oooo]Z>OoonfX002[ooo]Z1Ol0003DoookJPOo0000oooo
nfXgoookJP00:_oonfX5o`000=Kooo]Z1ol0003ooookJSGooo]Z000ZoookJPGo0000eooonfX7o`00
0?oooo]Z=?oonfX002[ooo]Z1Ol0003IoookJPOo0000oooonfXboookJP003_oonfX3o`00O`Cooo]Z
0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003JoookJPSo0000oooonfX`oookJP003_oo
nfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Sooo]Z1Ol0003LoookJPOo0000oooo
nfX_oookJP003_oonfX3o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`gooo]Z1Ol0003N
oookJPOo0000oooonfX]oookJP003_oonfX3o`00O`Wooo]Z1?l007l<oookJPGo0000gooonfX8o`00
0?oooo]Z:ooonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX6o`000>3ooo]Z2?l0003ooookJRWo
oo]Z000>oookJP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003SoookJPOo0000oooonfXXoookJP003_oo
nfX3o`00O`gooo]Z0ol007l9oookJPGo0000i?oonfX8o`000?oooo]Z9_oonfX000kooo]Z0ol007l>
oookJP?o001o2?oonfX5o`000>Oooo]Z1ol0003ooookJRCooo]Z000>oookJP?o001o2?oonfX3o`00
O`?ooo]Z0ol007l8oookJPGo0000j?oonfX7o`000?oooo]Z8ooonfX000_ooo]Z1_l007l8oookJP?o
001o0ooonfX3o`00O`Sooo]Z1Ol0003YoookJPSo0000oooonfXQoookJP002ooonfX6o`00O`Sooo]Z
1?l007l2oookJP?o001o2?oonfX5o`000>cooo]Z1ol0003ooookJQoooo]Z000=oookJPCo001o2Ooo
nfX7o`00O`Wooo]Z1Ol0003]oookJPOo0000oooonfXNoookJP003_oonfX3o`00O`[ooo]Z1Ol007l:
oookJPGo0000k_oonfX7o`000?oooo]Z7OoonfX002[ooo]Z1Ol0003aoookJPOo0000oooonfXJoook
JP00:_oonfX5o`000?;ooo]Z1ol0003ooookJQWooo]Z000ZoookJPGo0000looonfX7o`000?oooo]Z
6?oonfX002[ooo]Z1Ol0003doookJPWo0000oooonfXEoookJP00:_oonfX5o`000?Oooo]Z1ol0003o
oookJQCooo]Z000ZoookJPGo0000n?oonfX7o`000?oooo]Z4ooonfX002[ooo]Z1Ol0003joookJPOo
0000oooonfXAoookJP00:_oonfX5o`000?cooo]Z1ol0003ooookJPoooo]Z000ZoookJPGo0000oOoo
nfX7o`000?oooo]Z3_oonfX002[ooo]Z1Ol0003ooookJPOo0000oooonfX<oookJP00:_oonfX5o`00
0?oooo]Z0OoonfX7o`000?oooo]Z2ooonfX002[ooo]Z1Ol0003ooookJP?ooo]Z1ol0003ooookJPWo
oo]Z000ZoookJPGo0000oooonfX5oookJPOo0000oooonfX7oookJP00:_oonfX5o`000?oooo]Z1_oo
nfX7o`000?oooo]Z1_oonfX002[ooo]Z1Ol0003ooookJPOooo]Z2Ol0003ooookJP?ooo]Z000Zoook
JPGo0000oooonfX:oookJPOo0000oooonfX2oookJP00:_oonfX5o`000?oooo]Z2ooonfX7o`000?oo
oo]Z0OoonfX002[ooo]Z1Ol0003ooookJPcooo]Z1ol0003ooookJP00:_oonfX5o`000?oooo]Z3ooo
nfX7o`000?cooo]Z000ZoookJPGo0000oooonfX@oookJPOo0000nooonfX002[ooo]Z1Ol0003ooook
JQ7ooo]Z1ol0003joookJP00:_oonfX5o`000?oooo]Z4ooonfX7o`000?Sooo]Z000ZoookJPGo0000
oooonfXEoookJPOo0000m_oonfX002[ooo]Z1Ol0003ooookJQKooo]Z1ol0003eoookJP00:_oonfX5
o`000?oooo]Z6?oonfX7o`000??ooo]Z000ZoookJPGo0000oooonfXIoookJPOo0000l_oonfX002[o
oo]Z1Ol0003ooookJQ_ooo]Z2?l0003_oookJP00:_oonfX5o`000?oooo]Z7OoonfX7o`000>kooo]Z
000ZoookJPGo0000oooonfXNoookJPOo0000kOoonfX002[ooo]Z1Ol0003ooookJQoooo]Z1ol0003/
oookJP00:_oonfX5o`000?oooo]Z8_oonfX7o`000>Wooo]Z000ZoookJPGo0000oooonfXSoookJPOo
0000j?oonfX002[ooo]Z1Ol0003ooookJRCooo]Z1ol0003WoookJP00:_oonfX5o`000?oooo]Z9_oo
nfX7o`000>Gooo]Z000ZoookJPGo0000oooonfXXoookJPOo0000hooonfX002[ooo]Z1Ol0003ooook
JRWooo]Z1ol0003RoookJP00:_oonfX5o`000?oooo]Z:ooonfX7o`000>3ooo]Z000ZoookJPGo0000
oooonfX/oookJPOo0000gooonfX002[ooo]Z1Ol0003ooookJRkooo]Z1ol0003MoookJP00:_oonfX5
o`000?oooo]Z<?oonfX7o`000=_ooo]Z000ZoookJPGo0000oooonfXaoookJPOo0000f_oonfX002[o
oo]Z1Ol0003ooookJS;ooo]Z1ol0003IoookJP00:_oonfX5o`000?oooo]Z=OoonfX6o`000=Oooo]Z
000ZoookJPGo0000oooonfXfoookJPOo0000eOoonfX002[ooo]Z1Ol0003ooookJSOooo]Z1ol0003D
oookJP00:_oonfX5o`000?oooo]Z>OoonfX7o`000=;ooo]Z000ZoookJPGo0000oooonfXjoookJPOo
0000dOoonfX002[ooo]Z1Ol0003ooookJScooo]Z1ol0003?oookJP00:_oonfX5o`000?oooo]Z?_oo
nfX7o`000<gooo]Z000ZoookJPGo0000oooonfXooookJPOo0000c?oonfX000kooo]Z0ol007l4oook
JP?o001o0ooonfX5o`00O`[ooo]Z1Ol0003ooookJT3ooo]Z1ol0003;oookJP003_oonfX3o`00O`Co
oo]Z0ol007l2oookJPOo001o2OoonfX5o`000?oooo]Z@ooonfX5o`000<[ooo]Z000>oookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l8oookJPGo0000oooonfY4oookJPOo
0000aooonfX000kooo]Z0ol007l8oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0003ooookJTGooo]Z
1ol00036oookJP003_oonfX3o`00O`kooo]Z0ol007l8oookJPKo0000oooonfY5oookJPSo0000a?oo
nfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZB?oonfX7o`000<?ooo]Z000>oook
JP?o001o3?oonfX4o`00O`Wooo]Z1Ol0003ooookJT[ooo]Z1_l00032oookJP003_oonfX3o`00O`co
oo]Z0ol007l:oookJPGo0000oooonfY<oookJPOo0000_ooonfX000kooo]Z0ol007l>oookJP;o001o
2OoonfX5o`000?oooo]ZCOoonfX7o`000;kooo]Z000;oookJPKo001o2?oonfX3o`00O`?ooo]Z0ol0
07l8oookJPGo0000oooonfY>oookJPOo0000_OoonfX000_ooo]Z1_l007l8oookJP?o001o0ooonfX3
o`00O`Sooo]Z1Ol0003ooookJToooo]Z1ol0002loookJP003OoonfX4o`00O`Wooo]Z1ol007l9oook
JPGo0000oooonfYBoookJPKo0000^_oonfX000kooo]Z0ol007l:oookJPGo001o2_oonfX5o`000?oo
oo]ZDooonfX7o`000;Sooo]Z000ZoookJPGo0000oooonfYDoookJPOo0000]ooonfX002[ooo]Z1Ol0
003ooookJUKooo]Z1ol0002eoookJP00:_oonfX5o`000?oooo]ZEooonfX7o`000;Cooo]Z000Zoook
JPGo0000oooonfYIoookJPKo0000/ooonfX002[ooo]Z1Ol0003ooookJU_ooo]Z1ol0002`oookJP00
:_oonfX5o`000?oooo]ZG?oonfX7o`000:oooo]Z000ZoookJPGo0000oooonfYMoookJPOo0000[_oo
nfX002[ooo]Z1Ol0003ooookJUoooo]Z1ol0002/oookJP00:_oonfX5o`000?oooo]ZHOoonfX6o`00
0:_ooo]Z000ZoookJPGo0000oooonfYRoookJPOo0000ZOoonfX002[ooo]Z1Ol0003ooookJVCooo]Z
1ol0002WoookJP00:_oonfX5o`000?oooo]ZIOoonfX7o`000:Kooo]Z000ZoookJPGo0000oooonfYV
oookJPOo0000YOoonfX002[ooo]Z1Ol0003ooookJVWooo]Z1Ol0002ToookJP00:_oonfX5o`000?oo
oo]ZJ_oonfX6o`000:;ooo]Z000ZoookJPGo0000oooonfY[oookJPOo0000X?oonfX002[ooo]Z1Ol0
003ooookJVcooo]Z2?l0002NoookJP00:_oonfX5o`000?oooo]ZK_oonfX7o`0009gooo]Z000Zoook
JPGo0000oooonfY_oookJPOo0000W?oonfX002[ooo]Z1Ol0003ooookJW;ooo]Z1Ol0002KoookJP00
:_oonfX5o`000?oooo]ZLooonfX6o`0009Wooo]Z000ZoookJPGo0000oooonfYdoookJPOo0000Uooo
nfX002[ooo]Z1Ol0003ooookJWGooo]Z1ol0002FoookJP00:_oonfX5o`000?oooo]ZMooonfX7o`00
09Cooo]Z000ZoookJPGo0000oooonfYhoookJPOo0000TooonfX002[ooo]Z1Ol0003ooookJW[ooo]Z
1_l0002BoookJP00:_oonfX5o`000?oooo]ZO?oonfX5o`00097ooo]Z000ZoookJPGo0000oooonfYm
oookJPOo0000S_oonfX002[ooo]Z1Ol0003ooookJWkooo]Z1ol0002=oookJP00:_oonfX5o`000?oo
oo]ZOooonfX8o`0008_ooo]Z000ZoookJPGo0000oooonfZ1oookJPOo0000R_oonfX002[ooo]Z1Ol0
003ooookJX?ooo]Z1_l00029oookJP00:_oonfX5o`000?oooo]ZQOoonfX5o`0008Sooo]Z000Zoook
JPGo0000oooonfZ6oookJPKo0000Q_oonfX002[ooo]Z1Ol0003ooookJXOooo]Z1ol00024oookJP00
:_oonfX5o`000?oooo]ZR?oonfX7o`0008?ooo]Z000ZoookJPGo0000oooonfZ:oookJPOo0000POoo
nfX002[ooo]Z1Ol0003ooookJX_ooo]Z1ol00020oookJP00:_oonfX5o`000?oooo]ZSOoonfX6o`00
07oooo]Z000ZoookJPGo0000oooonfZ?oookJPGo0000O_oonfX002[ooo]Z1Ol0003ooookJY3ooo]Z
1_l0001loookJP00:_oonfX5o`000?oooo]ZTOoonfX7o`0007[ooo]Z000ZoookJPGo0000oooonfZB
oookJPOo0000NOoonfX002[ooo]Z1Ol0003ooookJYCooo]Z1ol0001goookJP00:_oonfX5o`000?oo
oo]ZUOoonfX7o`0007Kooo]Z000ZoookJPGo0000oooonfZGoookJPKo0000MOoonfX002[ooo]Z1Ol0
003ooookJYWooo]Z1_l0001coookJP00:_oonfX5o`000?oooo]ZV_oonfX6o`0007;ooo]Z000Zoook
JPGo0000oooonfZKoookJPOo0000L?oonfX002[ooo]Z1Ol0003ooookJYgooo]Z1ol0001^oookJP00
:_oonfX5o`000?oooo]ZW_oonfX7o`0006gooo]Z000>oookJP?o001o1?oonfX3o`00O`Kooo]Z0ol0
07l9oookJPGo0000oooonfZOoookJPOo0000K?oonfX000kooo]Z0ol007l4oookJP?o001o1_oonfX3
o`00O`Wooo]Z1Ol0003ooookJZ;ooo]Z1Ol0001[oookJP003_oonfX3o`00O`Cooo]Z0ol007l6oook
JP?o001o2OoonfX5o`000?oooo]ZXooonfX6o`0006Wooo]Z000>oookJP?o001o2?oonfX9o`00O`So
oo]Z1Ol0003ooookJZCooo]Z1_l0001XoookJP003_oonfX3o`00O`Sooo]Z2Ol007l8oookJPKo0000
oooonfZToookJPKo0000IooonfX000kooo]Z0ol007l8oookJP;o001o0ooonfX3o`00O`Wooo]Z1Ol0
003ooookJZOooo]Z1ol0001ToookJP003_oonfX3o`00O`Wooo]Z0_l007l2oookJP?o001o2OoonfX5
o`000?oooo]ZZ?oonfX7o`0006?ooo]Z000>oookJP?o001o2OoonfX3o`00O`04oookJ_l007oo001o
o`00O`Wooo]Z1Ol0003ooookJZWooo]Z1ol0001RoookJP003_oonfX3o`00O`[ooo]Z0_l007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000oooonfZZoookJPSo0000H?oonfX000_ooo]Z1_l007l;oook
JPGo001o2OoonfX5o`000?oooo]Z[OoonfX6o`0005oooo]Z000;oookJPKo001o2ooonfX5o`00O`Wo
oo]Z1Ol0003ooookJZkooo]Z1_l0001NoookJP003OoonfX4o`00O`cooo]Z1?l007l9oookJPGo0000
oooonfZ`oookJPGo0000GOoonfX000kooo]Z0ol007l=oookJP?o001o2OoonfX5o`000?oooo]Z/Ooo
nfX6o`0005_ooo]Z000ZoookJPGo0000oooonfZboookJPKo0000F_oonfX002[ooo]Z1Ol0003ooook
J[?ooo]Z1ol0001HoookJP00:_oonfX5o`000?oooo]Z]OoonfX7o`0005Kooo]Z000ZoookJPGo0000
oooonfZfoookJPOo0000EOoonfX002[ooo]Z1Ol0003ooookJ[Oooo]Z1ol0001DoookJP00:_oonfX5
o`000?oooo]Z^_oonfX5o`0005?ooo]Z000ZoookJPGo0000oooonfZkoookJPKo0000DOoonfX002[o
oo]Z1Ol0003ooookJ[cooo]Z1_l0001@oookJP00:_oonfX5o`000?oooo]Z_OoonfX6o`0004oooo]Z
000ZoookJPGo0000oooonfZooookJPKo0000COoonfX002[ooo]Z1Ol0003ooookJ/3ooo]Z1_l0001<
oookJP00:_oonfX5o`000?oooo]Z`OoonfX7o`0004[ooo]Z000ZoookJPGo0000oooonf[3oookJPOo
0000B?oonfX002[ooo]Z1Ol0003ooookJ/Cooo]Z1ol00017oookJP00:_oonfX5o`000?oooo]ZaOoo
nfX7o`0004Kooo]Z000ZoookJPGo0000oooonf[8oookJPGo0000AOoonfX002[ooo]Z1Ol0003ooook
J/Wooo]Z1_l00013oookJP00:_oonfX5o`000?oooo]Zb_oonfX6o`0004;ooo]Z000ZoookJPGo0000
oooonf[;oookJPKo0000@OoonfX002[ooo]Z1Ol0003ooookJ/gooo]Z1Ol00010oookJP00:_oonfX5
o`000?oooo]Zc_oonfX6o`0003kooo]Z000ZoookJPGo0000oooonf[?oookJPKo0000?OoonfX002[o
oo]Z1Ol0003ooookJ]3ooo]Z2?l0000joookJP00:_oonfX5o`000?oooo]Zd_oonfX7o`0003Wooo]Z
000ZoookJPGo0000oooonf[CoookJPOo0000>?oonfX002[ooo]Z1Ol0003ooookJ]Cooo]Z1ol0000g
oookJP00:_oonfX5o`000?oooo]ZeooonfX6o`0003Gooo]Z000ZoookJPGo0000oooonf[HoookJPKo
0000=?oonfX002[ooo]Z1Ol0003ooookJ]Wooo]Z1_l0000coookJP00:_oonfX5o`000?oooo]Zfooo
nfX5o`0003;ooo]Z000ZoookJPGo0000oooonf[LoookJPKo0000<?oonfX002[ooo]Z1Ol0003ooook
J]gooo]Z1_l0000_oookJP00:_oonfX5o`000?oooo]Zg_oonfX6o`0002kooo]Z000ZoookJPGo0000
oooonf[PoookJPGo0000;OoonfX002[ooo]Z1Ol0003ooookJ^7ooo]Z1_l0000[oookJP00:_oonfX5
o`000?oooo]Zh_oonfX7o`0002Wooo]Z000ZoookJPGo0000oooonf[SoookJPOo0000:?oonfX002[o
oo]Z1Ol0003ooookJ^Gooo]Z1ol0000VoookJP00:_oonfX5o`000?oooo]Zi_oonfX7o`0002Gooo]Z
000ZoookJPGo0000oooonf[XoookJPKo00009?oonfX002[ooo]Z1Ol0003ooookJ^[ooo]Z1_l0000R
oookJP00:_oonfX5o`000?oooo]ZjooonfX6o`00027ooo]Z000ZoookJPGo0000oooonf[/oookJPKo
00008?oonfX002[ooo]Z1Ol0003ooookJ^kooo]Z1Ol0000OoookJP00:_oonfX5o`000?oooo]Zkooo
nfX6o`0001gooo]Z000ZoookJPGo0000oooonf[`oookJPKo00007?oonfX002[ooo]Z1Ol0003ooook
J_7ooo]Z1_l0000KoookJP00:_oonfX5o`000?oooo]ZlooonfX5o`0001[ooo]Z000ZoookJPGo0000
oooonf[doookJPKo00006?oonfX002[ooo]Z1Ol0003ooookJ_Gooo]Z1_l0000GoookJP003_oonfX3
o`00O`Cooo]Z0ol007l3oookJPGo001o2_oonfX5o`000?oooo]Zm_oonfX5o`0001Oooo]Z000>oook
JP?o001o1?oonfX3o`00O`;ooo]Z1ol007l9oookJPGo0000oooonf[hoookJP;o00006?oonfX000ko
oo]Z0ol007l4oookJP?o001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007l9oook
JPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2?oonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o3_oonfX3o`00O`Sooo]Z1_l0003ooookJ_oooo]Z
4_oonfX000kooo]Z0ol007l>oookJP?o001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3
o`00O`Wooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]ZoooonfXCoookJP003_oonfX3o`00
O`Wooo]Z1ol007l9oookJPGo0000oooonf[ooookJQ?ooo]Z000>oookJP?o001o2OoonfX6o`00O`[o
oo]Z1Ol0003ooookJ_oooo]Z4ooonfX000_ooo]Z1_l007l9oookJP;o001o3_oonfX5o`000?oooo]Z
oooonfXCoookJP002ooonfX6o`00O`Wooo]Z0_l007oooookJ_oooo]Z9_oonfX000gooo]Z1?l007l:
oookJPOo001ooooonf[ooookJR3ooo]Z000>oookJP?o001o2_oonfX7o`00Oooooo]ZoooonfXPoook
JP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.3518, 0.958149, \
0.00790084, 0.0015709}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(DisplayLater\  = \ 
        DisplayFunction \[Rule] Identity;\)\), "\[IndentingNewLine]", 
    \(\(DisplayNow\  = \ 
        DisplayFunction \[Rule] $DisplayFunction;\)\)}], "Input",
  CellTags->"mmtag:19:DisplayNow_DisplayLater__example"],

Cell[BoxData[
    \(\(lp[i_]\  := 
        ListPlot[NestList[StepOnce[#, exampleFunction, 0.01] &, {0, i}, 400], 
          DisplayLater];\)\)], "Input"],

Cell["\<\
This will plot a family of related curves, each for a different \
starting value of the iterated function:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[Table[lp[i], {i, \(-4\), 4,  .5}], DisplayNow]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309017 0.049329 [
[.2619 .29652 -7 -20 ]
[.2619 .29652 7 0 ]
[.5 .29652 -7 -20 ]
[.5 .29652 7 0 ]
[.7381 .29652 -7 -20 ]
[.7381 .29652 7 0 ]
[.97619 .29652 -7 -20 ]
[.97619 .29652 7 0 ]
[.01131 .01304 -26.9375 -10 ]
[.01131 .01304 0 10 ]
[.01131 .1117 -26.9375 -10 ]
[.01131 .1117 0 10 ]
[.01131 .21036 -26.9375 -10 ]
[.01131 .21036 0 10 ]
[.01131 .40767 -14 -10 ]
[.01131 .40767 0 10 ]
[.01131 .50633 -14 -10 ]
[.01131 .50633 0 10 ]
[.01131 .60499 -14 -10 ]
[.01131 .60499 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30902 m
.2619 .31527 L
s
gsave
.2619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .30902 m
.5 .31527 L
s
gsave
.5 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.7381 .30902 m
.7381 .31527 L
s
gsave
.7381 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.01 w
0 .30902 m
1 .30902 L
s
.25 Mabswid
.02381 .01304 m
.03006 .01304 L
s
gsave
.01131 .01304 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.02381 .1117 m
.03006 .1117 L
s
gsave
.01131 .1117 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .21036 m
.03006 .21036 L
s
gsave
.01131 .21036 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .40767 m
.03006 .40767 L
s
gsave
.01131 .40767 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .50633 m
.03006 .50633 L
s
gsave
.01131 .50633 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .60499 m
.03006 .60499 L
s
gsave
.01131 .60499 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03771 m
.02756 .03771 L
s
.02381 .06237 m
.02756 .06237 L
s
.02381 .08704 m
.02756 .08704 L
s
.02381 .13637 m
.02756 .13637 L
s
.02381 .16103 m
.02756 .16103 L
s
.02381 .18569 m
.02756 .18569 L
s
.02381 .23502 m
.02756 .23502 L
s
.02381 .25969 m
.02756 .25969 L
s
.02381 .28435 m
.02756 .28435 L
s
.02381 .33368 m
.02756 .33368 L
s
.02381 .35835 m
.02756 .35835 L
s
.02381 .38301 m
.02756 .38301 L
s
.02381 .43234 m
.02756 .43234 L
s
.02381 .457 m
.02756 .457 L
s
.02381 .48167 m
.02756 .48167 L
s
.02381 .531 m
.02756 .531 L
s
.02381 .55566 m
.02756 .55566 L
s
.02381 .58033 m
.02756 .58033 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .1117 Mdot
.02619 .1115 Mdot
.02857 .11131 Mdot
.03095 .11111 Mdot
.03333 .11091 Mdot
.03571 .11071 Mdot
.0381 .11051 Mdot
.04048 .11032 Mdot
.04286 .11012 Mdot
.04524 .10992 Mdot
.04762 .10972 Mdot
.05 .10952 Mdot
.05238 .10932 Mdot
.05476 .10912 Mdot
.05714 .10892 Mdot
.05952 .10872 Mdot
.0619 .10852 Mdot
.06429 .10832 Mdot
.06667 .10812 Mdot
.06905 .10792 Mdot
.07143 .10772 Mdot
.07381 .10752 Mdot
.07619 .10731 Mdot
.07857 .10711 Mdot
.08095 .10691 Mdot
.08333 .10671 Mdot
.08571 .10651 Mdot
.0881 .1063 Mdot
.09048 .1061 Mdot
.09286 .1059 Mdot
.09524 .10569 Mdot
.09762 .10549 Mdot
.1 .10529 Mdot
.10238 .10508 Mdot
.10476 .10488 Mdot
.10714 .10468 Mdot
.10952 .10447 Mdot
.1119 .10427 Mdot
.11429 .10406 Mdot
.11667 .10386 Mdot
.11905 .10365 Mdot
.12143 .10345 Mdot
.12381 .10324 Mdot
.12619 .10304 Mdot
.12857 .10283 Mdot
.13095 .10262 Mdot
.13333 .10242 Mdot
.13571 .10221 Mdot
.1381 .102 Mdot
.14048 .1018 Mdot
.14286 .10159 Mdot
.14524 .10138 Mdot
.14762 .10117 Mdot
.15 .10097 Mdot
.15238 .10076 Mdot
.15476 .10055 Mdot
.15714 .10034 Mdot
.15952 .10013 Mdot
.1619 .09992 Mdot
.16429 .09972 Mdot
.16667 .09951 Mdot
.16905 .0993 Mdot
.17143 .09909 Mdot
.17381 .09888 Mdot
.17619 .09867 Mdot
.17857 .09846 Mdot
.18095 .09825 Mdot
.18333 .09804 Mdot
.18571 .09782 Mdot
.1881 .09761 Mdot
.19048 .0974 Mdot
.19286 .09719 Mdot
.19524 .09698 Mdot
.19762 .09677 Mdot
.2 .09655 Mdot
.20238 .09634 Mdot
.20476 .09613 Mdot
.20714 .09592 Mdot
.20952 .0957 Mdot
.2119 .09549 Mdot
.21429 .09528 Mdot
.21667 .09506 Mdot
.21905 .09485 Mdot
.22143 .09463 Mdot
.22381 .09442 Mdot
.22619 .0942 Mdot
.22857 .09399 Mdot
.23095 .09378 Mdot
.23333 .09356 Mdot
.23571 .09334 Mdot
.2381 .09313 Mdot
.24048 .09291 Mdot
.24286 .0927 Mdot
.24524 .09248 Mdot
.24762 .09226 Mdot
.25 .09205 Mdot
.25238 .09183 Mdot
.25476 .09161 Mdot
.25714 .0914 Mdot
.25952 .09118 Mdot
.2619 .09096 Mdot
.26429 .09074 Mdot
.26667 .09052 Mdot
.26905 .09031 Mdot
.27143 .09009 Mdot
.27381 .08987 Mdot
.27619 .08965 Mdot
.27857 .08943 Mdot
.28095 .08921 Mdot
.28333 .08899 Mdot
.28571 .08877 Mdot
.2881 .08855 Mdot
.29048 .08833 Mdot
.29286 .08811 Mdot
.29524 .08789 Mdot
.29762 .08767 Mdot
.3 .08744 Mdot
.30238 .08722 Mdot
.30476 .087 Mdot
.30714 .08678 Mdot
.30952 .08656 Mdot
.3119 .08633 Mdot
.31429 .08611 Mdot
.31667 .08589 Mdot
.31905 .08567 Mdot
.32143 .08544 Mdot
.32381 .08522 Mdot
.32619 .085 Mdot
.32857 .08477 Mdot
.33095 .08455 Mdot
.33333 .08432 Mdot
.33571 .0841 Mdot
.3381 .08387 Mdot
.34048 .08365 Mdot
.34286 .08342 Mdot
.34524 .0832 Mdot
.34762 .08297 Mdot
.35 .08275 Mdot
.35238 .08252 Mdot
.35476 .08229 Mdot
.35714 .08207 Mdot
.35952 .08184 Mdot
.3619 .08161 Mdot
.36429 .08138 Mdot
.36667 .08116 Mdot
.36905 .08093 Mdot
.37143 .0807 Mdot
.37381 .08047 Mdot
.37619 .08024 Mdot
.37857 .08001 Mdot
.38095 .07979 Mdot
.38333 .07956 Mdot
.38571 .07933 Mdot
.3881 .0791 Mdot
.39048 .07887 Mdot
.39286 .07864 Mdot
.39524 .07841 Mdot
.39762 .07818 Mdot
.4 .07795 Mdot
.40238 .07771 Mdot
.40476 .07748 Mdot
.40714 .07725 Mdot
.40952 .07702 Mdot
.4119 .07679 Mdot
.41429 .07656 Mdot
.41667 .07632 Mdot
.41905 .07609 Mdot
.42143 .07586 Mdot
.42381 .07562 Mdot
.42619 .07539 Mdot
.42857 .07516 Mdot
.43095 .07492 Mdot
.43333 .07469 Mdot
.43571 .07446 Mdot
.4381 .07422 Mdot
.44048 .07399 Mdot
.44286 .07375 Mdot
.44524 .07352 Mdot
.44762 .07328 Mdot
.45 .07304 Mdot
.45238 .07281 Mdot
.45476 .07257 Mdot
.45714 .07234 Mdot
.45952 .0721 Mdot
.4619 .07186 Mdot
.46429 .07162 Mdot
.46667 .07139 Mdot
.46905 .07115 Mdot
.47143 .07091 Mdot
.47381 .07067 Mdot
.47619 .07044 Mdot
.47857 .0702 Mdot
.48095 .06996 Mdot
.48333 .06972 Mdot
.48571 .06948 Mdot
.4881 .06924 Mdot
.49048 .069 Mdot
.49286 .06876 Mdot
.49524 .06852 Mdot
.49762 .06828 Mdot
.5 .06804 Mdot
.50238 .0678 Mdot
.50476 .06756 Mdot
.50714 .06732 Mdot
.50952 .06707 Mdot
.5119 .06683 Mdot
.51429 .06659 Mdot
.51667 .06635 Mdot
.51905 .0661 Mdot
.52143 .06586 Mdot
.52381 .06562 Mdot
.52619 .06537 Mdot
.52857 .06513 Mdot
.53095 .06489 Mdot
.53333 .06464 Mdot
.53571 .0644 Mdot
.5381 .06415 Mdot
.54048 .06391 Mdot
.54286 .06366 Mdot
.54524 .06342 Mdot
.54762 .06317 Mdot
.55 .06293 Mdot
.55238 .06268 Mdot
.55476 .06244 Mdot
.55714 .06219 Mdot
.55952 .06194 Mdot
.5619 .06169 Mdot
.56429 .06145 Mdot
.56667 .0612 Mdot
.56905 .06095 Mdot
.57143 .0607 Mdot
.57381 .06046 Mdot
.57619 .06021 Mdot
.57857 .05996 Mdot
.58095 .05971 Mdot
.58333 .05946 Mdot
.58571 .05921 Mdot
.5881 .05896 Mdot
.59048 .05871 Mdot
.59286 .05846 Mdot
.59524 .05821 Mdot
.59762 .05796 Mdot
.6 .05771 Mdot
.60238 .05746 Mdot
.60476 .0572 Mdot
.60714 .05695 Mdot
.60952 .0567 Mdot
.6119 .05645 Mdot
.61429 .0562 Mdot
.61667 .05594 Mdot
.61905 .05569 Mdot
.62143 .05544 Mdot
.62381 .05518 Mdot
.62619 .05493 Mdot
.62857 .05468 Mdot
.63095 .05442 Mdot
.63333 .05417 Mdot
.63571 .05391 Mdot
.6381 .05366 Mdot
.64048 .0534 Mdot
.64286 .05315 Mdot
.64524 .05289 Mdot
.64762 .05263 Mdot
.65 .05238 Mdot
.65238 .05212 Mdot
.65476 .05186 Mdot
.65714 .05161 Mdot
.65952 .05135 Mdot
.6619 .05109 Mdot
.66429 .05083 Mdot
.66667 .05058 Mdot
.66905 .05032 Mdot
.67143 .05006 Mdot
.67381 .0498 Mdot
.67619 .04954 Mdot
.67857 .04928 Mdot
.68095 .04902 Mdot
.68333 .04876 Mdot
.68571 .0485 Mdot
.6881 .04824 Mdot
.69048 .04798 Mdot
.69286 .04772 Mdot
.69524 .04746 Mdot
.69762 .0472 Mdot
.7 .04693 Mdot
.70238 .04667 Mdot
.70476 .04641 Mdot
.70714 .04615 Mdot
.70952 .04588 Mdot
.7119 .04562 Mdot
.71429 .04536 Mdot
.71667 .04509 Mdot
.71905 .04483 Mdot
.72143 .04457 Mdot
.72381 .0443 Mdot
.72619 .04404 Mdot
.72857 .04377 Mdot
.73095 .04351 Mdot
.73333 .04324 Mdot
.73571 .04297 Mdot
.7381 .04271 Mdot
.74048 .04244 Mdot
.74286 .04218 Mdot
.74524 .04191 Mdot
.74762 .04164 Mdot
.75 .04137 Mdot
.75238 .04111 Mdot
.75476 .04084 Mdot
.75714 .04057 Mdot
.75952 .0403 Mdot
.7619 .04003 Mdot
.76429 .03976 Mdot
.76667 .03949 Mdot
.76905 .03923 Mdot
.77143 .03896 Mdot
.77381 .03869 Mdot
.77619 .03842 Mdot
.77857 .03814 Mdot
.78095 .03787 Mdot
.78333 .0376 Mdot
.78571 .03733 Mdot
.7881 .03706 Mdot
.79048 .03679 Mdot
.79286 .03652 Mdot
.79524 .03624 Mdot
.79762 .03597 Mdot
.8 .0357 Mdot
.80238 .03542 Mdot
.80476 .03515 Mdot
.80714 .03488 Mdot
.80952 .0346 Mdot
.8119 .03433 Mdot
.81429 .03405 Mdot
.81667 .03378 Mdot
.81905 .0335 Mdot
.82143 .03323 Mdot
.82381 .03295 Mdot
.82619 .03268 Mdot
.82857 .0324 Mdot
.83095 .03212 Mdot
.83333 .03185 Mdot
.83571 .03157 Mdot
.8381 .03129 Mdot
.84048 .03101 Mdot
.84286 .03074 Mdot
.84524 .03046 Mdot
.84762 .03018 Mdot
.85 .0299 Mdot
.85238 .02962 Mdot
.85476 .02934 Mdot
.85714 .02906 Mdot
.85952 .02878 Mdot
.8619 .0285 Mdot
.86429 .02822 Mdot
.86667 .02794 Mdot
.86905 .02766 Mdot
.87143 .02738 Mdot
.87381 .0271 Mdot
.87619 .02681 Mdot
.87857 .02653 Mdot
.88095 .02625 Mdot
.88333 .02597 Mdot
.88571 .02568 Mdot
.8881 .0254 Mdot
.89048 .02512 Mdot
.89286 .02483 Mdot
.89524 .02455 Mdot
.89762 .02426 Mdot
.9 .02398 Mdot
.90238 .02369 Mdot
.90476 .02341 Mdot
.90714 .02312 Mdot
.90952 .02284 Mdot
.9119 .02255 Mdot
.91429 .02226 Mdot
.91667 .02198 Mdot
.91905 .02169 Mdot
.92143 .0214 Mdot
.92381 .02112 Mdot
.92619 .02083 Mdot
.92857 .02054 Mdot
.93095 .02025 Mdot
.93333 .01996 Mdot
.93571 .01967 Mdot
.9381 .01938 Mdot
.94048 .01909 Mdot
.94286 .0188 Mdot
.94524 .01851 Mdot
.94762 .01822 Mdot
.95 .01793 Mdot
.95238 .01764 Mdot
.95476 .01735 Mdot
.95714 .01706 Mdot
.95952 .01677 Mdot
.9619 .01647 Mdot
.96429 .01618 Mdot
.96667 .01589 Mdot
.96905 .0156 Mdot
.97143 .0153 Mdot
.97381 .01501 Mdot
.97619 .01472 Mdot
.02381 .13637 Mdot
.02619 .13619 Mdot
.02857 .13602 Mdot
.03095 .13585 Mdot
.03333 .13567 Mdot
.03571 .1355 Mdot
.0381 .13533 Mdot
.04048 .13515 Mdot
.04286 .13498 Mdot
.04524 .13481 Mdot
.04762 .13463 Mdot
.05 .13446 Mdot
.05238 .13428 Mdot
.05476 .13411 Mdot
.05714 .13393 Mdot
.05952 .13376 Mdot
.0619 .13358 Mdot
.06429 .13341 Mdot
.06667 .13323 Mdot
.06905 .13306 Mdot
.07143 .13288 Mdot
.07381 .1327 Mdot
.07619 .13253 Mdot
.07857 .13235 Mdot
.08095 .13217 Mdot
.08333 .132 Mdot
.08571 .13182 Mdot
.0881 .13164 Mdot
.09048 .13147 Mdot
.09286 .13129 Mdot
.09524 .13111 Mdot
.09762 .13093 Mdot
.1 .13075 Mdot
.10238 .13058 Mdot
.10476 .1304 Mdot
.10714 .13022 Mdot
.10952 .13004 Mdot
.1119 .12986 Mdot
.11429 .12968 Mdot
.11667 .1295 Mdot
.11905 .12932 Mdot
.12143 .12914 Mdot
.12381 .12896 Mdot
.12619 .12878 Mdot
.12857 .1286 Mdot
.13095 .12842 Mdot
.13333 .12824 Mdot
.13571 .12806 Mdot
.1381 .12788 Mdot
.14048 .1277 Mdot
.14286 .12752 Mdot
.14524 .12734 Mdot
.14762 .12715 Mdot
.15 .12697 Mdot
.15238 .12679 Mdot
.15476 .12661 Mdot
.15714 .12643 Mdot
.15952 .12624 Mdot
.1619 .12606 Mdot
.16429 .12588 Mdot
.16667 .12569 Mdot
.16905 .12551 Mdot
.17143 .12533 Mdot
.17381 .12514 Mdot
.17619 .12496 Mdot
.17857 .12478 Mdot
.18095 .12459 Mdot
.18333 .12441 Mdot
.18571 .12422 Mdot
.1881 .12404 Mdot
.19048 .12385 Mdot
.19286 .12367 Mdot
.19524 .12348 Mdot
.19762 .1233 Mdot
.2 .12311 Mdot
.20238 .12293 Mdot
.20476 .12274 Mdot
.20714 .12255 Mdot
.20952 .12237 Mdot
.2119 .12218 Mdot
.21429 .12199 Mdot
.21667 .12181 Mdot
.21905 .12162 Mdot
.22143 .12143 Mdot
.22381 .12124 Mdot
.22619 .12106 Mdot
.22857 .12087 Mdot
.23095 .12068 Mdot
.23333 .12049 Mdot
.23571 .1203 Mdot
.2381 .12011 Mdot
.24048 .11993 Mdot
.24286 .11974 Mdot
.24524 .11955 Mdot
.24762 .11936 Mdot
.25 .11917 Mdot
.25238 .11898 Mdot
.25476 .11879 Mdot
.25714 .1186 Mdot
.25952 .11841 Mdot
.2619 .11822 Mdot
.26429 .11803 Mdot
.26667 .11784 Mdot
.26905 .11764 Mdot
.27143 .11745 Mdot
.27381 .11726 Mdot
.27619 .11707 Mdot
.27857 .11688 Mdot
.28095 .11669 Mdot
.28333 .11649 Mdot
.28571 .1163 Mdot
.2881 .11611 Mdot
.29048 .11591 Mdot
.29286 .11572 Mdot
.29524 .11553 Mdot
.29762 .11534 Mdot
.3 .11514 Mdot
.30238 .11495 Mdot
.30476 .11475 Mdot
.30714 .11456 Mdot
.30952 .11436 Mdot
.3119 .11417 Mdot
.31429 .11398 Mdot
.31667 .11378 Mdot
.31905 .11358 Mdot
.32143 .11339 Mdot
.32381 .11319 Mdot
.32619 .113 Mdot
.32857 .1128 Mdot
.33095 .11261 Mdot
.33333 .11241 Mdot
.33571 .11221 Mdot
.3381 .11202 Mdot
.34048 .11182 Mdot
.34286 .11162 Mdot
.34524 .11142 Mdot
.34762 .11123 Mdot
.35 .11103 Mdot
.35238 .11083 Mdot
.35476 .11063 Mdot
.35714 .11043 Mdot
.35952 .11024 Mdot
.3619 .11004 Mdot
.36429 .10984 Mdot
.36667 .10964 Mdot
.36905 .10944 Mdot
.37143 .10924 Mdot
.37381 .10904 Mdot
.37619 .10884 Mdot
.37857 .10864 Mdot
.38095 .10844 Mdot
.38333 .10824 Mdot
.38571 .10804 Mdot
.3881 .10784 Mdot
.39048 .10764 Mdot
.39286 .10743 Mdot
.39524 .10723 Mdot
.39762 .10703 Mdot
.4 .10683 Mdot
.40238 .10663 Mdot
.40476 .10642 Mdot
.40714 .10622 Mdot
.40952 .10602 Mdot
.4119 .10582 Mdot
.41429 .10561 Mdot
.41667 .10541 Mdot
.41905 .10521 Mdot
.42143 .105 Mdot
.42381 .1048 Mdot
.42619 .10459 Mdot
.42857 .10439 Mdot
.43095 .10419 Mdot
.43333 .10398 Mdot
.43571 .10378 Mdot
.4381 .10357 Mdot
.44048 .10336 Mdot
.44286 .10316 Mdot
.44524 .10295 Mdot
.44762 .10275 Mdot
.45 .10254 Mdot
.45238 .10233 Mdot
.45476 .10213 Mdot
.45714 .10192 Mdot
.45952 .10171 Mdot
.4619 .10151 Mdot
.46429 .1013 Mdot
.46667 .10109 Mdot
.46905 .10088 Mdot
.47143 .10068 Mdot
.47381 .10047 Mdot
.47619 .10026 Mdot
.47857 .10005 Mdot
.48095 .09984 Mdot
.48333 .09963 Mdot
.48571 .09942 Mdot
.4881 .09921 Mdot
.49048 .099 Mdot
.49286 .09879 Mdot
.49524 .09858 Mdot
.49762 .09837 Mdot
.5 .09816 Mdot
.50238 .09795 Mdot
.50476 .09774 Mdot
.50714 .09753 Mdot
.50952 .09732 Mdot
.5119 .0971 Mdot
.51429 .09689 Mdot
.51667 .09668 Mdot
.51905 .09647 Mdot
.52143 .09626 Mdot
.52381 .09604 Mdot
.52619 .09583 Mdot
.52857 .09562 Mdot
.53095 .0954 Mdot
.53333 .09519 Mdot
.53571 .09498 Mdot
.5381 .09476 Mdot
.54048 .09455 Mdot
.54286 .09433 Mdot
.54524 .09412 Mdot
.54762 .0939 Mdot
.55 .09369 Mdot
.55238 .09347 Mdot
.55476 .09326 Mdot
.55714 .09304 Mdot
.55952 .09283 Mdot
.5619 .09261 Mdot
.56429 .09239 Mdot
.56667 .09218 Mdot
.56905 .09196 Mdot
.57143 .09174 Mdot
.57381 .09153 Mdot
.57619 .09131 Mdot
.57857 .09109 Mdot
.58095 .09087 Mdot
.58333 .09065 Mdot
.58571 .09044 Mdot
.5881 .09022 Mdot
.59048 .09 Mdot
.59286 .08978 Mdot
.59524 .08956 Mdot
.59762 .08934 Mdot
.6 .08912 Mdot
.60238 .0889 Mdot
.60476 .08868 Mdot
.60714 .08846 Mdot
.60952 .08824 Mdot
.6119 .08802 Mdot
.61429 .0878 Mdot
.61667 .08758 Mdot
.61905 .08736 Mdot
.62143 .08713 Mdot
.62381 .08691 Mdot
.62619 .08669 Mdot
.62857 .08647 Mdot
.63095 .08625 Mdot
.63333 .08602 Mdot
.63571 .0858 Mdot
.6381 .08558 Mdot
.64048 .08535 Mdot
.64286 .08513 Mdot
.64524 .08491 Mdot
.64762 .08468 Mdot
.65 .08446 Mdot
.65238 .08423 Mdot
.65476 .08401 Mdot
.65714 .08378 Mdot
.65952 .08356 Mdot
.6619 .08333 Mdot
.66429 .08311 Mdot
.66667 .08288 Mdot
.66905 .08265 Mdot
.67143 .08243 Mdot
.67381 .0822 Mdot
.67619 .08197 Mdot
.67857 .08175 Mdot
.68095 .08152 Mdot
.68333 .08129 Mdot
.68571 .08106 Mdot
.6881 .08084 Mdot
.69048 .08061 Mdot
.69286 .08038 Mdot
.69524 .08015 Mdot
.69762 .07992 Mdot
.7 .07969 Mdot
.70238 .07946 Mdot
.70476 .07923 Mdot
.70714 .07901 Mdot
.70952 .07878 Mdot
.7119 .07854 Mdot
.71429 .07831 Mdot
.71667 .07808 Mdot
.71905 .07785 Mdot
.72143 .07762 Mdot
.72381 .07739 Mdot
.72619 .07716 Mdot
.72857 .07693 Mdot
.73095 .07669 Mdot
.73333 .07646 Mdot
.73571 .07623 Mdot
.7381 .076 Mdot
.74048 .07576 Mdot
.74286 .07553 Mdot
.74524 .0753 Mdot
.74762 .07506 Mdot
.75 .07483 Mdot
.75238 .0746 Mdot
.75476 .07436 Mdot
.75714 .07413 Mdot
.75952 .07389 Mdot
.7619 .07366 Mdot
.76429 .07342 Mdot
.76667 .07319 Mdot
.76905 .07295 Mdot
.77143 .07271 Mdot
.77381 .07248 Mdot
.77619 .07224 Mdot
.77857 .072 Mdot
.78095 .07177 Mdot
.78333 .07153 Mdot
.78571 .07129 Mdot
.7881 .07105 Mdot
.79048 .07082 Mdot
.79286 .07058 Mdot
.79524 .07034 Mdot
.79762 .0701 Mdot
.8 .06986 Mdot
.80238 .06962 Mdot
.80476 .06938 Mdot
.80714 .06914 Mdot
.80952 .0689 Mdot
.8119 .06866 Mdot
.81429 .06842 Mdot
.81667 .06818 Mdot
.81905 .06794 Mdot
.82143 .0677 Mdot
.82381 .06746 Mdot
.82619 .06722 Mdot
.82857 .06698 Mdot
.83095 .06673 Mdot
.83333 .06649 Mdot
.83571 .06625 Mdot
.8381 .06601 Mdot
.84048 .06576 Mdot
.84286 .06552 Mdot
.84524 .06528 Mdot
.84762 .06503 Mdot
.85 .06479 Mdot
.85238 .06455 Mdot
.85476 .0643 Mdot
.85714 .06406 Mdot
.85952 .06381 Mdot
.8619 .06357 Mdot
.86429 .06332 Mdot
.86667 .06307 Mdot
.86905 .06283 Mdot
.87143 .06258 Mdot
.87381 .06234 Mdot
.87619 .06209 Mdot
.87857 .06184 Mdot
.88095 .0616 Mdot
.88333 .06135 Mdot
.88571 .0611 Mdot
.8881 .06085 Mdot
.89048 .0606 Mdot
.89286 .06036 Mdot
.89524 .06011 Mdot
.89762 .05986 Mdot
.9 .05961 Mdot
.90238 .05936 Mdot
.90476 .05911 Mdot
.90714 .05886 Mdot
.90952 .05861 Mdot
.9119 .05836 Mdot
.91429 .05811 Mdot
.91667 .05786 Mdot
.91905 .05761 Mdot
.92143 .05736 Mdot
.92381 .0571 Mdot
.92619 .05685 Mdot
.92857 .0566 Mdot
.93095 .05635 Mdot
.93333 .05609 Mdot
.93571 .05584 Mdot
.9381 .05559 Mdot
.94048 .05533 Mdot
.94286 .05508 Mdot
.94524 .05483 Mdot
.94762 .05457 Mdot
.95 .05432 Mdot
.95238 .05406 Mdot
.95476 .05381 Mdot
.95714 .05355 Mdot
.95952 .0533 Mdot
.9619 .05304 Mdot
.96429 .05279 Mdot
.96667 .05253 Mdot
.96905 .05227 Mdot
.97143 .05202 Mdot
.97381 .05176 Mdot
.97619 .0515 Mdot
.02381 .16103 Mdot
.02619 .16088 Mdot
.02857 .16073 Mdot
.03095 .16059 Mdot
.03333 .16044 Mdot
.03571 .16029 Mdot
.0381 .16014 Mdot
.04048 .15999 Mdot
.04286 .15984 Mdot
.04524 .15969 Mdot
.04762 .15954 Mdot
.05 .15939 Mdot
.05238 .15924 Mdot
.05476 .15909 Mdot
.05714 .15894 Mdot
.05952 .15879 Mdot
.0619 .15864 Mdot
.06429 .15849 Mdot
.06667 .15834 Mdot
.06905 .15819 Mdot
.07143 .15804 Mdot
.07381 .15789 Mdot
.07619 .15774 Mdot
.07857 .15759 Mdot
.08095 .15744 Mdot
.08333 .15729 Mdot
.08571 .15713 Mdot
.0881 .15698 Mdot
.09048 .15683 Mdot
.09286 .15668 Mdot
.09524 .15653 Mdot
.09762 .15637 Mdot
.1 .15622 Mdot
.10238 .15607 Mdot
.10476 .15591 Mdot
.10714 .15576 Mdot
.10952 .15561 Mdot
.1119 .15545 Mdot
.11429 .1553 Mdot
.11667 .15515 Mdot
.11905 .15499 Mdot
.12143 .15484 Mdot
.12381 .15469 Mdot
.12619 .15453 Mdot
.12857 .15438 Mdot
.13095 .15422 Mdot
.13333 .15407 Mdot
.13571 .15391 Mdot
.1381 .15376 Mdot
.14048 .1536 Mdot
.14286 .15345 Mdot
.14524 .15329 Mdot
.14762 .15314 Mdot
.15 .15298 Mdot
.15238 .15282 Mdot
.15476 .15267 Mdot
.15714 .15251 Mdot
.15952 .15235 Mdot
.1619 .1522 Mdot
.16429 .15204 Mdot
.16667 .15188 Mdot
.16905 .15173 Mdot
.17143 .15157 Mdot
.17381 .15141 Mdot
.17619 .15125 Mdot
.17857 .1511 Mdot
.18095 .15094 Mdot
.18333 .15078 Mdot
.18571 .15062 Mdot
.1881 .15046 Mdot
.19048 .15031 Mdot
.19286 .15015 Mdot
.19524 .14999 Mdot
.19762 .14983 Mdot
.2 .14967 Mdot
.20238 .14951 Mdot
.20476 .14935 Mdot
.20714 .14919 Mdot
.20952 .14903 Mdot
.2119 .14887 Mdot
.21429 .14871 Mdot
.21667 .14855 Mdot
.21905 .14839 Mdot
.22143 .14823 Mdot
.22381 .14807 Mdot
.22619 .14791 Mdot
.22857 .14775 Mdot
.23095 .14759 Mdot
.23333 .14742 Mdot
.23571 .14726 Mdot
.2381 .1471 Mdot
.24048 .14694 Mdot
.24286 .14678 Mdot
.24524 .14661 Mdot
.24762 .14645 Mdot
.25 .14629 Mdot
.25238 .14613 Mdot
.25476 .14596 Mdot
.25714 .1458 Mdot
.25952 .14564 Mdot
.2619 .14547 Mdot
.26429 .14531 Mdot
.26667 .14515 Mdot
.26905 .14498 Mdot
.27143 .14482 Mdot
.27381 .14465 Mdot
.27619 .14449 Mdot
.27857 .14433 Mdot
.28095 .14416 Mdot
.28333 .144 Mdot
.28571 .14383 Mdot
.2881 .14367 Mdot
.29048 .1435 Mdot
.29286 .14334 Mdot
.29524 .14317 Mdot
.29762 .143 Mdot
.3 .14284 Mdot
.30238 .14267 Mdot
.30476 .14251 Mdot
.30714 .14234 Mdot
.30952 .14217 Mdot
.3119 .14201 Mdot
.31429 .14184 Mdot
.31667 .14167 Mdot
.31905 .1415 Mdot
.32143 .14134 Mdot
.32381 .14117 Mdot
.32619 .141 Mdot
.32857 .14083 Mdot
.33095 .14066 Mdot
.33333 .1405 Mdot
.33571 .14033 Mdot
.3381 .14016 Mdot
.34048 .13999 Mdot
.34286 .13982 Mdot
.34524 .13965 Mdot
.34762 .13948 Mdot
.35 .13931 Mdot
.35238 .13914 Mdot
.35476 .13897 Mdot
.35714 .1388 Mdot
.35952 .13863 Mdot
.3619 .13846 Mdot
.36429 .13829 Mdot
.36667 .13812 Mdot
.36905 .13795 Mdot
.37143 .13778 Mdot
.37381 .13761 Mdot
.37619 .13744 Mdot
.37857 .13727 Mdot
.38095 .13709 Mdot
.38333 .13692 Mdot
.38571 .13675 Mdot
.3881 .13658 Mdot
.39048 .1364 Mdot
.39286 .13623 Mdot
.39524 .13606 Mdot
.39762 .13589 Mdot
.4 .13571 Mdot
.40238 .13554 Mdot
.40476 .13537 Mdot
.40714 .13519 Mdot
.40952 .13502 Mdot
.4119 .13485 Mdot
.41429 .13467 Mdot
.41667 .1345 Mdot
.41905 .13432 Mdot
.42143 .13415 Mdot
.42381 .13397 Mdot
.42619 .1338 Mdot
.42857 .13362 Mdot
.43095 .13345 Mdot
.43333 .13327 Mdot
.43571 .1331 Mdot
.4381 .13292 Mdot
.44048 .13274 Mdot
.44286 .13257 Mdot
.44524 .13239 Mdot
.44762 .13221 Mdot
.45 .13204 Mdot
.45238 .13186 Mdot
.45476 .13168 Mdot
.45714 .13151 Mdot
.45952 .13133 Mdot
.4619 .13115 Mdot
.46429 .13097 Mdot
.46667 .13079 Mdot
.46905 .13062 Mdot
.47143 .13044 Mdot
.47381 .13026 Mdot
.47619 .13008 Mdot
.47857 .1299 Mdot
.48095 .12972 Mdot
.48333 .12954 Mdot
.48571 .12936 Mdot
.4881 .12918 Mdot
.49048 .129 Mdot
.49286 .12882 Mdot
.49524 .12864 Mdot
.49762 .12846 Mdot
.5 .12828 Mdot
.50238 .1281 Mdot
.50476 .12792 Mdot
.50714 .12774 Mdot
.50952 .12756 Mdot
.5119 .12738 Mdot
.51429 .1272 Mdot
.51667 .12701 Mdot
.51905 .12683 Mdot
.52143 .12665 Mdot
.52381 .12647 Mdot
.52619 .12629 Mdot
.52857 .1261 Mdot
.53095 .12592 Mdot
.53333 .12574 Mdot
.53571 .12555 Mdot
.5381 .12537 Mdot
.54048 .12519 Mdot
.54286 .125 Mdot
.54524 .12482 Mdot
.54762 .12463 Mdot
.55 .12445 Mdot
.55238 .12427 Mdot
.55476 .12408 Mdot
.55714 .1239 Mdot
.55952 .12371 Mdot
.5619 .12353 Mdot
.56429 .12334 Mdot
.56667 .12315 Mdot
.56905 .12297 Mdot
.57143 .12278 Mdot
.57381 .1226 Mdot
.57619 .12241 Mdot
.57857 .12222 Mdot
.58095 .12204 Mdot
.58333 .12185 Mdot
.58571 .12166 Mdot
.5881 .12147 Mdot
.59048 .12129 Mdot
.59286 .1211 Mdot
.59524 .12091 Mdot
.59762 .12072 Mdot
.6 .12053 Mdot
.60238 .12035 Mdot
.60476 .12016 Mdot
.60714 .11997 Mdot
.60952 .11978 Mdot
.6119 .11959 Mdot
.61429 .1194 Mdot
.61667 .11921 Mdot
.61905 .11902 Mdot
.62143 .11883 Mdot
.62381 .11864 Mdot
.62619 .11845 Mdot
.62857 .11826 Mdot
.63095 .11807 Mdot
.63333 .11788 Mdot
.63571 .11769 Mdot
.6381 .1175 Mdot
.64048 .1173 Mdot
.64286 .11711 Mdot
.64524 .11692 Mdot
.64762 .11673 Mdot
.65 .11654 Mdot
.65238 .11634 Mdot
.65476 .11615 Mdot
.65714 .11596 Mdot
.65952 .11577 Mdot
.6619 .11557 Mdot
.66429 .11538 Mdot
.66667 .11519 Mdot
.66905 .11499 Mdot
.67143 .1148 Mdot
.67381 .1146 Mdot
.67619 .11441 Mdot
.67857 .11421 Mdot
.68095 .11402 Mdot
.68333 .11382 Mdot
.68571 .11363 Mdot
.6881 .11343 Mdot
.69048 .11324 Mdot
.69286 .11304 Mdot
.69524 .11285 Mdot
.69762 .11265 Mdot
.7 .11245 Mdot
.70238 .11226 Mdot
.70476 .11206 Mdot
.70714 .11186 Mdot
.70952 .11167 Mdot
.7119 .11147 Mdot
.71429 .11127 Mdot
.71667 .11107 Mdot
.71905 .11088 Mdot
.72143 .11068 Mdot
.72381 .11048 Mdot
.72619 .11028 Mdot
.72857 .11008 Mdot
.73095 .10988 Mdot
.73333 .10968 Mdot
.73571 .10949 Mdot
.7381 .10929 Mdot
.74048 .10909 Mdot
.74286 .10889 Mdot
.74524 .10869 Mdot
.74762 .10849 Mdot
.75 .10828 Mdot
.75238 .10808 Mdot
.75476 .10788 Mdot
.75714 .10768 Mdot
.75952 .10748 Mdot
.7619 .10728 Mdot
.76429 .10708 Mdot
.76667 .10688 Mdot
.76905 .10667 Mdot
.77143 .10647 Mdot
.77381 .10627 Mdot
.77619 .10607 Mdot
.77857 .10586 Mdot
.78095 .10566 Mdot
.78333 .10546 Mdot
.78571 .10525 Mdot
.7881 .10505 Mdot
.79048 .10484 Mdot
.79286 .10464 Mdot
.79524 .10444 Mdot
.79762 .10423 Mdot
.8 .10403 Mdot
.80238 .10382 Mdot
.80476 .10362 Mdot
.80714 .10341 Mdot
.80952 .10321 Mdot
.8119 .103 Mdot
.81429 .10279 Mdot
.81667 .10259 Mdot
.81905 .10238 Mdot
.82143 .10217 Mdot
.82381 .10197 Mdot
.82619 .10176 Mdot
.82857 .10155 Mdot
.83095 .10135 Mdot
.83333 .10114 Mdot
.83571 .10093 Mdot
.8381 .10072 Mdot
.84048 .10051 Mdot
.84286 .10031 Mdot
.84524 .1001 Mdot
.84762 .09989 Mdot
.85 .09968 Mdot
.85238 .09947 Mdot
.85476 .09926 Mdot
.85714 .09905 Mdot
.85952 .09884 Mdot
.8619 .09863 Mdot
.86429 .09842 Mdot
.86667 .09821 Mdot
.86905 .098 Mdot
.87143 .09779 Mdot
.87381 .09758 Mdot
.87619 .09736 Mdot
.87857 .09715 Mdot
.88095 .09694 Mdot
.88333 .09673 Mdot
.88571 .09652 Mdot
.8881 .0963 Mdot
.89048 .09609 Mdot
.89286 .09588 Mdot
.89524 .09567 Mdot
.89762 .09545 Mdot
.9 .09524 Mdot
.90238 .09502 Mdot
.90476 .09481 Mdot
.90714 .0946 Mdot
.90952 .09438 Mdot
.9119 .09417 Mdot
.91429 .09395 Mdot
.91667 .09374 Mdot
.91905 .09352 Mdot
.92143 .09331 Mdot
.92381 .09309 Mdot
.92619 .09288 Mdot
.92857 .09266 Mdot
.93095 .09244 Mdot
.93333 .09223 Mdot
.93571 .09201 Mdot
.9381 .09179 Mdot
.94048 .09158 Mdot
.94286 .09136 Mdot
.94524 .09114 Mdot
.94762 .09092 Mdot
.95 .0907 Mdot
.95238 .09049 Mdot
.95476 .09027 Mdot
.95714 .09005 Mdot
.95952 .08983 Mdot
.9619 .08961 Mdot
.96429 .08939 Mdot
.96667 .08917 Mdot
.96905 .08895 Mdot
.97143 .08873 Mdot
.97381 .08851 Mdot
.97619 .08829 Mdot
.02381 .18569 Mdot
.02619 .18557 Mdot
.02857 .18545 Mdot
.03095 .18532 Mdot
.03333 .1852 Mdot
.03571 .18508 Mdot
.0381 .18495 Mdot
.04048 .18483 Mdot
.04286 .1847 Mdot
.04524 .18458 Mdot
.04762 .18446 Mdot
.05 .18433 Mdot
.05238 .18421 Mdot
.05476 .18408 Mdot
.05714 .18396 Mdot
.05952 .18383 Mdot
.0619 .18371 Mdot
.06429 .18358 Mdot
.06667 .18346 Mdot
.06905 .18333 Mdot
.07143 .1832 Mdot
.07381 .18308 Mdot
.07619 .18295 Mdot
.07857 .18283 Mdot
.08095 .1827 Mdot
.08333 .18257 Mdot
.08571 .18245 Mdot
.0881 .18232 Mdot
.09048 .18219 Mdot
.09286 .18207 Mdot
.09524 .18194 Mdot
.09762 .18181 Mdot
.1 .18169 Mdot
.10238 .18156 Mdot
.10476 .18143 Mdot
.10714 .1813 Mdot
.10952 .18118 Mdot
.1119 .18105 Mdot
.11429 .18092 Mdot
.11667 .18079 Mdot
.11905 .18066 Mdot
.12143 .18054 Mdot
.12381 .18041 Mdot
.12619 .18028 Mdot
.12857 .18015 Mdot
.13095 .18002 Mdot
.13333 .17989 Mdot
.13571 .17976 Mdot
.1381 .17963 Mdot
.14048 .1795 Mdot
.14286 .17937 Mdot
.14524 .17925 Mdot
.14762 .17912 Mdot
.15 .17899 Mdot
.15238 .17886 Mdot
.15476 .17873 Mdot
.15714 .1786 Mdot
.15952 .17846 Mdot
.1619 .17833 Mdot
.16429 .1782 Mdot
.16667 .17807 Mdot
.16905 .17794 Mdot
.17143 .17781 Mdot
.17381 .17768 Mdot
.17619 .17755 Mdot
.17857 .17742 Mdot
.18095 .17729 Mdot
.18333 .17715 Mdot
.18571 .17702 Mdot
.1881 .17689 Mdot
.19048 .17676 Mdot
.19286 .17663 Mdot
.19524 .17649 Mdot
.19762 .17636 Mdot
.2 .17623 Mdot
.20238 .17609 Mdot
.20476 .17596 Mdot
.20714 .17583 Mdot
.20952 .1757 Mdot
.2119 .17556 Mdot
.21429 .17543 Mdot
.21667 .1753 Mdot
.21905 .17516 Mdot
.22143 .17503 Mdot
.22381 .17489 Mdot
.22619 .17476 Mdot
.22857 .17463 Mdot
.23095 .17449 Mdot
.23333 .17436 Mdot
.23571 .17422 Mdot
.2381 .17409 Mdot
.24048 .17395 Mdot
.24286 .17382 Mdot
.24524 .17368 Mdot
.24762 .17355 Mdot
.25 .17341 Mdot
.25238 .17328 Mdot
.25476 .17314 Mdot
.25714 .173 Mdot
.25952 .17287 Mdot
.2619 .17273 Mdot
.26429 .1726 Mdot
.26667 .17246 Mdot
.26905 .17232 Mdot
.27143 .17219 Mdot
.27381 .17205 Mdot
.27619 .17191 Mdot
.27857 .17177 Mdot
.28095 .17164 Mdot
.28333 .1715 Mdot
.28571 .17136 Mdot
.2881 .17122 Mdot
.29048 .17109 Mdot
.29286 .17095 Mdot
.29524 .17081 Mdot
.29762 .17067 Mdot
.3 .17053 Mdot
.30238 .1704 Mdot
.30476 .17026 Mdot
.30714 .17012 Mdot
.30952 .16998 Mdot
.3119 .16984 Mdot
.31429 .1697 Mdot
.31667 .16956 Mdot
.31905 .16942 Mdot
.32143 .16928 Mdot
.32381 .16914 Mdot
.32619 .169 Mdot
.32857 .16886 Mdot
.33095 .16872 Mdot
.33333 .16858 Mdot
.33571 .16844 Mdot
.3381 .1683 Mdot
.34048 .16816 Mdot
.34286 .16802 Mdot
.34524 .16788 Mdot
.34762 .16774 Mdot
.35 .1676 Mdot
.35238 .16746 Mdot
.35476 .16731 Mdot
.35714 .16717 Mdot
.35952 .16703 Mdot
.3619 .16689 Mdot
.36429 .16675 Mdot
.36667 .1666 Mdot
.36905 .16646 Mdot
.37143 .16632 Mdot
.37381 .16618 Mdot
.37619 .16603 Mdot
.37857 .16589 Mdot
.38095 .16575 Mdot
.38333 .1656 Mdot
.38571 .16546 Mdot
.3881 .16532 Mdot
.39048 .16517 Mdot
.39286 .16503 Mdot
.39524 .16489 Mdot
.39762 .16474 Mdot
.4 .1646 Mdot
.40238 .16445 Mdot
.40476 .16431 Mdot
.40714 .16416 Mdot
.40952 .16402 Mdot
.4119 .16387 Mdot
.41429 .16373 Mdot
.41667 .16358 Mdot
.41905 .16344 Mdot
.42143 .16329 Mdot
.42381 .16315 Mdot
.42619 .163 Mdot
.42857 .16285 Mdot
.43095 .16271 Mdot
.43333 .16256 Mdot
.43571 .16242 Mdot
.4381 .16227 Mdot
.44048 .16212 Mdot
.44286 .16198 Mdot
.44524 .16183 Mdot
.44762 .16168 Mdot
.45 .16153 Mdot
.45238 .16139 Mdot
.45476 .16124 Mdot
.45714 .16109 Mdot
.45952 .16094 Mdot
.4619 .1608 Mdot
.46429 .16065 Mdot
.46667 .1605 Mdot
.46905 .16035 Mdot
.47143 .1602 Mdot
.47381 .16005 Mdot
.47619 .1599 Mdot
.47857 .15975 Mdot
.48095 .15961 Mdot
.48333 .15946 Mdot
.48571 .15931 Mdot
.4881 .15916 Mdot
.49048 .15901 Mdot
.49286 .15886 Mdot
.49524 .15871 Mdot
.49762 .15856 Mdot
.5 .15841 Mdot
.50238 .15826 Mdot
.50476 .1581 Mdot
.50714 .15795 Mdot
.50952 .1578 Mdot
.5119 .15765 Mdot
.51429 .1575 Mdot
.51667 .15735 Mdot
.51905 .1572 Mdot
.52143 .15704 Mdot
.52381 .15689 Mdot
.52619 .15674 Mdot
.52857 .15659 Mdot
.53095 .15644 Mdot
.53333 .15628 Mdot
.53571 .15613 Mdot
.5381 .15598 Mdot
.54048 .15582 Mdot
.54286 .15567 Mdot
.54524 .15552 Mdot
.54762 .15536 Mdot
.55 .15521 Mdot
.55238 .15506 Mdot
.55476 .1549 Mdot
.55714 .15475 Mdot
.55952 .15459 Mdot
.5619 .15444 Mdot
.56429 .15429 Mdot
.56667 .15413 Mdot
.56905 .15398 Mdot
.57143 .15382 Mdot
.57381 .15367 Mdot
.57619 .15351 Mdot
.57857 .15336 Mdot
.58095 .1532 Mdot
.58333 .15304 Mdot
.58571 .15289 Mdot
.5881 .15273 Mdot
.59048 .15258 Mdot
.59286 .15242 Mdot
.59524 .15226 Mdot
.59762 .15211 Mdot
.6 .15195 Mdot
.60238 .15179 Mdot
.60476 .15163 Mdot
.60714 .15148 Mdot
.60952 .15132 Mdot
.6119 .15116 Mdot
.61429 .151 Mdot
.61667 .15085 Mdot
.61905 .15069 Mdot
.62143 .15053 Mdot
.62381 .15037 Mdot
.62619 .15021 Mdot
.62857 .15005 Mdot
.63095 .14989 Mdot
.63333 .14974 Mdot
.63571 .14958 Mdot
.6381 .14942 Mdot
.64048 .14926 Mdot
.64286 .1491 Mdot
.64524 .14894 Mdot
.64762 .14878 Mdot
.65 .14862 Mdot
.65238 .14846 Mdot
.65476 .1483 Mdot
.65714 .14814 Mdot
.65952 .14797 Mdot
.6619 .14781 Mdot
.66429 .14765 Mdot
.66667 .14749 Mdot
.66905 .14733 Mdot
.67143 .14717 Mdot
.67381 .14701 Mdot
.67619 .14684 Mdot
.67857 .14668 Mdot
.68095 .14652 Mdot
.68333 .14636 Mdot
.68571 .14619 Mdot
.6881 .14603 Mdot
.69048 .14587 Mdot
.69286 .14571 Mdot
.69524 .14554 Mdot
.69762 .14538 Mdot
.7 .14521 Mdot
.70238 .14505 Mdot
.70476 .14489 Mdot
.70714 .14472 Mdot
.70952 .14456 Mdot
.7119 .14439 Mdot
.71429 .14423 Mdot
.71667 .14406 Mdot
.71905 .1439 Mdot
.72143 .14373 Mdot
.72381 .14357 Mdot
.72619 .1434 Mdot
.72857 .14324 Mdot
.73095 .14307 Mdot
.73333 .14291 Mdot
.73571 .14274 Mdot
.7381 .14257 Mdot
.74048 .14241 Mdot
.74286 .14224 Mdot
.74524 .14207 Mdot
.74762 .14191 Mdot
.75 .14174 Mdot
.75238 .14157 Mdot
.75476 .14141 Mdot
.75714 .14124 Mdot
.75952 .14107 Mdot
.7619 .1409 Mdot
.76429 .14073 Mdot
.76667 .14057 Mdot
.76905 .1404 Mdot
.77143 .14023 Mdot
.77381 .14006 Mdot
.77619 .13989 Mdot
.77857 .13972 Mdot
.78095 .13955 Mdot
.78333 .13938 Mdot
.78571 .13921 Mdot
.7881 .13904 Mdot
.79048 .13887 Mdot
.79286 .1387 Mdot
.79524 .13853 Mdot
.79762 .13836 Mdot
.8 .13819 Mdot
.80238 .13802 Mdot
.80476 .13785 Mdot
.80714 .13768 Mdot
.80952 .13751 Mdot
.8119 .13734 Mdot
.81429 .13716 Mdot
.81667 .13699 Mdot
.81905 .13682 Mdot
.82143 .13665 Mdot
.82381 .13648 Mdot
.82619 .1363 Mdot
.82857 .13613 Mdot
.83095 .13596 Mdot
.83333 .13578 Mdot
.83571 .13561 Mdot
.8381 .13544 Mdot
.84048 .13526 Mdot
.84286 .13509 Mdot
.84524 .13492 Mdot
.84762 .13474 Mdot
.85 .13457 Mdot
.85238 .13439 Mdot
.85476 .13422 Mdot
.85714 .13404 Mdot
.85952 .13387 Mdot
.8619 .13369 Mdot
.86429 .13352 Mdot
.86667 .13334 Mdot
.86905 .13317 Mdot
.87143 .13299 Mdot
.87381 .13282 Mdot
.87619 .13264 Mdot
.87857 .13246 Mdot
.88095 .13229 Mdot
.88333 .13211 Mdot
.88571 .13193 Mdot
.8881 .13176 Mdot
.89048 .13158 Mdot
.89286 .1314 Mdot
.89524 .13122 Mdot
.89762 .13105 Mdot
.9 .13087 Mdot
.90238 .13069 Mdot
.90476 .13051 Mdot
.90714 .13033 Mdot
.90952 .13015 Mdot
.9119 .12998 Mdot
.91429 .1298 Mdot
.91667 .12962 Mdot
.91905 .12944 Mdot
.92143 .12926 Mdot
.92381 .12908 Mdot
.92619 .1289 Mdot
.92857 .12872 Mdot
.93095 .12854 Mdot
.93333 .12836 Mdot
.93571 .12818 Mdot
.9381 .128 Mdot
.94048 .12782 Mdot
.94286 .12763 Mdot
.94524 .12745 Mdot
.94762 .12727 Mdot
.95 .12709 Mdot
.95238 .12691 Mdot
.95476 .12673 Mdot
.95714 .12654 Mdot
.95952 .12636 Mdot
.9619 .12618 Mdot
.96429 .126 Mdot
.96667 .12581 Mdot
.96905 .12563 Mdot
.97143 .12545 Mdot
.97381 .12526 Mdot
.97619 .12508 Mdot
.02381 .21036 Mdot
.02619 .21026 Mdot
.02857 .21016 Mdot
.03095 .21006 Mdot
.03333 .20996 Mdot
.03571 .20986 Mdot
.0381 .20977 Mdot
.04048 .20967 Mdot
.04286 .20957 Mdot
.04524 .20947 Mdot
.04762 .20937 Mdot
.05 .20927 Mdot
.05238 .20917 Mdot
.05476 .20907 Mdot
.05714 .20897 Mdot
.05952 .20887 Mdot
.0619 .20877 Mdot
.06429 .20867 Mdot
.06667 .20857 Mdot
.06905 .20847 Mdot
.07143 .20837 Mdot
.07381 .20827 Mdot
.07619 .20817 Mdot
.07857 .20806 Mdot
.08095 .20796 Mdot
.08333 .20786 Mdot
.08571 .20776 Mdot
.0881 .20766 Mdot
.09048 .20756 Mdot
.09286 .20746 Mdot
.09524 .20736 Mdot
.09762 .20725 Mdot
.1 .20715 Mdot
.10238 .20705 Mdot
.10476 .20695 Mdot
.10714 .20685 Mdot
.10952 .20674 Mdot
.1119 .20664 Mdot
.11429 .20654 Mdot
.11667 .20644 Mdot
.11905 .20633 Mdot
.12143 .20623 Mdot
.12381 .20613 Mdot
.12619 .20603 Mdot
.12857 .20592 Mdot
.13095 .20582 Mdot
.13333 .20572 Mdot
.13571 .20561 Mdot
.1381 .20551 Mdot
.14048 .20541 Mdot
.14286 .2053 Mdot
.14524 .2052 Mdot
.14762 .2051 Mdot
.15 .20499 Mdot
.15238 .20489 Mdot
.15476 .20478 Mdot
.15714 .20468 Mdot
.15952 .20458 Mdot
.1619 .20447 Mdot
.16429 .20437 Mdot
.16667 .20426 Mdot
.16905 .20416 Mdot
.17143 .20405 Mdot
.17381 .20395 Mdot
.17619 .20384 Mdot
.17857 .20374 Mdot
.18095 .20363 Mdot
.18333 .20353 Mdot
.18571 .20342 Mdot
.1881 .20331 Mdot
.19048 .20321 Mdot
.19286 .2031 Mdot
.19524 .203 Mdot
.19762 .20289 Mdot
.2 .20279 Mdot
.20238 .20268 Mdot
.20476 .20257 Mdot
.20714 .20247 Mdot
.20952 .20236 Mdot
.2119 .20225 Mdot
.21429 .20215 Mdot
.21667 .20204 Mdot
.21905 .20193 Mdot
.22143 .20183 Mdot
.22381 .20172 Mdot
.22619 .20161 Mdot
.22857 .2015 Mdot
.23095 .2014 Mdot
.23333 .20129 Mdot
.23571 .20118 Mdot
.2381 .20107 Mdot
.24048 .20096 Mdot
.24286 .20086 Mdot
.24524 .20075 Mdot
.24762 .20064 Mdot
.25 .20053 Mdot
.25238 .20042 Mdot
.25476 .20031 Mdot
.25714 .20021 Mdot
.25952 .2001 Mdot
.2619 .19999 Mdot
.26429 .19988 Mdot
.26667 .19977 Mdot
.26905 .19966 Mdot
.27143 .19955 Mdot
.27381 .19944 Mdot
.27619 .19933 Mdot
.27857 .19922 Mdot
.28095 .19911 Mdot
.28333 .199 Mdot
.28571 .19889 Mdot
.2881 .19878 Mdot
.29048 .19867 Mdot
.29286 .19856 Mdot
.29524 .19845 Mdot
.29762 .19834 Mdot
.3 .19823 Mdot
.30238 .19812 Mdot
.30476 .19801 Mdot
.30714 .1979 Mdot
.30952 .19779 Mdot
.3119 .19768 Mdot
.31429 .19756 Mdot
.31667 .19745 Mdot
.31905 .19734 Mdot
.32143 .19723 Mdot
.32381 .19712 Mdot
.32619 .19701 Mdot
.32857 .19689 Mdot
.33095 .19678 Mdot
.33333 .19667 Mdot
.33571 .19656 Mdot
.3381 .19645 Mdot
.34048 .19633 Mdot
.34286 .19622 Mdot
.34524 .19611 Mdot
.34762 .19599 Mdot
.35 .19588 Mdot
.35238 .19577 Mdot
.35476 .19565 Mdot
.35714 .19554 Mdot
.35952 .19543 Mdot
.3619 .19531 Mdot
.36429 .1952 Mdot
.36667 .19509 Mdot
.36905 .19497 Mdot
.37143 .19486 Mdot
.37381 .19474 Mdot
.37619 .19463 Mdot
.37857 .19452 Mdot
.38095 .1944 Mdot
.38333 .19429 Mdot
.38571 .19417 Mdot
.3881 .19406 Mdot
.39048 .19394 Mdot
.39286 .19383 Mdot
.39524 .19371 Mdot
.39762 .1936 Mdot
.4 .19348 Mdot
.40238 .19337 Mdot
.40476 .19325 Mdot
.40714 .19313 Mdot
.40952 .19302 Mdot
.4119 .1929 Mdot
.41429 .19279 Mdot
.41667 .19267 Mdot
.41905 .19255 Mdot
.42143 .19244 Mdot
.42381 .19232 Mdot
.42619 .1922 Mdot
.42857 .19209 Mdot
.43095 .19197 Mdot
.43333 .19185 Mdot
.43571 .19174 Mdot
.4381 .19162 Mdot
.44048 .1915 Mdot
.44286 .19138 Mdot
.44524 .19127 Mdot
.44762 .19115 Mdot
.45 .19103 Mdot
.45238 .19091 Mdot
.45476 .19079 Mdot
.45714 .19068 Mdot
.45952 .19056 Mdot
.4619 .19044 Mdot
.46429 .19032 Mdot
.46667 .1902 Mdot
.46905 .19008 Mdot
.47143 .18996 Mdot
.47381 .18985 Mdot
.47619 .18973 Mdot
.47857 .18961 Mdot
.48095 .18949 Mdot
.48333 .18937 Mdot
.48571 .18925 Mdot
.4881 .18913 Mdot
.49048 .18901 Mdot
.49286 .18889 Mdot
.49524 .18877 Mdot
.49762 .18865 Mdot
.5 .18853 Mdot
.50238 .18841 Mdot
.50476 .18829 Mdot
.50714 .18817 Mdot
.50952 .18805 Mdot
.5119 .18792 Mdot
.51429 .1878 Mdot
.51667 .18768 Mdot
.51905 .18756 Mdot
.52143 .18744 Mdot
.52381 .18732 Mdot
.52619 .1872 Mdot
.52857 .18707 Mdot
.53095 .18695 Mdot
.53333 .18683 Mdot
.53571 .18671 Mdot
.5381 .18659 Mdot
.54048 .18646 Mdot
.54286 .18634 Mdot
.54524 .18622 Mdot
.54762 .1861 Mdot
.55 .18597 Mdot
.55238 .18585 Mdot
.55476 .18573 Mdot
.55714 .1856 Mdot
.55952 .18548 Mdot
.5619 .18536 Mdot
.56429 .18523 Mdot
.56667 .18511 Mdot
.56905 .18498 Mdot
.57143 .18486 Mdot
.57381 .18474 Mdot
.57619 .18461 Mdot
.57857 .18449 Mdot
.58095 .18436 Mdot
.58333 .18424 Mdot
.58571 .18411 Mdot
.5881 .18399 Mdot
.59048 .18386 Mdot
.59286 .18374 Mdot
.59524 .18361 Mdot
.59762 .18349 Mdot
.6 .18336 Mdot
.60238 .18324 Mdot
.60476 .18311 Mdot
.60714 .18298 Mdot
.60952 .18286 Mdot
.6119 .18273 Mdot
.61429 .18261 Mdot
.61667 .18248 Mdot
.61905 .18235 Mdot
.62143 .18223 Mdot
.62381 .1821 Mdot
.62619 .18197 Mdot
.62857 .18185 Mdot
.63095 .18172 Mdot
.63333 .18159 Mdot
.63571 .18146 Mdot
.6381 .18134 Mdot
.64048 .18121 Mdot
.64286 .18108 Mdot
.64524 .18095 Mdot
.64762 .18083 Mdot
.65 .1807 Mdot
.65238 .18057 Mdot
.65476 .18044 Mdot
.65714 .18031 Mdot
.65952 .18018 Mdot
.6619 .18005 Mdot
.66429 .17993 Mdot
.66667 .1798 Mdot
.66905 .17967 Mdot
.67143 .17954 Mdot
.67381 .17941 Mdot
.67619 .17928 Mdot
.67857 .17915 Mdot
.68095 .17902 Mdot
.68333 .17889 Mdot
.68571 .17876 Mdot
.6881 .17863 Mdot
.69048 .1785 Mdot
.69286 .17837 Mdot
.69524 .17824 Mdot
.69762 .17811 Mdot
.7 .17798 Mdot
.70238 .17784 Mdot
.70476 .17771 Mdot
.70714 .17758 Mdot
.70952 .17745 Mdot
.7119 .17732 Mdot
.71429 .17719 Mdot
.71667 .17706 Mdot
.71905 .17692 Mdot
.72143 .17679 Mdot
.72381 .17666 Mdot
.72619 .17653 Mdot
.72857 .17639 Mdot
.73095 .17626 Mdot
.73333 .17613 Mdot
.73571 .176 Mdot
.7381 .17586 Mdot
.74048 .17573 Mdot
.74286 .1756 Mdot
.74524 .17546 Mdot
.74762 .17533 Mdot
.75 .1752 Mdot
.75238 .17506 Mdot
.75476 .17493 Mdot
.75714 .17479 Mdot
.75952 .17466 Mdot
.7619 .17453 Mdot
.76429 .17439 Mdot
.76667 .17426 Mdot
.76905 .17412 Mdot
.77143 .17399 Mdot
.77381 .17385 Mdot
.77619 .17372 Mdot
.77857 .17358 Mdot
.78095 .17345 Mdot
.78333 .17331 Mdot
.78571 .17317 Mdot
.7881 .17304 Mdot
.79048 .1729 Mdot
.79286 .17277 Mdot
.79524 .17263 Mdot
.79762 .17249 Mdot
.8 .17236 Mdot
.80238 .17222 Mdot
.80476 .17208 Mdot
.80714 .17195 Mdot
.80952 .17181 Mdot
.8119 .17167 Mdot
.81429 .17154 Mdot
.81667 .1714 Mdot
.81905 .17126 Mdot
.82143 .17112 Mdot
.82381 .17098 Mdot
.82619 .17085 Mdot
.82857 .17071 Mdot
.83095 .17057 Mdot
.83333 .17043 Mdot
.83571 .17029 Mdot
.8381 .17015 Mdot
.84048 .17002 Mdot
.84286 .16988 Mdot
.84524 .16974 Mdot
.84762 .1696 Mdot
.85 .16946 Mdot
.85238 .16932 Mdot
.85476 .16918 Mdot
.85714 .16904 Mdot
.85952 .1689 Mdot
.8619 .16876 Mdot
.86429 .16862 Mdot
.86667 .16848 Mdot
.86905 .16834 Mdot
.87143 .1682 Mdot
.87381 .16806 Mdot
.87619 .16792 Mdot
.87857 .16777 Mdot
.88095 .16763 Mdot
.88333 .16749 Mdot
.88571 .16735 Mdot
.8881 .16721 Mdot
.89048 .16707 Mdot
.89286 .16692 Mdot
.89524 .16678 Mdot
.89762 .16664 Mdot
.9 .1665 Mdot
.90238 .16636 Mdot
.90476 .16621 Mdot
.90714 .16607 Mdot
.90952 .16593 Mdot
.9119 .16578 Mdot
.91429 .16564 Mdot
.91667 .1655 Mdot
.91905 .16535 Mdot
.92143 .16521 Mdot
.92381 .16507 Mdot
.92619 .16492 Mdot
.92857 .16478 Mdot
.93095 .16463 Mdot
.93333 .16449 Mdot
.93571 .16435 Mdot
.9381 .1642 Mdot
.94048 .16406 Mdot
.94286 .16391 Mdot
.94524 .16377 Mdot
.94762 .16362 Mdot
.95 .16348 Mdot
.95238 .16333 Mdot
.95476 .16318 Mdot
.95714 .16304 Mdot
.95952 .16289 Mdot
.9619 .16275 Mdot
.96429 .1626 Mdot
.96667 .16245 Mdot
.96905 .16231 Mdot
.97143 .16216 Mdot
.97381 .16201 Mdot
.97619 .16187 Mdot
.02381 .23502 Mdot
.02619 .23495 Mdot
.02857 .23488 Mdot
.03095 .2348 Mdot
.03333 .23473 Mdot
.03571 .23465 Mdot
.0381 .23458 Mdot
.04048 .2345 Mdot
.04286 .23443 Mdot
.04524 .23435 Mdot
.04762 .23428 Mdot
.05 .23421 Mdot
.05238 .23413 Mdot
.05476 .23406 Mdot
.05714 .23398 Mdot
.05952 .23391 Mdot
.0619 .23383 Mdot
.06429 .23376 Mdot
.06667 .23368 Mdot
.06905 .2336 Mdot
.07143 .23353 Mdot
.07381 .23345 Mdot
.07619 .23338 Mdot
.07857 .2333 Mdot
.08095 .23323 Mdot
.08333 .23315 Mdot
.08571 .23308 Mdot
.0881 .233 Mdot
.09048 .23292 Mdot
.09286 .23285 Mdot
.09524 .23277 Mdot
.09762 .23269 Mdot
.1 .23262 Mdot
.10238 .23254 Mdot
.10476 .23247 Mdot
.10714 .23239 Mdot
.10952 .23231 Mdot
.1119 .23224 Mdot
.11429 .23216 Mdot
.11667 .23208 Mdot
.11905 .23201 Mdot
.12143 .23193 Mdot
.12381 .23185 Mdot
.12619 .23177 Mdot
.12857 .2317 Mdot
.13095 .23162 Mdot
.13333 .23154 Mdot
.13571 .23146 Mdot
.1381 .23139 Mdot
.14048 .23131 Mdot
.14286 .23123 Mdot
.14524 .23115 Mdot
.14762 .23108 Mdot
.15 .231 Mdot
.15238 .23092 Mdot
.15476 .23084 Mdot
.15714 .23076 Mdot
.15952 .23069 Mdot
.1619 .23061 Mdot
.16429 .23053 Mdot
.16667 .23045 Mdot
.16905 .23037 Mdot
.17143 .23029 Mdot
.17381 .23021 Mdot
.17619 .23014 Mdot
.17857 .23006 Mdot
.18095 .22998 Mdot
.18333 .2299 Mdot
.18571 .22982 Mdot
.1881 .22974 Mdot
.19048 .22966 Mdot
.19286 .22958 Mdot
.19524 .2295 Mdot
.19762 .22942 Mdot
.2 .22934 Mdot
.20238 .22926 Mdot
.20476 .22918 Mdot
.20714 .2291 Mdot
.20952 .22902 Mdot
.2119 .22894 Mdot
.21429 .22886 Mdot
.21667 .22878 Mdot
.21905 .2287 Mdot
.22143 .22862 Mdot
.22381 .22854 Mdot
.22619 .22846 Mdot
.22857 .22838 Mdot
.23095 .2283 Mdot
.23333 .22822 Mdot
.23571 .22814 Mdot
.2381 .22806 Mdot
.24048 .22798 Mdot
.24286 .2279 Mdot
.24524 .22782 Mdot
.24762 .22773 Mdot
.25 .22765 Mdot
.25238 .22757 Mdot
.25476 .22749 Mdot
.25714 .22741 Mdot
.25952 .22733 Mdot
.2619 .22725 Mdot
.26429 .22716 Mdot
.26667 .22708 Mdot
.26905 .227 Mdot
.27143 .22692 Mdot
.27381 .22684 Mdot
.27619 .22675 Mdot
.27857 .22667 Mdot
.28095 .22659 Mdot
.28333 .22651 Mdot
.28571 .22642 Mdot
.2881 .22634 Mdot
.29048 .22626 Mdot
.29286 .22618 Mdot
.29524 .22609 Mdot
.29762 .22601 Mdot
.3 .22593 Mdot
.30238 .22584 Mdot
.30476 .22576 Mdot
.30714 .22568 Mdot
.30952 .22559 Mdot
.3119 .22551 Mdot
.31429 .22543 Mdot
.31667 .22534 Mdot
.31905 .22526 Mdot
.32143 .22518 Mdot
.32381 .22509 Mdot
.32619 .22501 Mdot
.32857 .22492 Mdot
.33095 .22484 Mdot
.33333 .22476 Mdot
.33571 .22467 Mdot
.3381 .22459 Mdot
.34048 .2245 Mdot
.34286 .22442 Mdot
.34524 .22433 Mdot
.34762 .22425 Mdot
.35 .22417 Mdot
.35238 .22408 Mdot
.35476 .224 Mdot
.35714 .22391 Mdot
.35952 .22383 Mdot
.3619 .22374 Mdot
.36429 .22365 Mdot
.36667 .22357 Mdot
.36905 .22348 Mdot
.37143 .2234 Mdot
.37381 .22331 Mdot
.37619 .22323 Mdot
.37857 .22314 Mdot
.38095 .22306 Mdot
.38333 .22297 Mdot
.38571 .22288 Mdot
.3881 .2228 Mdot
.39048 .22271 Mdot
.39286 .22262 Mdot
.39524 .22254 Mdot
.39762 .22245 Mdot
.4 .22237 Mdot
.40238 .22228 Mdot
.40476 .22219 Mdot
.40714 .2221 Mdot
.40952 .22202 Mdot
.4119 .22193 Mdot
.41429 .22184 Mdot
.41667 .22176 Mdot
.41905 .22167 Mdot
.42143 .22158 Mdot
.42381 .22149 Mdot
.42619 .22141 Mdot
.42857 .22132 Mdot
.43095 .22123 Mdot
.43333 .22114 Mdot
.43571 .22106 Mdot
.4381 .22097 Mdot
.44048 .22088 Mdot
.44286 .22079 Mdot
.44524 .2207 Mdot
.44762 .22062 Mdot
.45 .22053 Mdot
.45238 .22044 Mdot
.45476 .22035 Mdot
.45714 .22026 Mdot
.45952 .22017 Mdot
.4619 .22008 Mdot
.46429 .21999 Mdot
.46667 .21991 Mdot
.46905 .21982 Mdot
.47143 .21973 Mdot
.47381 .21964 Mdot
.47619 .21955 Mdot
.47857 .21946 Mdot
.48095 .21937 Mdot
.48333 .21928 Mdot
.48571 .21919 Mdot
.4881 .2191 Mdot
.49048 .21901 Mdot
.49286 .21892 Mdot
.49524 .21883 Mdot
.49762 .21874 Mdot
.5 .21865 Mdot
.50238 .21856 Mdot
.50476 .21847 Mdot
.50714 .21838 Mdot
.50952 .21829 Mdot
.5119 .2182 Mdot
.51429 .21811 Mdot
.51667 .21802 Mdot
.51905 .21792 Mdot
.52143 .21783 Mdot
.52381 .21774 Mdot
.52619 .21765 Mdot
.52857 .21756 Mdot
.53095 .21747 Mdot
.53333 .21738 Mdot
.53571 .21729 Mdot
.5381 .21719 Mdot
.54048 .2171 Mdot
.54286 .21701 Mdot
.54524 .21692 Mdot
.54762 .21683 Mdot
.55 .21673 Mdot
.55238 .21664 Mdot
.55476 .21655 Mdot
.55714 .21646 Mdot
.55952 .21636 Mdot
.5619 .21627 Mdot
.56429 .21618 Mdot
.56667 .21609 Mdot
.56905 .21599 Mdot
.57143 .2159 Mdot
.57381 .21581 Mdot
.57619 .21571 Mdot
.57857 .21562 Mdot
.58095 .21553 Mdot
.58333 .21543 Mdot
.58571 .21534 Mdot
.5881 .21525 Mdot
.59048 .21515 Mdot
.59286 .21506 Mdot
.59524 .21496 Mdot
.59762 .21487 Mdot
.6 .21478 Mdot
.60238 .21468 Mdot
.60476 .21459 Mdot
.60714 .21449 Mdot
.60952 .2144 Mdot
.6119 .2143 Mdot
.61429 .21421 Mdot
.61667 .21411 Mdot
.61905 .21402 Mdot
.62143 .21392 Mdot
.62381 .21383 Mdot
.62619 .21373 Mdot
.62857 .21364 Mdot
.63095 .21354 Mdot
.63333 .21345 Mdot
.63571 .21335 Mdot
.6381 .21326 Mdot
.64048 .21316 Mdot
.64286 .21307 Mdot
.64524 .21297 Mdot
.64762 .21287 Mdot
.65 .21278 Mdot
.65238 .21268 Mdot
.65476 .21258 Mdot
.65714 .21249 Mdot
.65952 .21239 Mdot
.6619 .21229 Mdot
.66429 .2122 Mdot
.66667 .2121 Mdot
.66905 .212 Mdot
.67143 .21191 Mdot
.67381 .21181 Mdot
.67619 .21171 Mdot
.67857 .21162 Mdot
.68095 .21152 Mdot
.68333 .21142 Mdot
.68571 .21132 Mdot
.6881 .21123 Mdot
.69048 .21113 Mdot
.69286 .21103 Mdot
.69524 .21093 Mdot
.69762 .21083 Mdot
.7 .21074 Mdot
.70238 .21064 Mdot
.70476 .21054 Mdot
.70714 .21044 Mdot
.70952 .21034 Mdot
.7119 .21024 Mdot
.71429 .21014 Mdot
.71667 .21005 Mdot
.71905 .20995 Mdot
.72143 .20985 Mdot
.72381 .20975 Mdot
.72619 .20965 Mdot
.72857 .20955 Mdot
.73095 .20945 Mdot
.73333 .20935 Mdot
.73571 .20925 Mdot
.7381 .20915 Mdot
.74048 .20905 Mdot
.74286 .20895 Mdot
.74524 .20885 Mdot
.74762 .20875 Mdot
.75 .20865 Mdot
.75238 .20855 Mdot
.75476 .20845 Mdot
.75714 .20835 Mdot
.75952 .20825 Mdot
.7619 .20815 Mdot
.76429 .20805 Mdot
.76667 .20795 Mdot
.76905 .20785 Mdot
.77143 .20774 Mdot
.77381 .20764 Mdot
.77619 .20754 Mdot
.77857 .20744 Mdot
.78095 .20734 Mdot
.78333 .20724 Mdot
.78571 .20713 Mdot
.7881 .20703 Mdot
.79048 .20693 Mdot
.79286 .20683 Mdot
.79524 .20673 Mdot
.79762 .20662 Mdot
.8 .20652 Mdot
.80238 .20642 Mdot
.80476 .20632 Mdot
.80714 .20621 Mdot
.80952 .20611 Mdot
.8119 .20601 Mdot
.81429 .20591 Mdot
.81667 .2058 Mdot
.81905 .2057 Mdot
.82143 .2056 Mdot
.82381 .20549 Mdot
.82619 .20539 Mdot
.82857 .20529 Mdot
.83095 .20518 Mdot
.83333 .20508 Mdot
.83571 .20497 Mdot
.8381 .20487 Mdot
.84048 .20477 Mdot
.84286 .20466 Mdot
.84524 .20456 Mdot
.84762 .20445 Mdot
.85 .20435 Mdot
.85238 .20424 Mdot
.85476 .20414 Mdot
.85714 .20403 Mdot
.85952 .20393 Mdot
.8619 .20382 Mdot
.86429 .20372 Mdot
.86667 .20361 Mdot
.86905 .20351 Mdot
.87143 .2034 Mdot
.87381 .2033 Mdot
.87619 .20319 Mdot
.87857 .20308 Mdot
.88095 .20298 Mdot
.88333 .20287 Mdot
.88571 .20277 Mdot
.8881 .20266 Mdot
.89048 .20255 Mdot
.89286 .20245 Mdot
.89524 .20234 Mdot
.89762 .20223 Mdot
.9 .20213 Mdot
.90238 .20202 Mdot
.90476 .20191 Mdot
.90714 .20181 Mdot
.90952 .2017 Mdot
.9119 .20159 Mdot
.91429 .20148 Mdot
.91667 .20138 Mdot
.91905 .20127 Mdot
.92143 .20116 Mdot
.92381 .20105 Mdot
.92619 .20095 Mdot
.92857 .20084 Mdot
.93095 .20073 Mdot
.93333 .20062 Mdot
.93571 .20051 Mdot
.9381 .2004 Mdot
.94048 .2003 Mdot
.94286 .20019 Mdot
.94524 .20008 Mdot
.94762 .19997 Mdot
.95 .19986 Mdot
.95238 .19975 Mdot
.95476 .19964 Mdot
.95714 .19953 Mdot
.95952 .19942 Mdot
.9619 .19931 Mdot
.96429 .1992 Mdot
.96667 .19909 Mdot
.96905 .19898 Mdot
.97143 .19887 Mdot
.97381 .19876 Mdot
.97619 .19865 Mdot
.02381 .25969 Mdot
.02619 .25964 Mdot
.02857 .25959 Mdot
.03095 .25954 Mdot
.03333 .25949 Mdot
.03571 .25944 Mdot
.0381 .25939 Mdot
.04048 .25934 Mdot
.04286 .25929 Mdot
.04524 .25924 Mdot
.04762 .25919 Mdot
.05 .25914 Mdot
.05238 .25909 Mdot
.05476 .25904 Mdot
.05714 .25899 Mdot
.05952 .25894 Mdot
.0619 .25889 Mdot
.06429 .25884 Mdot
.06667 .25879 Mdot
.06905 .25874 Mdot
.07143 .25869 Mdot
.07381 .25864 Mdot
.07619 .25859 Mdot
.07857 .25854 Mdot
.08095 .25849 Mdot
.08333 .25844 Mdot
.08571 .25839 Mdot
.0881 .25834 Mdot
.09048 .25829 Mdot
.09286 .25824 Mdot
.09524 .25819 Mdot
.09762 .25814 Mdot
.1 .25808 Mdot
.10238 .25803 Mdot
.10476 .25798 Mdot
.10714 .25793 Mdot
.10952 .25788 Mdot
.1119 .25783 Mdot
.11429 .25778 Mdot
.11667 .25773 Mdot
.11905 .25768 Mdot
.12143 .25762 Mdot
.12381 .25757 Mdot
.12619 .25752 Mdot
.12857 .25747 Mdot
.13095 .25742 Mdot
.13333 .25737 Mdot
.13571 .25732 Mdot
.1381 .25726 Mdot
.14048 .25721 Mdot
.14286 .25716 Mdot
.14524 .25711 Mdot
.14762 .25706 Mdot
.15 .257 Mdot
.15238 .25695 Mdot
.15476 .2569 Mdot
.15714 .25685 Mdot
.15952 .2568 Mdot
.1619 .25674 Mdot
.16429 .25669 Mdot
.16667 .25664 Mdot
.16905 .25659 Mdot
.17143 .25653 Mdot
.17381 .25648 Mdot
.17619 .25643 Mdot
.17857 .25638 Mdot
.18095 .25632 Mdot
.18333 .25627 Mdot
.18571 .25622 Mdot
.1881 .25617 Mdot
.19048 .25611 Mdot
.19286 .25606 Mdot
.19524 .25601 Mdot
.19762 .25595 Mdot
.2 .2559 Mdot
.20238 .25585 Mdot
.20476 .25579 Mdot
.20714 .25574 Mdot
.20952 .25569 Mdot
.2119 .25564 Mdot
.21429 .25558 Mdot
.21667 .25553 Mdot
.21905 .25547 Mdot
.22143 .25542 Mdot
.22381 .25537 Mdot
.22619 .25531 Mdot
.22857 .25526 Mdot
.23095 .25521 Mdot
.23333 .25515 Mdot
.23571 .2551 Mdot
.2381 .25504 Mdot
.24048 .25499 Mdot
.24286 .25494 Mdot
.24524 .25488 Mdot
.24762 .25483 Mdot
.25 .25477 Mdot
.25238 .25472 Mdot
.25476 .25467 Mdot
.25714 .25461 Mdot
.25952 .25456 Mdot
.2619 .2545 Mdot
.26429 .25445 Mdot
.26667 .25439 Mdot
.26905 .25434 Mdot
.27143 .25428 Mdot
.27381 .25423 Mdot
.27619 .25417 Mdot
.27857 .25412 Mdot
.28095 .25407 Mdot
.28333 .25401 Mdot
.28571 .25396 Mdot
.2881 .2539 Mdot
.29048 .25384 Mdot
.29286 .25379 Mdot
.29524 .25373 Mdot
.29762 .25368 Mdot
.3 .25362 Mdot
.30238 .25357 Mdot
.30476 .25351 Mdot
.30714 .25346 Mdot
.30952 .2534 Mdot
.3119 .25335 Mdot
.31429 .25329 Mdot
.31667 .25324 Mdot
.31905 .25318 Mdot
.32143 .25312 Mdot
.32381 .25307 Mdot
.32619 .25301 Mdot
.32857 .25296 Mdot
.33095 .2529 Mdot
.33333 .25284 Mdot
.33571 .25279 Mdot
.3381 .25273 Mdot
.34048 .25267 Mdot
.34286 .25262 Mdot
.34524 .25256 Mdot
.34762 .25251 Mdot
.35 .25245 Mdot
.35238 .25239 Mdot
.35476 .25234 Mdot
.35714 .25228 Mdot
.35952 .25222 Mdot
.3619 .25217 Mdot
.36429 .25211 Mdot
.36667 .25205 Mdot
.36905 .25199 Mdot
.37143 .25194 Mdot
.37381 .25188 Mdot
.37619 .25182 Mdot
.37857 .25177 Mdot
.38095 .25171 Mdot
.38333 .25165 Mdot
.38571 .25159 Mdot
.3881 .25154 Mdot
.39048 .25148 Mdot
.39286 .25142 Mdot
.39524 .25136 Mdot
.39762 .25131 Mdot
.4 .25125 Mdot
.40238 .25119 Mdot
.40476 .25113 Mdot
.40714 .25108 Mdot
.40952 .25102 Mdot
.4119 .25096 Mdot
.41429 .2509 Mdot
.41667 .25084 Mdot
.41905 .25079 Mdot
.42143 .25073 Mdot
.42381 .25067 Mdot
.42619 .25061 Mdot
.42857 .25055 Mdot
.43095 .25049 Mdot
.43333 .25044 Mdot
.43571 .25038 Mdot
.4381 .25032 Mdot
.44048 .25026 Mdot
.44286 .2502 Mdot
.44524 .25014 Mdot
.44762 .25008 Mdot
.45 .25002 Mdot
.45238 .24996 Mdot
.45476 .24991 Mdot
.45714 .24985 Mdot
.45952 .24979 Mdot
.4619 .24973 Mdot
.46429 .24967 Mdot
.46667 .24961 Mdot
.46905 .24955 Mdot
.47143 .24949 Mdot
.47381 .24943 Mdot
.47619 .24937 Mdot
.47857 .24931 Mdot
.48095 .24925 Mdot
.48333 .24919 Mdot
.48571 .24913 Mdot
.4881 .24907 Mdot
.49048 .24901 Mdot
.49286 .24895 Mdot
.49524 .24889 Mdot
.49762 .24883 Mdot
.5 .24877 Mdot
.50238 .24871 Mdot
.50476 .24865 Mdot
.50714 .24859 Mdot
.50952 .24853 Mdot
.5119 .24847 Mdot
.51429 .24841 Mdot
.51667 .24835 Mdot
.51905 .24829 Mdot
.52143 .24823 Mdot
.52381 .24817 Mdot
.52619 .24811 Mdot
.52857 .24805 Mdot
.53095 .24798 Mdot
.53333 .24792 Mdot
.53571 .24786 Mdot
.5381 .2478 Mdot
.54048 .24774 Mdot
.54286 .24768 Mdot
.54524 .24762 Mdot
.54762 .24756 Mdot
.55 .24749 Mdot
.55238 .24743 Mdot
.55476 .24737 Mdot
.55714 .24731 Mdot
.55952 .24725 Mdot
.5619 .24719 Mdot
.56429 .24712 Mdot
.56667 .24706 Mdot
.56905 .247 Mdot
.57143 .24694 Mdot
.57381 .24688 Mdot
.57619 .24681 Mdot
.57857 .24675 Mdot
.58095 .24669 Mdot
.58333 .24663 Mdot
.58571 .24657 Mdot
.5881 .2465 Mdot
.59048 .24644 Mdot
.59286 .24638 Mdot
.59524 .24632 Mdot
.59762 .24625 Mdot
.6 .24619 Mdot
.60238 .24613 Mdot
.60476 .24606 Mdot
.60714 .246 Mdot
.60952 .24594 Mdot
.6119 .24587 Mdot
.61429 .24581 Mdot
.61667 .24575 Mdot
.61905 .24569 Mdot
.62143 .24562 Mdot
.62381 .24556 Mdot
.62619 .2455 Mdot
.62857 .24543 Mdot
.63095 .24537 Mdot
.63333 .2453 Mdot
.63571 .24524 Mdot
.6381 .24518 Mdot
.64048 .24511 Mdot
.64286 .24505 Mdot
.64524 .24499 Mdot
.64762 .24492 Mdot
.65 .24486 Mdot
.65238 .24479 Mdot
.65476 .24473 Mdot
.65714 .24466 Mdot
.65952 .2446 Mdot
.6619 .24454 Mdot
.66429 .24447 Mdot
.66667 .24441 Mdot
.66905 .24434 Mdot
.67143 .24428 Mdot
.67381 .24421 Mdot
.67619 .24415 Mdot
.67857 .24408 Mdot
.68095 .24402 Mdot
.68333 .24395 Mdot
.68571 .24389 Mdot
.6881 .24382 Mdot
.69048 .24376 Mdot
.69286 .24369 Mdot
.69524 .24363 Mdot
.69762 .24356 Mdot
.7 .2435 Mdot
.70238 .24343 Mdot
.70476 .24336 Mdot
.70714 .2433 Mdot
.70952 .24323 Mdot
.7119 .24317 Mdot
.71429 .2431 Mdot
.71667 .24304 Mdot
.71905 .24297 Mdot
.72143 .2429 Mdot
.72381 .24284 Mdot
.72619 .24277 Mdot
.72857 .24271 Mdot
.73095 .24264 Mdot
.73333 .24257 Mdot
.73571 .24251 Mdot
.7381 .24244 Mdot
.74048 .24237 Mdot
.74286 .24231 Mdot
.74524 .24224 Mdot
.74762 .24217 Mdot
.75 .24211 Mdot
.75238 .24204 Mdot
.75476 .24197 Mdot
.75714 .24191 Mdot
.75952 .24184 Mdot
.7619 .24177 Mdot
.76429 .2417 Mdot
.76667 .24164 Mdot
.76905 .24157 Mdot
.77143 .2415 Mdot
.77381 .24143 Mdot
.77619 .24137 Mdot
.77857 .2413 Mdot
.78095 .24123 Mdot
.78333 .24116 Mdot
.78571 .2411 Mdot
.7881 .24103 Mdot
.79048 .24096 Mdot
.79286 .24089 Mdot
.79524 .24082 Mdot
.79762 .24076 Mdot
.8 .24069 Mdot
.80238 .24062 Mdot
.80476 .24055 Mdot
.80714 .24048 Mdot
.80952 .24041 Mdot
.8119 .24034 Mdot
.81429 .24028 Mdot
.81667 .24021 Mdot
.81905 .24014 Mdot
.82143 .24007 Mdot
.82381 .24 Mdot
.82619 .23993 Mdot
.82857 .23986 Mdot
.83095 .23979 Mdot
.83333 .23972 Mdot
.83571 .23965 Mdot
.8381 .23959 Mdot
.84048 .23952 Mdot
.84286 .23945 Mdot
.84524 .23938 Mdot
.84762 .23931 Mdot
.85 .23924 Mdot
.85238 .23917 Mdot
.85476 .2391 Mdot
.85714 .23903 Mdot
.85952 .23896 Mdot
.8619 .23889 Mdot
.86429 .23882 Mdot
.86667 .23875 Mdot
.86905 .23868 Mdot
.87143 .23861 Mdot
.87381 .23854 Mdot
.87619 .23847 Mdot
.87857 .2384 Mdot
.88095 .23833 Mdot
.88333 .23825 Mdot
.88571 .23818 Mdot
.8881 .23811 Mdot
.89048 .23804 Mdot
.89286 .23797 Mdot
.89524 .2379 Mdot
.89762 .23783 Mdot
.9 .23776 Mdot
.90238 .23769 Mdot
.90476 .23761 Mdot
.90714 .23754 Mdot
.90952 .23747 Mdot
.9119 .2374 Mdot
.91429 .23733 Mdot
.91667 .23726 Mdot
.91905 .23719 Mdot
.92143 .23711 Mdot
.92381 .23704 Mdot
.92619 .23697 Mdot
.92857 .2369 Mdot
.93095 .23683 Mdot
.93333 .23675 Mdot
.93571 .23668 Mdot
.9381 .23661 Mdot
.94048 .23654 Mdot
.94286 .23646 Mdot
.94524 .23639 Mdot
.94762 .23632 Mdot
.95 .23625 Mdot
.95238 .23617 Mdot
.95476 .2361 Mdot
.95714 .23603 Mdot
.95952 .23595 Mdot
.9619 .23588 Mdot
.96429 .23581 Mdot
.96667 .23574 Mdot
.96905 .23566 Mdot
.97143 .23559 Mdot
.97381 .23552 Mdot
.97619 .23544 Mdot
.02381 .28435 Mdot
.02619 .28433 Mdot
.02857 .2843 Mdot
.03095 .28428 Mdot
.03333 .28425 Mdot
.03571 .28423 Mdot
.0381 .2842 Mdot
.04048 .28418 Mdot
.04286 .28415 Mdot
.04524 .28413 Mdot
.04762 .2841 Mdot
.05 .28408 Mdot
.05238 .28405 Mdot
.05476 .28403 Mdot
.05714 .284 Mdot
.05952 .28398 Mdot
.0619 .28395 Mdot
.06429 .28393 Mdot
.06667 .2839 Mdot
.06905 .28388 Mdot
.07143 .28385 Mdot
.07381 .28383 Mdot
.07619 .2838 Mdot
.07857 .28378 Mdot
.08095 .28375 Mdot
.08333 .28373 Mdot
.08571 .2837 Mdot
.0881 .28368 Mdot
.09048 .28365 Mdot
.09286 .28363 Mdot
.09524 .2836 Mdot
.09762 .28358 Mdot
.1 .28355 Mdot
.10238 .28353 Mdot
.10476 .2835 Mdot
.10714 .28347 Mdot
.10952 .28345 Mdot
.1119 .28342 Mdot
.11429 .2834 Mdot
.11667 .28337 Mdot
.11905 .28335 Mdot
.12143 .28332 Mdot
.12381 .2833 Mdot
.12619 .28327 Mdot
.12857 .28324 Mdot
.13095 .28322 Mdot
.13333 .28319 Mdot
.13571 .28317 Mdot
.1381 .28314 Mdot
.14048 .28311 Mdot
.14286 .28309 Mdot
.14524 .28306 Mdot
.14762 .28304 Mdot
.15 .28301 Mdot
.15238 .28298 Mdot
.15476 .28296 Mdot
.15714 .28293 Mdot
.15952 .28291 Mdot
.1619 .28288 Mdot
.16429 .28285 Mdot
.16667 .28283 Mdot
.16905 .2828 Mdot
.17143 .28278 Mdot
.17381 .28275 Mdot
.17619 .28272 Mdot
.17857 .2827 Mdot
.18095 .28267 Mdot
.18333 .28264 Mdot
.18571 .28262 Mdot
.1881 .28259 Mdot
.19048 .28257 Mdot
.19286 .28254 Mdot
.19524 .28251 Mdot
.19762 .28249 Mdot
.2 .28246 Mdot
.20238 .28243 Mdot
.20476 .28241 Mdot
.20714 .28238 Mdot
.20952 .28235 Mdot
.2119 .28233 Mdot
.21429 .2823 Mdot
.21667 .28227 Mdot
.21905 .28225 Mdot
.22143 .28222 Mdot
.22381 .28219 Mdot
.22619 .28217 Mdot
.22857 .28214 Mdot
.23095 .28211 Mdot
.23333 .28208 Mdot
.23571 .28206 Mdot
.2381 .28203 Mdot
.24048 .282 Mdot
.24286 .28198 Mdot
.24524 .28195 Mdot
.24762 .28192 Mdot
.25 .2819 Mdot
.25238 .28187 Mdot
.25476 .28184 Mdot
.25714 .28181 Mdot
.25952 .28179 Mdot
.2619 .28176 Mdot
.26429 .28173 Mdot
.26667 .28171 Mdot
.26905 .28168 Mdot
.27143 .28165 Mdot
.27381 .28162 Mdot
.27619 .2816 Mdot
.27857 .28157 Mdot
.28095 .28154 Mdot
.28333 .28151 Mdot
.28571 .28149 Mdot
.2881 .28146 Mdot
.29048 .28143 Mdot
.29286 .2814 Mdot
.29524 .28138 Mdot
.29762 .28135 Mdot
.3 .28132 Mdot
.30238 .28129 Mdot
.30476 .28127 Mdot
.30714 .28124 Mdot
.30952 .28121 Mdot
.3119 .28118 Mdot
.31429 .28115 Mdot
.31667 .28113 Mdot
.31905 .2811 Mdot
.32143 .28107 Mdot
.32381 .28104 Mdot
.32619 .28101 Mdot
.32857 .28099 Mdot
.33095 .28096 Mdot
.33333 .28093 Mdot
.33571 .2809 Mdot
.3381 .28087 Mdot
.34048 .28085 Mdot
.34286 .28082 Mdot
.34524 .28079 Mdot
.34762 .28076 Mdot
.35 .28073 Mdot
.35238 .2807 Mdot
.35476 .28068 Mdot
.35714 .28065 Mdot
.35952 .28062 Mdot
.3619 .28059 Mdot
.36429 .28056 Mdot
.36667 .28053 Mdot
.36905 .28051 Mdot
.37143 .28048 Mdot
.37381 .28045 Mdot
.37619 .28042 Mdot
.37857 .28039 Mdot
.38095 .28036 Mdot
.38333 .28033 Mdot
.38571 .28031 Mdot
.3881 .28028 Mdot
.39048 .28025 Mdot
.39286 .28022 Mdot
.39524 .28019 Mdot
.39762 .28016 Mdot
.4 .28013 Mdot
.40238 .2801 Mdot
.40476 .28008 Mdot
.40714 .28005 Mdot
.40952 .28002 Mdot
.4119 .27999 Mdot
.41429 .27996 Mdot
.41667 .27993 Mdot
.41905 .2799 Mdot
.42143 .27987 Mdot
.42381 .27984 Mdot
.42619 .27981 Mdot
.42857 .27978 Mdot
.43095 .27976 Mdot
.43333 .27973 Mdot
.43571 .2797 Mdot
.4381 .27967 Mdot
.44048 .27964 Mdot
.44286 .27961 Mdot
.44524 .27958 Mdot
.44762 .27955 Mdot
.45 .27952 Mdot
.45238 .27949 Mdot
.45476 .27946 Mdot
.45714 .27943 Mdot
.45952 .2794 Mdot
.4619 .27937 Mdot
.46429 .27934 Mdot
.46667 .27931 Mdot
.46905 .27928 Mdot
.47143 .27925 Mdot
.47381 .27922 Mdot
.47619 .27919 Mdot
.47857 .27916 Mdot
.48095 .27913 Mdot
.48333 .2791 Mdot
.48571 .27907 Mdot
.4881 .27904 Mdot
.49048 .27901 Mdot
.49286 .27898 Mdot
.49524 .27895 Mdot
.49762 .27892 Mdot
.5 .27889 Mdot
.50238 .27886 Mdot
.50476 .27883 Mdot
.50714 .2788 Mdot
.50952 .27877 Mdot
.5119 .27874 Mdot
.51429 .27871 Mdot
.51667 .27868 Mdot
.51905 .27865 Mdot
.52143 .27862 Mdot
.52381 .27859 Mdot
.52619 .27856 Mdot
.52857 .27853 Mdot
.53095 .2785 Mdot
.53333 .27847 Mdot
.53571 .27844 Mdot
.5381 .27841 Mdot
.54048 .27838 Mdot
.54286 .27835 Mdot
.54524 .27832 Mdot
.54762 .27829 Mdot
.55 .27826 Mdot
.55238 .27823 Mdot
.55476 .27819 Mdot
.55714 .27816 Mdot
.55952 .27813 Mdot
.5619 .2781 Mdot
.56429 .27807 Mdot
.56667 .27804 Mdot
.56905 .27801 Mdot
.57143 .27798 Mdot
.57381 .27795 Mdot
.57619 .27792 Mdot
.57857 .27788 Mdot
.58095 .27785 Mdot
.58333 .27782 Mdot
.58571 .27779 Mdot
.5881 .27776 Mdot
.59048 .27773 Mdot
.59286 .2777 Mdot
.59524 .27767 Mdot
.59762 .27763 Mdot
.6 .2776 Mdot
.60238 .27757 Mdot
.60476 .27754 Mdot
.60714 .27751 Mdot
.60952 .27748 Mdot
.6119 .27745 Mdot
.61429 .27741 Mdot
.61667 .27738 Mdot
.61905 .27735 Mdot
.62143 .27732 Mdot
.62381 .27729 Mdot
.62619 .27726 Mdot
.62857 .27722 Mdot
.63095 .27719 Mdot
.63333 .27716 Mdot
.63571 .27713 Mdot
.6381 .2771 Mdot
.64048 .27706 Mdot
.64286 .27703 Mdot
.64524 .277 Mdot
.64762 .27697 Mdot
.65 .27694 Mdot
.65238 .2769 Mdot
.65476 .27687 Mdot
.65714 .27684 Mdot
.65952 .27681 Mdot
.6619 .27678 Mdot
.66429 .27674 Mdot
.66667 .27671 Mdot
.66905 .27668 Mdot
.67143 .27665 Mdot
.67381 .27661 Mdot
.67619 .27658 Mdot
.67857 .27655 Mdot
.68095 .27652 Mdot
.68333 .27648 Mdot
.68571 .27645 Mdot
.6881 .27642 Mdot
.69048 .27639 Mdot
.69286 .27635 Mdot
.69524 .27632 Mdot
.69762 .27629 Mdot
.7 .27626 Mdot
.70238 .27622 Mdot
.70476 .27619 Mdot
.70714 .27616 Mdot
.70952 .27613 Mdot
.7119 .27609 Mdot
.71429 .27606 Mdot
.71667 .27603 Mdot
.71905 .27599 Mdot
.72143 .27596 Mdot
.72381 .27593 Mdot
.72619 .27589 Mdot
.72857 .27586 Mdot
.73095 .27583 Mdot
.73333 .27579 Mdot
.73571 .27576 Mdot
.7381 .27573 Mdot
.74048 .2757 Mdot
.74286 .27566 Mdot
.74524 .27563 Mdot
.74762 .2756 Mdot
.75 .27556 Mdot
.75238 .27553 Mdot
.75476 .27549 Mdot
.75714 .27546 Mdot
.75952 .27543 Mdot
.7619 .27539 Mdot
.76429 .27536 Mdot
.76667 .27533 Mdot
.76905 .27529 Mdot
.77143 .27526 Mdot
.77381 .27523 Mdot
.77619 .27519 Mdot
.77857 .27516 Mdot
.78095 .27512 Mdot
.78333 .27509 Mdot
.78571 .27506 Mdot
.7881 .27502 Mdot
.79048 .27499 Mdot
.79286 .27495 Mdot
.79524 .27492 Mdot
.79762 .27489 Mdot
.8 .27485 Mdot
.80238 .27482 Mdot
.80476 .27478 Mdot
.80714 .27475 Mdot
.80952 .27472 Mdot
.8119 .27468 Mdot
.81429 .27465 Mdot
.81667 .27461 Mdot
.81905 .27458 Mdot
.82143 .27454 Mdot
.82381 .27451 Mdot
.82619 .27447 Mdot
.82857 .27444 Mdot
.83095 .27441 Mdot
.83333 .27437 Mdot
.83571 .27434 Mdot
.8381 .2743 Mdot
.84048 .27427 Mdot
.84286 .27423 Mdot
.84524 .2742 Mdot
.84762 .27416 Mdot
.85 .27413 Mdot
.85238 .27409 Mdot
.85476 .27406 Mdot
.85714 .27402 Mdot
.85952 .27399 Mdot
.8619 .27395 Mdot
.86429 .27392 Mdot
.86667 .27388 Mdot
.86905 .27385 Mdot
.87143 .27381 Mdot
.87381 .27378 Mdot
.87619 .27374 Mdot
.87857 .27371 Mdot
.88095 .27367 Mdot
.88333 .27364 Mdot
.88571 .2736 Mdot
.8881 .27356 Mdot
.89048 .27353 Mdot
.89286 .27349 Mdot
.89524 .27346 Mdot
.89762 .27342 Mdot
.9 .27339 Mdot
.90238 .27335 Mdot
.90476 .27332 Mdot
.90714 .27328 Mdot
.90952 .27324 Mdot
.9119 .27321 Mdot
.91429 .27317 Mdot
.91667 .27314 Mdot
.91905 .2731 Mdot
.92143 .27307 Mdot
.92381 .27303 Mdot
.92619 .27299 Mdot
.92857 .27296 Mdot
.93095 .27292 Mdot
.93333 .27289 Mdot
.93571 .27285 Mdot
.9381 .27281 Mdot
.94048 .27278 Mdot
.94286 .27274 Mdot
.94524 .2727 Mdot
.94762 .27267 Mdot
.95 .27263 Mdot
.95238 .2726 Mdot
.95476 .27256 Mdot
.95714 .27252 Mdot
.95952 .27249 Mdot
.9619 .27245 Mdot
.96429 .27241 Mdot
.96667 .27238 Mdot
.96905 .27234 Mdot
.97143 .2723 Mdot
.97381 .27227 Mdot
.97619 .27223 Mdot
.02381 .30902 Mdot
.02619 .30902 Mdot
.02857 .30902 Mdot
.03095 .30902 Mdot
.03333 .30902 Mdot
.03571 .30902 Mdot
.0381 .30902 Mdot
.04048 .30902 Mdot
.04286 .30902 Mdot
.04524 .30902 Mdot
.04762 .30902 Mdot
.05 .30902 Mdot
.05238 .30902 Mdot
.05476 .30902 Mdot
.05714 .30902 Mdot
.05952 .30902 Mdot
.0619 .30902 Mdot
.06429 .30902 Mdot
.06667 .30902 Mdot
.06905 .30902 Mdot
.07143 .30902 Mdot
.07381 .30902 Mdot
.07619 .30902 Mdot
.07857 .30902 Mdot
.08095 .30902 Mdot
.08333 .30902 Mdot
.08571 .30902 Mdot
.0881 .30902 Mdot
.09048 .30902 Mdot
.09286 .30902 Mdot
.09524 .30902 Mdot
.09762 .30902 Mdot
.1 .30902 Mdot
.10238 .30902 Mdot
.10476 .30902 Mdot
.10714 .30902 Mdot
.10952 .30902 Mdot
.1119 .30902 Mdot
.11429 .30902 Mdot
.11667 .30902 Mdot
.11905 .30902 Mdot
.12143 .30902 Mdot
.12381 .30902 Mdot
.12619 .30902 Mdot
.12857 .30902 Mdot
.13095 .30902 Mdot
.13333 .30902 Mdot
.13571 .30902 Mdot
.1381 .30902 Mdot
.14048 .30902 Mdot
.14286 .30902 Mdot
.14524 .30902 Mdot
.14762 .30902 Mdot
.15 .30902 Mdot
.15238 .30902 Mdot
.15476 .30902 Mdot
.15714 .30902 Mdot
.15952 .30902 Mdot
.1619 .30902 Mdot
.16429 .30902 Mdot
.16667 .30902 Mdot
.16905 .30902 Mdot
.17143 .30902 Mdot
.17381 .30902 Mdot
.17619 .30902 Mdot
.17857 .30902 Mdot
.18095 .30902 Mdot
.18333 .30902 Mdot
.18571 .30902 Mdot
.1881 .30902 Mdot
.19048 .30902 Mdot
.19286 .30902 Mdot
.19524 .30902 Mdot
.19762 .30902 Mdot
.2 .30902 Mdot
.20238 .30902 Mdot
.20476 .30902 Mdot
.20714 .30902 Mdot
.20952 .30902 Mdot
.2119 .30902 Mdot
.21429 .30902 Mdot
.21667 .30902 Mdot
.21905 .30902 Mdot
.22143 .30902 Mdot
.22381 .30902 Mdot
.22619 .30902 Mdot
.22857 .30902 Mdot
.23095 .30902 Mdot
.23333 .30902 Mdot
.23571 .30902 Mdot
.2381 .30902 Mdot
.24048 .30902 Mdot
.24286 .30902 Mdot
.24524 .30902 Mdot
.24762 .30902 Mdot
.25 .30902 Mdot
.25238 .30902 Mdot
.25476 .30902 Mdot
.25714 .30902 Mdot
.25952 .30902 Mdot
.2619 .30902 Mdot
.26429 .30902 Mdot
.26667 .30902 Mdot
.26905 .30902 Mdot
.27143 .30902 Mdot
.27381 .30902 Mdot
.27619 .30902 Mdot
.27857 .30902 Mdot
.28095 .30902 Mdot
.28333 .30902 Mdot
.28571 .30902 Mdot
.2881 .30902 Mdot
.29048 .30902 Mdot
.29286 .30902 Mdot
.29524 .30902 Mdot
.29762 .30902 Mdot
.3 .30902 Mdot
.30238 .30902 Mdot
.30476 .30902 Mdot
.30714 .30902 Mdot
.30952 .30902 Mdot
.3119 .30902 Mdot
.31429 .30902 Mdot
.31667 .30902 Mdot
.31905 .30902 Mdot
.32143 .30902 Mdot
.32381 .30902 Mdot
.32619 .30902 Mdot
.32857 .30902 Mdot
.33095 .30902 Mdot
.33333 .30902 Mdot
.33571 .30902 Mdot
.3381 .30902 Mdot
.34048 .30902 Mdot
.34286 .30902 Mdot
.34524 .30902 Mdot
.34762 .30902 Mdot
.35 .30902 Mdot
.35238 .30902 Mdot
.35476 .30902 Mdot
.35714 .30902 Mdot
.35952 .30902 Mdot
.3619 .30902 Mdot
.36429 .30902 Mdot
.36667 .30902 Mdot
.36905 .30902 Mdot
.37143 .30902 Mdot
.37381 .30902 Mdot
.37619 .30902 Mdot
.37857 .30902 Mdot
.38095 .30902 Mdot
.38333 .30902 Mdot
.38571 .30902 Mdot
.3881 .30902 Mdot
.39048 .30902 Mdot
.39286 .30902 Mdot
.39524 .30902 Mdot
.39762 .30902 Mdot
.4 .30902 Mdot
.40238 .30902 Mdot
.40476 .30902 Mdot
.40714 .30902 Mdot
.40952 .30902 Mdot
.4119 .30902 Mdot
.41429 .30902 Mdot
.41667 .30902 Mdot
.41905 .30902 Mdot
.42143 .30902 Mdot
.42381 .30902 Mdot
.42619 .30902 Mdot
.42857 .30902 Mdot
.43095 .30902 Mdot
.43333 .30902 Mdot
.43571 .30902 Mdot
.4381 .30902 Mdot
.44048 .30902 Mdot
.44286 .30902 Mdot
.44524 .30902 Mdot
.44762 .30902 Mdot
.45 .30902 Mdot
.45238 .30902 Mdot
.45476 .30902 Mdot
.45714 .30902 Mdot
.45952 .30902 Mdot
.4619 .30902 Mdot
.46429 .30902 Mdot
.46667 .30902 Mdot
.46905 .30902 Mdot
.47143 .30902 Mdot
.47381 .30902 Mdot
.47619 .30902 Mdot
.47857 .30902 Mdot
.48095 .30902 Mdot
.48333 .30902 Mdot
.48571 .30902 Mdot
.4881 .30902 Mdot
.49048 .30902 Mdot
.49286 .30902 Mdot
.49524 .30902 Mdot
.49762 .30902 Mdot
.5 .30902 Mdot
.50238 .30902 Mdot
.50476 .30902 Mdot
.50714 .30902 Mdot
.50952 .30902 Mdot
.5119 .30902 Mdot
.51429 .30902 Mdot
.51667 .30902 Mdot
.51905 .30902 Mdot
.52143 .30902 Mdot
.52381 .30902 Mdot
.52619 .30902 Mdot
.52857 .30902 Mdot
.53095 .30902 Mdot
.53333 .30902 Mdot
.53571 .30902 Mdot
.5381 .30902 Mdot
.54048 .30902 Mdot
.54286 .30902 Mdot
.54524 .30902 Mdot
.54762 .30902 Mdot
.55 .30902 Mdot
.55238 .30902 Mdot
.55476 .30902 Mdot
.55714 .30902 Mdot
.55952 .30902 Mdot
.5619 .30902 Mdot
.56429 .30902 Mdot
.56667 .30902 Mdot
.56905 .30902 Mdot
.57143 .30902 Mdot
.57381 .30902 Mdot
.57619 .30902 Mdot
.57857 .30902 Mdot
.58095 .30902 Mdot
.58333 .30902 Mdot
.58571 .30902 Mdot
.5881 .30902 Mdot
.59048 .30902 Mdot
.59286 .30902 Mdot
.59524 .30902 Mdot
.59762 .30902 Mdot
.6 .30902 Mdot
.60238 .30902 Mdot
.60476 .30902 Mdot
.60714 .30902 Mdot
.60952 .30902 Mdot
.6119 .30902 Mdot
.61429 .30902 Mdot
.61667 .30902 Mdot
.61905 .30902 Mdot
.62143 .30902 Mdot
.62381 .30902 Mdot
.62619 .30902 Mdot
.62857 .30902 Mdot
.63095 .30902 Mdot
.63333 .30902 Mdot
.63571 .30902 Mdot
.6381 .30902 Mdot
.64048 .30902 Mdot
.64286 .30902 Mdot
.64524 .30902 Mdot
.64762 .30902 Mdot
.65 .30902 Mdot
.65238 .30902 Mdot
.65476 .30902 Mdot
.65714 .30902 Mdot
.65952 .30902 Mdot
.6619 .30902 Mdot
.66429 .30902 Mdot
.66667 .30902 Mdot
.66905 .30902 Mdot
.67143 .30902 Mdot
.67381 .30902 Mdot
.67619 .30902 Mdot
.67857 .30902 Mdot
.68095 .30902 Mdot
.68333 .30902 Mdot
.68571 .30902 Mdot
.6881 .30902 Mdot
.69048 .30902 Mdot
.69286 .30902 Mdot
.69524 .30902 Mdot
.69762 .30902 Mdot
.7 .30902 Mdot
.70238 .30902 Mdot
.70476 .30902 Mdot
.70714 .30902 Mdot
.70952 .30902 Mdot
.7119 .30902 Mdot
.71429 .30902 Mdot
.71667 .30902 Mdot
.71905 .30902 Mdot
.72143 .30902 Mdot
.72381 .30902 Mdot
.72619 .30902 Mdot
.72857 .30902 Mdot
.73095 .30902 Mdot
.73333 .30902 Mdot
.73571 .30902 Mdot
.7381 .30902 Mdot
.74048 .30902 Mdot
.74286 .30902 Mdot
.74524 .30902 Mdot
.74762 .30902 Mdot
.75 .30902 Mdot
.75238 .30902 Mdot
.75476 .30902 Mdot
.75714 .30902 Mdot
.75952 .30902 Mdot
.7619 .30902 Mdot
.76429 .30902 Mdot
.76667 .30902 Mdot
.76905 .30902 Mdot
.77143 .30902 Mdot
.77381 .30902 Mdot
.77619 .30902 Mdot
.77857 .30902 Mdot
.78095 .30902 Mdot
.78333 .30902 Mdot
.78571 .30902 Mdot
.7881 .30902 Mdot
.79048 .30902 Mdot
.79286 .30902 Mdot
.79524 .30902 Mdot
.79762 .30902 Mdot
.8 .30902 Mdot
.80238 .30902 Mdot
.80476 .30902 Mdot
.80714 .30902 Mdot
.80952 .30902 Mdot
.8119 .30902 Mdot
.81429 .30902 Mdot
.81667 .30902 Mdot
.81905 .30902 Mdot
.82143 .30902 Mdot
.82381 .30902 Mdot
.82619 .30902 Mdot
.82857 .30902 Mdot
.83095 .30902 Mdot
.83333 .30902 Mdot
.83571 .30902 Mdot
.8381 .30902 Mdot
.84048 .30902 Mdot
.84286 .30902 Mdot
.84524 .30902 Mdot
.84762 .30902 Mdot
.85 .30902 Mdot
.85238 .30902 Mdot
.85476 .30902 Mdot
.85714 .30902 Mdot
.85952 .30902 Mdot
.8619 .30902 Mdot
.86429 .30902 Mdot
.86667 .30902 Mdot
.86905 .30902 Mdot
.87143 .30902 Mdot
.87381 .30902 Mdot
.87619 .30902 Mdot
.87857 .30902 Mdot
.88095 .30902 Mdot
.88333 .30902 Mdot
.88571 .30902 Mdot
.8881 .30902 Mdot
.89048 .30902 Mdot
.89286 .30902 Mdot
.89524 .30902 Mdot
.89762 .30902 Mdot
.9 .30902 Mdot
.90238 .30902 Mdot
.90476 .30902 Mdot
.90714 .30902 Mdot
.90952 .30902 Mdot
.9119 .30902 Mdot
.91429 .30902 Mdot
.91667 .30902 Mdot
.91905 .30902 Mdot
.92143 .30902 Mdot
.92381 .30902 Mdot
.92619 .30902 Mdot
.92857 .30902 Mdot
.93095 .30902 Mdot
.93333 .30902 Mdot
.93571 .30902 Mdot
.9381 .30902 Mdot
.94048 .30902 Mdot
.94286 .30902 Mdot
.94524 .30902 Mdot
.94762 .30902 Mdot
.95 .30902 Mdot
.95238 .30902 Mdot
.95476 .30902 Mdot
.95714 .30902 Mdot
.95952 .30902 Mdot
.9619 .30902 Mdot
.96429 .30902 Mdot
.96667 .30902 Mdot
.96905 .30902 Mdot
.97143 .30902 Mdot
.97381 .30902 Mdot
.97619 .30902 Mdot
.02381 .33368 Mdot
.02619 .33371 Mdot
.02857 .33373 Mdot
.03095 .33376 Mdot
.03333 .33378 Mdot
.03571 .33381 Mdot
.0381 .33383 Mdot
.04048 .33385 Mdot
.04286 .33388 Mdot
.04524 .3339 Mdot
.04762 .33393 Mdot
.05 .33395 Mdot
.05238 .33398 Mdot
.05476 .334 Mdot
.05714 .33403 Mdot
.05952 .33405 Mdot
.0619 .33408 Mdot
.06429 .3341 Mdot
.06667 .33413 Mdot
.06905 .33415 Mdot
.07143 .33418 Mdot
.07381 .3342 Mdot
.07619 .33423 Mdot
.07857 .33426 Mdot
.08095 .33428 Mdot
.08333 .33431 Mdot
.08571 .33433 Mdot
.0881 .33436 Mdot
.09048 .33438 Mdot
.09286 .33441 Mdot
.09524 .33443 Mdot
.09762 .33446 Mdot
.1 .33448 Mdot
.10238 .33451 Mdot
.10476 .33453 Mdot
.10714 .33456 Mdot
.10952 .33459 Mdot
.1119 .33461 Mdot
.11429 .33464 Mdot
.11667 .33466 Mdot
.11905 .33469 Mdot
.12143 .33471 Mdot
.12381 .33474 Mdot
.12619 .33476 Mdot
.12857 .33479 Mdot
.13095 .33482 Mdot
.13333 .33484 Mdot
.13571 .33487 Mdot
.1381 .33489 Mdot
.14048 .33492 Mdot
.14286 .33495 Mdot
.14524 .33497 Mdot
.14762 .335 Mdot
.15 .33502 Mdot
.15238 .33505 Mdot
.15476 .33508 Mdot
.15714 .3351 Mdot
.15952 .33513 Mdot
.1619 .33515 Mdot
.16429 .33518 Mdot
.16667 .33521 Mdot
.16905 .33523 Mdot
.17143 .33526 Mdot
.17381 .33528 Mdot
.17619 .33531 Mdot
.17857 .33534 Mdot
.18095 .33536 Mdot
.18333 .33539 Mdot
.18571 .33542 Mdot
.1881 .33544 Mdot
.19048 .33547 Mdot
.19286 .3355 Mdot
.19524 .33552 Mdot
.19762 .33555 Mdot
.2 .33557 Mdot
.20238 .3356 Mdot
.20476 .33563 Mdot
.20714 .33565 Mdot
.20952 .33568 Mdot
.2119 .33571 Mdot
.21429 .33573 Mdot
.21667 .33576 Mdot
.21905 .33579 Mdot
.22143 .33581 Mdot
.22381 .33584 Mdot
.22619 .33587 Mdot
.22857 .3359 Mdot
.23095 .33592 Mdot
.23333 .33595 Mdot
.23571 .33598 Mdot
.2381 .336 Mdot
.24048 .33603 Mdot
.24286 .33606 Mdot
.24524 .33608 Mdot
.24762 .33611 Mdot
.25 .33614 Mdot
.25238 .33617 Mdot
.25476 .33619 Mdot
.25714 .33622 Mdot
.25952 .33625 Mdot
.2619 .33627 Mdot
.26429 .3363 Mdot
.26667 .33633 Mdot
.26905 .33636 Mdot
.27143 .33638 Mdot
.27381 .33641 Mdot
.27619 .33644 Mdot
.27857 .33647 Mdot
.28095 .33649 Mdot
.28333 .33652 Mdot
.28571 .33655 Mdot
.2881 .33658 Mdot
.29048 .3366 Mdot
.29286 .33663 Mdot
.29524 .33666 Mdot
.29762 .33669 Mdot
.3 .33671 Mdot
.30238 .33674 Mdot
.30476 .33677 Mdot
.30714 .3368 Mdot
.30952 .33682 Mdot
.3119 .33685 Mdot
.31429 .33688 Mdot
.31667 .33691 Mdot
.31905 .33694 Mdot
.32143 .33696 Mdot
.32381 .33699 Mdot
.32619 .33702 Mdot
.32857 .33705 Mdot
.33095 .33708 Mdot
.33333 .3371 Mdot
.33571 .33713 Mdot
.3381 .33716 Mdot
.34048 .33719 Mdot
.34286 .33722 Mdot
.34524 .33724 Mdot
.34762 .33727 Mdot
.35 .3373 Mdot
.35238 .33733 Mdot
.35476 .33736 Mdot
.35714 .33739 Mdot
.35952 .33741 Mdot
.3619 .33744 Mdot
.36429 .33747 Mdot
.36667 .3375 Mdot
.36905 .33753 Mdot
.37143 .33756 Mdot
.37381 .33759 Mdot
.37619 .33761 Mdot
.37857 .33764 Mdot
.38095 .33767 Mdot
.38333 .3377 Mdot
.38571 .33773 Mdot
.3881 .33776 Mdot
.39048 .33779 Mdot
.39286 .33781 Mdot
.39524 .33784 Mdot
.39762 .33787 Mdot
.4 .3379 Mdot
.40238 .33793 Mdot
.40476 .33796 Mdot
.40714 .33799 Mdot
.40952 .33802 Mdot
.4119 .33805 Mdot
.41429 .33807 Mdot
.41667 .3381 Mdot
.41905 .33813 Mdot
.42143 .33816 Mdot
.42381 .33819 Mdot
.42619 .33822 Mdot
.42857 .33825 Mdot
.43095 .33828 Mdot
.43333 .33831 Mdot
.43571 .33834 Mdot
.4381 .33837 Mdot
.44048 .3384 Mdot
.44286 .33843 Mdot
.44524 .33845 Mdot
.44762 .33848 Mdot
.45 .33851 Mdot
.45238 .33854 Mdot
.45476 .33857 Mdot
.45714 .3386 Mdot
.45952 .33863 Mdot
.4619 .33866 Mdot
.46429 .33869 Mdot
.46667 .33872 Mdot
.46905 .33875 Mdot
.47143 .33878 Mdot
.47381 .33881 Mdot
.47619 .33884 Mdot
.47857 .33887 Mdot
.48095 .3389 Mdot
.48333 .33893 Mdot
.48571 .33896 Mdot
.4881 .33899 Mdot
.49048 .33902 Mdot
.49286 .33905 Mdot
.49524 .33908 Mdot
.49762 .33911 Mdot
.5 .33914 Mdot
.50238 .33917 Mdot
.50476 .3392 Mdot
.50714 .33923 Mdot
.50952 .33926 Mdot
.5119 .33929 Mdot
.51429 .33932 Mdot
.51667 .33935 Mdot
.51905 .33938 Mdot
.52143 .33941 Mdot
.52381 .33944 Mdot
.52619 .33947 Mdot
.52857 .3395 Mdot
.53095 .33953 Mdot
.53333 .33956 Mdot
.53571 .33959 Mdot
.5381 .33962 Mdot
.54048 .33966 Mdot
.54286 .33969 Mdot
.54524 .33972 Mdot
.54762 .33975 Mdot
.55 .33978 Mdot
.55238 .33981 Mdot
.55476 .33984 Mdot
.55714 .33987 Mdot
.55952 .3399 Mdot
.5619 .33993 Mdot
.56429 .33996 Mdot
.56667 .33999 Mdot
.56905 .34003 Mdot
.57143 .34006 Mdot
.57381 .34009 Mdot
.57619 .34012 Mdot
.57857 .34015 Mdot
.58095 .34018 Mdot
.58333 .34021 Mdot
.58571 .34024 Mdot
.5881 .34027 Mdot
.59048 .34031 Mdot
.59286 .34034 Mdot
.59524 .34037 Mdot
.59762 .3404 Mdot
.6 .34043 Mdot
.60238 .34046 Mdot
.60476 .34049 Mdot
.60714 .34053 Mdot
.60952 .34056 Mdot
.6119 .34059 Mdot
.61429 .34062 Mdot
.61667 .34065 Mdot
.61905 .34068 Mdot
.62143 .34071 Mdot
.62381 .34075 Mdot
.62619 .34078 Mdot
.62857 .34081 Mdot
.63095 .34084 Mdot
.63333 .34087 Mdot
.63571 .34091 Mdot
.6381 .34094 Mdot
.64048 .34097 Mdot
.64286 .341 Mdot
.64524 .34103 Mdot
.64762 .34106 Mdot
.65 .3411 Mdot
.65238 .34113 Mdot
.65476 .34116 Mdot
.65714 .34119 Mdot
.65952 .34123 Mdot
.6619 .34126 Mdot
.66429 .34129 Mdot
.66667 .34132 Mdot
.66905 .34135 Mdot
.67143 .34139 Mdot
.67381 .34142 Mdot
.67619 .34145 Mdot
.67857 .34148 Mdot
.68095 .34152 Mdot
.68333 .34155 Mdot
.68571 .34158 Mdot
.6881 .34161 Mdot
.69048 .34165 Mdot
.69286 .34168 Mdot
.69524 .34171 Mdot
.69762 .34174 Mdot
.7 .34178 Mdot
.70238 .34181 Mdot
.70476 .34184 Mdot
.70714 .34188 Mdot
.70952 .34191 Mdot
.7119 .34194 Mdot
.71429 .34197 Mdot
.71667 .34201 Mdot
.71905 .34204 Mdot
.72143 .34207 Mdot
.72381 .34211 Mdot
.72619 .34214 Mdot
.72857 .34217 Mdot
.73095 .34221 Mdot
.73333 .34224 Mdot
.73571 .34227 Mdot
.7381 .34231 Mdot
.74048 .34234 Mdot
.74286 .34237 Mdot
.74524 .34241 Mdot
.74762 .34244 Mdot
.75 .34247 Mdot
.75238 .34251 Mdot
.75476 .34254 Mdot
.75714 .34257 Mdot
.75952 .34261 Mdot
.7619 .34264 Mdot
.76429 .34267 Mdot
.76667 .34271 Mdot
.76905 .34274 Mdot
.77143 .34277 Mdot
.77381 .34281 Mdot
.77619 .34284 Mdot
.77857 .34288 Mdot
.78095 .34291 Mdot
.78333 .34294 Mdot
.78571 .34298 Mdot
.7881 .34301 Mdot
.79048 .34305 Mdot
.79286 .34308 Mdot
.79524 .34311 Mdot
.79762 .34315 Mdot
.8 .34318 Mdot
.80238 .34322 Mdot
.80476 .34325 Mdot
.80714 .34328 Mdot
.80952 .34332 Mdot
.8119 .34335 Mdot
.81429 .34339 Mdot
.81667 .34342 Mdot
.81905 .34346 Mdot
.82143 .34349 Mdot
.82381 .34353 Mdot
.82619 .34356 Mdot
.82857 .34359 Mdot
.83095 .34363 Mdot
.83333 .34366 Mdot
.83571 .3437 Mdot
.8381 .34373 Mdot
.84048 .34377 Mdot
.84286 .3438 Mdot
.84524 .34384 Mdot
.84762 .34387 Mdot
.85 .34391 Mdot
.85238 .34394 Mdot
.85476 .34398 Mdot
.85714 .34401 Mdot
.85952 .34405 Mdot
.8619 .34408 Mdot
.86429 .34412 Mdot
.86667 .34415 Mdot
.86905 .34419 Mdot
.87143 .34422 Mdot
.87381 .34426 Mdot
.87619 .34429 Mdot
.87857 .34433 Mdot
.88095 .34436 Mdot
.88333 .3444 Mdot
.88571 .34443 Mdot
.8881 .34447 Mdot
.89048 .3445 Mdot
.89286 .34454 Mdot
.89524 .34458 Mdot
.89762 .34461 Mdot
.9 .34465 Mdot
.90238 .34468 Mdot
.90476 .34472 Mdot
.90714 .34475 Mdot
.90952 .34479 Mdot
.9119 .34483 Mdot
.91429 .34486 Mdot
.91667 .3449 Mdot
.91905 .34493 Mdot
.92143 .34497 Mdot
.92381 .345 Mdot
.92619 .34504 Mdot
.92857 .34508 Mdot
.93095 .34511 Mdot
.93333 .34515 Mdot
.93571 .34518 Mdot
.9381 .34522 Mdot
.94048 .34526 Mdot
.94286 .34529 Mdot
.94524 .34533 Mdot
.94762 .34537 Mdot
.95 .3454 Mdot
.95238 .34544 Mdot
.95476 .34548 Mdot
.95714 .34551 Mdot
.95952 .34555 Mdot
.9619 .34558 Mdot
.96429 .34562 Mdot
.96667 .34566 Mdot
.96905 .34569 Mdot
.97143 .34573 Mdot
.97381 .34577 Mdot
.97619 .3458 Mdot
.02381 .35835 Mdot
.02619 .3584 Mdot
.02857 .35844 Mdot
.03095 .35849 Mdot
.03333 .35854 Mdot
.03571 .35859 Mdot
.0381 .35864 Mdot
.04048 .35869 Mdot
.04286 .35874 Mdot
.04524 .35879 Mdot
.04762 .35884 Mdot
.05 .35889 Mdot
.05238 .35894 Mdot
.05476 .35899 Mdot
.05714 .35904 Mdot
.05952 .35909 Mdot
.0619 .35914 Mdot
.06429 .35919 Mdot
.06667 .35924 Mdot
.06905 .35929 Mdot
.07143 .35934 Mdot
.07381 .35939 Mdot
.07619 .35944 Mdot
.07857 .35949 Mdot
.08095 .35954 Mdot
.08333 .35959 Mdot
.08571 .35964 Mdot
.0881 .3597 Mdot
.09048 .35975 Mdot
.09286 .3598 Mdot
.09524 .35985 Mdot
.09762 .3599 Mdot
.1 .35995 Mdot
.10238 .36 Mdot
.10476 .36005 Mdot
.10714 .3601 Mdot
.10952 .36015 Mdot
.1119 .3602 Mdot
.11429 .36026 Mdot
.11667 .36031 Mdot
.11905 .36036 Mdot
.12143 .36041 Mdot
.12381 .36046 Mdot
.12619 .36051 Mdot
.12857 .36056 Mdot
.13095 .36062 Mdot
.13333 .36067 Mdot
.13571 .36072 Mdot
.1381 .36077 Mdot
.14048 .36082 Mdot
.14286 .36087 Mdot
.14524 .36093 Mdot
.14762 .36098 Mdot
.15 .36103 Mdot
.15238 .36108 Mdot
.15476 .36113 Mdot
.15714 .36119 Mdot
.15952 .36124 Mdot
.1619 .36129 Mdot
.16429 .36134 Mdot
.16667 .36139 Mdot
.16905 .36145 Mdot
.17143 .3615 Mdot
.17381 .36155 Mdot
.17619 .3616 Mdot
.17857 .36166 Mdot
.18095 .36171 Mdot
.18333 .36176 Mdot
.18571 .36182 Mdot
.1881 .36187 Mdot
.19048 .36192 Mdot
.19286 .36197 Mdot
.19524 .36203 Mdot
.19762 .36208 Mdot
.2 .36213 Mdot
.20238 .36219 Mdot
.20476 .36224 Mdot
.20714 .36229 Mdot
.20952 .36235 Mdot
.2119 .3624 Mdot
.21429 .36245 Mdot
.21667 .36251 Mdot
.21905 .36256 Mdot
.22143 .36261 Mdot
.22381 .36267 Mdot
.22619 .36272 Mdot
.22857 .36277 Mdot
.23095 .36283 Mdot
.23333 .36288 Mdot
.23571 .36294 Mdot
.2381 .36299 Mdot
.24048 .36304 Mdot
.24286 .3631 Mdot
.24524 .36315 Mdot
.24762 .36321 Mdot
.25 .36326 Mdot
.25238 .36331 Mdot
.25476 .36337 Mdot
.25714 .36342 Mdot
.25952 .36348 Mdot
.2619 .36353 Mdot
.26429 .36359 Mdot
.26667 .36364 Mdot
.26905 .36369 Mdot
.27143 .36375 Mdot
.27381 .3638 Mdot
.27619 .36386 Mdot
.27857 .36391 Mdot
.28095 .36397 Mdot
.28333 .36402 Mdot
.28571 .36408 Mdot
.2881 .36413 Mdot
.29048 .36419 Mdot
.29286 .36424 Mdot
.29524 .3643 Mdot
.29762 .36435 Mdot
.3 .36441 Mdot
.30238 .36447 Mdot
.30476 .36452 Mdot
.30714 .36458 Mdot
.30952 .36463 Mdot
.3119 .36469 Mdot
.31429 .36474 Mdot
.31667 .3648 Mdot
.31905 .36485 Mdot
.32143 .36491 Mdot
.32381 .36497 Mdot
.32619 .36502 Mdot
.32857 .36508 Mdot
.33095 .36513 Mdot
.33333 .36519 Mdot
.33571 .36525 Mdot
.3381 .3653 Mdot
.34048 .36536 Mdot
.34286 .36542 Mdot
.34524 .36547 Mdot
.34762 .36553 Mdot
.35 .36558 Mdot
.35238 .36564 Mdot
.35476 .3657 Mdot
.35714 .36575 Mdot
.35952 .36581 Mdot
.3619 .36587 Mdot
.36429 .36593 Mdot
.36667 .36598 Mdot
.36905 .36604 Mdot
.37143 .3661 Mdot
.37381 .36615 Mdot
.37619 .36621 Mdot
.37857 .36627 Mdot
.38095 .36632 Mdot
.38333 .36638 Mdot
.38571 .36644 Mdot
.3881 .3665 Mdot
.39048 .36655 Mdot
.39286 .36661 Mdot
.39524 .36667 Mdot
.39762 .36673 Mdot
.4 .36678 Mdot
.40238 .36684 Mdot
.40476 .3669 Mdot
.40714 .36696 Mdot
.40952 .36702 Mdot
.4119 .36707 Mdot
.41429 .36713 Mdot
.41667 .36719 Mdot
.41905 .36725 Mdot
.42143 .36731 Mdot
.42381 .36737 Mdot
.42619 .36742 Mdot
.42857 .36748 Mdot
.43095 .36754 Mdot
.43333 .3676 Mdot
.43571 .36766 Mdot
.4381 .36772 Mdot
.44048 .36777 Mdot
.44286 .36783 Mdot
.44524 .36789 Mdot
.44762 .36795 Mdot
.45 .36801 Mdot
.45238 .36807 Mdot
.45476 .36813 Mdot
.45714 .36819 Mdot
.45952 .36825 Mdot
.4619 .36831 Mdot
.46429 .36837 Mdot
.46667 .36842 Mdot
.46905 .36848 Mdot
.47143 .36854 Mdot
.47381 .3686 Mdot
.47619 .36866 Mdot
.47857 .36872 Mdot
.48095 .36878 Mdot
.48333 .36884 Mdot
.48571 .3689 Mdot
.4881 .36896 Mdot
.49048 .36902 Mdot
.49286 .36908 Mdot
.49524 .36914 Mdot
.49762 .3692 Mdot
.5 .36926 Mdot
.50238 .36932 Mdot
.50476 .36938 Mdot
.50714 .36944 Mdot
.50952 .3695 Mdot
.5119 .36956 Mdot
.51429 .36962 Mdot
.51667 .36968 Mdot
.51905 .36975 Mdot
.52143 .36981 Mdot
.52381 .36987 Mdot
.52619 .36993 Mdot
.52857 .36999 Mdot
.53095 .37005 Mdot
.53333 .37011 Mdot
.53571 .37017 Mdot
.5381 .37023 Mdot
.54048 .37029 Mdot
.54286 .37036 Mdot
.54524 .37042 Mdot
.54762 .37048 Mdot
.55 .37054 Mdot
.55238 .3706 Mdot
.55476 .37066 Mdot
.55714 .37072 Mdot
.55952 .37079 Mdot
.5619 .37085 Mdot
.56429 .37091 Mdot
.56667 .37097 Mdot
.56905 .37103 Mdot
.57143 .3711 Mdot
.57381 .37116 Mdot
.57619 .37122 Mdot
.57857 .37128 Mdot
.58095 .37134 Mdot
.58333 .37141 Mdot
.58571 .37147 Mdot
.5881 .37153 Mdot
.59048 .37159 Mdot
.59286 .37166 Mdot
.59524 .37172 Mdot
.59762 .37178 Mdot
.6 .37184 Mdot
.60238 .37191 Mdot
.60476 .37197 Mdot
.60714 .37203 Mdot
.60952 .3721 Mdot
.6119 .37216 Mdot
.61429 .37222 Mdot
.61667 .37229 Mdot
.61905 .37235 Mdot
.62143 .37241 Mdot
.62381 .37248 Mdot
.62619 .37254 Mdot
.62857 .3726 Mdot
.63095 .37267 Mdot
.63333 .37273 Mdot
.63571 .37279 Mdot
.6381 .37286 Mdot
.64048 .37292 Mdot
.64286 .37298 Mdot
.64524 .37305 Mdot
.64762 .37311 Mdot
.65 .37318 Mdot
.65238 .37324 Mdot
.65476 .37331 Mdot
.65714 .37337 Mdot
.65952 .37343 Mdot
.6619 .3735 Mdot
.66429 .37356 Mdot
.66667 .37363 Mdot
.66905 .37369 Mdot
.67143 .37376 Mdot
.67381 .37382 Mdot
.67619 .37389 Mdot
.67857 .37395 Mdot
.68095 .37402 Mdot
.68333 .37408 Mdot
.68571 .37415 Mdot
.6881 .37421 Mdot
.69048 .37428 Mdot
.69286 .37434 Mdot
.69524 .37441 Mdot
.69762 .37447 Mdot
.7 .37454 Mdot
.70238 .3746 Mdot
.70476 .37467 Mdot
.70714 .37473 Mdot
.70952 .3748 Mdot
.7119 .37487 Mdot
.71429 .37493 Mdot
.71667 .375 Mdot
.71905 .37506 Mdot
.72143 .37513 Mdot
.72381 .3752 Mdot
.72619 .37526 Mdot
.72857 .37533 Mdot
.73095 .37539 Mdot
.73333 .37546 Mdot
.73571 .37553 Mdot
.7381 .37559 Mdot
.74048 .37566 Mdot
.74286 .37573 Mdot
.74524 .37579 Mdot
.74762 .37586 Mdot
.75 .37593 Mdot
.75238 .37599 Mdot
.75476 .37606 Mdot
.75714 .37613 Mdot
.75952 .3762 Mdot
.7619 .37626 Mdot
.76429 .37633 Mdot
.76667 .3764 Mdot
.76905 .37646 Mdot
.77143 .37653 Mdot
.77381 .3766 Mdot
.77619 .37667 Mdot
.77857 .37674 Mdot
.78095 .3768 Mdot
.78333 .37687 Mdot
.78571 .37694 Mdot
.7881 .37701 Mdot
.79048 .37707 Mdot
.79286 .37714 Mdot
.79524 .37721 Mdot
.79762 .37728 Mdot
.8 .37735 Mdot
.80238 .37742 Mdot
.80476 .37748 Mdot
.80714 .37755 Mdot
.80952 .37762 Mdot
.8119 .37769 Mdot
.81429 .37776 Mdot
.81667 .37783 Mdot
.81905 .3779 Mdot
.82143 .37796 Mdot
.82381 .37803 Mdot
.82619 .3781 Mdot
.82857 .37817 Mdot
.83095 .37824 Mdot
.83333 .37831 Mdot
.83571 .37838 Mdot
.8381 .37845 Mdot
.84048 .37852 Mdot
.84286 .37859 Mdot
.84524 .37866 Mdot
.84762 .37873 Mdot
.85 .3788 Mdot
.85238 .37887 Mdot
.85476 .37894 Mdot
.85714 .37901 Mdot
.85952 .37908 Mdot
.8619 .37915 Mdot
.86429 .37922 Mdot
.86667 .37929 Mdot
.86905 .37936 Mdot
.87143 .37943 Mdot
.87381 .3795 Mdot
.87619 .37957 Mdot
.87857 .37964 Mdot
.88095 .37971 Mdot
.88333 .37978 Mdot
.88571 .37985 Mdot
.8881 .37992 Mdot
.89048 .37999 Mdot
.89286 .38006 Mdot
.89524 .38013 Mdot
.89762 .38021 Mdot
.9 .38028 Mdot
.90238 .38035 Mdot
.90476 .38042 Mdot
.90714 .38049 Mdot
.90952 .38056 Mdot
.9119 .38063 Mdot
.91429 .38071 Mdot
.91667 .38078 Mdot
.91905 .38085 Mdot
.92143 .38092 Mdot
.92381 .38099 Mdot
.92619 .38106 Mdot
.92857 .38114 Mdot
.93095 .38121 Mdot
.93333 .38128 Mdot
.93571 .38135 Mdot
.9381 .38143 Mdot
.94048 .3815 Mdot
.94286 .38157 Mdot
.94524 .38164 Mdot
.94762 .38172 Mdot
.95 .38179 Mdot
.95238 .38186 Mdot
.95476 .38193 Mdot
.95714 .38201 Mdot
.95952 .38208 Mdot
.9619 .38215 Mdot
.96429 .38223 Mdot
.96667 .3823 Mdot
.96905 .38237 Mdot
.97143 .38245 Mdot
.97381 .38252 Mdot
.97619 .38259 Mdot
.02381 .38301 Mdot
.02619 .38308 Mdot
.02857 .38316 Mdot
.03095 .38323 Mdot
.03333 .38331 Mdot
.03571 .38338 Mdot
.0381 .38346 Mdot
.04048 .38353 Mdot
.04286 .3836 Mdot
.04524 .38368 Mdot
.04762 .38375 Mdot
.05 .38383 Mdot
.05238 .3839 Mdot
.05476 .38398 Mdot
.05714 .38405 Mdot
.05952 .38413 Mdot
.0619 .3842 Mdot
.06429 .38428 Mdot
.06667 .38435 Mdot
.06905 .38443 Mdot
.07143 .3845 Mdot
.07381 .38458 Mdot
.07619 .38466 Mdot
.07857 .38473 Mdot
.08095 .38481 Mdot
.08333 .38488 Mdot
.08571 .38496 Mdot
.0881 .38503 Mdot
.09048 .38511 Mdot
.09286 .38519 Mdot
.09524 .38526 Mdot
.09762 .38534 Mdot
.1 .38542 Mdot
.10238 .38549 Mdot
.10476 .38557 Mdot
.10714 .38564 Mdot
.10952 .38572 Mdot
.1119 .3858 Mdot
.11429 .38587 Mdot
.11667 .38595 Mdot
.11905 .38603 Mdot
.12143 .38611 Mdot
.12381 .38618 Mdot
.12619 .38626 Mdot
.12857 .38634 Mdot
.13095 .38641 Mdot
.13333 .38649 Mdot
.13571 .38657 Mdot
.1381 .38665 Mdot
.14048 .38672 Mdot
.14286 .3868 Mdot
.14524 .38688 Mdot
.14762 .38696 Mdot
.15 .38704 Mdot
.15238 .38711 Mdot
.15476 .38719 Mdot
.15714 .38727 Mdot
.15952 .38735 Mdot
.1619 .38743 Mdot
.16429 .38751 Mdot
.16667 .38758 Mdot
.16905 .38766 Mdot
.17143 .38774 Mdot
.17381 .38782 Mdot
.17619 .3879 Mdot
.17857 .38798 Mdot
.18095 .38806 Mdot
.18333 .38814 Mdot
.18571 .38821 Mdot
.1881 .38829 Mdot
.19048 .38837 Mdot
.19286 .38845 Mdot
.19524 .38853 Mdot
.19762 .38861 Mdot
.2 .38869 Mdot
.20238 .38877 Mdot
.20476 .38885 Mdot
.20714 .38893 Mdot
.20952 .38901 Mdot
.2119 .38909 Mdot
.21429 .38917 Mdot
.21667 .38925 Mdot
.21905 .38933 Mdot
.22143 .38941 Mdot
.22381 .38949 Mdot
.22619 .38957 Mdot
.22857 .38965 Mdot
.23095 .38973 Mdot
.23333 .38981 Mdot
.23571 .38989 Mdot
.2381 .38998 Mdot
.24048 .39006 Mdot
.24286 .39014 Mdot
.24524 .39022 Mdot
.24762 .3903 Mdot
.25 .39038 Mdot
.25238 .39046 Mdot
.25476 .39054 Mdot
.25714 .39063 Mdot
.25952 .39071 Mdot
.2619 .39079 Mdot
.26429 .39087 Mdot
.26667 .39095 Mdot
.26905 .39103 Mdot
.27143 .39112 Mdot
.27381 .3912 Mdot
.27619 .39128 Mdot
.27857 .39136 Mdot
.28095 .39144 Mdot
.28333 .39153 Mdot
.28571 .39161 Mdot
.2881 .39169 Mdot
.29048 .39178 Mdot
.29286 .39186 Mdot
.29524 .39194 Mdot
.29762 .39202 Mdot
.3 .39211 Mdot
.30238 .39219 Mdot
.30476 .39227 Mdot
.30714 .39236 Mdot
.30952 .39244 Mdot
.3119 .39252 Mdot
.31429 .39261 Mdot
.31667 .39269 Mdot
.31905 .39277 Mdot
.32143 .39286 Mdot
.32381 .39294 Mdot
.32619 .39303 Mdot
.32857 .39311 Mdot
.33095 .39319 Mdot
.33333 .39328 Mdot
.33571 .39336 Mdot
.3381 .39345 Mdot
.34048 .39353 Mdot
.34286 .39361 Mdot
.34524 .3937 Mdot
.34762 .39378 Mdot
.35 .39387 Mdot
.35238 .39395 Mdot
.35476 .39404 Mdot
.35714 .39412 Mdot
.35952 .39421 Mdot
.3619 .39429 Mdot
.36429 .39438 Mdot
.36667 .39446 Mdot
.36905 .39455 Mdot
.37143 .39464 Mdot
.37381 .39472 Mdot
.37619 .39481 Mdot
.37857 .39489 Mdot
.38095 .39498 Mdot
.38333 .39506 Mdot
.38571 .39515 Mdot
.3881 .39524 Mdot
.39048 .39532 Mdot
.39286 .39541 Mdot
.39524 .3955 Mdot
.39762 .39558 Mdot
.4 .39567 Mdot
.40238 .39576 Mdot
.40476 .39584 Mdot
.40714 .39593 Mdot
.40952 .39602 Mdot
.4119 .3961 Mdot
.41429 .39619 Mdot
.41667 .39628 Mdot
.41905 .39636 Mdot
.42143 .39645 Mdot
.42381 .39654 Mdot
.42619 .39663 Mdot
.42857 .39671 Mdot
.43095 .3968 Mdot
.43333 .39689 Mdot
.43571 .39698 Mdot
.4381 .39707 Mdot
.44048 .39715 Mdot
.44286 .39724 Mdot
.44524 .39733 Mdot
.44762 .39742 Mdot
.45 .39751 Mdot
.45238 .3976 Mdot
.45476 .39768 Mdot
.45714 .39777 Mdot
.45952 .39786 Mdot
.4619 .39795 Mdot
.46429 .39804 Mdot
.46667 .39813 Mdot
.46905 .39822 Mdot
.47143 .39831 Mdot
.47381 .3984 Mdot
.47619 .39849 Mdot
.47857 .39857 Mdot
.48095 .39866 Mdot
.48333 .39875 Mdot
.48571 .39884 Mdot
.4881 .39893 Mdot
.49048 .39902 Mdot
.49286 .39911 Mdot
.49524 .3992 Mdot
.49762 .39929 Mdot
.5 .39938 Mdot
.50238 .39947 Mdot
.50476 .39956 Mdot
.50714 .39966 Mdot
.50952 .39975 Mdot
.5119 .39984 Mdot
.51429 .39993 Mdot
.51667 .40002 Mdot
.51905 .40011 Mdot
.52143 .4002 Mdot
.52381 .40029 Mdot
.52619 .40038 Mdot
.52857 .40047 Mdot
.53095 .40057 Mdot
.53333 .40066 Mdot
.53571 .40075 Mdot
.5381 .40084 Mdot
.54048 .40093 Mdot
.54286 .40102 Mdot
.54524 .40112 Mdot
.54762 .40121 Mdot
.55 .4013 Mdot
.55238 .40139 Mdot
.55476 .40149 Mdot
.55714 .40158 Mdot
.55952 .40167 Mdot
.5619 .40176 Mdot
.56429 .40186 Mdot
.56667 .40195 Mdot
.56905 .40204 Mdot
.57143 .40213 Mdot
.57381 .40223 Mdot
.57619 .40232 Mdot
.57857 .40241 Mdot
.58095 .40251 Mdot
.58333 .4026 Mdot
.58571 .40269 Mdot
.5881 .40279 Mdot
.59048 .40288 Mdot
.59286 .40298 Mdot
.59524 .40307 Mdot
.59762 .40316 Mdot
.6 .40326 Mdot
.60238 .40335 Mdot
.60476 .40345 Mdot
.60714 .40354 Mdot
.60952 .40364 Mdot
.6119 .40373 Mdot
.61429 .40382 Mdot
.61667 .40392 Mdot
.61905 .40401 Mdot
.62143 .40411 Mdot
.62381 .4042 Mdot
.62619 .4043 Mdot
.62857 .4044 Mdot
.63095 .40449 Mdot
.63333 .40459 Mdot
.63571 .40468 Mdot
.6381 .40478 Mdot
.64048 .40487 Mdot
.64286 .40497 Mdot
.64524 .40506 Mdot
.64762 .40516 Mdot
.65 .40526 Mdot
.65238 .40535 Mdot
.65476 .40545 Mdot
.65714 .40555 Mdot
.65952 .40564 Mdot
.6619 .40574 Mdot
.66429 .40584 Mdot
.66667 .40593 Mdot
.66905 .40603 Mdot
.67143 .40613 Mdot
.67381 .40622 Mdot
.67619 .40632 Mdot
.67857 .40642 Mdot
.68095 .40652 Mdot
.68333 .40661 Mdot
.68571 .40671 Mdot
.6881 .40681 Mdot
.69048 .40691 Mdot
.69286 .407 Mdot
.69524 .4071 Mdot
.69762 .4072 Mdot
.7 .4073 Mdot
.70238 .4074 Mdot
.70476 .4075 Mdot
.70714 .40759 Mdot
.70952 .40769 Mdot
.7119 .40779 Mdot
.71429 .40789 Mdot
.71667 .40799 Mdot
.71905 .40809 Mdot
.72143 .40819 Mdot
.72381 .40829 Mdot
.72619 .40838 Mdot
.72857 .40848 Mdot
.73095 .40858 Mdot
.73333 .40868 Mdot
.73571 .40878 Mdot
.7381 .40888 Mdot
.74048 .40898 Mdot
.74286 .40908 Mdot
.74524 .40918 Mdot
.74762 .40928 Mdot
.75 .40938 Mdot
.75238 .40948 Mdot
.75476 .40958 Mdot
.75714 .40968 Mdot
.75952 .40979 Mdot
.7619 .40989 Mdot
.76429 .40999 Mdot
.76667 .41009 Mdot
.76905 .41019 Mdot
.77143 .41029 Mdot
.77381 .41039 Mdot
.77619 .41049 Mdot
.77857 .41059 Mdot
.78095 .4107 Mdot
.78333 .4108 Mdot
.78571 .4109 Mdot
.7881 .411 Mdot
.79048 .4111 Mdot
.79286 .41121 Mdot
.79524 .41131 Mdot
.79762 .41141 Mdot
.8 .41151 Mdot
.80238 .41161 Mdot
.80476 .41172 Mdot
.80714 .41182 Mdot
.80952 .41192 Mdot
.8119 .41203 Mdot
.81429 .41213 Mdot
.81667 .41223 Mdot
.81905 .41233 Mdot
.82143 .41244 Mdot
.82381 .41254 Mdot
.82619 .41265 Mdot
.82857 .41275 Mdot
.83095 .41285 Mdot
.83333 .41296 Mdot
.83571 .41306 Mdot
.8381 .41316 Mdot
.84048 .41327 Mdot
.84286 .41337 Mdot
.84524 .41348 Mdot
.84762 .41358 Mdot
.85 .41369 Mdot
.85238 .41379 Mdot
.85476 .4139 Mdot
.85714 .414 Mdot
.85952 .41411 Mdot
.8619 .41421 Mdot
.86429 .41432 Mdot
.86667 .41442 Mdot
.86905 .41453 Mdot
.87143 .41463 Mdot
.87381 .41474 Mdot
.87619 .41484 Mdot
.87857 .41495 Mdot
.88095 .41505 Mdot
.88333 .41516 Mdot
.88571 .41527 Mdot
.8881 .41537 Mdot
.89048 .41548 Mdot
.89286 .41559 Mdot
.89524 .41569 Mdot
.89762 .4158 Mdot
.9 .41591 Mdot
.90238 .41601 Mdot
.90476 .41612 Mdot
.90714 .41623 Mdot
.90952 .41633 Mdot
.9119 .41644 Mdot
.91429 .41655 Mdot
.91667 .41666 Mdot
.91905 .41676 Mdot
.92143 .41687 Mdot
.92381 .41698 Mdot
.92619 .41709 Mdot
.92857 .4172 Mdot
.93095 .4173 Mdot
.93333 .41741 Mdot
.93571 .41752 Mdot
.9381 .41763 Mdot
.94048 .41774 Mdot
.94286 .41785 Mdot
.94524 .41796 Mdot
.94762 .41806 Mdot
.95 .41817 Mdot
.95238 .41828 Mdot
.95476 .41839 Mdot
.95714 .4185 Mdot
.95952 .41861 Mdot
.9619 .41872 Mdot
.96429 .41883 Mdot
.96667 .41894 Mdot
.96905 .41905 Mdot
.97143 .41916 Mdot
.97381 .41927 Mdot
.97619 .41938 Mdot
.02381 .40767 Mdot
.02619 .40777 Mdot
.02857 .40787 Mdot
.03095 .40797 Mdot
.03333 .40807 Mdot
.03571 .40817 Mdot
.0381 .40827 Mdot
.04048 .40837 Mdot
.04286 .40847 Mdot
.04524 .40857 Mdot
.04762 .40867 Mdot
.05 .40877 Mdot
.05238 .40887 Mdot
.05476 .40897 Mdot
.05714 .40907 Mdot
.05952 .40917 Mdot
.0619 .40927 Mdot
.06429 .40937 Mdot
.06667 .40947 Mdot
.06905 .40957 Mdot
.07143 .40967 Mdot
.07381 .40977 Mdot
.07619 .40987 Mdot
.07857 .40997 Mdot
.08095 .41007 Mdot
.08333 .41017 Mdot
.08571 .41027 Mdot
.0881 .41037 Mdot
.09048 .41047 Mdot
.09286 .41058 Mdot
.09524 .41068 Mdot
.09762 .41078 Mdot
.1 .41088 Mdot
.10238 .41098 Mdot
.10476 .41109 Mdot
.10714 .41119 Mdot
.10952 .41129 Mdot
.1119 .41139 Mdot
.11429 .41149 Mdot
.11667 .4116 Mdot
.11905 .4117 Mdot
.12143 .4118 Mdot
.12381 .4119 Mdot
.12619 .41201 Mdot
.12857 .41211 Mdot
.13095 .41221 Mdot
.13333 .41232 Mdot
.13571 .41242 Mdot
.1381 .41252 Mdot
.14048 .41263 Mdot
.14286 .41273 Mdot
.14524 .41283 Mdot
.14762 .41294 Mdot
.15 .41304 Mdot
.15238 .41315 Mdot
.15476 .41325 Mdot
.15714 .41335 Mdot
.15952 .41346 Mdot
.1619 .41356 Mdot
.16429 .41367 Mdot
.16667 .41377 Mdot
.16905 .41388 Mdot
.17143 .41398 Mdot
.17381 .41409 Mdot
.17619 .41419 Mdot
.17857 .4143 Mdot
.18095 .4144 Mdot
.18333 .41451 Mdot
.18571 .41461 Mdot
.1881 .41472 Mdot
.19048 .41482 Mdot
.19286 .41493 Mdot
.19524 .41504 Mdot
.19762 .41514 Mdot
.2 .41525 Mdot
.20238 .41535 Mdot
.20476 .41546 Mdot
.20714 .41557 Mdot
.20952 .41567 Mdot
.2119 .41578 Mdot
.21429 .41589 Mdot
.21667 .41599 Mdot
.21905 .4161 Mdot
.22143 .41621 Mdot
.22381 .41632 Mdot
.22619 .41642 Mdot
.22857 .41653 Mdot
.23095 .41664 Mdot
.23333 .41675 Mdot
.23571 .41685 Mdot
.2381 .41696 Mdot
.24048 .41707 Mdot
.24286 .41718 Mdot
.24524 .41729 Mdot
.24762 .41739 Mdot
.25 .4175 Mdot
.25238 .41761 Mdot
.25476 .41772 Mdot
.25714 .41783 Mdot
.25952 .41794 Mdot
.2619 .41805 Mdot
.26429 .41815 Mdot
.26667 .41826 Mdot
.26905 .41837 Mdot
.27143 .41848 Mdot
.27381 .41859 Mdot
.27619 .4187 Mdot
.27857 .41881 Mdot
.28095 .41892 Mdot
.28333 .41903 Mdot
.28571 .41914 Mdot
.2881 .41925 Mdot
.29048 .41936 Mdot
.29286 .41947 Mdot
.29524 .41958 Mdot
.29762 .41969 Mdot
.3 .4198 Mdot
.30238 .41991 Mdot
.30476 .42002 Mdot
.30714 .42014 Mdot
.30952 .42025 Mdot
.3119 .42036 Mdot
.31429 .42047 Mdot
.31667 .42058 Mdot
.31905 .42069 Mdot
.32143 .4208 Mdot
.32381 .42092 Mdot
.32619 .42103 Mdot
.32857 .42114 Mdot
.33095 .42125 Mdot
.33333 .42136 Mdot
.33571 .42148 Mdot
.3381 .42159 Mdot
.34048 .4217 Mdot
.34286 .42181 Mdot
.34524 .42193 Mdot
.34762 .42204 Mdot
.35 .42215 Mdot
.35238 .42227 Mdot
.35476 .42238 Mdot
.35714 .42249 Mdot
.35952 .42261 Mdot
.3619 .42272 Mdot
.36429 .42283 Mdot
.36667 .42295 Mdot
.36905 .42306 Mdot
.37143 .42318 Mdot
.37381 .42329 Mdot
.37619 .4234 Mdot
.37857 .42352 Mdot
.38095 .42363 Mdot
.38333 .42375 Mdot
.38571 .42386 Mdot
.3881 .42398 Mdot
.39048 .42409 Mdot
.39286 .42421 Mdot
.39524 .42432 Mdot
.39762 .42444 Mdot
.4 .42455 Mdot
.40238 .42467 Mdot
.40476 .42478 Mdot
.40714 .4249 Mdot
.40952 .42502 Mdot
.4119 .42513 Mdot
.41429 .42525 Mdot
.41667 .42536 Mdot
.41905 .42548 Mdot
.42143 .4256 Mdot
.42381 .42571 Mdot
.42619 .42583 Mdot
.42857 .42595 Mdot
.43095 .42606 Mdot
.43333 .42618 Mdot
.43571 .4263 Mdot
.4381 .42642 Mdot
.44048 .42653 Mdot
.44286 .42665 Mdot
.44524 .42677 Mdot
.44762 .42689 Mdot
.45 .427 Mdot
.45238 .42712 Mdot
.45476 .42724 Mdot
.45714 .42736 Mdot
.45952 .42748 Mdot
.4619 .42759 Mdot
.46429 .42771 Mdot
.46667 .42783 Mdot
.46905 .42795 Mdot
.47143 .42807 Mdot
.47381 .42819 Mdot
.47619 .42831 Mdot
.47857 .42843 Mdot
.48095 .42855 Mdot
.48333 .42867 Mdot
.48571 .42879 Mdot
.4881 .42891 Mdot
.49048 .42903 Mdot
.49286 .42915 Mdot
.49524 .42927 Mdot
.49762 .42939 Mdot
.5 .42951 Mdot
.50238 .42963 Mdot
.50476 .42975 Mdot
.50714 .42987 Mdot
.50952 .42999 Mdot
.5119 .43011 Mdot
.51429 .43023 Mdot
.51667 .43035 Mdot
.51905 .43047 Mdot
.52143 .43059 Mdot
.52381 .43072 Mdot
.52619 .43084 Mdot
.52857 .43096 Mdot
.53095 .43108 Mdot
.53333 .4312 Mdot
.53571 .43133 Mdot
.5381 .43145 Mdot
.54048 .43157 Mdot
.54286 .43169 Mdot
.54524 .43182 Mdot
.54762 .43194 Mdot
.55 .43206 Mdot
.55238 .43218 Mdot
.55476 .43231 Mdot
.55714 .43243 Mdot
.55952 .43255 Mdot
.5619 .43268 Mdot
.56429 .4328 Mdot
.56667 .43293 Mdot
.56905 .43305 Mdot
.57143 .43317 Mdot
.57381 .4333 Mdot
.57619 .43342 Mdot
.57857 .43355 Mdot
.58095 .43367 Mdot
.58333 .4338 Mdot
.58571 .43392 Mdot
.5881 .43405 Mdot
.59048 .43417 Mdot
.59286 .4343 Mdot
.59524 .43442 Mdot
.59762 .43455 Mdot
.6 .43467 Mdot
.60238 .4348 Mdot
.60476 .43492 Mdot
.60714 .43505 Mdot
.60952 .43518 Mdot
.6119 .4353 Mdot
.61429 .43543 Mdot
.61667 .43555 Mdot
.61905 .43568 Mdot
.62143 .43581 Mdot
.62381 .43593 Mdot
.62619 .43606 Mdot
.62857 .43619 Mdot
.63095 .43632 Mdot
.63333 .43644 Mdot
.63571 .43657 Mdot
.6381 .4367 Mdot
.64048 .43683 Mdot
.64286 .43695 Mdot
.64524 .43708 Mdot
.64762 .43721 Mdot
.65 .43734 Mdot
.65238 .43747 Mdot
.65476 .43759 Mdot
.65714 .43772 Mdot
.65952 .43785 Mdot
.6619 .43798 Mdot
.66429 .43811 Mdot
.66667 .43824 Mdot
.66905 .43837 Mdot
.67143 .4385 Mdot
.67381 .43863 Mdot
.67619 .43876 Mdot
.67857 .43889 Mdot
.68095 .43902 Mdot
.68333 .43915 Mdot
.68571 .43928 Mdot
.6881 .43941 Mdot
.69048 .43954 Mdot
.69286 .43967 Mdot
.69524 .4398 Mdot
.69762 .43993 Mdot
.7 .44006 Mdot
.70238 .44019 Mdot
.70476 .44032 Mdot
.70714 .44045 Mdot
.70952 .44058 Mdot
.7119 .44072 Mdot
.71429 .44085 Mdot
.71667 .44098 Mdot
.71905 .44111 Mdot
.72143 .44124 Mdot
.72381 .44138 Mdot
.72619 .44151 Mdot
.72857 .44164 Mdot
.73095 .44177 Mdot
.73333 .44191 Mdot
.73571 .44204 Mdot
.7381 .44217 Mdot
.74048 .4423 Mdot
.74286 .44244 Mdot
.74524 .44257 Mdot
.74762 .4427 Mdot
.75 .44284 Mdot
.75238 .44297 Mdot
.75476 .44311 Mdot
.75714 .44324 Mdot
.75952 .44337 Mdot
.7619 .44351 Mdot
.76429 .44364 Mdot
.76667 .44378 Mdot
.76905 .44391 Mdot
.77143 .44405 Mdot
.77381 .44418 Mdot
.77619 .44432 Mdot
.77857 .44445 Mdot
.78095 .44459 Mdot
.78333 .44472 Mdot
.78571 .44486 Mdot
.7881 .445 Mdot
.79048 .44513 Mdot
.79286 .44527 Mdot
.79524 .4454 Mdot
.79762 .44554 Mdot
.8 .44568 Mdot
.80238 .44581 Mdot
.80476 .44595 Mdot
.80714 .44609 Mdot
.80952 .44622 Mdot
.8119 .44636 Mdot
.81429 .4465 Mdot
.81667 .44664 Mdot
.81905 .44677 Mdot
.82143 .44691 Mdot
.82381 .44705 Mdot
.82619 .44719 Mdot
.82857 .44733 Mdot
.83095 .44746 Mdot
.83333 .4476 Mdot
.83571 .44774 Mdot
.8381 .44788 Mdot
.84048 .44802 Mdot
.84286 .44816 Mdot
.84524 .4483 Mdot
.84762 .44844 Mdot
.85 .44858 Mdot
.85238 .44872 Mdot
.85476 .44885 Mdot
.85714 .44899 Mdot
.85952 .44913 Mdot
.8619 .44927 Mdot
.86429 .44942 Mdot
.86667 .44956 Mdot
.86905 .4497 Mdot
.87143 .44984 Mdot
.87381 .44998 Mdot
.87619 .45012 Mdot
.87857 .45026 Mdot
.88095 .4504 Mdot
.88333 .45054 Mdot
.88571 .45068 Mdot
.8881 .45083 Mdot
.89048 .45097 Mdot
.89286 .45111 Mdot
.89524 .45125 Mdot
.89762 .45139 Mdot
.9 .45154 Mdot
.90238 .45168 Mdot
.90476 .45182 Mdot
.90714 .45196 Mdot
.90952 .45211 Mdot
.9119 .45225 Mdot
.91429 .45239 Mdot
.91667 .45254 Mdot
.91905 .45268 Mdot
.92143 .45282 Mdot
.92381 .45297 Mdot
.92619 .45311 Mdot
.92857 .45326 Mdot
.93095 .4534 Mdot
.93333 .45354 Mdot
.93571 .45369 Mdot
.9381 .45383 Mdot
.94048 .45398 Mdot
.94286 .45412 Mdot
.94524 .45427 Mdot
.94762 .45441 Mdot
.95 .45456 Mdot
.95238 .4547 Mdot
.95476 .45485 Mdot
.95714 .455 Mdot
.95952 .45514 Mdot
.9619 .45529 Mdot
.96429 .45543 Mdot
.96667 .45558 Mdot
.96905 .45573 Mdot
.97143 .45587 Mdot
.97381 .45602 Mdot
.97619 .45617 Mdot
.02381 .43234 Mdot
.02619 .43246 Mdot
.02857 .43259 Mdot
.03095 .43271 Mdot
.03333 .43283 Mdot
.03571 .43296 Mdot
.0381 .43308 Mdot
.04048 .43321 Mdot
.04286 .43333 Mdot
.04524 .43345 Mdot
.04762 .43358 Mdot
.05 .4337 Mdot
.05238 .43383 Mdot
.05476 .43395 Mdot
.05714 .43408 Mdot
.05952 .4342 Mdot
.0619 .43433 Mdot
.06429 .43445 Mdot
.06667 .43458 Mdot
.06905 .4347 Mdot
.07143 .43483 Mdot
.07381 .43496 Mdot
.07619 .43508 Mdot
.07857 .43521 Mdot
.08095 .43533 Mdot
.08333 .43546 Mdot
.08571 .43559 Mdot
.0881 .43571 Mdot
.09048 .43584 Mdot
.09286 .43597 Mdot
.09524 .43609 Mdot
.09762 .43622 Mdot
.1 .43635 Mdot
.10238 .43647 Mdot
.10476 .4366 Mdot
.10714 .43673 Mdot
.10952 .43686 Mdot
.1119 .43699 Mdot
.11429 .43711 Mdot
.11667 .43724 Mdot
.11905 .43737 Mdot
.12143 .4375 Mdot
.12381 .43763 Mdot
.12619 .43776 Mdot
.12857 .43788 Mdot
.13095 .43801 Mdot
.13333 .43814 Mdot
.13571 .43827 Mdot
.1381 .4384 Mdot
.14048 .43853 Mdot
.14286 .43866 Mdot
.14524 .43879 Mdot
.14762 .43892 Mdot
.15 .43905 Mdot
.15238 .43918 Mdot
.15476 .43931 Mdot
.15714 .43944 Mdot
.15952 .43957 Mdot
.1619 .4397 Mdot
.16429 .43983 Mdot
.16667 .43996 Mdot
.16905 .44009 Mdot
.17143 .44022 Mdot
.17381 .44035 Mdot
.17619 .44049 Mdot
.17857 .44062 Mdot
.18095 .44075 Mdot
.18333 .44088 Mdot
.18571 .44101 Mdot
.1881 .44114 Mdot
.19048 .44128 Mdot
.19286 .44141 Mdot
.19524 .44154 Mdot
.19762 .44167 Mdot
.2 .44181 Mdot
.20238 .44194 Mdot
.20476 .44207 Mdot
.20714 .44221 Mdot
.20952 .44234 Mdot
.2119 .44247 Mdot
.21429 .44261 Mdot
.21667 .44274 Mdot
.21905 .44287 Mdot
.22143 .44301 Mdot
.22381 .44314 Mdot
.22619 .44327 Mdot
.22857 .44341 Mdot
.23095 .44354 Mdot
.23333 .44368 Mdot
.23571 .44381 Mdot
.2381 .44395 Mdot
.24048 .44408 Mdot
.24286 .44422 Mdot
.24524 .44435 Mdot
.24762 .44449 Mdot
.25 .44462 Mdot
.25238 .44476 Mdot
.25476 .44489 Mdot
.25714 .44503 Mdot
.25952 .44517 Mdot
.2619 .4453 Mdot
.26429 .44544 Mdot
.26667 .44558 Mdot
.26905 .44571 Mdot
.27143 .44585 Mdot
.27381 .44599 Mdot
.27619 .44612 Mdot
.27857 .44626 Mdot
.28095 .4464 Mdot
.28333 .44653 Mdot
.28571 .44667 Mdot
.2881 .44681 Mdot
.29048 .44695 Mdot
.29286 .44708 Mdot
.29524 .44722 Mdot
.29762 .44736 Mdot
.3 .4475 Mdot
.30238 .44764 Mdot
.30476 .44778 Mdot
.30714 .44792 Mdot
.30952 .44805 Mdot
.3119 .44819 Mdot
.31429 .44833 Mdot
.31667 .44847 Mdot
.31905 .44861 Mdot
.32143 .44875 Mdot
.32381 .44889 Mdot
.32619 .44903 Mdot
.32857 .44917 Mdot
.33095 .44931 Mdot
.33333 .44945 Mdot
.33571 .44959 Mdot
.3381 .44973 Mdot
.34048 .44987 Mdot
.34286 .45001 Mdot
.34524 .45015 Mdot
.34762 .4503 Mdot
.35 .45044 Mdot
.35238 .45058 Mdot
.35476 .45072 Mdot
.35714 .45086 Mdot
.35952 .451 Mdot
.3619 .45115 Mdot
.36429 .45129 Mdot
.36667 .45143 Mdot
.36905 .45157 Mdot
.37143 .45171 Mdot
.37381 .45186 Mdot
.37619 .452 Mdot
.37857 .45214 Mdot
.38095 .45229 Mdot
.38333 .45243 Mdot
.38571 .45257 Mdot
.3881 .45272 Mdot
.39048 .45286 Mdot
.39286 .453 Mdot
.39524 .45315 Mdot
.39762 .45329 Mdot
.4 .45344 Mdot
.40238 .45358 Mdot
.40476 .45373 Mdot
.40714 .45387 Mdot
.40952 .45402 Mdot
.4119 .45416 Mdot
.41429 .45431 Mdot
.41667 .45445 Mdot
.41905 .4546 Mdot
.42143 .45474 Mdot
.42381 .45489 Mdot
.42619 .45503 Mdot
.42857 .45518 Mdot
.43095 .45533 Mdot
.43333 .45547 Mdot
.43571 .45562 Mdot
.4381 .45576 Mdot
.44048 .45591 Mdot
.44286 .45606 Mdot
.44524 .45621 Mdot
.44762 .45635 Mdot
.45 .4565 Mdot
.45238 .45665 Mdot
.45476 .4568 Mdot
.45714 .45694 Mdot
.45952 .45709 Mdot
.4619 .45724 Mdot
.46429 .45739 Mdot
.46667 .45754 Mdot
.46905 .45768 Mdot
.47143 .45783 Mdot
.47381 .45798 Mdot
.47619 .45813 Mdot
.47857 .45828 Mdot
.48095 .45843 Mdot
.48333 .45858 Mdot
.48571 .45873 Mdot
.4881 .45888 Mdot
.49048 .45903 Mdot
.49286 .45918 Mdot
.49524 .45933 Mdot
.49762 .45948 Mdot
.5 .45963 Mdot
.50238 .45978 Mdot
.50476 .45993 Mdot
.50714 .46008 Mdot
.50952 .46023 Mdot
.5119 .46038 Mdot
.51429 .46053 Mdot
.51667 .46069 Mdot
.51905 .46084 Mdot
.52143 .46099 Mdot
.52381 .46114 Mdot
.52619 .46129 Mdot
.52857 .46145 Mdot
.53095 .4616 Mdot
.53333 .46175 Mdot
.53571 .4619 Mdot
.5381 .46206 Mdot
.54048 .46221 Mdot
.54286 .46236 Mdot
.54524 .46252 Mdot
.54762 .46267 Mdot
.55 .46282 Mdot
.55238 .46298 Mdot
.55476 .46313 Mdot
.55714 .46328 Mdot
.55952 .46344 Mdot
.5619 .46359 Mdot
.56429 .46375 Mdot
.56667 .4639 Mdot
.56905 .46406 Mdot
.57143 .46421 Mdot
.57381 .46437 Mdot
.57619 .46452 Mdot
.57857 .46468 Mdot
.58095 .46483 Mdot
.58333 .46499 Mdot
.58571 .46515 Mdot
.5881 .4653 Mdot
.59048 .46546 Mdot
.59286 .46562 Mdot
.59524 .46577 Mdot
.59762 .46593 Mdot
.6 .46609 Mdot
.60238 .46624 Mdot
.60476 .4664 Mdot
.60714 .46656 Mdot
.60952 .46671 Mdot
.6119 .46687 Mdot
.61429 .46703 Mdot
.61667 .46719 Mdot
.61905 .46735 Mdot
.62143 .4675 Mdot
.62381 .46766 Mdot
.62619 .46782 Mdot
.62857 .46798 Mdot
.63095 .46814 Mdot
.63333 .4683 Mdot
.63571 .46846 Mdot
.6381 .46862 Mdot
.64048 .46878 Mdot
.64286 .46894 Mdot
.64524 .4691 Mdot
.64762 .46926 Mdot
.65 .46942 Mdot
.65238 .46958 Mdot
.65476 .46974 Mdot
.65714 .4699 Mdot
.65952 .47006 Mdot
.6619 .47022 Mdot
.66429 .47038 Mdot
.66667 .47054 Mdot
.66905 .4707 Mdot
.67143 .47087 Mdot
.67381 .47103 Mdot
.67619 .47119 Mdot
.67857 .47135 Mdot
.68095 .47151 Mdot
.68333 .47168 Mdot
.68571 .47184 Mdot
.6881 .472 Mdot
.69048 .47217 Mdot
.69286 .47233 Mdot
.69524 .47249 Mdot
.69762 .47266 Mdot
.7 .47282 Mdot
.70238 .47298 Mdot
.70476 .47315 Mdot
.70714 .47331 Mdot
.70952 .47348 Mdot
.7119 .47364 Mdot
.71429 .4738 Mdot
.71667 .47397 Mdot
.71905 .47413 Mdot
.72143 .4743 Mdot
.72381 .47446 Mdot
.72619 .47463 Mdot
.72857 .4748 Mdot
.73095 .47496 Mdot
.73333 .47513 Mdot
.73571 .47529 Mdot
.7381 .47546 Mdot
.74048 .47563 Mdot
.74286 .47579 Mdot
.74524 .47596 Mdot
.74762 .47613 Mdot
.75 .47629 Mdot
.75238 .47646 Mdot
.75476 .47663 Mdot
.75714 .4768 Mdot
.75952 .47696 Mdot
.7619 .47713 Mdot
.76429 .4773 Mdot
.76667 .47747 Mdot
.76905 .47764 Mdot
.77143 .47781 Mdot
.77381 .47797 Mdot
.77619 .47814 Mdot
.77857 .47831 Mdot
.78095 .47848 Mdot
.78333 .47865 Mdot
.78571 .47882 Mdot
.7881 .47899 Mdot
.79048 .47916 Mdot
.79286 .47933 Mdot
.79524 .4795 Mdot
.79762 .47967 Mdot
.8 .47984 Mdot
.80238 .48001 Mdot
.80476 .48018 Mdot
.80714 .48035 Mdot
.80952 .48053 Mdot
.8119 .4807 Mdot
.81429 .48087 Mdot
.81667 .48104 Mdot
.81905 .48121 Mdot
.82143 .48139 Mdot
.82381 .48156 Mdot
.82619 .48173 Mdot
.82857 .4819 Mdot
.83095 .48208 Mdot
.83333 .48225 Mdot
.83571 .48242 Mdot
.8381 .4826 Mdot
.84048 .48277 Mdot
.84286 .48294 Mdot
.84524 .48312 Mdot
.84762 .48329 Mdot
.85 .48347 Mdot
.85238 .48364 Mdot
.85476 .48381 Mdot
.85714 .48399 Mdot
.85952 .48416 Mdot
.8619 .48434 Mdot
.86429 .48451 Mdot
.86667 .48469 Mdot
.86905 .48487 Mdot
.87143 .48504 Mdot
.87381 .48522 Mdot
.87619 .48539 Mdot
.87857 .48557 Mdot
.88095 .48575 Mdot
.88333 .48592 Mdot
.88571 .4861 Mdot
.8881 .48628 Mdot
.89048 .48645 Mdot
.89286 .48663 Mdot
.89524 .48681 Mdot
.89762 .48699 Mdot
.9 .48717 Mdot
.90238 .48734 Mdot
.90476 .48752 Mdot
.90714 .4877 Mdot
.90952 .48788 Mdot
.9119 .48806 Mdot
.91429 .48824 Mdot
.91667 .48842 Mdot
.91905 .4886 Mdot
.92143 .48878 Mdot
.92381 .48896 Mdot
.92619 .48914 Mdot
.92857 .48932 Mdot
.93095 .4895 Mdot
.93333 .48968 Mdot
.93571 .48986 Mdot
.9381 .49004 Mdot
.94048 .49022 Mdot
.94286 .4904 Mdot
.94524 .49058 Mdot
.94762 .49076 Mdot
.95 .49094 Mdot
.95238 .49113 Mdot
.95476 .49131 Mdot
.95714 .49149 Mdot
.95952 .49167 Mdot
.9619 .49186 Mdot
.96429 .49204 Mdot
.96667 .49222 Mdot
.96905 .4924 Mdot
.97143 .49259 Mdot
.97381 .49277 Mdot
.97619 .49296 Mdot
.02381 .457 Mdot
.02619 .45715 Mdot
.02857 .4573 Mdot
.03095 .45745 Mdot
.03333 .4576 Mdot
.03571 .45775 Mdot
.0381 .45789 Mdot
.04048 .45804 Mdot
.04286 .45819 Mdot
.04524 .45834 Mdot
.04762 .45849 Mdot
.05 .45864 Mdot
.05238 .45879 Mdot
.05476 .45894 Mdot
.05714 .45909 Mdot
.05952 .45924 Mdot
.0619 .45939 Mdot
.06429 .45954 Mdot
.06667 .45969 Mdot
.06905 .45984 Mdot
.07143 .45999 Mdot
.07381 .46014 Mdot
.07619 .46029 Mdot
.07857 .46045 Mdot
.08095 .4606 Mdot
.08333 .46075 Mdot
.08571 .4609 Mdot
.0881 .46105 Mdot
.09048 .4612 Mdot
.09286 .46136 Mdot
.09524 .46151 Mdot
.09762 .46166 Mdot
.1 .46181 Mdot
.10238 .46197 Mdot
.10476 .46212 Mdot
.10714 .46227 Mdot
.10952 .46243 Mdot
.1119 .46258 Mdot
.11429 .46273 Mdot
.11667 .46289 Mdot
.11905 .46304 Mdot
.12143 .46319 Mdot
.12381 .46335 Mdot
.12619 .4635 Mdot
.12857 .46366 Mdot
.13095 .46381 Mdot
.13333 .46397 Mdot
.13571 .46412 Mdot
.1381 .46428 Mdot
.14048 .46443 Mdot
.14286 .46459 Mdot
.14524 .46474 Mdot
.14762 .4649 Mdot
.15 .46505 Mdot
.15238 .46521 Mdot
.15476 .46537 Mdot
.15714 .46552 Mdot
.15952 .46568 Mdot
.1619 .46584 Mdot
.16429 .46599 Mdot
.16667 .46615 Mdot
.16905 .46631 Mdot
.17143 .46646 Mdot
.17381 .46662 Mdot
.17619 .46678 Mdot
.17857 .46694 Mdot
.18095 .4671 Mdot
.18333 .46725 Mdot
.18571 .46741 Mdot
.1881 .46757 Mdot
.19048 .46773 Mdot
.19286 .46789 Mdot
.19524 .46805 Mdot
.19762 .46821 Mdot
.2 .46836 Mdot
.20238 .46852 Mdot
.20476 .46868 Mdot
.20714 .46884 Mdot
.20952 .469 Mdot
.2119 .46916 Mdot
.21429 .46932 Mdot
.21667 .46948 Mdot
.21905 .46964 Mdot
.22143 .4698 Mdot
.22381 .46997 Mdot
.22619 .47013 Mdot
.22857 .47029 Mdot
.23095 .47045 Mdot
.23333 .47061 Mdot
.23571 .47077 Mdot
.2381 .47093 Mdot
.24048 .4711 Mdot
.24286 .47126 Mdot
.24524 .47142 Mdot
.24762 .47158 Mdot
.25 .47174 Mdot
.25238 .47191 Mdot
.25476 .47207 Mdot
.25714 .47223 Mdot
.25952 .4724 Mdot
.2619 .47256 Mdot
.26429 .47272 Mdot
.26667 .47289 Mdot
.26905 .47305 Mdot
.27143 .47321 Mdot
.27381 .47338 Mdot
.27619 .47354 Mdot
.27857 .47371 Mdot
.28095 .47387 Mdot
.28333 .47404 Mdot
.28571 .4742 Mdot
.2881 .47437 Mdot
.29048 .47453 Mdot
.29286 .4747 Mdot
.29524 .47486 Mdot
.29762 .47503 Mdot
.3 .4752 Mdot
.30238 .47536 Mdot
.30476 .47553 Mdot
.30714 .4757 Mdot
.30952 .47586 Mdot
.3119 .47603 Mdot
.31429 .4762 Mdot
.31667 .47636 Mdot
.31905 .47653 Mdot
.32143 .4767 Mdot
.32381 .47687 Mdot
.32619 .47703 Mdot
.32857 .4772 Mdot
.33095 .47737 Mdot
.33333 .47754 Mdot
.33571 .47771 Mdot
.3381 .47787 Mdot
.34048 .47804 Mdot
.34286 .47821 Mdot
.34524 .47838 Mdot
.34762 .47855 Mdot
.35 .47872 Mdot
.35238 .47889 Mdot
.35476 .47906 Mdot
.35714 .47923 Mdot
.35952 .4794 Mdot
.3619 .47957 Mdot
.36429 .47974 Mdot
.36667 .47991 Mdot
.36905 .48008 Mdot
.37143 .48025 Mdot
.37381 .48043 Mdot
.37619 .4806 Mdot
.37857 .48077 Mdot
.38095 .48094 Mdot
.38333 .48111 Mdot
.38571 .48128 Mdot
.3881 .48146 Mdot
.39048 .48163 Mdot
.39286 .4818 Mdot
.39524 .48197 Mdot
.39762 .48215 Mdot
.4 .48232 Mdot
.40238 .48249 Mdot
.40476 .48267 Mdot
.40714 .48284 Mdot
.40952 .48301 Mdot
.4119 .48319 Mdot
.41429 .48336 Mdot
.41667 .48354 Mdot
.41905 .48371 Mdot
.42143 .48389 Mdot
.42381 .48406 Mdot
.42619 .48424 Mdot
.42857 .48441 Mdot
.43095 .48459 Mdot
.43333 .48476 Mdot
.43571 .48494 Mdot
.4381 .48511 Mdot
.44048 .48529 Mdot
.44286 .48547 Mdot
.44524 .48564 Mdot
.44762 .48582 Mdot
.45 .486 Mdot
.45238 .48617 Mdot
.45476 .48635 Mdot
.45714 .48653 Mdot
.45952 .48671 Mdot
.4619 .48688 Mdot
.46429 .48706 Mdot
.46667 .48724 Mdot
.46905 .48742 Mdot
.47143 .4876 Mdot
.47381 .48777 Mdot
.47619 .48795 Mdot
.47857 .48813 Mdot
.48095 .48831 Mdot
.48333 .48849 Mdot
.48571 .48867 Mdot
.4881 .48885 Mdot
.49048 .48903 Mdot
.49286 .48921 Mdot
.49524 .48939 Mdot
.49762 .48957 Mdot
.5 .48975 Mdot
.50238 .48993 Mdot
.50476 .49011 Mdot
.50714 .49029 Mdot
.50952 .49047 Mdot
.5119 .49066 Mdot
.51429 .49084 Mdot
.51667 .49102 Mdot
.51905 .4912 Mdot
.52143 .49138 Mdot
.52381 .49157 Mdot
.52619 .49175 Mdot
.52857 .49193 Mdot
.53095 .49211 Mdot
.53333 .4923 Mdot
.53571 .49248 Mdot
.5381 .49266 Mdot
.54048 .49285 Mdot
.54286 .49303 Mdot
.54524 .49322 Mdot
.54762 .4934 Mdot
.55 .49358 Mdot
.55238 .49377 Mdot
.55476 .49395 Mdot
.55714 .49414 Mdot
.55952 .49432 Mdot
.5619 .49451 Mdot
.56429 .49469 Mdot
.56667 .49488 Mdot
.56905 .49507 Mdot
.57143 .49525 Mdot
.57381 .49544 Mdot
.57619 .49562 Mdot
.57857 .49581 Mdot
.58095 .496 Mdot
.58333 .49618 Mdot
.58571 .49637 Mdot
.5881 .49656 Mdot
.59048 .49675 Mdot
.59286 .49693 Mdot
.59524 .49712 Mdot
.59762 .49731 Mdot
.6 .4975 Mdot
.60238 .49769 Mdot
.60476 .49788 Mdot
.60714 .49807 Mdot
.60952 .49825 Mdot
.6119 .49844 Mdot
.61429 .49863 Mdot
.61667 .49882 Mdot
.61905 .49901 Mdot
.62143 .4992 Mdot
.62381 .49939 Mdot
.62619 .49958 Mdot
.62857 .49977 Mdot
.63095 .49996 Mdot
.63333 .50016 Mdot
.63571 .50035 Mdot
.6381 .50054 Mdot
.64048 .50073 Mdot
.64286 .50092 Mdot
.64524 .50111 Mdot
.64762 .5013 Mdot
.65 .5015 Mdot
.65238 .50169 Mdot
.65476 .50188 Mdot
.65714 .50208 Mdot
.65952 .50227 Mdot
.6619 .50246 Mdot
.66429 .50265 Mdot
.66667 .50285 Mdot
.66905 .50304 Mdot
.67143 .50324 Mdot
.67381 .50343 Mdot
.67619 .50362 Mdot
.67857 .50382 Mdot
.68095 .50401 Mdot
.68333 .50421 Mdot
.68571 .5044 Mdot
.6881 .5046 Mdot
.69048 .5048 Mdot
.69286 .50499 Mdot
.69524 .50519 Mdot
.69762 .50538 Mdot
.7 .50558 Mdot
.70238 .50578 Mdot
.70476 .50597 Mdot
.70714 .50617 Mdot
.70952 .50637 Mdot
.7119 .50656 Mdot
.71429 .50676 Mdot
.71667 .50696 Mdot
.71905 .50716 Mdot
.72143 .50736 Mdot
.72381 .50755 Mdot
.72619 .50775 Mdot
.72857 .50795 Mdot
.73095 .50815 Mdot
.73333 .50835 Mdot
.73571 .50855 Mdot
.7381 .50875 Mdot
.74048 .50895 Mdot
.74286 .50915 Mdot
.74524 .50935 Mdot
.74762 .50955 Mdot
.75 .50975 Mdot
.75238 .50995 Mdot
.75476 .51015 Mdot
.75714 .51035 Mdot
.75952 .51055 Mdot
.7619 .51075 Mdot
.76429 .51096 Mdot
.76667 .51116 Mdot
.76905 .51136 Mdot
.77143 .51156 Mdot
.77381 .51177 Mdot
.77619 .51197 Mdot
.77857 .51217 Mdot
.78095 .51237 Mdot
.78333 .51258 Mdot
.78571 .51278 Mdot
.7881 .51299 Mdot
.79048 .51319 Mdot
.79286 .51339 Mdot
.79524 .5136 Mdot
.79762 .5138 Mdot
.8 .51401 Mdot
.80238 .51421 Mdot
.80476 .51442 Mdot
.80714 .51462 Mdot
.80952 .51483 Mdot
.8119 .51503 Mdot
.81429 .51524 Mdot
.81667 .51545 Mdot
.81905 .51565 Mdot
.82143 .51586 Mdot
.82381 .51607 Mdot
.82619 .51627 Mdot
.82857 .51648 Mdot
.83095 .51669 Mdot
.83333 .5169 Mdot
.83571 .5171 Mdot
.8381 .51731 Mdot
.84048 .51752 Mdot
.84286 .51773 Mdot
.84524 .51794 Mdot
.84762 .51815 Mdot
.85 .51836 Mdot
.85238 .51856 Mdot
.85476 .51877 Mdot
.85714 .51898 Mdot
.85952 .51919 Mdot
.8619 .5194 Mdot
.86429 .51961 Mdot
.86667 .51982 Mdot
.86905 .52004 Mdot
.87143 .52025 Mdot
.87381 .52046 Mdot
.87619 .52067 Mdot
.87857 .52088 Mdot
.88095 .52109 Mdot
.88333 .5213 Mdot
.88571 .52152 Mdot
.8881 .52173 Mdot
.89048 .52194 Mdot
.89286 .52216 Mdot
.89524 .52237 Mdot
.89762 .52258 Mdot
.9 .5228 Mdot
.90238 .52301 Mdot
.90476 .52322 Mdot
.90714 .52344 Mdot
.90952 .52365 Mdot
.9119 .52387 Mdot
.91429 .52408 Mdot
.91667 .5243 Mdot
.91905 .52451 Mdot
.92143 .52473 Mdot
.92381 .52494 Mdot
.92619 .52516 Mdot
.92857 .52537 Mdot
.93095 .52559 Mdot
.93333 .52581 Mdot
.93571 .52602 Mdot
.9381 .52624 Mdot
.94048 .52646 Mdot
.94286 .52668 Mdot
.94524 .52689 Mdot
.94762 .52711 Mdot
.95 .52733 Mdot
.95238 .52755 Mdot
.95476 .52777 Mdot
.95714 .52799 Mdot
.95952 .5282 Mdot
.9619 .52842 Mdot
.96429 .52864 Mdot
.96667 .52886 Mdot
.96905 .52908 Mdot
.97143 .5293 Mdot
.97381 .52952 Mdot
.97619 .52974 Mdot
.02381 .48167 Mdot
.02619 .48184 Mdot
.02857 .48201 Mdot
.03095 .48219 Mdot
.03333 .48236 Mdot
.03571 .48253 Mdot
.0381 .48271 Mdot
.04048 .48288 Mdot
.04286 .48305 Mdot
.04524 .48323 Mdot
.04762 .4834 Mdot
.05 .48358 Mdot
.05238 .48375 Mdot
.05476 .48393 Mdot
.05714 .4841 Mdot
.05952 .48428 Mdot
.0619 .48445 Mdot
.06429 .48463 Mdot
.06667 .4848 Mdot
.06905 .48498 Mdot
.07143 .48515 Mdot
.07381 .48533 Mdot
.07619 .48551 Mdot
.07857 .48568 Mdot
.08095 .48586 Mdot
.08333 .48604 Mdot
.08571 .48621 Mdot
.0881 .48639 Mdot
.09048 .48657 Mdot
.09286 .48675 Mdot
.09524 .48692 Mdot
.09762 .4871 Mdot
.1 .48728 Mdot
.10238 .48746 Mdot
.10476 .48764 Mdot
.10714 .48782 Mdot
.10952 .48799 Mdot
.1119 .48817 Mdot
.11429 .48835 Mdot
.11667 .48853 Mdot
.11905 .48871 Mdot
.12143 .48889 Mdot
.12381 .48907 Mdot
.12619 .48925 Mdot
.12857 .48943 Mdot
.13095 .48961 Mdot
.13333 .48979 Mdot
.13571 .48997 Mdot
.1381 .49015 Mdot
.14048 .49033 Mdot
.14286 .49052 Mdot
.14524 .4907 Mdot
.14762 .49088 Mdot
.15 .49106 Mdot
.15238 .49124 Mdot
.15476 .49143 Mdot
.15714 .49161 Mdot
.15952 .49179 Mdot
.1619 .49197 Mdot
.16429 .49216 Mdot
.16667 .49234 Mdot
.16905 .49252 Mdot
.17143 .49271 Mdot
.17381 .49289 Mdot
.17619 .49307 Mdot
.17857 .49326 Mdot
.18095 .49344 Mdot
.18333 .49363 Mdot
.18571 .49381 Mdot
.1881 .494 Mdot
.19048 .49418 Mdot
.19286 .49437 Mdot
.19524 .49455 Mdot
.19762 .49474 Mdot
.2 .49492 Mdot
.20238 .49511 Mdot
.20476 .49529 Mdot
.20714 .49548 Mdot
.20952 .49567 Mdot
.2119 .49585 Mdot
.21429 .49604 Mdot
.21667 .49623 Mdot
.21905 .49641 Mdot
.22143 .4966 Mdot
.22381 .49679 Mdot
.22619 .49698 Mdot
.22857 .49717 Mdot
.23095 .49735 Mdot
.23333 .49754 Mdot
.23571 .49773 Mdot
.2381 .49792 Mdot
.24048 .49811 Mdot
.24286 .4983 Mdot
.24524 .49849 Mdot
.24762 .49868 Mdot
.25 .49887 Mdot
.25238 .49906 Mdot
.25476 .49925 Mdot
.25714 .49944 Mdot
.25952 .49963 Mdot
.2619 .49982 Mdot
.26429 .50001 Mdot
.26667 .5002 Mdot
.26905 .50039 Mdot
.27143 .50058 Mdot
.27381 .50077 Mdot
.27619 .50096 Mdot
.27857 .50116 Mdot
.28095 .50135 Mdot
.28333 .50154 Mdot
.28571 .50173 Mdot
.2881 .50193 Mdot
.29048 .50212 Mdot
.29286 .50231 Mdot
.29524 .50251 Mdot
.29762 .5027 Mdot
.3 .50289 Mdot
.30238 .50309 Mdot
.30476 .50328 Mdot
.30714 .50347 Mdot
.30952 .50367 Mdot
.3119 .50386 Mdot
.31429 .50406 Mdot
.31667 .50425 Mdot
.31905 .50445 Mdot
.32143 .50464 Mdot
.32381 .50484 Mdot
.32619 .50504 Mdot
.32857 .50523 Mdot
.33095 .50543 Mdot
.33333 .50562 Mdot
.33571 .50582 Mdot
.3381 .50602 Mdot
.34048 .50621 Mdot
.34286 .50641 Mdot
.34524 .50661 Mdot
.34762 .50681 Mdot
.35 .507 Mdot
.35238 .5072 Mdot
.35476 .5074 Mdot
.35714 .5076 Mdot
.35952 .5078 Mdot
.3619 .508 Mdot
.36429 .5082 Mdot
.36667 .5084 Mdot
.36905 .50859 Mdot
.37143 .50879 Mdot
.37381 .50899 Mdot
.37619 .50919 Mdot
.37857 .50939 Mdot
.38095 .50959 Mdot
.38333 .50979 Mdot
.38571 .51 Mdot
.3881 .5102 Mdot
.39048 .5104 Mdot
.39286 .5106 Mdot
.39524 .5108 Mdot
.39762 .511 Mdot
.4 .5112 Mdot
.40238 .51141 Mdot
.40476 .51161 Mdot
.40714 .51181 Mdot
.40952 .51201 Mdot
.4119 .51222 Mdot
.41429 .51242 Mdot
.41667 .51262 Mdot
.41905 .51283 Mdot
.42143 .51303 Mdot
.42381 .51324 Mdot
.42619 .51344 Mdot
.42857 .51364 Mdot
.43095 .51385 Mdot
.43333 .51405 Mdot
.43571 .51426 Mdot
.4381 .51446 Mdot
.44048 .51467 Mdot
.44286 .51488 Mdot
.44524 .51508 Mdot
.44762 .51529 Mdot
.45 .51549 Mdot
.45238 .5157 Mdot
.45476 .51591 Mdot
.45714 .51611 Mdot
.45952 .51632 Mdot
.4619 .51653 Mdot
.46429 .51674 Mdot
.46667 .51694 Mdot
.46905 .51715 Mdot
.47143 .51736 Mdot
.47381 .51757 Mdot
.47619 .51778 Mdot
.47857 .51798 Mdot
.48095 .51819 Mdot
.48333 .5184 Mdot
.48571 .51861 Mdot
.4881 .51882 Mdot
.49048 .51903 Mdot
.49286 .51924 Mdot
.49524 .51945 Mdot
.49762 .51966 Mdot
.5 .51987 Mdot
.50238 .52008 Mdot
.50476 .52029 Mdot
.50714 .52051 Mdot
.50952 .52072 Mdot
.5119 .52093 Mdot
.51429 .52114 Mdot
.51667 .52135 Mdot
.51905 .52157 Mdot
.52143 .52178 Mdot
.52381 .52199 Mdot
.52619 .5222 Mdot
.52857 .52242 Mdot
.53095 .52263 Mdot
.53333 .52284 Mdot
.53571 .52306 Mdot
.5381 .52327 Mdot
.54048 .52349 Mdot
.54286 .5237 Mdot
.54524 .52392 Mdot
.54762 .52413 Mdot
.55 .52435 Mdot
.55238 .52456 Mdot
.55476 .52478 Mdot
.55714 .52499 Mdot
.55952 .52521 Mdot
.5619 .52542 Mdot
.56429 .52564 Mdot
.56667 .52586 Mdot
.56905 .52607 Mdot
.57143 .52629 Mdot
.57381 .52651 Mdot
.57619 .52673 Mdot
.57857 .52694 Mdot
.58095 .52716 Mdot
.58333 .52738 Mdot
.58571 .5276 Mdot
.5881 .52782 Mdot
.59048 .52804 Mdot
.59286 .52825 Mdot
.59524 .52847 Mdot
.59762 .52869 Mdot
.6 .52891 Mdot
.60238 .52913 Mdot
.60476 .52935 Mdot
.60714 .52957 Mdot
.60952 .52979 Mdot
.6119 .53001 Mdot
.61429 .53024 Mdot
.61667 .53046 Mdot
.61905 .53068 Mdot
.62143 .5309 Mdot
.62381 .53112 Mdot
.62619 .53134 Mdot
.62857 .53157 Mdot
.63095 .53179 Mdot
.63333 .53201 Mdot
.63571 .53223 Mdot
.6381 .53246 Mdot
.64048 .53268 Mdot
.64286 .5329 Mdot
.64524 .53313 Mdot
.64762 .53335 Mdot
.65 .53358 Mdot
.65238 .5338 Mdot
.65476 .53403 Mdot
.65714 .53425 Mdot
.65952 .53448 Mdot
.6619 .5347 Mdot
.66429 .53493 Mdot
.66667 .53515 Mdot
.66905 .53538 Mdot
.67143 .53561 Mdot
.67381 .53583 Mdot
.67619 .53606 Mdot
.67857 .53629 Mdot
.68095 .53651 Mdot
.68333 .53674 Mdot
.68571 .53697 Mdot
.6881 .5372 Mdot
.69048 .53743 Mdot
.69286 .53765 Mdot
.69524 .53788 Mdot
.69762 .53811 Mdot
.7 .53834 Mdot
.70238 .53857 Mdot
.70476 .5388 Mdot
.70714 .53903 Mdot
.70952 .53926 Mdot
.7119 .53949 Mdot
.71429 .53972 Mdot
.71667 .53995 Mdot
.71905 .54018 Mdot
.72143 .54041 Mdot
.72381 .54064 Mdot
.72619 .54088 Mdot
.72857 .54111 Mdot
.73095 .54134 Mdot
.73333 .54157 Mdot
.73571 .5418 Mdot
.7381 .54204 Mdot
.74048 .54227 Mdot
.74286 .5425 Mdot
.74524 .54274 Mdot
.74762 .54297 Mdot
.75 .5432 Mdot
.75238 .54344 Mdot
.75476 .54367 Mdot
.75714 .54391 Mdot
.75952 .54414 Mdot
.7619 .54438 Mdot
.76429 .54461 Mdot
.76667 .54485 Mdot
.76905 .54508 Mdot
.77143 .54532 Mdot
.77381 .54556 Mdot
.77619 .54579 Mdot
.77857 .54603 Mdot
.78095 .54627 Mdot
.78333 .5465 Mdot
.78571 .54674 Mdot
.7881 .54698 Mdot
.79048 .54722 Mdot
.79286 .54746 Mdot
.79524 .54769 Mdot
.79762 .54793 Mdot
.8 .54817 Mdot
.80238 .54841 Mdot
.80476 .54865 Mdot
.80714 .54889 Mdot
.80952 .54913 Mdot
.8119 .54937 Mdot
.81429 .54961 Mdot
.81667 .54985 Mdot
.81905 .55009 Mdot
.82143 .55033 Mdot
.82381 .55057 Mdot
.82619 .55082 Mdot
.82857 .55106 Mdot
.83095 .5513 Mdot
.83333 .55154 Mdot
.83571 .55178 Mdot
.8381 .55203 Mdot
.84048 .55227 Mdot
.84286 .55251 Mdot
.84524 .55276 Mdot
.84762 .553 Mdot
.85 .55324 Mdot
.85238 .55349 Mdot
.85476 .55373 Mdot
.85714 .55398 Mdot
.85952 .55422 Mdot
.8619 .55447 Mdot
.86429 .55471 Mdot
.86667 .55496 Mdot
.86905 .55521 Mdot
.87143 .55545 Mdot
.87381 .5557 Mdot
.87619 .55594 Mdot
.87857 .55619 Mdot
.88095 .55644 Mdot
.88333 .55669 Mdot
.88571 .55693 Mdot
.8881 .55718 Mdot
.89048 .55743 Mdot
.89286 .55768 Mdot
.89524 .55793 Mdot
.89762 .55818 Mdot
.9 .55843 Mdot
.90238 .55867 Mdot
.90476 .55892 Mdot
.90714 .55917 Mdot
.90952 .55942 Mdot
.9119 .55967 Mdot
.91429 .55993 Mdot
.91667 .56018 Mdot
.91905 .56043 Mdot
.92143 .56068 Mdot
.92381 .56093 Mdot
.92619 .56118 Mdot
.92857 .56143 Mdot
.93095 .56169 Mdot
.93333 .56194 Mdot
.93571 .56219 Mdot
.9381 .56245 Mdot
.94048 .5627 Mdot
.94286 .56295 Mdot
.94524 .56321 Mdot
.94762 .56346 Mdot
.95 .56372 Mdot
.95238 .56397 Mdot
.95476 .56423 Mdot
.95714 .56448 Mdot
.95952 .56474 Mdot
.9619 .56499 Mdot
.96429 .56525 Mdot
.96667 .5655 Mdot
.96905 .56576 Mdot
.97143 .56602 Mdot
.97381 .56627 Mdot
.97619 .56653 Mdot
.02381 .50633 Mdot
.02619 .50653 Mdot
.02857 .50673 Mdot
.03095 .50693 Mdot
.03333 .50712 Mdot
.03571 .50732 Mdot
.0381 .50752 Mdot
.04048 .50772 Mdot
.04286 .50792 Mdot
.04524 .50812 Mdot
.04762 .50831 Mdot
.05 .50851 Mdot
.05238 .50871 Mdot
.05476 .50891 Mdot
.05714 .50911 Mdot
.05952 .50931 Mdot
.0619 .50951 Mdot
.06429 .50971 Mdot
.06667 .50991 Mdot
.06905 .51012 Mdot
.07143 .51032 Mdot
.07381 .51052 Mdot
.07619 .51072 Mdot
.07857 .51092 Mdot
.08095 .51112 Mdot
.08333 .51133 Mdot
.08571 .51153 Mdot
.0881 .51173 Mdot
.09048 .51193 Mdot
.09286 .51214 Mdot
.09524 .51234 Mdot
.09762 .51254 Mdot
.1 .51275 Mdot
.10238 .51295 Mdot
.10476 .51315 Mdot
.10714 .51336 Mdot
.10952 .51356 Mdot
.1119 .51377 Mdot
.11429 .51397 Mdot
.11667 .51418 Mdot
.11905 .51438 Mdot
.12143 .51459 Mdot
.12381 .51479 Mdot
.12619 .515 Mdot
.12857 .5152 Mdot
.13095 .51541 Mdot
.13333 .51562 Mdot
.13571 .51582 Mdot
.1381 .51603 Mdot
.14048 .51624 Mdot
.14286 .51644 Mdot
.14524 .51665 Mdot
.14762 .51686 Mdot
.15 .51707 Mdot
.15238 .51728 Mdot
.15476 .51748 Mdot
.15714 .51769 Mdot
.15952 .5179 Mdot
.1619 .51811 Mdot
.16429 .51832 Mdot
.16667 .51853 Mdot
.16905 .51874 Mdot
.17143 .51895 Mdot
.17381 .51916 Mdot
.17619 .51937 Mdot
.17857 .51958 Mdot
.18095 .51979 Mdot
.18333 .52 Mdot
.18571 .52021 Mdot
.1881 .52042 Mdot
.19048 .52063 Mdot
.19286 .52084 Mdot
.19524 .52106 Mdot
.19762 .52127 Mdot
.2 .52148 Mdot
.20238 .52169 Mdot
.20476 .52191 Mdot
.20714 .52212 Mdot
.20952 .52233 Mdot
.2119 .52254 Mdot
.21429 .52276 Mdot
.21667 .52297 Mdot
.21905 .52319 Mdot
.22143 .5234 Mdot
.22381 .52361 Mdot
.22619 .52383 Mdot
.22857 .52404 Mdot
.23095 .52426 Mdot
.23333 .52447 Mdot
.23571 .52469 Mdot
.2381 .52491 Mdot
.24048 .52512 Mdot
.24286 .52534 Mdot
.24524 .52555 Mdot
.24762 .52577 Mdot
.25 .52599 Mdot
.25238 .5262 Mdot
.25476 .52642 Mdot
.25714 .52664 Mdot
.25952 .52686 Mdot
.2619 .52707 Mdot
.26429 .52729 Mdot
.26667 .52751 Mdot
.26905 .52773 Mdot
.27143 .52795 Mdot
.27381 .52817 Mdot
.27619 .52839 Mdot
.27857 .5286 Mdot
.28095 .52882 Mdot
.28333 .52904 Mdot
.28571 .52926 Mdot
.2881 .52948 Mdot
.29048 .52971 Mdot
.29286 .52993 Mdot
.29524 .53015 Mdot
.29762 .53037 Mdot
.3 .53059 Mdot
.30238 .53081 Mdot
.30476 .53103 Mdot
.30714 .53125 Mdot
.30952 .53148 Mdot
.3119 .5317 Mdot
.31429 .53192 Mdot
.31667 .53214 Mdot
.31905 .53237 Mdot
.32143 .53259 Mdot
.32381 .53281 Mdot
.32619 .53304 Mdot
.32857 .53326 Mdot
.33095 .53349 Mdot
.33333 .53371 Mdot
.33571 .53394 Mdot
.3381 .53416 Mdot
.34048 .53439 Mdot
.34286 .53461 Mdot
.34524 .53484 Mdot
.34762 .53506 Mdot
.35 .53529 Mdot
.35238 .53552 Mdot
.35476 .53574 Mdot
.35714 .53597 Mdot
.35952 .5362 Mdot
.3619 .53642 Mdot
.36429 .53665 Mdot
.36667 .53688 Mdot
.36905 .53711 Mdot
.37143 .53733 Mdot
.37381 .53756 Mdot
.37619 .53779 Mdot
.37857 .53802 Mdot
.38095 .53825 Mdot
.38333 .53848 Mdot
.38571 .53871 Mdot
.3881 .53894 Mdot
.39048 .53917 Mdot
.39286 .5394 Mdot
.39524 .53963 Mdot
.39762 .53986 Mdot
.4 .54009 Mdot
.40238 .54032 Mdot
.40476 .54055 Mdot
.40714 .54078 Mdot
.40952 .54101 Mdot
.4119 .54125 Mdot
.41429 .54148 Mdot
.41667 .54171 Mdot
.41905 .54194 Mdot
.42143 .54218 Mdot
.42381 .54241 Mdot
.42619 .54264 Mdot
.42857 .54288 Mdot
.43095 .54311 Mdot
.43333 .54334 Mdot
.43571 .54358 Mdot
.4381 .54381 Mdot
.44048 .54405 Mdot
.44286 .54428 Mdot
.44524 .54452 Mdot
.44762 .54475 Mdot
.45 .54499 Mdot
.45238 .54523 Mdot
.45476 .54546 Mdot
.45714 .5457 Mdot
.45952 .54594 Mdot
.4619 .54617 Mdot
.46429 .54641 Mdot
.46667 .54665 Mdot
.46905 .54688 Mdot
.47143 .54712 Mdot
.47381 .54736 Mdot
.47619 .5476 Mdot
.47857 .54784 Mdot
.48095 .54808 Mdot
.48333 .54831 Mdot
.48571 .54855 Mdot
.4881 .54879 Mdot
.49048 .54903 Mdot
.49286 .54927 Mdot
.49524 .54951 Mdot
.49762 .54975 Mdot
.5 .55 Mdot
.50238 .55024 Mdot
.50476 .55048 Mdot
.50714 .55072 Mdot
.50952 .55096 Mdot
.5119 .5512 Mdot
.51429 .55144 Mdot
.51667 .55169 Mdot
.51905 .55193 Mdot
.52143 .55217 Mdot
.52381 .55242 Mdot
.52619 .55266 Mdot
.52857 .5529 Mdot
.53095 .55315 Mdot
.53333 .55339 Mdot
.53571 .55364 Mdot
.5381 .55388 Mdot
.54048 .55412 Mdot
.54286 .55437 Mdot
.54524 .55462 Mdot
.54762 .55486 Mdot
.55 .55511 Mdot
.55238 .55535 Mdot
.55476 .5556 Mdot
.55714 .55585 Mdot
.55952 .55609 Mdot
.5619 .55634 Mdot
.56429 .55659 Mdot
.56667 .55683 Mdot
.56905 .55708 Mdot
.57143 .55733 Mdot
.57381 .55758 Mdot
.57619 .55783 Mdot
.57857 .55808 Mdot
.58095 .55832 Mdot
.58333 .55857 Mdot
.58571 .55882 Mdot
.5881 .55907 Mdot
.59048 .55932 Mdot
.59286 .55957 Mdot
.59524 .55982 Mdot
.59762 .56008 Mdot
.6 .56033 Mdot
.60238 .56058 Mdot
.60476 .56083 Mdot
.60714 .56108 Mdot
.60952 .56133 Mdot
.6119 .56159 Mdot
.61429 .56184 Mdot
.61667 .56209 Mdot
.61905 .56234 Mdot
.62143 .5626 Mdot
.62381 .56285 Mdot
.62619 .5631 Mdot
.62857 .56336 Mdot
.63095 .56361 Mdot
.63333 .56387 Mdot
.63571 .56412 Mdot
.6381 .56438 Mdot
.64048 .56463 Mdot
.64286 .56489 Mdot
.64524 .56514 Mdot
.64762 .5654 Mdot
.65 .56566 Mdot
.65238 .56591 Mdot
.65476 .56617 Mdot
.65714 .56643 Mdot
.65952 .56669 Mdot
.6619 .56694 Mdot
.66429 .5672 Mdot
.66667 .56746 Mdot
.66905 .56772 Mdot
.67143 .56798 Mdot
.67381 .56824 Mdot
.67619 .56849 Mdot
.67857 .56875 Mdot
.68095 .56901 Mdot
.68333 .56927 Mdot
.68571 .56953 Mdot
.6881 .56979 Mdot
.69048 .57006 Mdot
.69286 .57032 Mdot
.69524 .57058 Mdot
.69762 .57084 Mdot
.7 .5711 Mdot
.70238 .57136 Mdot
.70476 .57163 Mdot
.70714 .57189 Mdot
.70952 .57215 Mdot
.7119 .57241 Mdot
.71429 .57268 Mdot
.71667 .57294 Mdot
.71905 .5732 Mdot
.72143 .57347 Mdot
.72381 .57373 Mdot
.72619 .574 Mdot
.72857 .57426 Mdot
.73095 .57453 Mdot
.73333 .57479 Mdot
.73571 .57506 Mdot
.7381 .57533 Mdot
.74048 .57559 Mdot
.74286 .57586 Mdot
.74524 .57613 Mdot
.74762 .57639 Mdot
.75 .57666 Mdot
.75238 .57693 Mdot
.75476 .5772 Mdot
.75714 .57746 Mdot
.75952 .57773 Mdot
.7619 .578 Mdot
.76429 .57827 Mdot
.76667 .57854 Mdot
.76905 .57881 Mdot
.77143 .57908 Mdot
.77381 .57935 Mdot
.77619 .57962 Mdot
.77857 .57989 Mdot
.78095 .58016 Mdot
.78333 .58043 Mdot
.78571 .5807 Mdot
.7881 .58097 Mdot
.79048 .58125 Mdot
.79286 .58152 Mdot
.79524 .58179 Mdot
.79762 .58206 Mdot
.8 .58234 Mdot
.80238 .58261 Mdot
.80476 .58288 Mdot
.80714 .58316 Mdot
.80952 .58343 Mdot
.8119 .58371 Mdot
.81429 .58398 Mdot
.81667 .58426 Mdot
.81905 .58453 Mdot
.82143 .58481 Mdot
.82381 .58508 Mdot
.82619 .58536 Mdot
.82857 .58563 Mdot
.83095 .58591 Mdot
.83333 .58619 Mdot
.83571 .58647 Mdot
.8381 .58674 Mdot
.84048 .58702 Mdot
.84286 .5873 Mdot
.84524 .58758 Mdot
.84762 .58786 Mdot
.85 .58813 Mdot
.85238 .58841 Mdot
.85476 .58869 Mdot
.85714 .58897 Mdot
.85952 .58925 Mdot
.8619 .58953 Mdot
.86429 .58981 Mdot
.86667 .59009 Mdot
.86905 .59038 Mdot
.87143 .59066 Mdot
.87381 .59094 Mdot
.87619 .59122 Mdot
.87857 .5915 Mdot
.88095 .59178 Mdot
.88333 .59207 Mdot
.88571 .59235 Mdot
.8881 .59263 Mdot
.89048 .59292 Mdot
.89286 .5932 Mdot
.89524 .59349 Mdot
.89762 .59377 Mdot
.9 .59405 Mdot
.90238 .59434 Mdot
.90476 .59463 Mdot
.90714 .59491 Mdot
.90952 .5952 Mdot
.9119 .59548 Mdot
.91429 .59577 Mdot
.91667 .59606 Mdot
.91905 .59634 Mdot
.92143 .59663 Mdot
.92381 .59692 Mdot
.92619 .59721 Mdot
.92857 .59749 Mdot
.93095 .59778 Mdot
.93333 .59807 Mdot
.93571 .59836 Mdot
.9381 .59865 Mdot
.94048 .59894 Mdot
.94286 .59923 Mdot
.94524 .59952 Mdot
.94762 .59981 Mdot
.95 .6001 Mdot
.95238 .60039 Mdot
.95476 .60068 Mdot
.95714 .60098 Mdot
.95952 .60127 Mdot
.9619 .60156 Mdot
.96429 .60185 Mdot
.96667 .60214 Mdot
.96905 .60244 Mdot
.97143 .60273 Mdot
.97381 .60302 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooook
J_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z
7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX0017ooo]Z1Ol007l9oookJPGo0000oooonf[o
oookJQkooo]Z000@oookJPOo001o2?oonfX5o`000?oooo]ZoooonfXNoookJP004?oonfX3o`00O`;o
oo]Z0ol007l7oookJPGo0000oooonf[ooookJQkooo]Z0003oookJP[o001o0_oonfX3o`00O`?ooo]Z
0ol007l7oookJPGo0000oooonf[ooookJPcooo]Z0_l0000@oookJP000ooonfX:o`00O`;ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`000?oooo]ZoooonfX2oookJP_o00003ooonfX000oooo]Z1?l007l2
oookJP?o001o1ooonfX5o`000?oooo]Zn_oonfXDo`0000oooo]Z000?oookJPSo001o2?oonfX5o`00
0?oooo]Zl_oonfXKo`00013ooo]Z000?oookJP?o001o00Cooo]Zo`00Ool007oo001o2OoonfX5o`00
0?oooo]Zj_oonfXRo`00017ooo]Z000?oookJP?o001o3OoonfX5o`000?oooo]Zh_oonfXRo`0001Wo
oo]Z000?oookJP?o001o3OoonfX5o`000?oooo]ZfOoonfXRo`0002;ooo]Z000@oookJP?o001o0_oo
nfX3o`00O`Oooo]Z1Ol0003ooookJ]7ooo]Z8_l0000ZoookJP004?oonfX7o`00O`Sooo]Z1Ol0003o
oookJ/Sooo]Z8ol0000boookJP004_oonfX4o`00O`Wooo]Z1Ol0003ooookJ/3ooo]Z8ol0000joook
JP007ooonfX5o`000?oooo]Z]ooonfXSo`0004?ooo]Z000OoookJPGo0000oooonfZ_oookJR?o0000
BooonfX001oooo]Z1Ol0003ooookJZKooo]Z8ol0001DoookJP007ooonfX5o`000?oooo]ZWOoonfXT
o`0005cooo]Z000OoookJPGo0000oooonfZEoookJR?o0000IOoonfX001oooo]Z1Ol0003ooookJXco
oo]Z9?l0001]oookJP007ooonfX5o`000?oooo]ZP_oonfXTo`0007Oooo]Z000OoookJPGo0000oooo
nfYioookJRCo0000P?oonfX001oooo]Z1Ol0003ooookJW3ooo]Z9Ol00028oookJP007ooonfX5o`00
0?oooo]ZIooonfXUo`00097ooo]Z000OoookJPGo0000oooonfYNoookJRGo0000V_oonfX001oooo]Z
1Ol0003ooookJUCooo]Z9_l0002:oookJPWo00004?oonfX001oooo]Z1Ol0003ooookJT_ooo]Z9_l0
002:oookJQ?o00003ooonfX001oooo]Z1Ol0003ooookJT;ooo]Z9Ol0002;oookJQco00003ooonfX0
01oooo]Z1Ol0003ooookJSWooo]Z9Ol00029oookJRKo00004?oonfX001oooo]Z1Ol0003ooookJRko
oo]Z9ol00029oookJROo00006?oonfX001oooo]Z1Ol0003ooookJRGooo]Z9ol00029oookJROo0000
8OoonfX001oooo]Z1Ol0003ooookJQcooo]Z9ol00028oookJRSo0000:_oonfX001oooo]Z1Ol0003o
oookJQ7ooo]Z:Ol00027oookJROo0000=OoonfX001oooo]Z1Ol0003ooookJPSooo]Z9ol00028oook
JRSo0000?_oonfX001oooo]Z1Ol0003moookJRSo0000R?oonfXXo`0004Oooo]Z000OoookJPGo0000
m?oonfXXo`0008Kooo]Z:?l0001BoookJP007ooonfX5o`000>Wooo]Z:?l00028oookJRSo0000Fooo
nfX001oooo]Z1Ol0003OoookJRWo0000Q_oonfXYo`0006Gooo]Z000OoookJPGo0000eOoonfXXo`00
08Oooo]Z:Ol0001_oookJP007ooonfX5o`000<_ooo]Z:Ol00025oookJR[o0000NOoonfX001oooo]Z
1Ol00030oookJR[o0000QOoonfX[o`0008;ooo]Z000OoookJPGo0000]_oonfXYo`0008Gooo]Z:ol0
002=oookJP007ooonfX5o`000:_ooo]Z:ol00024oookJR_o0000UooonfX001oooo]Z1Ol0002Qoook
JR_o0000PooonfX[o`000:;ooo]Z000OoookJPGo0000U_oonfX[o`0008Cooo]Z:ol0002/oookJP00
7ooonfX5o`0008[ooo]Z;?l00024oookJR_o0000X?oonfX7o`00013ooo]Z000OoookJPGo0000P?oo
nfX/o`0008Cooo]Z:ol0002OoookJQ?o00003ooonfX001oooo]Z1Ol0001eoookJRco0000PooonfX/
o`000:3ooo]Z7Ol0000?oookJP007ooonfX5o`0006[ooo]Z;Ol00023oookJRco0000W_oonfXXo`00
013ooo]Z000OoookJPGo0000GooonfX/o`0008?ooo]Z;Ol0002NoookJRco00005ooonfX001oooo]Z
1Ol0001CoookJRko0000P_oonfX^o`0009gooo]Z;Ol0000QoookJP007ooonfX5o`0004Wooo]Z;Ol0
0021oookJRko0000WOoonfX^o`0002cooo]Z000OoookJPGo0000?OoonfX]o`0008;ooo]Z;_l0002M
oookJRko0000=ooonfX001oooo]Z1Ol0000aoookJRoo0000POoonfX]o`0009gooo]Z;ol00012oook
JP007ooonfX5o`0002Gooo]Z;ol00021oookJRoo0000W?oonfX^o`0004kooo]Z000DoookJP?o001o
2?oonfX5o`0001[ooo]Z;ol00021oookJRko0000W?oonfX^o`0005[ooo]Z000DoookJP?o001o2?oo
nfX5o`0000kooo]Z<?l00020oookJRko0000W?oonfX`o`0006Cooo]Z000DoookJP?o001o2?oonfX5
o`0000;ooo]Z<?l00020oookJS3o0000V_oonfX`o`00073ooo]Z0003oookJP[o001o0_oonfX9o`00
O`Oooo]Z:ol0001ooookJS7o0000V_oonfX`o`0007cooo]Z0003oookJP[o001o0_oonfX9o`00O`Oo
oo]Z7ol0001ooookJS7o0000VOoonfXao`0008Sooo]Z000?oookJP;o001o0ooonfX3o`00O`Sooo]Z
4ol0001ooookJS7o0000VOoonfXbo`0009?ooo]Z000@oookJP;o001o0_oonfX3o`00O`Sooo]Z2?l0
001moookJS?o0000VOoonfXao`0009oooo]Z000@oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX5o`0007Cooo]Z<Ol0002IoookJS?o0000ZooonfX0017ooo]Z0_l007l01?oonf[o001oo`00Ool0
07l8oookJPGo0000IooonfXco`0009Oooo]Z<ol0002hoookJP004_oonfX5o`00O`Sooo]Z1Ol0001J
oookJSCo0000UooonfXco`000<Cooo]Z000BoookJPGo001o2?oonfX5o`0004kooo]Z<ol0002Goook
JSCo0000^ooonfX5o`00013ooo]Z000CoookJPCo001o2?oonfX5o`00047ooo]Z=?l0002FoookJSCo
0000^ooonfXCo`0000oooo]Z000DoookJP?o001o2?oonfX5o`0003Cooo]Z=?l0002FoookJSCo0000
^ooonfXPo`0000oooo]Z000OoookJPGo00009OoonfXfo`0009Kooo]Z=Ol0002joookJRco00004?oo
nfX001oooo]Z1Ol0000HoookJSOo0000TooonfXgo`000;[ooo]Z=Ol0000DoookJP007ooonfX5o`00
00_ooo]Z=ol0002CoookJSOo0000^_oonfXeo`00027ooo]Z000OoookJSWo0000U?oonfXgo`000;So
oo]Z=ol0000^oookJP007ooonfX[o`0009Cooo]Z>?l0002hoookJSOo0000>ooonfX001oooo]Z7_l0
002BoookJSSo0000^OoonfXgo`0004Wooo]Z000OoookJQ7o0000T_oonfXho`000;Oooo]Z>Ol0001F
oookJP007ooonfX5o`00093ooo]Z>Ol0002foookJSWo0000I?oonfX001oooo]Z1Ol00021oookJSWo
0000]_oonfXko`00077ooo]Z000OoookJPGo0000LooonfXio`000;Kooo]Z>_l00020oookJP007ooo
nfX5o`0006?ooo]Z??l0002doookJS_o0000S_oonfX001oooo]Z1Ol0001EoookJS_o0000]?oonfXk
o`0009gooo]Z000OoookJPGo0000AOoonfXmo`000;?ooo]Z??l0002[oookJP007ooonfX5o`0003Ko
oo]Z?_l0002aoookJSko0000^OoonfX001oooo]Z1Ol0000WoookJSgo0000/_oonfXno`000<Sooo]Z
000OoookJPGo00005ooonfXno`000;7ooo]Z?_l0003HoookJP007ooonfX5o`0000Oooo]Z?ol0002`
oookJT3o0000i_oonfX001oooo]Z??l0002_oookJT3o0000m_oonfX001oooo]Z;?l0002`oookJSoo
0000iOoonfXAo`00013ooo]Z000OoookJQgo0000[_oonfY1o`000>?ooo]Z8ol0000?oookJP007ooo
nfX=o`000:cooo]Z@ol0003ToookJS;o00003ooonfX001oooo]Z1Ol0002SoookJTCo0000hooonfY2
o`00013ooo]Z000OoookJPGo0000T_oonfY5o`000>;ooo]Z@ol0000PoookJP007ooonfX5o`00087o
oo]ZAOl0003PoookJTGo0000<OoonfX001oooo]Z1Ol0001`oookJTGo0000h?oonfY6o`00047ooo]Z
000OoookJPGo0000G_oonfY6o`000=oooo]ZAol0001BoookJP007ooonfX5o`0004_ooo]ZB?l0003O
oookJTOo0000HooonfX001oooo]Z1Ol0000ioookJTWo0000gOoonfY8o`0007Gooo]Z000OoookJPGo
00009ooonfY:o`000=cooo]ZBOl00026oookJP007ooonfX5o`0001Cooo]ZBol0003JoookJT[o0000
VOoonfX001oooo]Z1Ol000000ooonf[o0000o`000019o`000=_ooo]ZBol0002ZoookJP007ooonfXo
o`000=Wooo]ZCOl0002loookJP007ooonfX/o`000=Sooo]ZCol0003>oookJP007ooonfXJo`000=Oo
oo]ZC_l0003RoookJP007ooonfX6o`000=Kooo]ZD?l0003eoookJP007ooonfX5o`000<?ooo]ZDOl0
003ooookJPWooo]Z000OoookJPGo0000[_oonfYBo`000?oooo]Z7OoonfX001oooo]Z1Ol0002Hoook
JUCo0000oooonfXaoookJP007ooonfX5o`0008?ooo]ZE?l0003ooookJROooo]Z3ol0000@oookJP00
7ooonfX5o`0006cooo]ZF?l0003ooookJR?ooo]Z9ol0000?oookJP007ooonfX5o`0005Kooo]ZFOl0
003ooookJR;ooo]Z?Ol0000?oookJP007ooonfX5o`00043ooo]ZF?l0003ooookJR?ooo]ZD_l0000@
oookJP003ooonfX9o`00O`Oooo]Z1Ol0000XoookJU_o0000oooonfXPoookJU_o00007ooonfX000oo
oo]Z2Ol007l7oookJPGo00004?oonfYMo`000?oooo]Z7ooonfYLo`0003Gooo]Z000?oookJPCo001o
3?oonfYLo`000?oooo]Z7OoonfYNo`0004_ooo]Z0003oookJP[o001o0ooonfX4o`00O`_ooo]ZAOl0
003ooookJQ_ooo]ZHOl0001QoookJP000ooonfX:o`00O`Cooo]Z1Ol007l9oookJRko0000oooonfXI
oookJV;o0000NOoonfX001?ooo]Z1?l007l8oookJQKo0000oooonfXHoookJV?o0000TOoonfX001Co
oo]Z0ol007l8oookJPGo0000oooonfX?oookJVKo0000Z?oonfX001Gooo]Z0ol007l7oookJPGo0000
m?oonfYWo`000<7ooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0003HoookJV[o0000f_oo
nfX000oooo]Z0ol007l3oookJP?o001o1ooonfX5o`000;cooo]ZKOl0003coookJP003ooonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000XOoonfY]o`000?oooo]Z3ooonfX0013ooo]Z1ol007l8oookJPGo
0000Q?oonfY`o`000?oooo]Z:OoonfX0017ooo]Z1Ol007l9oookJPGo0000IooonfYbo`000?oooo]Z
A?oonfX001oooo]Z1Ol00019oookJWCo0000oooonfYPoookJP007ooonfX5o`0002Wooo]ZN?l0003o
oookJWcooo]Z000OoookJPGo00002_oonfYko`000?oooo]ZV?oonfX001oooo]ZKOl0003ooookJYSo
oo]Z3Ol0000@oookJP007ooonfY>o`000?oooo]ZUOoonfX`o`0000oooo]Z000OoookJRoo0000oooo
nfZBoookJU;o00003ooonfX001oooo]Z3ol0003ooookJY3ooo]ZLol0000@oookJP007ooonfX5o`00
0?oooo]ZMooonfZ:o`0001cooo]Z000OoookJPGo0000oooonfYBoookJXgo0000?_oonfX001oooo]Z
1Ol0003ooookJRcooo]ZTOl0001PoookJP007ooonfX5o`000?oooo]Z1?oonfZGo`0008;ooo]Z000O
oookJPGo0000g?oonfZJo`000:Kooo]Z000OoookJPGo0000/_oonfZOo`000<_ooo]Z000OoookJPGo
0000R?oonfZSo`000?7ooo]Z000OoookJPGo0000FooonfZYo`000?oooo]Z6OoonfX001oooo]Z1Ol0
000]oookJ[3o0000oooonfY0oookJP007ooonfZho`000?oooo]ZJ_oonfX001oooo]ZS_l0003ooook
JYCooo]Z000OoookJV7o0000oooonf[1oookJP007ooonfXco`000?oooo]ZkooonfX001oooo]Z1Ol0
003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooook
J_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z2?oonfX6o`00013ooo]Z000OoookJPGo0000
P?oonfX3o`00Ogcooo]Z2Ol007mloookJPGo001o>_oonfY:o`000003o`00Oooonf[ooo]Z00cooo]Z
000OoookJPGo0000P?oonfX3o`00Ogcooo]Z2Ol007meoookJY3o000000?o001ooookJ_oonfX03?oo
nfX001oooo]Z1Ol00020oookJP?o001oO?oonfX4o`00Oc3ooo]ZfOl00002o`00O`kooo]Z000Ooook
JPGo0000P?oonfX3o`00Of7ooo]Zool0000To`0000So001o3OoonfX001oooo]Z1Ol00020oookJP?o
001o3_oonf[oo`0003Co0000@_oonfX9o`00O`gooo]Z000OoookJPGo0000>?oonf[oo`0004Oo0000
2_oonfX3o`00Og_ooo]Z0_l007l3oookJP?o001o3_oonfX001oooo]Zool0000io`0005?ooo]Z1?l0
07mmoookJP;o001o0_oonfX3o`00O`kooo]Z000OoookJ^Wo00008OoonfX3o`00Ogkooo]Z0ol007mn
oookJP?o001o00Cooo]Zo`00Ool007oo001o3_oonfX001oooo]ZUol0001]oookJP?o001o0ooonfX3
o`00Oh3ooo]Z0_l007mnoookJP;o001o00Cooo]Zo`00Ool007oo001o3_oonfX001oooo]Z?Ol00015
oookJPKo001oO?oonfX3o`00O`?ooo]Z0ol007mjoookJP?o001o0ooonfX3o`00Ogkooo]Z1Ol007l>
oookJP007ooonfX5o`0007gooo]Z1_l007mloookJPCo001o0_oonfX3o`00Og[ooo]Z0ol007l3oook
JP?o001oO_oonfX5o`00O`kooo]Z000OoookJPGo0000OooonfX4o`00Oggooo]Z1ol007mloookJPOo
001oP?oonfX4o`00O`kooo]Z000OoookJPGo0000P?oonfX3o`00Ogkooo]Z1Ol007mnoookJPGo001o
P_oonfX3o`00O`kooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[o
oookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQko
oo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000OoookJPGo0000oooonf[ooookJQkooo]Z000B
oookJ_oo0000ool0000_o`00007ooo]Z000BoookJ_oo0000ool0000_o`00007ooo]Z000BoookJ_oo
0000ool0000_o`00007ooo]Z000BoookJ_oo0000ool0000_o`00007ooo]Z000BoookJ_oo0000ool0
000_o`00007ooo]Z000OoookJPGo0000POoonfX00ol0003ooo]ZoookJP20oookJP03o`000?oonf[o
oo]Z083ooo]Z00?o0000oookJ_oonfX0POoonfX00ol0003ooo]ZoookJP0>oookJP007ooonfX5o`00
0?oooo]ZoooonfXNoookJP007ooonfX5o`000?oooo]ZoooonfXNoookJP007ooonfX5o`000?oooo]Z
oooonfXNoookJP007ooonfX5o`000?oooo]ZoooonfXNoookJP007ooonfX5o`000?oooo]ZoooonfXN
oookJP007ooonfX5o`000?oooo]ZoooonfXNoookJP007ooonfX5o`000?oooo]ZoooonfXNoookJP00
7ooonfX5o`000?oooo]ZoooonfXNoookJP007ooonfXEo`000?oooo]ZoooonfX>oookJP007ooonfYa
o`000?oooo]Z/OoonfX001oooo]Za_l0003ooookJUcooo]Z000OoookJ_oo00006?l0003ooookJP_o
oo]Z000OoookJPGo00003ooonf[oo`0004oo0000_ooonfX001oooo]Z1Ol0001[oookJ_oo0000>ol0
001goookJP007ooonfX5o`000<3ooo]Zool0000[o`0003;ooo]Z000OoookJPGo0000oooonfXCoook
J_[o00004?oonfX001oooo]Z1Ol0003ooookJUkooo]Z/?l0000?oookJP007ooonfX5o`000?oooo]Z
Y_oonfYXo`0000oooo]Z000OoookJPGo0000oooonf[ZoookJR?o00004?oonfX001oooo]Z1Ol0003o
oookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oooo]Z7_oonfX001oooo]Z1Ol0003ooookJ_oo
oo]Z7_oonfX001oooo]Z7_l0003ooookJ_oooo]Z1OoonfX001oooo]ZCOl0003ooookJ]Gooo]Z000O
oookJW[o0000oooonfZXoookJP007ooonfZUo`000?oooo]ZOOoonfX001oooo]Z1Ol0000HoookJ[;o
0000oooonfYCoookJP007ooonfX5o`0004Oooo]Z[?l0003ooookJR[ooo]Z000OoookJPGo0000M?oo
nfZVo`000?oooo]Z0ooonfX001oooo]Z1Ol0002OoookJZ7o0000g?oonfX001oooo]Z1Ol0003:oook
JYco0000]_oonfX001oooo]Z1Ol0003boookJYSo0000T_oonfX001oooo]Z1Ol0003ooookJQ_ooo]Z
Tol0001_oookJP007ooonfX5o`000?oooo]Z@OoonfZ@o`0004cooo]Z000OoookJPGo0000oooonfYW
oookJXco0000:_oonfX001oooo]Z1Ol0003ooookJX[ooo]ZPol0000@oookJP007ooonfXRo`000?oo
oo]ZTOoonfYPo`0000oooo]Z000OoookJT7o0000oooonfZDoookJSko00003ooonfX001oooo]ZH?l0
003ooookJYOooo]Z6ol0000@oookJP007ooonfYlo`000?oooo]ZY_oonfX001oooo]Z1Ol0000Loook
JW[o0000oooonfZ7oookJP007ooonfX5o`0003cooo]ZMOl0003ooookJVcooo]Z000OoookJPGo0000
F_oonfYco`000?oooo]ZD?oonfX001oooo]Z1Ol0001goookJW7o0000oooonfXeoookJP007ooonfX5
o`0009Gooo]ZK_l0003ooookJQ[ooo]Z000OoookJPGo0000/OoonfY/o`000?oooo]Z000?oookJPWo
001o1ooonfX5o`000<cooo]ZJol0003UoookJP003ooonfX9o`00O`Oooo]Z1Ol0003XoookJVSo0000
c?oonfX000oooo]Z1?l007l<oookJPGo0000oooonfX3oookJVOo0000/ooonfX0013ooo]Z1?l007l;
oookJPco0000oooonfXFoookJVGo0000VooonfX0017ooo]Z1Ol007l9oookJR?o0000oooonfXJoook
JV7o0000Q?oonfX001?ooo]Z1?l007l8oookJS_o0000oooonfXJoookJV7o0000K?oonfX001Cooo]Z
0ol007l8oookJU;o0000oooonfXLoookJUko0000E_oonfX001Gooo]Z0ol007l7oookJPGo00001_oo
nfYNo`000?oooo]Z7OoonfYNo`0003kooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000M
oookJUgo0000oooonfXOoookJU_o0000:OoonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX5o`00
03Gooo]ZF_l0003ooookJR7ooo]ZF_l0000CoookJP003ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo
0000COoonfYHo`000?oooo]Z8_oonfY6o`00013ooo]Z000@oookJPOo001o2?oonfX5o`0006?ooo]Z
Eol0003ooookJRCooo]Z<?l0000?oookJP004OoonfX5o`00O`Wooo]Z1Ol0001ioookJUGo0000oooo
nfXUoookJQ_o00003ooonfX001oooo]Z1Ol0002>oookJUGo0000oooonfXWoookJP?o00004?oonfX0
01oooo]Z1Ol0002UoookJU;o0000oooonfXVoookJP007ooonfX5o`000;[ooo]ZDOl0003ooookJQ;o
oo]Z000OoookJPGo0000cOoonfYAo`000?kooo]Z000OoookJQ;o0000eOoonfY@o`000>[ooo]Z000O
oookJRCo0000eooonfY>o`000=Sooo]Z000OoookJSOo0000f?oonfY>o`000<Cooo]Z000OoookJTWo
0000f_oonfY<o`000;;ooo]Z000OoookJPGo00003?oonfY;o`000=[ooo]ZB_l0002QoookJP007ooo
nfX5o`0001oooo]ZB_l0003KoookJT[o0000S_oonfX001oooo]Z1Ol0000aoookJTWo0000gOoonfY9
o`0007cooo]Z000OoookJPGo0000A?oonfY8o`000=kooo]ZAol0001[oookJP007ooonfX5o`0005Ko
oo]ZB?l0003MoookJTOo0000F_oonfX001oooo]Z1Ol0001XoookJTOo0000g_oonfY6o`0004Wooo]Z
000OoookJPGo0000NOoonfY5o`000>;ooo]ZAOl0000goookJP007ooonfX5o`0008cooo]Z@ol0003R
oookJT?o0000:?oonfX001oooo]Z1Ol0002MoookJTCo0000hOoonfY3o`0001Oooo]Z000OoookJPGo
0000[_oonfY2o`000>?ooo]Z>Ol0000@oookJP007ooonfXFo`000:gooo]Z@_l0003ToookJRWo0000
3ooonfX001oooo]Z9_l0002^oookJT7o0000i?oonfXIo`0000oooo]Z000OoookJSKo0000[ooonfY0
o`000>Gooo]Z1ol0000@oookJP007ooonfY4o`000;7ooo]Z?ol0003]oookJP007ooonfX5o`00013o
oo]Z?ol0002`oookJSoo0000g_oonfX001oooo]Z1Ol0000PoookJSgo0000/_oonfXoo`000<kooo]Z
000OoookJPGo0000<?oonfXmo`000;;ooo]Z?Ol00030oookJP007ooonfX5o`0003kooo]Z?Ol0002d
oookJS_o0000/_oonfX001oooo]Z1Ol0001>oookJSco0000/ooonfXlo`000:?ooo]Z000OoookJPGo
0000GOoonfXko`000;Gooo]Z>_l0002EoookJP007ooonfX5o`0006cooo]Z>ol0002doookJS_o0000
Q_oonfX001oooo]Z1Ol0001koookJSWo0000]_oonfXjo`0007Sooo]Z000OoookJPGo0000ROoonfXi
o`000;Kooo]Z>Ol0001[oookJP007ooonfX:o`0009?ooo]Z>Ol0002foookJSWo0000G?oonfX001oo
oo]Z6Ol0002BoookJSSo0000]ooonfXho`0004oooo]Z000OoookJRKo0000T_oonfXho`000;Sooo]Z
>?l00011oookJP007ooonfXco`0009Cooo]Z=_l0002ioookJSOo0000=?oonfX001oooo]Z1Ol00005
oookJSKo0000UOoonfXgo`000;Sooo]Z=ol0000VoookJP007ooonfX5o`0001?ooo]Z=Ol0002Eoook
JSGo0000^_oonfXgo`0001Wooo]Z000OoookJPGo00008?oonfXeo`0009Gooo]Z=_l0002koookJS7o
00004?oonfX001oooo]Z1Ol0000]oookJSGo0000UOoonfXfo`000;_ooo]Z9Ol0000?oookJP007ooo
nfX5o`0003[ooo]Z=_l0002FoookJSCo0000^ooonfXHo`0000oooo]Z000OoookJPGo0000AooonfXd
o`0009Oooo]Z=?l0002loookJP[o00004?oonfX001oooo]Z1Ol0001EoookJSCo0000U_oonfXdo`00
0<Wooo]Z000DoookJP?o001o2?oonfX5o`0006;ooo]Z<_l0002HoookJS?o0000_OoonfX001Cooo]Z
0ol007l8oookJPGo0000KooonfXao`0009Wooo]Z<ol0002`oookJP005?oonfX3o`00O`Sooo]Z1Ol0
001koookJS;o0000V?oonfXco`000:Cooo]Z000?oookJPWo001o1ooonfX>o`0007oooo]Z<Ol0002I
oookJS7o0000VOoonfX000oooo]Z2Ol007l7oookJQ[o0000OooonfXao`0009Wooo]Z<Ol0002=oook
JP003ooonfX2o`00O`?ooo]Z0ol007l8oookJRKo0000O_oonfXbo`0009[ooo]Z<?l00021oookJP00
4?oonfX2o`00O`;ooo]Z0ol007l8oookJS;o0000P?oonfX`o`0009[ooo]Z<?l0001eoookJP004?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00008oookJS3o0000P?oonfX`o`0009_ooo]Z
<?l0001YoookJP004OoonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol0000DoookJS3o0000
P?oonfX_o`0009_ooo]Z<?l0001NoookJP004_oonfX5o`00O`Sooo]Z1Ol0000PoookJRoo0000POoo
nfX_o`0009_ooo]Z;ol0001CoookJP004_oonfX5o`00O`Sooo]Z1Ol0000/oookJRoo0000POoonfX_
o`0009_ooo]Z;ol00017oookJP004ooonfX4o`00O`Sooo]Z1Ol0000hoookJRko0000P_oonfX]o`00
09gooo]Z;Ol0000moookJP005?oonfX3o`00O`Sooo]Z1Ol00014oookJRgo0000POoonfX_o`0009go
oo]Z;Ol0000aoookJP007ooonfX5o`0004kooo]Z;Ol00023oookJRgo0000WOoonfX^o`0002Kooo]Z
000OoookJPGo0000F_oonfX]o`0008?ooo]Z;?l0002NoookJRgo00006ooonfX001oooo]Z1Ol0001V
oookJRco0000P_oonfX^o`0009gooo]Z;Ol0000@oookJP007ooonfX5o`00073ooo]Z;?l00024oook
JRco0000W_oonfXSo`0000oooo]Z000OoookJPGo0000NooonfX/o`0008Cooo]Z;?l0002NoookJQSo
00003ooonfX001oooo]Z1Ol00027oookJR[o0000Q?oonfX/o`000:3ooo]Z2ol0000@oookJP007ooo
nfX5o`00097ooo]Z:ol00025oookJR_o0000/?oonfX001oooo]Z1Ol0002LoookJR[o0000Q_oonfXZ
o`000:Kooo]Z000OoookJPGo0000Y_oonfX[o`0008Gooo]Z:ol0002KoookJP007ooonfX5o`000;7o
oo]Z:_l00026oookJR[o0000TOoonfX001oooo]Z1Ol0002koookJR_o0000QOoonfXYo`0008Sooo]Z
000OoookJPGo0000a_oonfXYo`0008Oooo]Z:Ol0001moookJP007ooonfX5o`000=3ooo]Z:Ol00027
oookJRWo0000LooonfX001oooo]Z1Ol0003KoookJRWo0000QooonfXXo`0006Wooo]Z000OoookJPGo
0000iOoonfXXo`0008Oooo]Z:Ol0001OoookJP007ooonfX5o`000>kooo]Z:_l00026oookJRSo0000
E_oonfX001oooo]Z1Ol0003ioookJRSo0000R?oonfXWo`0004cooo]Z000OoookJPGo0000oooonfX4
oookJROo0000R?oonfXXo`0004;ooo]Z000OoookJPGo0000oooonfX=oookJRWo0000QooonfXWo`00
03Wooo]Z000OoookJPGo0000oooonfXHoookJROo0000R?oonfXVo`00033ooo]Z000OoookJPGo0000
oooonfXQoookJROo0000R?oonfXXo`0002Gooo]Z000OoookJPGo0000oooonfXZoookJROo0000ROoo
nfXWo`0001cooo]Z000OoookJPGo0000oooonfXeoookJRGo0000R_oonfXVo`0001?ooo]Z000Ooook
JPGo0000oooonfXnoookJRKo0000ROoonfXPo`00013ooo]Z000OoookJPGo0000oooonfY7oookJRKo
0000R_oonfXGo`0000oooo]Z000OoookJPGo0000oooonfY@oookJRKo0000R_oonfX>o`0000oooo]Z
000OoookJPGo0000oooonfYJoookJRGo0000RooonfX3o`00013ooo]Z000OoookJPGo0000oooonfYS
oookJRGo0000UOoonfX001oooo]Z1Ol0003ooookJVcooo]Z9Ol0002<oookJP007ooonfX5o`000?oo
oo]ZMOoonfXTo`0008Cooo]Z000OoookJPGo0000oooonfYnoookJRGo0000N_oonfX001oooo]Z1Ol0
003ooookJXSooo]Z9?l0001aoookJP007ooonfX5o`000?oooo]ZTOoonfXSo`0006Wooo]Z000Ooook
JPGo0000oooonfZIoookJRCo0000H?oonfX001oooo]Z1Ol0003ooookJZ;ooo]Z8ol0001HoookJP00
7ooonfX5o`000?oooo]ZZooonfXSo`0004oooo]Z000OoookJPGo0000oooonfZcoookJR?o0000Aooo
nfX001oooo]Z1Ol0003ooookJ[cooo]Z8ol0000noookJP007ooonfX5o`000?oooo]Za?oonfXSo`00
03Kooo]Z000OoookJPGo0000oooonf[=oookJR;o0000;_oonfX001oooo]Z1Ol0003ooookJ]Gooo]Z
8ol0000UoookJP004OoonfX5o`00O`Wooo]Z1Ol0003ooookJ]kooo]Z8_l0000MoookJP004?oonfX7
o`00O`Sooo]Z1Ol0003ooookJ^Kooo]Z8_l0000EoookJP004?oonfX3o`00O`;ooo]Z0ol007l7oook
JPGo0000oooonf[^oookJQoo00004?oonfX000oooo]Z0ol007l3oookJP?o001o1ooonfX5o`000?oo
oo]ZmooonfXGo`0000oooo]Z000?oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0003ooookJ_gooo]Z
3ol0000?oookJP003ooonfX4o`00O`;ooo]Z0ol007l7oookJPGo0000oooonf[ooookJPSooo]Z1_l0
000@oookJP003ooonfX8o`00O`Sooo]Z1Ol0003ooookJ_oooo]Z7_oonfX000oooo]Z0ol007l01?oo
nf[o001oo`00Ool007l9oookJPGo0000oooonf[ooookJQkooo]Z000?oookJP?o001o3OoonfX5o`00
0?oooo]ZoooonfXNoookJP003ooonfX3o`00O`gooo]Z1Ol0003ooookJ_oooo]Z7_oonfX0013ooo]Z
0ol007l2oookJP?o001o1ooonfX5o`000?oooo]ZoooonfXNoookJP004?oonfX7o`00O`Sooo]Z1Ol0
003ooookJ_oooo]Z7_oonfX001;ooo]Z1?l007l9oookJPGo0000oooonf[ooookJQkooo]Z000Ooook
JPGo0000oooonf[ooookJQkooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.25765, -6.523, \
0.00761509, 0.0367555}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
To summarize what was done up to now, we've seen how a given \
function can be changed incrementally by stepping forward the independent \
variables and calculating a corresponding change in the function's value. By \
doing so, we trace out trajectories in space, the paths of which depend on \
the starting values of the independent variables.\
\>", "Subsubsection"],

Cell["Visualizing Geometry of First-Order ODEs", "Subtitle",
  CellTags->{
  "mmtag:19:first-order_ODES__visualizing", "mmtag:19:first-order_ODES"}],

Cell[TextData[{
  "Newton's law of cooling ",
  Cell[BoxData[
      \(TraditionalForm\`dT\/dt\)]],
  "= -k(T - ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  ") can be written in the non-dimensional form  ",
  Cell[BoxData[
      \(TraditionalForm\`d\[CapitalTheta]\/d\[Tau]\)]],
  "= 1-\[CapitalTheta] "
}], "Text"],

Cell[TextData[{
  "In the general case, ",
  Cell[BoxData[
      \(TraditionalForm\`d\[CapitalTheta]\/d\[Tau]\)]],
  " will depend on both \[CapitalTheta] and t, i.e., ",
  Cell[BoxData[
      \(TraditionalForm\`d\[CapitalTheta]\/d\[Tau]\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`d\[CapitalTheta]\/d\[Tau]\)]],
  "(\[CapitalTheta],t). This the equation of a surface in three dimensions, \
as shown in the following plot (in this specific case there is no t \
dependence):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      1 - \[CapitalTheta], \ {tau, \ \(-1\), 
        1}, \ {\[CapitalTheta], \ \(-2\), 3}, 
      AxesLabel \[Rule] {"\<\[Tau]\>", "\<\[CapitalTheta]\>", \*"\"\<\!\(d\
\[CapitalTheta]\/d\[Tau]\)\>\""}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.37803e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -26.9375 -19.3395 ]
[.02757 .24618 0 .66054 ]
[.17646 .18758 -41.2346 -20 ]
[.17646 .18758 .70288 0 ]
[.3345 .12542 -13.0356 -20 ]
[.3345 .12542 .96436 0 ]
[.50253 .05935 -25.4908 -20 ]
[.50253 .05935 3.50918 0 ]
[.68156 -0.01098 -11.5762 -20 ]
[.68156 -0.01098 2.42381 0 ]
[.29165 .07573 -12.2791 -20 ]
[.29165 .07573 .9084 0 ]
[.70096 -0.00478 0 -13.9157 ]
[.70096 -0.00478 26.9375 6.08431 ]
[.76745 .09703 0 -13.693 ]
[.76745 .09703 26.9375 6.30695 ]
[.82812 .18993 0 -13.4944 ]
[.82812 .18993 14 6.50564 ]
[.88369 .27502 0 -13.316 ]
[.88369 .27502 14 6.68404 ]
[.93478 .35327 0 -13.1549 ]
[.93478 .35327 14 6.84511 ]
[.98191 .42546 0 -13.0087 ]
[.98191 .42546 14 6.99126 ]
[.91861 .21225 0 -13.4028 ]
[.91861 .21225 17.125 6.59718 ]
[.02411 .26511 -26.9375 -6.09404 ]
[.02411 .26511 0 13.906 ]
[.01048 .35054 -14 -6.25471 ]
[.01048 .35054 0 13.7453 ]
[-0.00392 .44084 -14 -6.42551 ]
[-0.00392 .44084 0 13.5745 ]
[-0.05457 .39542 -36.6875 -14.5408 ]
[-0.05457 .39542 0 31.6467 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -102.235 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -86.4908 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -73.2791 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
72.188 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -17.9157 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.75514 .10158 m
.74899 .10385 L
s
gsave
.76745 .09703 -61 -17.693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81573 .19425 m
.80953 .19642 L
s
gsave
.82812 .18993 -61 -17.4944 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.87123 .27915 m
.865 .28122 L
s
gsave
.88369 .27502 -61 -17.316 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.92227 .35722 m
.91601 .35919 L
s
gsave
.93478 .35327 -61 -17.1549 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -17.0087 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.125 Mabswid
.70252 .02109 m
.69885 .02251 L
s
.71605 .04178 m
.71237 .04318 L
s
.72932 .06208 m
.72564 .06347 L
s
.74235 .08201 m
.73866 .08339 L
s
.7677 .12078 m
.764 .12213 L
s
.78003 .13965 m
.77633 .14098 L
s
.79214 .15817 m
.78843 .1595 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8385 .22909 m
.83478 .23037 L
s
.8496 .24606 m
.84587 .24733 L
s
.86051 .26275 m
.85677 .264 L
s
.88178 .29529 m
.87804 .29651 L
s
.89215 .31115 m
.88841 .31237 L
s
.90235 .32676 m
.89861 .32797 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.94155 .38671 m
.93779 .38788 L
s
.95096 .40111 m
.9472 .40226 L
s
.96022 .41528 m
.95646 .41643 L
s
gsave
.91861 .21225 -61 -17.4028 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Q) show
76.125 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03634 .26033 m
.04245 .25795 L
s
gsave
.02411 .26511 -87.9375 -10.094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02277 .34593 m
.02892 .34363 L
s
gsave
.01048 .35054 -75 -10.2547 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.00843 .43642 m
.01461 .43421 L
s
gsave
-0.00392 .44084 -75 -10.4255 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.125 Mabswid
.03301 .2813 m
.03669 .27988 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.01926 .36808 m
.02295 .36671 L
s
.0157 .39054 m
.0194 .38919 L
s
.01209 .41332 m
.01579 .41198 L
s
.00472 .45986 m
.00843 .45855 L
s
.00095 .48363 m
.00467 .48234 L
s
gsave
-0.05457 .39542 -97.6875 -18.5408 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 54.1875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 32.438 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
67.312 17.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(d) show
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Q) show
0.000 0.000 0.500 setrgbcolor
1.750 setlinewidth
65.875 27.000 moveto
27.062 0.000 rlineto
stroke
69.250 48.875 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(d) show
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
95.688 32.438 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.601 .88 .992 r
.39205 .59983 .40512 .60371 .42651 .5973 .41359 .59333 Metetra
.601 .88 .992 r
.41359 .59333 .42651 .5973 .44806 .59083 .43531 .58679 Metetra
.601 .88 .992 r
.43531 .58679 .44806 .59083 .46979 .58431 .4572 .58019 Metetra
.601 .88 .992 r
.4572 .58019 .46979 .58431 .4917 .57774 .47927 .57354 Metetra
.601 .88 .992 r
.47927 .57354 .4917 .57774 .51378 .57112 .50152 .56683 Metetra
.601 .88 .992 r
.50152 .56683 .51378 .57112 .53604 .56444 .52395 .56007 Metetra
.601 .88 .992 r
.52395 .56007 .53604 .56444 .55848 .55771 .54656 .55325 Metetra
.601 .88 .992 r
.54656 .55325 .55848 .55771 .58111 .55092 .56937 .54637 Metetra
.601 .88 .992 r
.56937 .54637 .58111 .55092 .60392 .54407 .59236 .53944 Metetra
.601 .88 .992 r
.59236 .53944 .60392 .54407 .62692 .53717 .61554 .53245 Metetra
.601 .88 .992 r
.61554 .53245 .62692 .53717 .65011 .53022 .63892 .52541 Metetra
.601 .88 .992 r
.63892 .52541 .65011 .53022 .67349 .5232 .6625 .5183 Metetra
.601 .88 .992 r
.6625 .5183 .67349 .5232 .69706 .51613 .68627 .51113 Metetra
.601 .88 .992 r
.68627 .51113 .69706 .51613 .72084 .509 .71024 .50391 Metetra
.601 .88 .992 r
.71024 .50391 .72084 .509 .74481 .50181 .73442 .49662 Metetra
.601 .88 .992 r
.73442 .49662 .74481 .50181 .76899 .49455 .7588 .48927 Metetra
.601 .88 .992 r
.7588 .48927 .76899 .49455 .79338 .48724 .7834 .48185 Metetra
.601 .88 .992 r
.7834 .48185 .79338 .48724 .81797 .47986 .8082 .47438 Metetra
.601 .88 .992 r
.8082 .47438 .81797 .47986 .84277 .47242 .83322 .46683 Metetra
.601 .88 .992 r
.83322 .46683 .84277 .47242 .86778 .46492 .85846 .45923 Metetra
.601 .88 .992 r
.85846 .45923 .86778 .46492 .89301 .45735 .88392 .45155 Metetra
.601 .88 .992 r
.88392 .45155 .89301 .45735 .91846 .44971 .9096 .44381 Metetra
.601 .88 .992 r
.9096 .44381 .91846 .44971 .94414 .44201 .93551 .436 Metetra
.601 .88 .992 r
.93551 .436 .94414 .44201 .97003 .43424 .96165 .42812 Metetra
.601 .88 .992 r
.37872 .59587 .39205 .59983 .41359 .59333 .40042 .58929 Metetra
.601 .88 .992 r
.40042 .58929 .41359 .59333 .43531 .58679 .42229 .58267 Metetra
.601 .88 .992 r
.42229 .58267 .43531 .58679 .4572 .58019 .44435 .57598 Metetra
.601 .88 .992 r
.44435 .57598 .4572 .58019 .47927 .57354 .46659 .56925 Metetra
.601 .88 .992 r
.46659 .56925 .47927 .57354 .50152 .56683 .48901 .56246 Metetra
.601 .88 .992 r
.48901 .56246 .50152 .56683 .52395 .56007 .51161 .55561 Metetra
.601 .88 .992 r
.51161 .55561 .52395 .56007 .54656 .55325 .53441 .5487 Metetra
.601 .88 .992 r
.53441 .5487 .54656 .55325 .56937 .54637 .55739 .54174 Metetra
.601 .88 .992 r
.55739 .54174 .56937 .54637 .59236 .53944 .58057 .53472 Metetra
.601 .88 .992 r
.58057 .53472 .59236 .53944 .61554 .53245 .60394 .52764 Metetra
.601 .88 .992 r
.60394 .52764 .61554 .53245 .63892 .52541 .62751 .5205 Metetra
.601 .88 .992 r
.62751 .5205 .63892 .52541 .6625 .5183 .65128 .5133 Metetra
.601 .88 .992 r
.65128 .5133 .6625 .5183 .68627 .51113 .67525 .50604 Metetra
.601 .88 .992 r
.67525 .50604 .68627 .51113 .71024 .50391 .69942 .49871 Metetra
.601 .88 .992 r
.69942 .49871 .71024 .50391 .73442 .49662 .72381 .49132 Metetra
.601 .88 .992 r
.72381 .49132 .73442 .49662 .7588 .48927 .7484 .48387 Metetra
.601 .88 .992 r
.7484 .48387 .7588 .48927 .7834 .48185 .77321 .47636 Metetra
.601 .88 .992 r
.77321 .47636 .7834 .48185 .8082 .47438 .79824 .46878 Metetra
.601 .88 .992 r
.79824 .46878 .8082 .47438 .83322 .46683 .82348 .46113 Metetra
.601 .88 .992 r
.82348 .46113 .83322 .46683 .85846 .45923 .84894 .45342 Metetra
.601 .88 .992 r
.84894 .45342 .85846 .45923 .88392 .45155 .87463 .44563 Metetra
.601 .88 .992 r
.87463 .44563 .88392 .45155 .9096 .44381 .90055 .43778 Metetra
.601 .88 .992 r
.90055 .43778 .9096 .44381 .93551 .436 .9267 .42986 Metetra
.601 .88 .992 r
.9267 .42986 .93551 .436 .96165 .42812 .95308 .42187 Metetra
.601 .88 .992 r
.36512 .59183 .37872 .59587 .40042 .58929 .38698 .58517 Metetra
.601 .88 .992 r
.38698 .58517 .40042 .58929 .42229 .58267 .40902 .57846 Metetra
.601 .88 .992 r
.40902 .57846 .42229 .58267 .44435 .57598 .43125 .5717 Metetra
.601 .88 .992 r
.43125 .5717 .44435 .57598 .46659 .56925 .45365 .56487 Metetra
.601 .88 .992 r
.45365 .56487 .46659 .56925 .48901 .56246 .47625 .55799 Metetra
.601 .88 .992 r
.47625 .55799 .48901 .56246 .51161 .55561 .49903 .55106 Metetra
.601 .88 .992 r
.49903 .55106 .51161 .55561 .53441 .5487 .522 .54406 Metetra
.601 .88 .992 r
.522 .54406 .53441 .5487 .55739 .54174 .54517 .53701 Metetra
.601 .88 .992 r
.54517 .53701 .55739 .54174 .58057 .53472 .56853 .5299 Metetra
.601 .88 .992 r
.56853 .5299 .58057 .53472 .60394 .52764 .59209 .52272 Metetra
.601 .88 .992 r
.59209 .52272 .60394 .52764 .62751 .5205 .61586 .51549 Metetra
.601 .88 .992 r
.61586 .51549 .62751 .5205 .65128 .5133 .63982 .50819 Metetra
.601 .88 .992 r
.63982 .50819 .65128 .5133 .67525 .50604 .664 .50083 Metetra
.601 .88 .992 r
.664 .50083 .67525 .50604 .69942 .49871 .68838 .49341 Metetra
.601 .88 .992 r
.68838 .49341 .69942 .49871 .72381 .49132 .71297 .48592 Metetra
.601 .88 .992 r
.71297 .48592 .72381 .49132 .7484 .48387 .73778 .47836 Metetra
.601 .88 .992 r
.73778 .47836 .7484 .48387 .77321 .47636 .76281 .47074 Metetra
.601 .88 .992 r
.76281 .47074 .77321 .47636 .79824 .46878 .78805 .46306 Metetra
.601 .88 .992 r
.78805 .46306 .79824 .46878 .82348 .46113 .81352 .4553 Metetra
.601 .88 .992 r
.81352 .4553 .82348 .46113 .84894 .45342 .83922 .44748 Metetra
.601 .88 .992 r
.83922 .44748 .84894 .45342 .87463 .44563 .86514 .43959 Metetra
.601 .88 .992 r
.86514 .43959 .87463 .44563 .90055 .43778 .8913 .43162 Metetra
.601 .88 .992 r
.8913 .43162 .90055 .43778 .9267 .42986 .91769 .42359 Metetra
.601 .88 .992 r
.91769 .42359 .9267 .42986 .95308 .42187 .94432 .41548 Metetra
.601 .88 .992 r
.35125 .58771 .36512 .59183 .38698 .58517 .37328 .58097 Metetra
.601 .88 .992 r
.37328 .58097 .38698 .58517 .40902 .57846 .39548 .57417 Metetra
.601 .88 .992 r
.39548 .57417 .40902 .57846 .43125 .5717 .41788 .56732 Metetra
.601 .88 .992 r
.41788 .56732 .43125 .5717 .45365 .56487 .44045 .56041 Metetra
.601 .88 .992 r
.44045 .56041 .45365 .56487 .47625 .55799 .46322 .55344 Metetra
.601 .88 .992 r
.46322 .55344 .47625 .55799 .49903 .55106 .48618 .54641 Metetra
.601 .88 .992 r
.48618 .54641 .49903 .55106 .522 .54406 .50934 .53933 Metetra
.601 .88 .992 r
.50934 .53933 .522 .54406 .54517 .53701 .53269 .53218 Metetra
.601 .88 .992 r
.53269 .53218 .54517 .53701 .56853 .5299 .55625 .52497 Metetra
.601 .88 .992 r
.55625 .52497 .56853 .5299 .59209 .52272 .58 .5177 Metetra
.601 .88 .992 r
.58 .5177 .59209 .52272 .61586 .51549 .60396 .51037 Metetra
.601 .88 .992 r
.60396 .51037 .61586 .51549 .63982 .50819 .62813 .50297 Metetra
.601 .88 .992 r
.62813 .50297 .63982 .50819 .664 .50083 .65251 .49551 Metetra
.601 .88 .992 r
.65251 .49551 .664 .50083 .68838 .49341 .6771 .48799 Metetra
.601 .88 .992 r
.6771 .48799 .68838 .49341 .71297 .48592 .70191 .4804 Metetra
.601 .88 .992 r
.70191 .4804 .71297 .48592 .73778 .47836 .72693 .47274 Metetra
.601 .88 .992 r
.72693 .47274 .73778 .47836 .76281 .47074 .75218 .46501 Metetra
.601 .88 .992 r
.75218 .46501 .76281 .47074 .78805 .46306 .77765 .45721 Metetra
.601 .88 .992 r
.77765 .45721 .78805 .46306 .81352 .4553 .80335 .44935 Metetra
.601 .88 .992 r
.80335 .44935 .81352 .4553 .83922 .44748 .82928 .44141 Metetra
.601 .88 .992 r
.82928 .44141 .83922 .44748 .86514 .43959 .85544 .43341 Metetra
.601 .88 .992 r
.85544 .43341 .86514 .43959 .8913 .43162 .88184 .42533 Metetra
.601 .88 .992 r
.88184 .42533 .8913 .43162 .91769 .42359 .90848 .41717 Metetra
.601 .88 .992 r
.90848 .41717 .91769 .42359 .94432 .41548 .93537 .40895 Metetra
.601 .88 .992 r
.33711 .5835 .35125 .58771 .37328 .58097 .35929 .57668 Metetra
.601 .88 .992 r
.35929 .57668 .37328 .58097 .39548 .57417 .38167 .5698 Metetra
.601 .88 .992 r
.38167 .5698 .39548 .57417 .41788 .56732 .40423 .56285 Metetra
.601 .88 .992 r
.40423 .56285 .41788 .56732 .44045 .56041 .42698 .55585 Metetra
.601 .88 .992 r
.42698 .55585 .44045 .56041 .46322 .55344 .44993 .54879 Metetra
.601 .88 .992 r
.44993 .54879 .46322 .55344 .48618 .54641 .47307 .54167 Metetra
.601 .88 .992 r
.47307 .54167 .48618 .54641 .50934 .53933 .49641 .53449 Metetra
.601 .88 .992 r
.49641 .53449 .50934 .53933 .53269 .53218 .51996 .52725 Metetra
.601 .88 .992 r
.51996 .52725 .53269 .53218 .55625 .52497 .5437 .51995 Metetra
.601 .88 .992 r
.5437 .51995 .55625 .52497 .58 .5177 .56765 .51258 Metetra
.601 .88 .992 r
.56765 .51258 .58 .5177 .60396 .51037 .59181 .50515 Metetra
.601 .88 .992 r
.59181 .50515 .60396 .51037 .62813 .50297 .61619 .49765 Metetra
.601 .88 .992 r
.61619 .49765 .62813 .50297 .65251 .49551 .64077 .49008 Metetra
.601 .88 .992 r
.64077 .49008 .65251 .49551 .6771 .48799 .66558 .48245 Metetra
.601 .88 .992 r
.66558 .48245 .6771 .48799 .70191 .4804 .6906 .47475 Metetra
.601 .88 .992 r
.6906 .47475 .70191 .4804 .72693 .47274 .71585 .46699 Metetra
.601 .88 .992 r
.71585 .46699 .72693 .47274 .75218 .46501 .74132 .45915 Metetra
.601 .88 .992 r
.74132 .45915 .75218 .46501 .77765 .45721 .76702 .45124 Metetra
.601 .88 .992 r
.76702 .45124 .77765 .45721 .80335 .44935 .79295 .44327 Metetra
.601 .88 .992 r
.79295 .44327 .80335 .44935 .82928 .44141 .81912 .43522 Metetra
.601 .88 .992 r
.81912 .43522 .82928 .44141 .85544 .43341 .84553 .42709 Metetra
.601 .88 .992 r
.84553 .42709 .85544 .43341 .88184 .42533 .87218 .41889 Metetra
.601 .88 .992 r
.87218 .41889 .88184 .42533 .90848 .41717 .89907 .41062 Metetra
.601 .88 .992 r
.89907 .41062 .90848 .41717 .93537 .40895 .92622 .40227 Metetra
.601 .88 .992 r
.32267 .57922 .33711 .5835 .35929 .57668 .34502 .5723 Metetra
.601 .88 .992 r
.34502 .5723 .35929 .57668 .38167 .5698 .36757 .56533 Metetra
.601 .88 .992 r
.36757 .56533 .38167 .5698 .40423 .56285 .3903 .5583 Metetra
.601 .88 .992 r
.3903 .5583 .40423 .56285 .42698 .55585 .41323 .5512 Metetra
.601 .88 .992 r
.41323 .5512 .42698 .55585 .44993 .54879 .43636 .54405 Metetra
.601 .88 .992 r
.43636 .54405 .44993 .54879 .47307 .54167 .45969 .53684 Metetra
.601 .88 .992 r
.45969 .53684 .47307 .54167 .49641 .53449 .48322 .52956 Metetra
.601 .88 .992 r
.48322 .52956 .49641 .53449 .51996 .52725 .50695 .52222 Metetra
.601 .88 .992 r
.50695 .52222 .51996 .52725 .5437 .51995 .53089 .51481 Metetra
.601 .88 .992 r
.53089 .51481 .5437 .51995 .56765 .51258 .55504 .50734 Metetra
.601 .88 .992 r
.55504 .50734 .56765 .51258 .59181 .50515 .57941 .49981 Metetra
.601 .88 .992 r
.57941 .49981 .59181 .50515 .61619 .49765 .60399 .49221 Metetra
.601 .88 .992 r
.60399 .49221 .61619 .49765 .64077 .49008 .62878 .48454 Metetra
.601 .88 .992 r
.62878 .48454 .64077 .49008 .66558 .48245 .6538 .4768 Metetra
.601 .88 .992 r
.6538 .4768 .66558 .48245 .6906 .47475 .67905 .46899 Metetra
.601 .88 .992 r
.67905 .46899 .6906 .47475 .71585 .46699 .70452 .46111 Metetra
.601 .88 .992 r
.70452 .46111 .71585 .46699 .74132 .45915 .73022 .45316 Metetra
.601 .88 .992 r
.73022 .45316 .74132 .45915 .76702 .45124 .75615 .44514 Metetra
.601 .88 .992 r
.75615 .44514 .76702 .45124 .79295 .44327 .78233 .43705 Metetra
.601 .88 .992 r
.78233 .43705 .79295 .44327 .81912 .43522 .80874 .42888 Metetra
.601 .88 .992 r
.80874 .42888 .81912 .43522 .84553 .42709 .83539 .42063 Metetra
.601 .88 .992 r
.83539 .42063 .84553 .42709 .87218 .41889 .8623 .41231 Metetra
.601 .88 .992 r
.8623 .41231 .87218 .41889 .89907 .41062 .88945 .40391 Metetra
.601 .88 .992 r
.88945 .40391 .89907 .41062 .92622 .40227 .91686 .39544 Metetra
.601 .88 .992 r
.30793 .57484 .32267 .57922 .34502 .5723 .33046 .56783 Metetra
.601 .88 .992 r
.33046 .56783 .34502 .5723 .36757 .56533 .35317 .56077 Metetra
.601 .88 .992 r
.35317 .56077 .36757 .56533 .3903 .5583 .37609 .55364 Metetra
.601 .88 .992 r
.37609 .55364 .3903 .5583 .41323 .5512 .3992 .54646 Metetra
.601 .88 .992 r
.3992 .54646 .41323 .5512 .43636 .54405 .42251 .53921 Metetra
.601 .88 .992 r
.42251 .53921 .43636 .54405 .45969 .53684 .44602 .53189 Metetra
.601 .88 .992 r
.44602 .53189 .45969 .53684 .48322 .52956 .46974 .52452 Metetra
.601 .88 .992 r
.46974 .52452 .48322 .52956 .50695 .52222 .49367 .51708 Metetra
.601 .88 .992 r
.49367 .51708 .50695 .52222 .53089 .51481 .51781 .50957 Metetra
.601 .88 .992 r
.51781 .50957 .53089 .51481 .55504 .50734 .54216 .502 Metetra
.601 .88 .992 r
.54216 .502 .55504 .50734 .57941 .49981 .56673 .49436 Metetra
.601 .88 .992 r
.56673 .49436 .57941 .49981 .60399 .49221 .59152 .48665 Metetra
.601 .88 .992 r
.59152 .48665 .60399 .49221 .62878 .48454 .61653 .47887 Metetra
.601 .88 .992 r
.61653 .47887 .62878 .48454 .6538 .4768 .64177 .47102 Metetra
.601 .88 .992 r
.64177 .47102 .6538 .4768 .67905 .46899 .66724 .4631 Metetra
.601 .88 .992 r
.66724 .4631 .67905 .46899 .70452 .46111 .69294 .45511 Metetra
.601 .88 .992 r
.69294 .45511 .70452 .46111 .73022 .45316 .71887 .44704 Metetra
.601 .88 .992 r
.71887 .44704 .73022 .45316 .75615 .44514 .74505 .4389 Metetra
.601 .88 .992 r
.74505 .4389 .75615 .44514 .78233 .43705 .77146 .43069 Metetra
.601 .88 .992 r
.77146 .43069 .78233 .43705 .80874 .42888 .79812 .4224 Metetra
.601 .88 .992 r
.79812 .4224 .80874 .42888 .83539 .42063 .82503 .41403 Metetra
.601 .88 .992 r
.82503 .41403 .83539 .42063 .8623 .41231 .85219 .40558 Metetra
.601 .88 .992 r
.85219 .40558 .8623 .41231 .88945 .40391 .8796 .39706 Metetra
.601 .88 .992 r
.8796 .39706 .88945 .40391 .91686 .39544 .90728 .38845 Metetra
.601 .88 .992 r
.29289 .57037 .30793 .57484 .33046 .56783 .31558 .56327 Metetra
.601 .88 .992 r
.31558 .56327 .33046 .56783 .35317 .56077 .33848 .55611 Metetra
.601 .88 .992 r
.33848 .55611 .35317 .56077 .37609 .55364 .36157 .54889 Metetra
.601 .88 .992 r
.36157 .54889 .37609 .55364 .3992 .54646 .38486 .54161 Metetra
.601 .88 .992 r
.38486 .54161 .3992 .54646 .42251 .53921 .40835 .53426 Metetra
.601 .88 .992 r
.40835 .53426 .42251 .53921 .44602 .53189 .43206 .52685 Metetra
.601 .88 .992 r
.43206 .52685 .44602 .53189 .46974 .52452 .45597 .51937 Metetra
.601 .88 .992 r
.45597 .51937 .46974 .52452 .49367 .51708 .4801 .51182 Metetra
.601 .88 .992 r
.4801 .51182 .49367 .51708 .51781 .50957 .50444 .50421 Metetra
.601 .88 .992 r
.50444 .50421 .51781 .50957 .54216 .502 .529 .49653 Metetra
.601 .88 .992 r
.529 .49653 .54216 .502 .56673 .49436 .55378 .48878 Metetra
.601 .88 .992 r
.55378 .48878 .56673 .49436 .59152 .48665 .57878 .48096 Metetra
.601 .88 .992 r
.57878 .48096 .59152 .48665 .61653 .47887 .60401 .47307 Metetra
.601 .88 .992 r
.60401 .47307 .61653 .47887 .64177 .47102 .62947 .46511 Metetra
.601 .88 .992 r
.62947 .46511 .64177 .47102 .66724 .4631 .65517 .45708 Metetra
.601 .88 .992 r
.65517 .45708 .66724 .4631 .69294 .45511 .6811 .44897 Metetra
.601 .88 .992 r
.6811 .44897 .69294 .45511 .71887 .44704 .70727 .44078 Metetra
.601 .88 .992 r
.70727 .44078 .71887 .44704 .74505 .4389 .73369 .43252 Metetra
.601 .88 .992 r
.73369 .43252 .74505 .4389 .77146 .43069 .76035 .42418 Metetra
.601 .88 .992 r
.76035 .42418 .77146 .43069 .79812 .4224 .78726 .41577 Metetra
.601 .88 .992 r
.78726 .41577 .79812 .4224 .82503 .41403 .81443 .40727 Metetra
.601 .88 .992 r
.81443 .40727 .82503 .41403 .85219 .40558 .84185 .3987 Metetra
.601 .88 .992 r
.84185 .3987 .85219 .40558 .8796 .39706 .86953 .39004 Metetra
.601 .88 .992 r
.86953 .39004 .8796 .39706 .90728 .38845 .89748 .3813 Metetra
.601 .88 .992 r
.27753 .5658 .29289 .57037 .31558 .56327 .3004 .55861 Metetra
.601 .88 .992 r
.3004 .55861 .31558 .56327 .33848 .55611 .32347 .55136 Metetra
.601 .88 .992 r
.32347 .55136 .33848 .55611 .36157 .54889 .34674 .54404 Metetra
.601 .88 .992 r
.34674 .54404 .36157 .54889 .38486 .54161 .37021 .53665 Metetra
.601 .88 .992 r
.37021 .53665 .38486 .54161 .40835 .53426 .3939 .52921 Metetra
.601 .88 .992 r
.3939 .52921 .40835 .53426 .43206 .52685 .41779 .52169 Metetra
.601 .88 .992 r
.41779 .52169 .43206 .52685 .45597 .51937 .4419 .51411 Metetra
.601 .88 .992 r
.4419 .51411 .45597 .51937 .4801 .51182 .46623 .50646 Metetra
.601 .88 .992 r
.46623 .50646 .4801 .51182 .50444 .50421 .49077 .49874 Metetra
.601 .88 .992 r
.49077 .49874 .50444 .50421 .529 .49653 .51554 .49095 Metetra
.601 .88 .992 r
.51554 .49095 .529 .49653 .55378 .48878 .54053 .48309 Metetra
.601 .88 .992 r
.54053 .48309 .55378 .48878 .57878 .48096 .56576 .47516 Metetra
.601 .88 .992 r
.56576 .47516 .57878 .48096 .60401 .47307 .59121 .46715 Metetra
.601 .88 .992 r
.59121 .46715 .60401 .47307 .62947 .46511 .6169 .45907 Metetra
.601 .88 .992 r
.6169 .45907 .62947 .46511 .65517 .45708 .64282 .45092 Metetra
.601 .88 .992 r
.64282 .45092 .65517 .45708 .6811 .44897 .66899 .44269 Metetra
.601 .88 .992 r
.66899 .44269 .6811 .44897 .70727 .44078 .6954 .43438 Metetra
.601 .88 .992 r
.6954 .43438 .70727 .44078 .73369 .43252 .72207 .426 Metetra
.601 .88 .992 r
.72207 .426 .73369 .43252 .76035 .42418 .74898 .41753 Metetra
.601 .88 .992 r
.74898 .41753 .76035 .42418 .78726 .41577 .77615 .40899 Metetra
.601 .88 .992 r
.77615 .40899 .78726 .41577 .81443 .40727 .80358 .40036 Metetra
.601 .88 .992 r
.80358 .40036 .81443 .40727 .84185 .3987 .83127 .39165 Metetra
.601 .88 .992 r
.83127 .39165 .84185 .3987 .86953 .39004 .85922 .38286 Metetra
.601 .88 .992 r
.85922 .38286 .86953 .39004 .89748 .3813 .88745 .37398 Metetra
.601 .88 .992 r
.26184 .56114 .27753 .5658 .3004 .55861 .28488 .55385 Metetra
.601 .88 .992 r
.28488 .55385 .3004 .55861 .32347 .55136 .30813 .5465 Metetra
.601 .88 .992 r
.30813 .5465 .32347 .55136 .34674 .54404 .33159 .53908 Metetra
.601 .88 .992 r
.33159 .53908 .34674 .54404 .37021 .53665 .35525 .53159 Metetra
.601 .88 .992 r
.35525 .53159 .37021 .53665 .3939 .52921 .37913 .52404 Metetra
.601 .88 .992 r
.37913 .52404 .3939 .52921 .41779 .52169 .40322 .51642 Metetra
.601 .88 .992 r
.40322 .51642 .41779 .52169 .4419 .51411 .42753 .50873 Metetra
.601 .88 .992 r
.42753 .50873 .4419 .51411 .46623 .50646 .45205 .50097 Metetra
.601 .88 .992 r
.45205 .50097 .46623 .50646 .49077 .49874 .47681 .49314 Metetra
.601 .88 .992 r
.47681 .49314 .49077 .49874 .51554 .49095 .50179 .48524 Metetra
.601 .88 .992 r
.50179 .48524 .51554 .49095 .54053 .48309 .527 .47726 Metetra
.601 .88 .992 r
.527 .47726 .54053 .48309 .56576 .47516 .55244 .46922 Metetra
.601 .88 .992 r
.55244 .46922 .56576 .47516 .59121 .46715 .57812 .46109 Metetra
.601 .88 .992 r
.57812 .46109 .59121 .46715 .6169 .45907 .60404 .45289 Metetra
.601 .88 .992 r
.60404 .45289 .6169 .45907 .64282 .45092 .6302 .44462 Metetra
.601 .88 .992 r
.6302 .44462 .64282 .45092 .66899 .44269 .65661 .43626 Metetra
.601 .88 .992 r
.65661 .43626 .66899 .44269 .6954 .43438 .68327 .42783 Metetra
.601 .88 .992 r
.68327 .42783 .6954 .43438 .72207 .426 .71018 .41932 Metetra
.601 .88 .992 r
.71018 .41932 .72207 .426 .74898 .41753 .73735 .41072 Metetra
.601 .88 .992 r
.73735 .41072 .74898 .41753 .77615 .40899 .76478 .40205 Metetra
.601 .88 .992 r
.76478 .40205 .77615 .40899 .80358 .40036 .79247 .39329 Metetra
.601 .88 .992 r
.79247 .39329 .80358 .40036 .83127 .39165 .82044 .38444 Metetra
.601 .88 .992 r
.82044 .38444 .83127 .39165 .85922 .38286 .84867 .37551 Metetra
.601 .88 .992 r
.84867 .37551 .85922 .38286 .88745 .37398 .87718 .36649 Metetra
.601 .88 .992 r
.24581 .55638 .26184 .56114 .28488 .55385 .26904 .54899 Metetra
.601 .88 .992 r
.26904 .54899 .28488 .55385 .30813 .5465 .29247 .54154 Metetra
.601 .88 .992 r
.29247 .54154 .30813 .5465 .33159 .53908 .31611 .53401 Metetra
.601 .88 .992 r
.31611 .53401 .33159 .53908 .35525 .53159 .33996 .52642 Metetra
.601 .88 .992 r
.33996 .52642 .35525 .53159 .37913 .52404 .36403 .51876 Metetra
.601 .88 .992 r
.36403 .51876 .37913 .52404 .40322 .51642 .38832 .51103 Metetra
.601 .88 .992 r
.38832 .51103 .40322 .51642 .42753 .50873 .41283 .50323 Metetra
.601 .88 .992 r
.41283 .50323 .42753 .50873 .45205 .50097 .43756 .49536 Metetra
.601 .88 .992 r
.43756 .49536 .45205 .50097 .47681 .49314 .46253 .48742 Metetra
.601 .88 .992 r
.46253 .48742 .47681 .49314 .50179 .48524 .48772 .4794 Metetra
.601 .88 .992 r
.48772 .4794 .50179 .48524 .527 .47726 .51315 .47131 Metetra
.601 .88 .992 r
.51315 .47131 .527 .47726 .55244 .46922 .53882 .46314 Metetra
.601 .88 .992 r
.53882 .46314 .55244 .46922 .57812 .46109 .56473 .4549 Metetra
.601 .88 .992 r
.56473 .4549 .57812 .46109 .60404 .45289 .59088 .44658 Metetra
.601 .88 .992 r
.59088 .44658 .60404 .45289 .6302 .44462 .61728 .43817 Metetra
.601 .88 .992 r
.61728 .43817 .6302 .44462 .65661 .43626 .64394 .42969 Metetra
.601 .88 .992 r
.64394 .42969 .65661 .43626 .68327 .42783 .67084 .42113 Metetra
.601 .88 .992 r
.67084 .42113 .68327 .42783 .71018 .41932 .69801 .41248 Metetra
.601 .88 .992 r
.69801 .41248 .71018 .41932 .73735 .41072 .72544 .40376 Metetra
.601 .88 .992 r
.72544 .40376 .73735 .41072 .76478 .40205 .75314 .39494 Metetra
.601 .88 .992 r
.75314 .39494 .76478 .40205 .79247 .39329 .7811 .38604 Metetra
.601 .88 .992 r
.7811 .38604 .79247 .39329 .82044 .38444 .80935 .37706 Metetra
.601 .88 .992 r
.80935 .37706 .82044 .38444 .84867 .37551 .83787 .36798 Metetra
.601 .88 .992 r
.83787 .36798 .84867 .37551 .87718 .36649 .86667 .35881 Metetra
.601 .88 .992 r
.22944 .55152 .24581 .55638 .26904 .54899 .25284 .54402 Metetra
.601 .88 .992 r
.25284 .54402 .26904 .54899 .29247 .54154 .27646 .53646 Metetra
.601 .88 .992 r
.27646 .53646 .29247 .54154 .31611 .53401 .30029 .52884 Metetra
.601 .88 .992 r
.30029 .52884 .31611 .53401 .33996 .52642 .32433 .52114 Metetra
.601 .88 .992 r
.32433 .52114 .33996 .52642 .36403 .51876 .3486 .51337 Metetra
.601 .88 .992 r
.3486 .51337 .36403 .51876 .38832 .51103 .37309 .50553 Metetra
.601 .88 .992 r
.37309 .50553 .38832 .51103 .41283 .50323 .3978 .49761 Metetra
.601 .88 .992 r
.3978 .49761 .41283 .50323 .43756 .49536 .42275 .48963 Metetra
.601 .88 .992 r
.42275 .48963 .43756 .49536 .46253 .48742 .44792 .48157 Metetra
.601 .88 .992 r
.44792 .48157 .46253 .48742 .48772 .4794 .47334 .47343 Metetra
.601 .88 .992 r
.47334 .47343 .48772 .4794 .51315 .47131 .49899 .46522 Metetra
.601 .88 .992 r
.49899 .46522 .51315 .47131 .53882 .46314 .52489 .45693 Metetra
.601 .88 .992 r
.52489 .45693 .53882 .46314 .56473 .4549 .55103 .44856 Metetra
.601 .88 .992 r
.55103 .44856 .56473 .4549 .59088 .44658 .57742 .44011 Metetra
.601 .88 .992 r
.57742 .44011 .59088 .44658 .61728 .43817 .60407 .43158 Metetra
.601 .88 .992 r
.60407 .43158 .61728 .43817 .64394 .42969 .63097 .42297 Metetra
.601 .88 .992 r
.63097 .42297 .64394 .42969 .67084 .42113 .65813 .41427 Metetra
.601 .88 .992 r
.65813 .41427 .67084 .42113 .69801 .41248 .68556 .40549 Metetra
.601 .88 .992 r
.68556 .40549 .69801 .41248 .72544 .40376 .71325 .39662 Metetra
.601 .88 .992 r
.71325 .39662 .72544 .40376 .75314 .39494 .74122 .38767 Metetra
.601 .88 .992 r
.74122 .38767 .75314 .39494 .7811 .38604 .76946 .37863 Metetra
.601 .88 .992 r
.76946 .37863 .7811 .38604 .80935 .37706 .79799 .36949 Metetra
.601 .88 .992 r
.79799 .36949 .80935 .37706 .83787 .36798 .8268 .36027 Metetra
.601 .88 .992 r
.8268 .36027 .83787 .36798 .86667 .35881 .8559 .35095 Metetra
.601 .88 .992 r
.2127 .54654 .22944 .55152 .25284 .54402 .23629 .53895 Metetra
.601 .88 .992 r
.23629 .53895 .25284 .54402 .27646 .53646 .26009 .53128 Metetra
.601 .88 .992 r
.26009 .53128 .27646 .53646 .30029 .52884 .28411 .52354 Metetra
.601 .88 .992 r
.28411 .52354 .30029 .52884 .32433 .52114 .30835 .51573 Metetra
.601 .88 .992 r
.30835 .51573 .32433 .52114 .3486 .51337 .33282 .50785 Metetra
.601 .88 .992 r
.33282 .50785 .3486 .51337 .37309 .50553 .35751 .4999 Metetra
.601 .88 .992 r
.35751 .4999 .37309 .50553 .3978 .49761 .38243 .49187 Metetra
.601 .88 .992 r
.38243 .49187 .3978 .49761 .42275 .48963 .40759 .48376 Metetra
.601 .88 .992 r
.40759 .48376 .42275 .48963 .44792 .48157 .43299 .47558 Metetra
.601 .88 .992 r
.43299 .47558 .44792 .48157 .47334 .47343 .45862 .46732 Metetra
.601 .88 .992 r
.45862 .46732 .47334 .47343 .49899 .46522 .4845 .45899 Metetra
.601 .88 .992 r
.4845 .45899 .49899 .46522 .52489 .45693 .51063 .45057 Metetra
.601 .88 .992 r
.51063 .45057 .52489 .45693 .55103 .44856 .53701 .44207 Metetra
.601 .88 .992 r
.53701 .44207 .55103 .44856 .57742 .44011 .56364 .43349 Metetra
.601 .88 .992 r
.56364 .43349 .57742 .44011 .60407 .43158 .59054 .42483 Metetra
.601 .88 .992 r
.59054 .42483 .60407 .43158 .63097 .42297 .61769 .41608 Metetra
.601 .88 .992 r
.61769 .41608 .63097 .42297 .65813 .41427 .64511 .40725 Metetra
.601 .88 .992 r
.64511 .40725 .65813 .41427 .68556 .40549 .6728 .39833 Metetra
.601 .88 .992 r
.6728 .39833 .68556 .40549 .71325 .39662 .70077 .38932 Metetra
.601 .88 .992 r
.70077 .38932 .71325 .39662 .74122 .38767 .72901 .38022 Metetra
.601 .88 .992 r
.72901 .38022 .74122 .38767 .76946 .37863 .75754 .37103 Metetra
.601 .88 .992 r
.75754 .37103 .76946 .37863 .79799 .36949 .78635 .36175 Metetra
.601 .88 .992 r
.78635 .36175 .79799 .36949 .8268 .36027 .81546 .35237 Metetra
.601 .88 .992 r
.81546 .35237 .8268 .36027 .8559 .35095 .84486 .3429 Metetra
.601 .88 .992 r
.1956 .54146 .2127 .54654 .23629 .53895 .21937 .53376 Metetra
.601 .88 .992 r
.21937 .53376 .23629 .53895 .26009 .53128 .24336 .52598 Metetra
.601 .88 .992 r
.24336 .52598 .26009 .53128 .28411 .52354 .26757 .51813 Metetra
.601 .88 .992 r
.26757 .51813 .28411 .52354 .30835 .51573 .29201 .51021 Metetra
.601 .88 .992 r
.29201 .51021 .30835 .51573 .33282 .50785 .31668 .50221 Metetra
.601 .88 .992 r
.31668 .50221 .33282 .50785 .35751 .4999 .34158 .49414 Metetra
.601 .88 .992 r
.34158 .49414 .35751 .4999 .38243 .49187 .36671 .48599 Metetra
.601 .88 .992 r
.36671 .48599 .38243 .49187 .40759 .48376 .39208 .47776 Metetra
.601 .88 .992 r
.39208 .47776 .40759 .48376 .43299 .47558 .4177 .46946 Metetra
.601 .88 .992 r
.4177 .46946 .43299 .47558 .45862 .46732 .44356 .46107 Metetra
.601 .88 .992 r
.44356 .46107 .45862 .46732 .4845 .45899 .46967 .45261 Metetra
.601 .88 .992 r
.46967 .45261 .4845 .45899 .51063 .45057 .49604 .44406 Metetra
.601 .88 .992 r
.49604 .44406 .51063 .45057 .53701 .44207 .52266 .43543 Metetra
.601 .88 .992 r
.52266 .43543 .53701 .44207 .56364 .43349 .54954 .42672 Metetra
.601 .88 .992 r
.54954 .42672 .56364 .43349 .59054 .42483 .57668 .41792 Metetra
.601 .88 .992 r
.57668 .41792 .59054 .42483 .61769 .41608 .6041 .40903 Metetra
.601 .88 .992 r
.6041 .40903 .61769 .41608 .64511 .40725 .63178 .40005 Metetra
.601 .88 .992 r
.63178 .40005 .64511 .40725 .6728 .39833 .65974 .39099 Metetra
.601 .88 .992 r
.65974 .39099 .6728 .39833 .70077 .38932 .68798 .38183 Metetra
.601 .88 .992 r
.68798 .38183 .70077 .38932 .72901 .38022 .71651 .37259 Metetra
.601 .88 .992 r
.71651 .37259 .72901 .38022 .75754 .37103 .74532 .36324 Metetra
.601 .88 .992 r
.74532 .36324 .75754 .37103 .78635 .36175 .77443 .35381 Metetra
.601 .88 .992 r
.77443 .35381 .78635 .36175 .81546 .35237 .80384 .34427 Metetra
.601 .88 .992 r
.80384 .34427 .81546 .35237 .84486 .3429 .83354 .33464 Metetra
.601 .88 .992 r
.1781 .53626 .1956 .54146 .21937 .53376 .20206 .52845 Metetra
.601 .88 .992 r
.20206 .52845 .21937 .53376 .24336 .52598 .22624 .52056 Metetra
.601 .88 .992 r
.22624 .52056 .24336 .52598 .26757 .51813 .25065 .51259 Metetra
.601 .88 .992 r
.25065 .51259 .26757 .51813 .29201 .51021 .27529 .50455 Metetra
.601 .88 .992 r
.27529 .50455 .29201 .51021 .31668 .50221 .30016 .49644 Metetra
.601 .88 .992 r
.30016 .49644 .31668 .50221 .34158 .49414 .32527 .48824 Metetra
.601 .88 .992 r
.32527 .48824 .34158 .49414 .36671 .48599 .35062 .47997 Metetra
.601 .88 .992 r
.35062 .47997 .36671 .48599 .39208 .47776 .37622 .47162 Metetra
.601 .88 .992 r
.37622 .47162 .39208 .47776 .4177 .46946 .40206 .46319 Metetra
.601 .88 .992 r
.40206 .46319 .4177 .46946 .44356 .46107 .42815 .45467 Metetra
.601 .88 .992 r
.42815 .45467 .44356 .46107 .46967 .45261 .45449 .44608 Metetra
.601 .88 .992 r
.45449 .44608 .46967 .45261 .49604 .44406 .4811 .4374 Metetra
.601 .88 .992 r
.4811 .4374 .49604 .44406 .52266 .43543 .50796 .42863 Metetra
.601 .88 .992 r
.50796 .42863 .52266 .43543 .54954 .42672 .53509 .41978 Metetra
.601 .88 .992 r
.53509 .41978 .54954 .42672 .57668 .41792 .56249 .41084 Metetra
.601 .88 .992 r
.56249 .41084 .57668 .41792 .6041 .40903 .59017 .40181 Metetra
.601 .88 .992 r
.59017 .40181 .6041 .40903 .63178 .40005 .61812 .39269 Metetra
.601 .88 .992 r
.61812 .39269 .63178 .40005 .65974 .39099 .64636 .38347 Metetra
.601 .88 .992 r
.64636 .38347 .65974 .39099 .68798 .38183 .67488 .37417 Metetra
.601 .88 .992 r
.67488 .37417 .68798 .38183 .71651 .37259 .70369 .36476 Metetra
.601 .88 .992 r
.70369 .36476 .71651 .37259 .74532 .36324 .7328 .35527 Metetra
.601 .88 .992 r
.7328 .35527 .74532 .36324 .77443 .35381 .76221 .34567 Metetra
.601 .88 .992 r
.76221 .34567 .77443 .35381 .80384 .34427 .79192 .33597 Metetra
.601 .88 .992 r
.79192 .33597 .80384 .34427 .83354 .33464 .82194 .32618 Metetra
.601 .88 .992 r
.16021 .53095 .1781 .53626 .20206 .52845 .18436 .52302 Metetra
.601 .88 .992 r
.18436 .52302 .20206 .52845 .22624 .52056 .20874 .51501 Metetra
.601 .88 .992 r
.20874 .51501 .22624 .52056 .25065 .51259 .23334 .50693 Metetra
.601 .88 .992 r
.23334 .50693 .25065 .51259 .27529 .50455 .25819 .49877 Metetra
.601 .88 .992 r
.25819 .49877 .27529 .50455 .30016 .49644 .28327 .49053 Metetra
.601 .88 .992 r
.28327 .49053 .30016 .49644 .32527 .48824 .30859 .48221 Metetra
.601 .88 .992 r
.30859 .48221 .32527 .48824 .35062 .47997 .33416 .47381 Metetra
.601 .88 .992 r
.33416 .47381 .35062 .47997 .37622 .47162 .35997 .46533 Metetra
.601 .88 .992 r
.35997 .46533 .37622 .47162 .40206 .46319 .38604 .45677 Metetra
.601 .88 .992 r
.38604 .45677 .40206 .46319 .42815 .45467 .41236 .44812 Metetra
.601 .88 .992 r
.41236 .44812 .42815 .45467 .45449 .44608 .43895 .43939 Metetra
.601 .88 .992 r
.43895 .43939 .45449 .44608 .4811 .4374 .46579 .43057 Metetra
.601 .88 .992 r
.46579 .43057 .4811 .4374 .50796 .42863 .49291 .42167 Metetra
.601 .88 .992 r
.49291 .42167 .50796 .42863 .53509 .41978 .5203 .41267 Metetra
.601 .88 .992 r
.5203 .41267 .53509 .41978 .56249 .41084 .54796 .40358 Metetra
.601 .88 .992 r
.54796 .40358 .56249 .41084 .59017 .40181 .5759 .39441 Metetra
.601 .88 .992 r
.5759 .39441 .59017 .40181 .61812 .39269 .60413 .38513 Metetra
.601 .88 .992 r
.60413 .38513 .61812 .39269 .64636 .38347 .63264 .37577 Metetra
.601 .88 .992 r
.63264 .37577 .64636 .38347 .67488 .37417 .66145 .36631 Metetra
.601 .88 .992 r
.66145 .36631 .67488 .37417 .70369 .36476 .69055 .35674 Metetra
.601 .88 .992 r
.69055 .35674 .70369 .36476 .7328 .35527 .71996 .34709 Metetra
.601 .88 .992 r
.71996 .34709 .7328 .35527 .76221 .34567 .74968 .33732 Metetra
.601 .88 .992 r
.74968 .33732 .76221 .34567 .79192 .33597 .7797 .32746 Metetra
.601 .88 .992 r
.7797 .32746 .79192 .33597 .82194 .32618 .81005 .3175 Metetra
.601 .88 .992 r
.14191 .52551 .16021 .53095 .18436 .52302 .16625 .51746 Metetra
.601 .88 .992 r
.16625 .51746 .18436 .52302 .20874 .51501 .19082 .50933 Metetra
.601 .88 .992 r
.19082 .50933 .20874 .51501 .23334 .50693 .21563 .50113 Metetra
.601 .88 .992 r
.21563 .50113 .23334 .50693 .25819 .49877 .24068 .49285 Metetra
.601 .88 .992 r
.24068 .49285 .25819 .49877 .28327 .49053 .26597 .48448 Metetra
.601 .88 .992 r
.26597 .48448 .28327 .49053 .30859 .48221 .29151 .47604 Metetra
.601 .88 .992 r
.29151 .47604 .30859 .48221 .33416 .47381 .3173 .46751 Metetra
.601 .88 .992 r
.3173 .46751 .33416 .47381 .35997 .46533 .34334 .4589 Metetra
.601 .88 .992 r
.34334 .4589 .35997 .46533 .38604 .45677 .36964 .4502 Metetra
.601 .88 .992 r
.36964 .4502 .38604 .45677 .41236 .44812 .3962 .44141 Metetra
.601 .88 .992 r
.3962 .44141 .41236 .44812 .43895 .43939 .42302 .43254 Metetra
.601 .88 .992 r
.42302 .43254 .43895 .43939 .46579 .43057 .45012 .42358 Metetra
.601 .88 .992 r
.45012 .42358 .46579 .43057 .49291 .42167 .47749 .41453 Metetra
.601 .88 .992 r
.47749 .41453 .49291 .42167 .5203 .41267 .50513 .40539 Metetra
.601 .88 .992 r
.50513 .40539 .5203 .41267 .54796 .40358 .53306 .39615 Metetra
.601 .88 .992 r
.53306 .39615 .54796 .40358 .5759 .39441 .56128 .38682 Metetra
.601 .88 .992 r
.56128 .38682 .5759 .39441 .60413 .38513 .58978 .37739 Metetra
.601 .88 .992 r
.58978 .37739 .60413 .38513 .63264 .37577 .61858 .36787 Metetra
.601 .88 .992 r
.61858 .36787 .63264 .37577 .66145 .36631 .64768 .35825 Metetra
.601 .88 .992 r
.64768 .35825 .66145 .36631 .69055 .35674 .67708 .34852 Metetra
.601 .88 .992 r
.67708 .34852 .69055 .35674 .71996 .34709 .7068 .3387 Metetra
.601 .88 .992 r
.7068 .3387 .71996 .34709 .74968 .33732 .73682 .32877 Metetra
.601 .88 .992 r
.73682 .32877 .74968 .33732 .7797 .32746 .76717 .31873 Metetra
.601 .88 .992 r
.76717 .31873 .7797 .32746 .81005 .3175 .79784 .30859 Metetra
.601 .88 .992 r
.12318 .51995 .14191 .52551 .16625 .51746 .14772 .51178 Metetra
.601 .88 .992 r
.14772 .51178 .16625 .51746 .19082 .50933 .17249 .50353 Metetra
.601 .88 .992 r
.17249 .50353 .19082 .50933 .21563 .50113 .1975 .4952 Metetra
.601 .88 .992 r
.1975 .4952 .21563 .50113 .24068 .49285 .22276 .48679 Metetra
.601 .88 .992 r
.22276 .48679 .24068 .49285 .26597 .48448 .24826 .47829 Metetra
.601 .88 .992 r
.24826 .47829 .26597 .48448 .29151 .47604 .27402 .46971 Metetra
.601 .88 .992 r
.27402 .46971 .29151 .47604 .3173 .46751 .30003 .46105 Metetra
.601 .88 .992 r
.30003 .46105 .3173 .46751 .34334 .4589 .3263 .4523 Metetra
.601 .88 .992 r
.3263 .4523 .34334 .4589 .36964 .4502 .35284 .44347 Metetra
.601 .88 .992 r
.35284 .44347 .36964 .4502 .3962 .44141 .37964 .43454 Metetra
.601 .88 .992 r
.37964 .43454 .3962 .44141 .42302 .43254 .40671 .42553 Metetra
.601 .88 .992 r
.40671 .42553 .42302 .43254 .45012 .42358 .43406 .41642 Metetra
.601 .88 .992 r
.43406 .41642 .45012 .42358 .47749 .41453 .46168 .40722 Metetra
.601 .88 .992 r
.46168 .40722 .47749 .41453 .50513 .40539 .48959 .39792 Metetra
.601 .88 .992 r
.48959 .39792 .50513 .40539 .53306 .39615 .51779 .38853 Metetra
.601 .88 .992 r
.51779 .38853 .53306 .39615 .56128 .38682 .54628 .37904 Metetra
.601 .88 .992 r
.54628 .37904 .56128 .38682 .58978 .37739 .57507 .36946 Metetra
.601 .88 .992 r
.57507 .36946 .58978 .37739 .61858 .36787 .60416 .35977 Metetra
.601 .88 .992 r
.60416 .35977 .61858 .36787 .64768 .35825 .63356 .34998 Metetra
.601 .88 .992 r
.63356 .34998 .64768 .35825 .67708 .34852 .66326 .34009 Metetra
.601 .88 .992 r
.66326 .34009 .67708 .34852 .7068 .3387 .69329 .33009 Metetra
.601 .88 .992 r
.69329 .33009 .7068 .3387 .73682 .32877 .72363 .31998 Metetra
.601 .88 .992 r
.72363 .31998 .73682 .32877 .76717 .31873 .7543 .30977 Metetra
.601 .88 .992 r
.7543 .30977 .76717 .31873 .79784 .30859 .78531 .29944 Metetra
.601 .88 .992 r
.10401 .51425 .12318 .51995 .14772 .51178 .12874 .50596 Metetra
.601 .88 .992 r
.12874 .50596 .14772 .51178 .17249 .50353 .15372 .49758 Metetra
.601 .88 .992 r
.15372 .49758 .17249 .50353 .1975 .4952 .17894 .48912 Metetra
.601 .88 .992 r
.17894 .48912 .1975 .4952 .22276 .48679 .2044 .48058 Metetra
.601 .88 .992 r
.2044 .48058 .22276 .48679 .24826 .47829 .23013 .47195 Metetra
.601 .88 .992 r
.23013 .47195 .24826 .47829 .27402 .46971 .25611 .46324 Metetra
.601 .88 .992 r
.25611 .46324 .27402 .46971 .30003 .46105 .28235 .45444 Metetra
.601 .88 .992 r
.28235 .45444 .30003 .46105 .3263 .4523 .30885 .44555 Metetra
.601 .88 .992 r
.30885 .44555 .3263 .4523 .35284 .44347 .33562 .43657 Metetra
.601 .88 .992 r
.33562 .43657 .35284 .44347 .37964 .43454 .36267 .4275 Metetra
.601 .88 .992 r
.36267 .4275 .37964 .43454 .40671 .42553 .38999 .41833 Metetra
.601 .88 .992 r
.38999 .41833 .40671 .42553 .43406 .41642 .41759 .40908 Metetra
.601 .88 .992 r
.41759 .40908 .43406 .41642 .46168 .40722 .44548 .39972 Metetra
.601 .88 .992 r
.44548 .39972 .46168 .40722 .48959 .39792 .47366 .39027 Metetra
.601 .88 .992 r
.47366 .39027 .48959 .39792 .51779 .38853 .50213 .38072 Metetra
.601 .88 .992 r
.50213 .38072 .51779 .38853 .54628 .37904 .53091 .37107 Metetra
.601 .88 .992 r
.53091 .37107 .54628 .37904 .57507 .36946 .55998 .36132 Metetra
.601 .88 .992 r
.55998 .36132 .57507 .36946 .60416 .35977 .58937 .35146 Metetra
.601 .88 .992 r
.58937 .35146 .60416 .35977 .63356 .34998 .61907 .3415 Metetra
.601 .88 .992 r
.61907 .3415 .63356 .34998 .66326 .34009 .64908 .33143 Metetra
.601 .88 .992 r
.64908 .33143 .66326 .34009 .69329 .33009 .67943 .32126 Metetra
.601 .88 .992 r
.67943 .32126 .69329 .33009 .72363 .31998 .7101 .31097 Metetra
.601 .88 .992 r
.7101 .31097 .72363 .31998 .7543 .30977 .7411 .30057 Metetra
.601 .88 .992 r
.7411 .30057 .7543 .30977 .78531 .29944 .77245 .29006 Metetra
.601 .88 .992 r
.08438 .50842 .10401 .51425 .12874 .50596 .10931 .5 Metetra
.601 .88 .992 r
.10931 .5 .12874 .50596 .15372 .49758 .13449 .49149 Metetra
.601 .88 .992 r
.13449 .49149 .15372 .49758 .17894 .48912 .15992 .4829 Metetra
.601 .88 .992 r
.15992 .4829 .17894 .48912 .2044 .48058 .1856 .47422 Metetra
.601 .88 .992 r
.1856 .47422 .2044 .48058 .23013 .47195 .21155 .46546 Metetra
.601 .88 .992 r
.21155 .46546 .23013 .47195 .25611 .46324 .23775 .4566 Metetra
.601 .88 .992 r
.23775 .4566 .25611 .46324 .28235 .45444 .26422 .44766 Metetra
.601 .88 .992 r
.26422 .44766 .28235 .45444 .30885 .44555 .29096 .43862 Metetra
.601 .88 .992 r
.29096 .43862 .30885 .44555 .33562 .43657 .31798 .4295 Metetra
.601 .88 .992 r
.31798 .4295 .33562 .43657 .36267 .4275 .34527 .42028 Metetra
.601 .88 .992 r
.34527 .42028 .36267 .4275 .38999 .41833 .37285 .41096 Metetra
.601 .88 .992 r
.37285 .41096 .38999 .41833 .41759 .40908 .40071 .40155 Metetra
.601 .88 .992 r
.40071 .40155 .41759 .40908 .44548 .39972 .42887 .39203 Metetra
.601 .88 .992 r
.42887 .39203 .44548 .39972 .47366 .39027 .45732 .38242 Metetra
.601 .88 .992 r
.45732 .38242 .47366 .39027 .50213 .38072 .48607 .37271 Metetra
.601 .88 .992 r
.48607 .37271 .50213 .38072 .53091 .37107 .51513 .36289 Metetra
.601 .88 .992 r
.51513 .36289 .53091 .37107 .55998 .36132 .5445 .35297 Metetra
.601 .88 .992 r
.5445 .35297 .55998 .36132 .58937 .35146 .57419 .34294 Metetra
.601 .88 .992 r
.57419 .34294 .58937 .35146 .61907 .3415 .6042 .3328 Metetra
.601 .88 .992 r
.6042 .3328 .61907 .3415 .64908 .33143 .63453 .32255 Metetra
.601 .88 .992 r
.63453 .32255 .64908 .33143 .67943 .32126 .66519 .31219 Metetra
.601 .88 .992 r
.66519 .31219 .67943 .32126 .7101 .31097 .6962 .30172 Metetra
.601 .88 .992 r
.6962 .30172 .7101 .31097 .7411 .30057 .72754 .29113 Metetra
.601 .88 .992 r
.72754 .29113 .7411 .30057 .77245 .29006 .75924 .28042 Metetra
.601 .88 .992 r
.06428 .50245 .08438 .50842 .10931 .5 .08941 .49389 Metetra
.601 .88 .992 r
.08941 .49389 .10931 .5 .13449 .49149 .1148 .48525 Metetra
.601 .88 .992 r
.1148 .48525 .13449 .49149 .15992 .4829 .14044 .47652 Metetra
.601 .88 .992 r
.14044 .47652 .15992 .4829 .1856 .47422 .16634 .46771 Metetra
.601 .88 .992 r
.16634 .46771 .1856 .47422 .21155 .46546 .19251 .4588 Metetra
.601 .88 .992 r
.19251 .4588 .21155 .46546 .23775 .4566 .21894 .4498 Metetra
.601 .88 .992 r
.21894 .4498 .23775 .4566 .26422 .44766 .24564 .44071 Metetra
.601 .88 .992 r
.24564 .44071 .26422 .44766 .29096 .43862 .27263 .43153 Metetra
.601 .88 .992 r
.27263 .43153 .29096 .43862 .31798 .4295 .29989 .42225 Metetra
.601 .88 .992 r
.29989 .42225 .31798 .4295 .34527 .42028 .32743 .41287 Metetra
.601 .88 .992 r
.32743 .41287 .34527 .42028 .37285 .41096 .35527 .4034 Metetra
.601 .88 .992 r
.35527 .4034 .37285 .41096 .40071 .40155 .3834 .39382 Metetra
.601 .88 .992 r
.3834 .39382 .40071 .40155 .42887 .39203 .41182 .38415 Metetra
.601 .88 .992 r
.41182 .38415 .42887 .39203 .45732 .38242 .44055 .37437 Metetra
.601 .88 .992 r
.44055 .37437 .45732 .38242 .48607 .37271 .46959 .36448 Metetra
.601 .88 .992 r
.46959 .36448 .48607 .37271 .51513 .36289 .49894 .35449 Metetra
.601 .88 .992 r
.49894 .35449 .51513 .36289 .5445 .35297 .52861 .34439 Metetra
.601 .88 .992 r
.52861 .34439 .5445 .35297 .57419 .34294 .55861 .33418 Metetra
.601 .88 .992 r
.55861 .33418 .57419 .34294 .6042 .3328 .58893 .32386 Metetra
.601 .88 .992 r
.58893 .32386 .6042 .3328 .63453 .32255 .61958 .31343 Metetra
.601 .88 .992 r
.61958 .31343 .63453 .32255 .66519 .31219 .65058 .30288 Metetra
.601 .88 .992 r
.65058 .30288 .66519 .31219 .6962 .30172 .68192 .29221 Metetra
.601 .88 .992 r
.68192 .29221 .6962 .30172 .72754 .29113 .71361 .28142 Metetra
.601 .88 .992 r
.71361 .28142 .72754 .29113 .75924 .28042 .74566 .27051 Metetra
.601 .88 .992 r
.04369 .49633 .06428 .50245 .08941 .49389 .06902 .48764 Metetra
.601 .88 .992 r
.06902 .48764 .08941 .49389 .1148 .48525 .09462 .47886 Metetra
.601 .88 .992 r
.09462 .47886 .1148 .48525 .14044 .47652 .12048 .46999 Metetra
.601 .88 .992 r
.12048 .46999 .14044 .47652 .16634 .46771 .1466 .46103 Metetra
.601 .88 .992 r
.1466 .46103 .16634 .46771 .19251 .4588 .17299 .45198 Metetra
.601 .88 .992 r
.17299 .45198 .19251 .4588 .21894 .4498 .19966 .44283 Metetra
.601 .88 .992 r
.19966 .44283 .21894 .4498 .24564 .44071 .2266 .43359 Metetra
.601 .88 .992 r
.2266 .43359 .24564 .44071 .27263 .43153 .25382 .42425 Metetra
.601 .88 .992 r
.25382 .42425 .27263 .43153 .29989 .42225 .28133 .41481 Metetra
.601 .88 .992 r
.28133 .41481 .29989 .42225 .32743 .41287 .30913 .40528 Metetra
.601 .88 .992 r
.30913 .40528 .32743 .41287 .35527 .4034 .33723 .39564 Metetra
.601 .88 .992 r
.33723 .39564 .35527 .4034 .3834 .39382 .36563 .3859 Metetra
.601 .88 .992 r
.36563 .3859 .3834 .39382 .41182 .38415 .39433 .37605 Metetra
.601 .88 .992 r
.39433 .37605 .41182 .38415 .44055 .37437 .42335 .3661 Metetra
.601 .88 .992 r
.42335 .3661 .44055 .37437 .46959 .36448 .45268 .35604 Metetra
.601 .88 .992 r
.45268 .35604 .46959 .36448 .49894 .35449 .48233 .34587 Metetra
.601 .88 .992 r
.48233 .34587 .49894 .35449 .52861 .34439 .5123 .33559 Metetra
.601 .88 .992 r
.5123 .33559 .52861 .34439 .55861 .33418 .54261 .3252 Metetra
.601 .88 .992 r
.54261 .3252 .55861 .33418 .58893 .32386 .57325 .31469 Metetra
.601 .88 .992 r
.57325 .31469 .58893 .32386 .61958 .31343 .60423 .30406 Metetra
.601 .88 .992 r
.60423 .30406 .61958 .31343 .65058 .30288 .63557 .29331 Metetra
.601 .88 .992 r
.63557 .29331 .65058 .30288 .68192 .29221 .66725 .28244 Metetra
.601 .88 .992 r
.66725 .28244 .68192 .29221 .71361 .28142 .6993 .27145 Metetra
.601 .88 .992 r
.6993 .27145 .71361 .28142 .74566 .27051 .73171 .26033 Metetra
.601 .88 .992 r
.02258 .49006 .04369 .49633 .06902 .48764 .04813 .48123 Metetra
.601 .88 .992 r
.04813 .48123 .06902 .48764 .09462 .47886 .07394 .4723 Metetra
.601 .88 .992 r
.07394 .4723 .09462 .47886 .12048 .46999 .10001 .46329 Metetra
.601 .88 .992 r
.10001 .46329 .12048 .46999 .1466 .46103 .12636 .45418 Metetra
.601 .88 .992 r
.12636 .45418 .1466 .46103 .17299 .45198 .15298 .44498 Metetra
.601 .88 .992 r
.15298 .44498 .17299 .45198 .19966 .44283 .17988 .43568 Metetra
.601 .88 .992 r
.17988 .43568 .19966 .44283 .2266 .43359 .20706 .42628 Metetra
.601 .88 .992 r
.20706 .42628 .2266 .43359 .25382 .42425 .23453 .41679 Metetra
.601 .88 .992 r
.23453 .41679 .25382 .42425 .28133 .41481 .2623 .40719 Metetra
.601 .88 .992 r
.2623 .40719 .28133 .41481 .30913 .40528 .29036 .39749 Metetra
.601 .88 .992 r
.29036 .39749 .30913 .40528 .33723 .39564 .31873 .38768 Metetra
.601 .88 .992 r
.31873 .38768 .33723 .39564 .36563 .3859 .3474 .37777 Metetra
.601 .88 .992 r
.3474 .37777 .36563 .3859 .39433 .37605 .37638 .36775 Metetra
.601 .88 .992 r
.37638 .36775 .39433 .37605 .42335 .3661 .40568 .35762 Metetra
.601 .88 .992 r
.40568 .35762 .42335 .3661 .45268 .35604 .43531 .34738 Metetra
.601 .88 .992 r
.43531 .34738 .45268 .35604 .48233 .34587 .46526 .33702 Metetra
.601 .88 .992 r
.46526 .33702 .48233 .34587 .5123 .33559 .49554 .32655 Metetra
.601 .88 .992 r
.49554 .32655 .5123 .33559 .54261 .3252 .52617 .31597 Metetra
.601 .88 .992 r
.52617 .31597 .54261 .3252 .57325 .31469 .55714 .30526 Metetra
.601 .88 .992 r
.55714 .30526 .57325 .31469 .60423 .30406 .58846 .29443 Metetra
.601 .88 .992 r
.58846 .29443 .60423 .30406 .63557 .29331 .62014 .28348 Metetra
.601 .88 .992 r
.62014 .28348 .63557 .29331 .66725 .28244 .65218 .2724 Metetra
.601 .88 .992 r
.65218 .2724 .66725 .28244 .6993 .27145 .68459 .2612 Metetra
.601 .88 .992 r
.68459 .2612 .6993 .27145 .73171 .26033 .71737 .24987 Metetra
.601 .88 .992 r
.00095 .48363 .02258 .49006 .04813 .48123 .02671 .47466 Metetra
.601 .88 .992 r
.02671 .47466 .04813 .48123 .07394 .4723 .05273 .46559 Metetra
.601 .88 .992 r
.05273 .46559 .07394 .4723 .10001 .46329 .07903 .45642 Metetra
.601 .88 .992 r
.07903 .45642 .10001 .46329 .12636 .45418 .1056 .44716 Metetra
.601 .88 .992 r
.1056 .44716 .12636 .45418 .15298 .44498 .13245 .4378 Metetra
.601 .88 .992 r
.13245 .4378 .15298 .44498 .17988 .43568 .15959 .42835 Metetra
.601 .88 .992 r
.15959 .42835 .17988 .43568 .20706 .42628 .18702 .41879 Metetra
.601 .88 .992 r
.18702 .41879 .20706 .42628 .23453 .41679 .21474 .40913 Metetra
.601 .88 .992 r
.21474 .40913 .23453 .41679 .2623 .40719 .24276 .39936 Metetra
.601 .88 .992 r
.24276 .39936 .2623 .40719 .29036 .39749 .27109 .38949 Metetra
.601 .88 .992 r
.27109 .38949 .29036 .39749 .31873 .38768 .29973 .37951 Metetra
.601 .88 .992 r
.29973 .37951 .31873 .38768 .3474 .37777 .32868 .36942 Metetra
.601 .88 .992 r
.32868 .36942 .3474 .37777 .37638 .36775 .35795 .35922 Metetra
.601 .88 .992 r
.35795 .35922 .37638 .36775 .40568 .35762 .38754 .3489 Metetra
.601 .88 .992 r
.38754 .3489 .40568 .35762 .43531 .34738 .41747 .33848 Metetra
.601 .88 .992 r
.41747 .33848 .43531 .34738 .46526 .33702 .44773 .32793 Metetra
.601 .88 .992 r
.44773 .32793 .46526 .33702 .49554 .32655 .47833 .31727 Metetra
.601 .88 .992 r
.47833 .31727 .49554 .32655 .52617 .31597 .50928 .30648 Metetra
.601 .88 .992 r
.50928 .30648 .52617 .31597 .55714 .30526 .54058 .29557 Metetra
.601 .88 .992 r
.54058 .29557 .55714 .30526 .58846 .29443 .57225 .28454 Metetra
.601 .88 .992 r
.57225 .28454 .58846 .29443 .62014 .28348 .60427 .27337 Metetra
.601 .88 .992 r
.60427 .27337 .62014 .28348 .65218 .2724 .63667 .26208 Metetra
.601 .88 .992 r
.63667 .26208 .65218 .2724 .68459 .2612 .66945 .25066 Metetra
.601 .88 .992 r
.66945 .25066 .68459 .2612 .71737 .24987 .70262 .2391 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -87.9375 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.18558 .19702 m
.19014 .20174 L
s
gsave
.17646 .18758 -102.235 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.34306 .13535 m
.34735 .14032 L
s
gsave
.3345 .12542 -74.0356 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.51046 .06981 m
.51442 .07504 L
s
gsave
.50253 .05935 -86.4908 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -72.5762 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -73.2791 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
72.188 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfZDoook
JP?o001oZ_oonfX00?oooo]ZU?oonfX3o`00Oj[ooo]Z003ooookJYCooo]Z0ol007nZoookJP00oooo
nfZDoookJP?o001oZ_oonfX00?oooo]ZU?oonfX3o`00Oj[ooo]Z003ooookJYCooo]Z0ol007nZoook
JP00oooonfZDoookJP?o001oZ_oonfX00?oooo]ZU?oonfX3o`00Oj[ooo]Z003ooookJYCooo]Z0ol0
07nZoookJP00oooonfZAoookJPKo001oZ_oonfX00?oooo]ZTOoonfX6o`00Oa_ooo]Z2Ol007n6oook
JP00oooonfZCoookJPCo001o6ooonfX9o`00OhKooo]Z003ooookJYCooo]Z0ol007lKoookJPCo001o
RooonfX00?oooo]ZY_oonfX:o`00O`?ooo]Z1?l007n:oookJP00oooonfZVoookJP[o001o1?oonfX5
o`00OhSooo]Z003ooookJ[Kooo]Z1?l007n7oookJP00oooonfZgoookJP?o001oQooonfX00?oooo]Z
^?oonfX3o`00OhKooo]Z003ooookJY[ooo]Z1_l0000BoookJP?o001o0ooonfX3o`00OhKooo]Z003o
oookJYOooo]Z2Ol0000BoookJP?o001o0ooonfX3o`00OhKooo]Z003ooookJYGooo]Z3?l0000Aoook
JPCo001o0_oonfX3o`00OhKooo]Z003ooookJY;ooo]Z4?l0000AoookJPOo001oQooonfX00?oooo]Z
T?oonfXBo`0001;ooo]Z1Ol007n8oookJP00oooonfZ=oookJQKo0000W_oonfX00?oooo]ZR_oonfXA
o`000003oookJ_l0003o000000Ko0000WOoonfX00?oooo]ZR?oonfXAo`0000Cooo]Z1ol0002Moook
JP00oooonfZ5oookJQ7o00001ooonfX8o`0009cooo]Z003ooookJX?ooo]Z4Ol00009oookJPWo0000
VooonfX00?oooo]ZP?oonfXAo`0000cooo]Z00?o0000oookJ_l000001_l0002KoookJP00oooonfYn
oookJQ3o00003ooonfX00ol0003ooo]Zo`000007o`0009[ooo]Z003ooookJW_ooo]Z4Ol0000Boook
JP03o`000?oonf[o000000Oo0000VOoonfX00?oooo]ZNOoonfX@o`0001Gooo]Z00?o0000oookJ_oo
nfX01ol0002IoookJP00oooonfYfoookJQ7o00005ooonfX00ol0003ooo]ZoookJP08o`0009Sooo]Z
003ooookJW?ooo]Z4Ol0000JoookJP04o`000?oonf[ooo]ZoookJPOo0000V?oonfX00?oooo]ZLOoo
nfXAo`0001cooo]Z00?o0000oookJ_oonfX00_oonfX7o`0009Oooo]Z003ooookJVkooo]Z4Ol0000O
oookJP03o`000?oonf[ooo]Z00;ooo]Z2?l0002FoookJP00oooonfXZoookJPGo001o1?oonfX3o`00
O`?ooo]Z1Ol007l^oookJQ7o00008OoonfX00ol0003ooo]ZoookJP03oookJPOo0000U_oonfX00?oo
oo]Z:OoonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o:_oonfXAo`0002Cooo]Z00?o0000oookJ_oo
nfX00ooonfX8o`0009Gooo]Z003ooookJRWooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o00?ooo]Zo`00Ool007l00_l007l01?oonf[o001oo`00Ool007lXoookJQ3o00009ooonfX00ol0
003ooo]ZoookJP04oookJPSo0000U?oonfX00?oooo]Z:?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o
001o0ooonfX3o`00ObCooo]Z4Ol0000YoookJP03o`000?oonf[ooo]Z00Gooo]Z1ol0002DoookJP00
oooonfXXoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007lRoookJQ3o0000;?oonfX00ol0003ooo]Z
oookJP05oookJPSo0000TooonfX00?oooo]Z:?oonfX3o`00O`?ooo]Z0ol007l<oookJP?o001o7ooo
nfXAo`0002kooo]Z00?o0000oookJ_oonfX01_oonfX8o`0009;ooo]Z003ooookJRSooo]Z0ol007l3
oookJP?o001o1ooonfX2o`00O`;ooo]Z1?l007lMoookJQ3o0000<OoonfX00ol0003ooo]ZoookJP07
oookJPOo0000T_oonfX00?oooo]Z:?oonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o6ooonfXAo`00
03?ooo]Z00?o0000oookJ_oonfX01ooonfX8o`00097ooo]Z003<oookJP03oa`KO?l007oo:2Qk05So
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00OaWooo]Z4Ol0000foookJP03o`000?oonf[ooo]Z00So
oo]Z2?l0002@oookJP00c?oonfX2o`00O`03oa8AOOoonf[ooo]Z05Kooo]Z0ol007l3oookJP?o001o
1ooonfX2o`00Oa_ooo]Z4Ol0000hoookJP03o`000?oonf[ooo]Z00Wooo]Z1ol0002@oookJP00c?oo
nfX00ol417ko001oog1_M@1IoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00OaSooo]Z
4Ol0000koookJP03o`000?oonf[ooo]Z00Wooo]Z2?l0002?oookJP00c?oonfX00olL6gco001ooe]I
M`1IoookJPOo001o2OoonfX7o`00Oa3ooo]Z4Ol0000moookJP03o`000?oonf[ooo]Z00[ooo]Z2?l0
002>oookJP00c?oonfX00omKFGOo001ooa`KO01JoookJPGo001o2_oonfX7o`00O`gooo]Z4Ol00011
oookJP03o`000?oonf[ooo]Z00[ooo]Z1ol0002>oookJP00bOoonfX01?l92GkoFeUgoookJ_no_6h2
o`00Og_ooo]Z4?l00014oookJP03o`000?oonf[ooo]Z00[ooo]Z2?l0002=oookJP00bOoonfX00onS
X77o001oo`00O`06o`00O`03obPXNooonf[ooo]Z07;ooo]Z4Ol00016oookJP03o`000?oonf[ooo]Z
00_ooo]Z2?l0002<oookJP00b_oonfX00onSX77o2@Uno`00O`05o`00O`03o`41O_oonf[ooo]Z073o
oo]Z4?l00019oookJP03o`000?oonf[ooo]Z00cooo]Z1ol0002<oookJP00oooonfY3oookJQ7o0000
BooonfX00ol0003ooo]ZoookJP0<oookJPSo0000RooonfX00?oooo]Z@?oonfXAo`0004kooo]Z00?o
0000oookJ_oonfX03OoonfX8o`0008[ooo]Z003ooookJSkooo]Z4Ol0001@oookJP03o`000?oonf[o
oo]Z00kooo]Z1ol0002:oookJP00oooonfXkoookJQ7o0000DooonfX00ol0003ooo]ZoookJP0>oook
JPSo0000ROoonfX00?oooo]Z>OoonfXAo`0005Gooo]Z00?o0000oookJ_oonfX03ooonfX8o`0008So
oo]Z003ooookJSKooo]Z4Ol0001HoookJP03o`000?oonf[ooo]Z013ooo]Z1ol00028oookJP00oooo
nfXdoookJQ3o000000?ooo]Zo`000?oonfX0F?oonfX00ol0003ooo]ZoookJP0@oookJPSo0000Qooo
nfX00?oooo]Z<OoonfXAo`0005gooo]Z00?o0000oookJ_oonfX04OoonfX8o`0008Kooo]Z003ooook
JRoooo]Z4?l0001PoookJP03o`000?oonf[ooo]Z01;ooo]Z1ol00026oookJP00oooonfX/oookJQ7o
0000H_oonfX00ol0003ooo]ZoookJP0BoookJPSo00007?oonfX3o`00OfKooo]Z003ooookJR[ooo]Z
4?l0001UoookJP03o`000?oonf[ooo]Z01?ooo]Z1ol0000LoookJP?o001oI_oonfX00?oooo]Z9ooo
nfXAo`0006Oooo]Z00?o0000oookJ_oonfX05?oonfX7o`0001_ooo]Z0ol007mVoookJP00oooonfXT
oookJQ7o0000J_oonfX00ol0003ooo]ZoookJP0DoookJPSo00002_oonfX:o`00O`Kooo]Z0ol007mV
oookJP00oooonfXRoookJQ7o0000KOoonfX00ol0003ooo]ZoookJP0DoookJPOo00002_oonfX:o`00
O`Kooo]Z0ol007mVoookJP00oooonfXOoookJQ7o0000L?oonfX00ol0003ooo]ZoookJP0DoookJPSo
00006OoonfX3o`00OfKooo]Z003ooookJQgooo]Z4Ol0001boookJP03o`000?oonf[ooo]Z01Gooo]Z
2?l0000HoookJP?o001oI_oonfX00?oooo]Z6_oonfXAo`0007Gooo]Z00?o0000oookJ_oonfX05_oo
nfX7o`0001Sooo]Z0ol007mVoookJP00h?oonfX5o`00Oc;ooo]Z4?l0001hoookJP03o`000?oonf[o
oo]Z01Kooo]Z2?l0000GoookJP?o001oI_oonfX00=oooo]Z1ol007l^oookJQ7o0000N_oonfX00ol0
003ooo]ZoookJP0GoookJPSo00004ooonfX6o`00OfKooo]Z003OoookJP?o001o00Cooo]Zo`00Ool0
07oo001o;?oonfX@o`0007gooo]Z00?o0000oookJ_oonfX06?oonfX7o`0001?ooo]Z1_l007mVoook
JP00g_oonfX3o`00O`?ooo]Z0ol007lXoookJQ7o0000OooonfX00ol0003ooo]ZoookJP0HoookJPSo
00005?oonfX4o`00OfKooo]Z003NoookJP?o001o0ooonfX3o`00ObGooo]Z4Ol00022oookJP03o`00
0?oonf[ooo]Z01Wooo]Z2?l0000DoookJP?o001oI_oonfX00=kooo]Z0ol007l3oookJP?o001o8ooo
nfXAo`0008Cooo]Z00?o0000oookJ_oonfX06_oonfX7o`0007gooo]Z003NoookJP?o001o0ooonfX3
o`00Ob3ooo]Z4Ol00027oookJP03o`000?oonf[ooo]Z01[ooo]Z2?l0001loookJP00g_oonfX3o`00
O`?ooo]Z0ol007lNoookJQ7o0000ROoonfX00ol0003ooo]ZoookJP0KoookJPSo0000NooonfX00=ko
oo]Z0ol007l3oookJP?o001o6ooonfXAo`0008cooo]Z00?o0000oookJ_oonfX07?oonfX7o`0007_o
oo]Z003NoookJP?o001o0ooonfX3o`00OaWooo]Z4?l0002?oookJP03o`000?oonf[ooo]Z01cooo]Z
2?l0001joookJP00gooonfX3o`00O`04oookJ_l007oo001oo`00OaOooo]Z4Ol0002AoookJP03o`00
0?oonf[ooo]Z01gooo]Z2?l0001ioookJP00gooonfX7o`00OaGooo]Z4?l0002DoookJP03o`000?oo
nf[ooo]Z01kooo]Z1ol0001ioookJP00h?oonfX5o`00Oa?ooo]Z4Ol0002FoookJP03o`000?oonf[o
oo]Z01kooo]Z2?l0001hoookJP00mOoonfXAo`0009Wooo]Z00?o0000oookJ_oonfX07ooonfX8o`00
07Oooo]Z003coookJQ7o0000W?oonfX00ol0003ooo]ZoookJP0OoookJPOo0000MooonfX00?3ooo]Z
4Ol0002OoookJP03o`000?oonf[ooo]Z01oooo]Z2?l0001foookJP00k_oonfXAo`000:7ooo]Z00?o
0000oookJ_oonfX08?oonfX8o`0007Gooo]Z003[oookJQ7o0000Y?oonfX00ol0003ooo]ZoookJP0Q
oookJPOo0000MOoonfX00>Wooo]Z4?l0002WoookJP03o`000?oonf[ooo]Z027ooo]Z2?l0001doook
JP00i_oonfXAo`000:Wooo]Z00?o0000oookJ_oonfX08_oonfX7o`0007Cooo]Z003ToookJQ3o0000
[?oonfX00ol0003ooo]ZoookJP0SoookJPOo0000LooonfX00>7ooo]Z4Ol0002^oookJP03o`000?oo
nf[ooo]Z02?ooo]Z2?l0001boookJP00gooonfX@o`000003oookJ_l0003ooo]Z0:kooo]Z00?o0000
oookJ_oonfX09?oonfX7o`0007;ooo]Z003LoookJQ7o0000/ooonfX00ol0003ooo]ZoookJP0Toook
JPSo0000LOoonfX00=Wooo]Z4Ol0002foookJP03o`000?oonf[ooo]Z02Gooo]Z2?l0001`oookJP00
eooonfXAo`000;Sooo]Z00?o0000oookJ_oonfX09_oonfX7o`00073ooo]Z003DoookJQ7o0000^ooo
nfX00ol0003ooo]ZoookJP0VoookJPSo0000KooonfX00=;ooo]Z4Ol0002moookJP03o`000?oonf[o
oo]Z02Oooo]Z2?l0001^oookJP00cooonfXAo`000<3ooo]Z00?o0000oookJ_oonfX0:?oonfX7o`00
06kooo]Z003=oookJQ3o0000`ooonfX00ol0003ooo]ZoookJP0XoookJPSo0000KOoonfX00<[ooo]Z
4Ol00035oookJP03o`000?oonf[ooo]Z02Wooo]Z2?l0001/oookJP00b?oonfX@o`000<Sooo]Z00?o
0000oookJ_oonfX0:_oonfX7o`0006cooo]Z0021oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l`
oookJQ7o0000booonfX00ol0003ooo]ZoookJP0YoookJPSo0000JooonfX0083ooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00Obcooo]Z4Ol0003>oookJP03o`000?oonf[ooo]Z02[ooo]Z2?l0001Zoook
JP00P?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00
O`04oookJ_l007oo001oo`00Ob[ooo]Z4Ol0003@oookJP03o`000?oonf[ooo]Z02_ooo]Z1ol0001Z
oookJP00LooonfX:o`00O`;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lVoook
JQ7o0000dooonfX00ol0003ooo]ZoookJP0[oookJPSo0000JOoonfX007?ooo]Z2_l007l2oookJP?o
001o0ooonfX3o`00O`cooo]Z0ol007lToookJQ7o0000eOoonfX00ol0003ooo]ZoookJP0/oookJPSo
0000J?oonfX007oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00Ob7ooo]Z4Ol0003HoookJP03o`00
0?oonf[ooo]Z02gooo]Z1ol0001XoookJP00OooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oo
nfX4o`00Oaoooo]Z4?l0003KoookJP03o`000?oonf[ooo]Z02gooo]Z2?l0001WoookJP00OooonfX3
o`00O`?ooo]Z0ol007l7oookJPOo001o7OoonfXAo`000=gooo]Z00?o0000oookJ_oonfX0;_oonfX8
o`0006Kooo]Z001ooookJP?o001o0ooonfX3o`00O`Oooo]Z1_l007lLoookJQ3o0000h?oonfX00ol0
003ooo]ZoookJP0_oookJPOo00003OoonfX5o`00OeCooo]Z001ooookJP?o001o0ooonfX3o`00O`Oo
oo]Z0_l007lMoookJQ7o0000h_oonfX00ol0003ooo]ZoookJP0_oookJPSo00002ooonfX7o`00Oe?o
oo]Z0020oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX2o`00Oa_ooo]Z4?l0003UoookJP03
o`000?oonf[ooo]Z033ooo]Z2?l0000:oookJP?o001o00Cooo]Zo`00Ool007oo001oDooonfX0083o
oo]Z1ol007l9oookJPOo001o4_oonfXAo`000>Oooo]Z00?o0000oookJ_oonfX0<OoonfX7o`0000Wo
oo]Z0ol007l3oookJP?o001oD_oonfX0087ooo]Z1Ol007l:oookJPOo001o3ooonfXAo`000>[ooo]Z
00?o0000oookJ_oonfX0<OoonfX8o`0000Sooo]Z0ol007l3oookJP?o001oD_oonfX00:Cooo]Z4Ol0
003/oookJP03o`000?oonf[ooo]Z03;ooo]Z1ol00008oookJP?o001o0ooonfX3o`00Oe;ooo]Z002Q
oookJQ7o0000kooonfX00ol0003ooo]ZoookJP0coookJPOo00001ooonfX3o`00O`?ooo]Z0ol007mB
oookJP00WooonfXAo`000?7ooo]Z00?o0000oookJ_oonfX0<ooonfX8o`0000Kooo]Z0ol007l3oook
JP?o001oD_oonfX009cooo]Z4Ol0003doookJP03o`000?oonf[ooo]Z03Cooo]Z1ol00006oookJP?o
001o0ooonfX3o`00Oe;ooo]Z002JoookJQ3o0000n?oonfX00ol0003ooo]ZoookJP0coookJPSo0000
1OoonfX3o`00O`?ooo]Z0ol007mBoookJP00UooonfXAo`000?[ooo]Z00?o0000oookJ_oonfX0=?oo
nfX8o`0000Gooo]Z0ol007l01?oonf[o001oo`00Ool007mCoookJP00UOoonfX@o`000?gooo]Z00?o
0000oookJ_oonfX0=OoonfX7o`0000Gooo]Z1ol007lXoookJP03oiRFL_m4@WWo001o00;o001o00?o
A49ioiRFL_oonfX08ooonfX009;ooo]Z4Ol0003ooookJP03o`000?oonf[ooo]Z03Gooo]Z2?l00005
oookJPGo001o9ooonfX02oo^jV_o<S9jo`00OomEDgOogMU/oookJ_o<b6ko8B5lo`00Oolb<W[ok^Y[
02;ooo]Z002?oookJQ;o0000oooonfX2oookJP03o`000?oonf[ooo]Z03Kooo]Z2?l0000`oookJP03
oc8bN_l007oo411m00Cooo]Z00Cok^Y[oa0@OOl007oo<S9j8_oonfX008gooo]Z4Ol0003ooookJPGo
oo]Z00?o0000oookJ_oonfX0=ooonfX7o`0002oooo]Z00CoV9Ibo`00Ool007ooV9Ib1OoonfX01?n7
QG?o001oo`00OonHUW8QoookJP00R_oonfXAo`000?oooo]Z2?oonfX00ol0003ooo]ZoookJP0goook
JPSo0000;_oonfX01?m4@WWo001oo`00Ooo<b6h5oookJP04olc8K_l007oo001oodA2NB7ooo]Z0028
oookJQ7o0000oooonfX:oookJP03o`000?oonf[ooo]Z03Sooo]Z2?l0000]oookJP?o001o00Oooo]Z
o`00OooMfFcooo]ZomgIK?l007oooo]Z00?o001o8OoonfX008Gooo]Z4Ol0003ooookJPgooo]Z00?o
0000oookJ_oonfX0>OoonfX7o`0002gooo]Z0ol007l00ooonf[o001oo`00O`03o`00O`04oookJ_l0
07oo001oo`00Ob7ooo]Z0023oookJQ3o0000oooonfX@oookJP03o`000?oonf[ooo]Z03Wooo]Z2?l0
000/oookJP?o001o00?ooo]Zo`00Ool007l00ol007l01?oonf[o001oo`00Ool007lQoookJP00P?oo
nfXAo`000?oooo]Z4_oonfX00ol0003ooo]ZoookJP0joookJPSo0000:ooonfX02_m4@WWo001oo`00
OooMfFco001oolc8K_oonf[oc<Q^o`00Ooo<b6h2o`00O`03odA2NOoonf[ooo]Z01oooo]Z001noook
JQ3o0000oooonfXEoookJP03o`000?oonf[ooo]Z03_ooo]Z1ol0000[oookJP04oiRFL_l007oo001o
oiRFLPGooo]Z00CoQhEco`00Ool007oo^[Q_8OoonfX007_ooo]Z4Ol0003ooookJQOooo]Z00?o0000
oookJ_oonfX0>ooonfX8o`0002_ooo]Z00Co<S9jo`00Ool@47gok^Y[1?oonfX00ol@47go001oodA2
N@0RoookJP00A_oonfX3o`00Oc3ooo]Z4?l0003ooookJQ[ooo]Z00?o0000oookJ_oonfX0??oonfX8
o`0002[ooo]Z00_ok^Y[oc8bN_l007oo<S9jolc8K_oonf[ogMU/odA2NOl007oo<S9jonkZJ`0Roook
JP00A_oonfX3o`00Obgooo]Z4Ol0003ooookJQcooo]Z00?o0000oookJ_oonfX0?OoonfX7o`0002co
oo]Z00?oV9IbodA2NOl007l00_l007l00olb<W[oV9IboookJP0SoookJP00A_oonfX3o`00Ob[ooo]Z
4Ol0003ooookJQoooo]Z00?o0000oookJ_oonfX0?OoonfX8o`0005Kooo]Z000foookJP[o001o1_oo
nfX3o`00ObSooo]Z4Ol0003ooookJR7ooo]Z00?o0000oookJ_oonfX0?_oonfX8o`0005Gooo]Z000f
oookJP[o001o1_oonfX3o`00ObGooo]Z4Ol0003ooookJRCooo]Z00?o0000oookJ_oonfX0?ooonfX7
o`0005Gooo]Z0016oookJP?o001o8ooonfXAo`000?oooo]Z9ooonfX00ol0003ooo]ZoookJP0noook
JPSo0000E?oonfX004Kooo]Z0ol007lPoookJQ7o0000oooonfXZoookJP03o`000?oonf[ooo]Z03oo
oo]Z2?l0001CoookJP00A_oonfX3o`00Oakooo]Z4?l0003ooookJRgooo]Z00?o0000oookJ_oonfX0
@?oonfX7o`0005?ooo]Z0016oookJP?o001o6ooonfXAo`000?oooo]Z;ooonfX00ol0003ooo]Zoook
JP10oookJPSo0000D_oonfX004?ooo]Z1_l007lIoookJQ3o0000oooonfXboookJP03o`000?oonf[o
oo]Z047ooo]Z2?l0001AoookJP00@ooonfX6o`00OaKooo]Z4Ol0003ooookJS?ooo]Z0ol00013oook
JPOo0000DOoonfX004Gooo]Z1?l007lCoookJQ7o0000oooonfXcoookJP?o000000CoVN7mo`000?nI
hOgo0000@_oonfX8o`00053ooo]Z0016oookJP?o001o4OoonfXAo`000?oooo]Z<_oonfX3o`0000Co
VN7m00?o0000oiWQoOnIhOd00_l00011oookJPOo0000D?oonfX005Oooo]Z4Ol0003ooookJS;ooo]Z
0ol00006oiWQo@;o00001?nIhOd2o`00043ooo]Z1ol0001?oookJP00EOoonfXAo`000?oooo]Z<Ooo
nfX3o`0000KoVN7m0ol000000onIhOgo0000oiWQo@05oiWQo@03o`000?oonf[ooo]Z03gooo]Z2?l0
001>oookJP00D_oonfXAo`000?oooo]Z<OoonfX3o`0000KoVN7m0ol00005oiWQo@03o`000?nIhOgo
VN7m00?oVN7m0ol0000noookJPOo0000C_oonfX0057ooo]Z3ol0003ooookJS;ooo]Z0ol00005oiWQ
o@?o00002OnIhOd00ol0003oVN7mo`000002o`0000?oVN7m00?o0000oookJ_oonfX0>ooonfX8o`00
04gooo]Z001AoookJPgo0000oooonfXaoookJP?o00000onIhOd00ol0003oVN7mo`000002o`0000_o
VN7m0ol00007oiWQo@03o`000?oonf[ooo]Z03_ooo]Z2?l0001<oookJP00DOoonfX:o`000?oooo]Z
<OoonfX3o`0000GoVN7m1?l0000:oiWQo@?o00000_nIhOd00ol0003oVN7moiWQo@06oiWQo@03o`00
0?oonf[ooo]Z03_ooo]Z1ol0001<oookJP00DOoonfX8o`000?oooo]Z<OoonfX2o`0000GoVN7m0ol0
0004oiWQo@;o00001OnIhOd3o`0000KoVN7m00?o0000oiWQoOnIhOd01_nIhOd00ol0003ooo]Zoook
JP0joookJPSo0000BooonfX0053ooo]Z1ol0003ooookJS3ooo]Z0ol00005oiWQo@;o00002OnIhOd0
0ol0003oVN7mo`000002o`0000[oVN7m00?o0000oiWQoOnIhOd01_nIhOd00ol0003ooo]ZoookJP0j
oookJPSo0000B_oonfX0053ooo]Z1_l000000ooonf[o0000oookJP3ooookJR_ooo]Z0ol00005oiWQ
o@?o00002onIhOd3o`0000coVN7m00?o0000oiWQoOnIhOd01OnIhOd4o`0003_ooo]Z1ol0000?oook
JP?o001o>?oonfX0053ooo]Z1_l00002oookJP03o`000?oonf[ooo]Z0?oooo]Z9_oonfX4o`0000Co
VN7m0ol0000;oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0:oiWQo@04o`000?nIhOgoVN7moiWQ
o@?o00001?nIhOd00ol0003ooo]ZoookJP0hoookJPSo00003_oonfX3o`00OcSooo]Z0010oookJPWo
001o1ooonfX6o`0000?ooo]Z00?o0000oookJ_oonfX0oooonfXRoookJP?o00001?nIhOd4o`0000_o
VN7m0ol00007oiWQo@;o00002onIhOd3o`0000SoVN7m0_l0000ioookJPSo00003OoonfX3o`00OcSo
oo]Z0010oookJPWo001o1ooonfX5o`0000Gooo]Z00?o0000oookJ_oonfX0oooonfXMoookJPCo0000
1OnIhOd5o`0000[oVN7m0_l0000<oiWQo@;o00001_nIhOd3o`000003oiWQoOl0003oVN7m00[oVN7m
00?o0000oookJ_oonfX0=ooonfX7o`0000gooo]Z0ol007lhoookJP00@?oonfX4o`00O`cooo]Z1Ol0
0006oookJP03o`000?oonf[ooo]Z0?oooo]Z6OoonfX3o`0000KoVN7m0ol00005oiWQo@;o00001OnI
hOd3o`00013oVN7m00?o0000oiWQoOnIhOd00ol00004oiWQo@03o`000?nIhOgoVN7m00[oVN7m00?o
0000oookJ_oonfX0=_oonfX8o`0000cooo]Z0ol007lhoookJP00=?oonfX:o`00O`?ooo]Z1?l007l:
oookJPKo00001ooonfX00ol0003ooo]ZoookJP3ooookJQGooo]Z0ol00006oiWQo@?o00002_nIhOd0
0ol0003oVN7mo`000002o`0001?oVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00SoVN7m1?l0000g
oookJPSo00002ooonfX3o`00OcSooo]Z000doookJP[o001o1?oonfX5o`00O`Sooo]Z1_l00008oook
JP03o`000?oonf[ooo]Z0?oooo]Z4OoonfX3o`0000KoVN7m0ol0000<oiWQo@Co00004_nIhOd3o`00
00?oVN7m00?o0000oiWQoOnIhOd01_nIhOd00ol0003oVN7moiWQo@04oiWQo@?o00001?nIhOd00ol0
003ooo]ZoookJP0eoookJPOo00002ooonfX3o`00OcSooo]Z0014oookJPCo001o1ooonfX6o`0000Wo
oo]Z00?o0000oookJ_oonfX0oooonfX=oookJP?o00000onIhOd01?l0003oVN7moiWQoOnIhOd2o`00
00coVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00coVN7m0ol00007oiWQo@;o00001onIhOd00ol0
003oVN7moiWQo@03o`0000SoVN7m0_l0000eoookJPSo00002_oonfX3o`00OcSooo]Z0015oookJP?o
001o1ooonfX6o`0000[ooo]Z00?o0000oookJ_oonfX0oooonfX9oookJP?o00001onIhOd3o`0000[o
VN7m1?l00008oiWQo@;o00002OnIhOd3o`0000coVN7m00?o0000oiWQoOnIhOd01?nIhOd3o`0000go
VN7m00?o0000oookJ_oonfX0<ooonfX8o`0000Wooo]Z0ol007lhoookJP00A_oonfX3o`00O`Kooo]Z
1Ol0000<oookJP03o`000?oonf[ooo]Z0?oooo]Z1_oonfX2o`0000OoVN7m0ol00002oiWQo@;o0000
1_nIhOd3o`0000koVN7m00?o0000oiWQoOnIhOd00onIhOd3o`00013oVN7m00?o0000oiWQoOnIhOd0
0ol000000onIhOgo0000oiWQo@0>oiWQo@03o`000?oonf[ooo]Z03?ooo]Z1ol00006oookJPKo001o
>?oonfX0043ooo]Z0ol007l3oookJP?o001o1_oonfX5o`0000gooo]Z00?o0000oookJ_oonfX0oooo
nfX2oookJP?o00001_nIhOd3o`0000OoVN7m00?o0000oiWQoOnIhOd00ol0000BoiWQo@03o`000?nI
hOgo000000;o00004onIhOd3o`0000GoVN7m00?o0000oiWQoOnIhOd02onIhOd4o`0003?ooo]Z2?l0
0005oookJPKo001o>?oonfX0043ooo]Z0ol007l3oookJP?o001o1_oonfX5o`0000kooo]Z0_l0003n
oookJP?o00001_nIhOd3o`0000[oVN7m0ol0000DoiWQo@Co00004_nIhOd3o`0000?oVN7m00?o0000
oiWQoOnIhOd00_nIhOd00ol0003oVN7moiWQo@08oiWQo@?o00001?nIhOd00ol0003ooo]ZoookJP0a
oookJPSo00001_oonfX4o`00OcSooo]Z0010oookJPCo001o0_oonfX3o`00O`Gooo]Z1_l0000@oook
JP03o`000?oonf[ooo]Z0?Wooo]Z0ol00005oiWQo@?o00002_nIhOd3o`0000?oVN7m00?o0000oiWQ
oOnIhOd03_nIhOd3o`0000CoVN7m00?o0000oiWQoOnIhOd03?nIhOd3o`0000OoVN7m0_l00003oiWQ
o@03o`000?nIhOgoVN7m00CoVN7m0ol00008oiWQo@;o0000<_oonfX7o`0000Oooo]Z0ol007lhoook
JP00@OoonfX7o`00O`Kooo]Z1_l0000AoookJP03o`000?oonf[ooo]Z0?Gooo]Z0ol00003oiWQo@03
o`000?nIhOgo000000;o00002_nIhOd3o`0000OoVN7m0_l0000;oiWQo@?o00002?nIhOd2o`0000[o
VN7m0_l0000<oiWQo@05o`000?nIhOgoVN7moiWQoOl000000_nIhOd3o`0000goVN7m00?o0000oook
J_oonfX0;ooonfX8o`00047ooo]Z0012oookJPGo001o1ooonfX6o`0001;ooo]Z00?o0000oookJ_oo
nfX0lOoonfX3o`0000KoVN7m0ol0000:oiWQo@;o00003?nIhOd2o`0000KoVN7m0ol0000=oiWQo@;o
00001OnIhOd3o`0000ooVN7m00?o0000oiWQoOnIhOd00ol0000AoiWQo@03o`000?oonf[ooo]Z02oo
oo]Z2?l00010oookJP00C_oonfX6o`0001?ooo]Z00?o0000oookJ_oonfX0k_oonfX2o`0000KoVN7m
0ol00003oiWQo@;o00001OnIhOd3o`00013oVN7m00?o0000oiWQoOnIhOd00ol0000BoiWQo@03o`00
0?nIhOgo000000;o00004_nIhOd3o`000003oiWQoOl0003oVN7m013oVN7m1?l0000`oookJPOo0000
@?oonfX004kooo]Z1Ol0000EoookJP03o`000?oonf[ooo]Z0>[ooo]Z0ol00005oiWQo@?o00002?nI
hOd00ol0003oVN7mo`000002o`0001?oVN7m0ol0000DoiWQo@Co00004OnIhOd3o`0000?oVN7m00?o
0000oiWQoOl000003OnIhOd3o`0000CoVN7m00?o0000oookJ_oonfX0;OoonfX8o`0003oooo]Z001>
oookJPGo00005_oonfX00ol0003ooo]ZoookJP3VoookJP?o00001OnIhOd3o`0000_oVN7m0ol0000B
oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0>oiWQo@?o00001?nIhOd00ol0003oVN7moiWQo@0;
oiWQo@?o00001onIhOd3o`0000WoVN7m0ol00008oiWQo@;o0000;_oonfX7o`0003oooo]Z001=oook
JPKo00005ooonfX00ol0003ooo]ZoookJP3RoookJPCo00001?nIhOd3o`0000_oVN7m0ol00003oiWQ
o@03o`000?nIhOgoVN7m00coVN7m0ol00007oiWQo@;o00002onIhOd3o`0000SoVN7m0_l00009oiWQ
o@;o00003?nIhOd2o`0000GoVN7m0ol0000=oiWQo@03o`000?oonf[ooo]Z02cooo]Z1ol0000noook
JP00COoonfX6o`0001Sooo]Z00?o0000oookJ_oonfX0g_oonfX3o`0000CoVN7m1?l0000;oiWQo@?o
00001onIhOd2o`0000[oVN7m0_l0000<oiWQo@;o00001_nIhOd3o`0000goVN7m00?o0000oiWQoOnI
hOd00onIhOd3o`0000ooVN7m00?o0000oiWQoOnIhOd00ol0000@oiWQo@?o0000;?oonfX8o`0003go
oo]Z001=oookJPKo00006OoonfX00ol0003ooo]ZoookJP3JoookJP?o00001OnIhOd3o`000004oiWQ
oOl0003o0000o`0000OoVN7m0ol0000<oiWQo@;o00001OnIhOd3o`00013oVN7m00?o0000oiWQoOnI
hOd00ol0000AoiWQo@03o`000?nIhOgo000000;o00004OnIhOd4o`00013oVN7m0ol00003oiWQo@03
o`000?oonf[ooo]Z02[ooo]Z1ol0000moookJP00COoonfX6o`0001[ooo]Z00?o0000oookJ_oonfX0
e_oonfX3o`0000KoVN7m0_l00007oiWQo@;o00000_nIhOd3o`00017oVN7m00?o0000oiWQoOl00000
0_l0000CoiWQo@?o00004onIhOd4o`00013oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000OoVN7m
00?o0000oookJ_oonfX0:OoonfX8o`0003cooo]Z001=oookJPGo00007?oonfX00ol0003ooo]Zoook
JP3BoookJP?o00001_nIhOd3o`0000[oVN7m0ol0000DoiWQo@?o00004_nIhOd3o`0000?oVN7m00?o
0000oiWQoOnIhOd03OnIhOd3o`0000CoVN7m0_l0000;oiWQo@?o00001onIhOd2o`0000WoVN7m0_l0
000;oiWQo@03o`000?oonf[ooo]Z02Wooo]Z2?l0000koookJP00COoonfX5o`0001gooo]Z00?o0000
oookJ_oonfX0c_oonfX3o`0000KoVN7m0ol0000:oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0>
oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0<oiWQo@?o00001onIhOd2o`0000[oVN7m0ol00009
oiWQo@03o`000?nIhOgoVN7m00GoVN7m0ol0000:oiWQo@03o`000?nIhOgo000000GoVN7m0ol0000>
oiWQo@03o`000?oonf[ooo]Z02Wooo]Z1ol0000koookJP00C?oonfX6o`0001kooo]Z00?o0000oook
J_oonfX0b_oonfX3o`0000?oVN7m0_l000001?nIhOgo0000o`000?l0000:oiWQo@?o00001onIhOd2
o`0000_oVN7m0ol00007oiWQo@;o00002_nIhOd2o`0000coVN7m00?o0000oiWQoOnIhOd01?nIhOd3
o`0000goVN7m0_l00002oiWQo@?o00003_nIhOd01?l0003oVN7mo`000?nIhOd3o`00017oVN7m0ol0
000YoookJPSo0000>_oonfX004cooo]Z1_l0000OoookJP03o`000?oonf[ooo]Z0<Oooo]Z0_l00006
oiWQo@Co00002_nIhOd2o`0000coVN7m0_l00006oiWQo@?o00003?nIhOd2o`0000GoVN7m0ol0000?
oiWQo@03o`000?nIhOgoVN7m00?o00004OnIhOd3o`0001;oVN7m1?l0000@oiWQo@?o00000onIhOd0
0ol0003ooo]ZoookJP0WoookJPSo0000>OoonfX004cooo]Z1_l0000PoookJP;o0000a?oonfX3o`00
00GoVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00CoVN7m0ol0000@oiWQo@03o`000?nIhOgoVN7m
00?o00004OnIhOd00ol0003oVN7mo`000002o`0001;oVN7m0ol0000AoiWQo@?o00000onIhOd00ol0
003oVN7moiWQo@0=oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00007oiWQo@;o0000:?oonfX7o`00
03Wooo]Z001<oookJPKo00008_oonfX00ol0003ooo]ZoookJP2ooookJP;o00001OnIhOd3o`0000So
VN7m0_l000001?nIhOgo0000o`000?l0000CoiWQo@?o00005?nIhOd3o`00017oVN7m0ol00003oiWQ
o@03o`000?nIhOgoVN7m00_oVN7m0ol00007oiWQo@;o00002_nIhOd3o`0000?oVN7m00?o0000oiWQ
oOnIhOd00_nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nIhOd00ol0003ooo]ZoookJP0Uoook
JPSo0000>?oonfX004cooo]Z1Ol0000ToookJP03o`000?oonf[ooo]Z0;_ooo]Z0ol00005oiWQo@;o
00002onIhOd4o`0001;oVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00koVN7m0ol00003oiWQo@;o
00003?nIhOd3o`0000OoVN7m0_l00009oiWQo@;o00003?nIhOd00ol0003oVN7moiWQo@04oiWQo@?o
00001onIhOd00ol0003oVN7moiWQo@02oiWQo@;o00000_nIhOd3o`00013oVN7m00?o0000oookJ_oo
nfX09OoonfX8o`0003Oooo]Z001<oookJPGo00009OoonfX00ol0003ooo]ZoookJP2goookJPCo0000
1?nIhOd3o`0000[oVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00coVN7m0ol00007oiWQo@;o0000
2onIhOd3o`0000SoVN7m0_l00007oiWQo@?o00003?nIhOd00ol0003oVN7moiWQo@03oiWQo@?o0000
3onIhOd00ol0003oVN7moiWQo@03o`0000_oVN7m00?o0000oiWQoOnIhOd00_nIhOd3o`0001;oVN7m
1?l0000VoookJPOo0000=ooonfX004_ooo]Z1_l0000VoookJP03o`000?oonf[ooo]Z0;?ooo]Z0ol0
0004oiWQo@Co00002_nIhOd3o`0000SoVN7m0_l0000:oiWQo@;o00003?nIhOd2o`0000KoVN7m0ol0
000=oiWQo@;o00000_nIhOd3o`00013oVN7m00?o0000oiWQoOl000000_l0000AoiWQo@Co00003_nI
hOd00ol0003oVN7mo`000002o`0000?oVN7m00?o0000oiWQoOnIhOd03?nIhOd3o`0000CoVN7m00?o
0000oookJ_oonfX08ooonfX8o`0003Kooo]Z001;oookJPKo00009ooonfX00ol0003ooo]ZoookJP2_
oookJP?o00001OnIhOd3o`000003oiWQoOl0003o000000OoVN7m0ol0000=oiWQo@;o00001OnIhOd3
o`00013oVN7m00?o0000oiWQoOnIhOd00ol0000@oiWQo@Co00004onIhOd3o`00013oVN7m0ol00004
oiWQo@;o00002onIhOd3o`0000OoVN7m00?o0000oiWQoOnIhOd02?nIhOd3o`0000SoVN7m0_l0000T
oookJPSo0000=OoonfX004_ooo]Z1_l0000XoookJP03o`000?oonf[ooo]Z0:_ooo]Z0ol00005oiWQ
o@?o00001_nIhOd2o`0000;oVN7m0ol0000BoiWQo@03o`000?nIhOgo000000;o00004_nIhOd4o`00
013oVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00goVN7m0ol00003oiWQo@;o00002onIhOd3o`00
00WoVN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd01OnIhOd00ol0
003oVN7moiWQo@04oiWQo@?o00003OnIhOd00ol0003ooo]ZoookJP0RoookJPOo0000=OoonfX004_o
oo]Z1_l0000YoookJP03o`000?oonf[ooo]Z0:Oooo]Z0ol00005oiWQo@?o00002_nIhOd3o`0001Go
VN7m0ol0000AoiWQo@?o00001?nIhOd2o`0000_oVN7m0ol00008oiWQo@;o00002_nIhOd3o`0000So
VN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000goVN7m0_l00002oiWQo@?o00001onIhOd00ol0003o
VN7moiWQo@05oiWQo@03o`000?nIhOgoVN7m00?o00003onIhOd4o`0002;ooo]Z2?l0000doookJP00
BooonfX5o`0002_ooo]Z00?o0000oookJ_oonfX0XooonfX3o`0000GoVN7m0ol0000:oiWQo@?o0000
0onIhOd2o`00013oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd0
1OnIhOd3o`0000goVN7m00?o0000oiWQoOnIhOd01?nIhOd3o`0000coVN7m0_l00002oiWQo@?o0000
4?nIhOd4o`0000[oVN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000ooVN7m0ol00004oiWQo@03o`00
0?oonf[ooo]Z023ooo]Z2?l0000coookJP00BooonfX5o`0002cooo]Z00?o0000oookJ_oonfX0Wooo
nfX3o`0000?oVN7m1Ol0000;oiWQo@;o00002?nIhOd2o`0000_oVN7m0ol00008oiWQo@;o00001onI
hOd3o`0000goVN7m0_l00002oiWQo@?o00004OnIhOd00ol0003oVN7moiWQo@03o`00013oVN7m0ol0
000@oiWQo@?o00001?nIhOd00ol0003oVN7moiWQo@08oiWQo@04o`000?nIhOgoVN7moiWQo@?o0000
0onIhOd00ol0003oVN7moiWQo@09oiWQo@?o00002?nIhOd00ol0003ooo]ZoookJP0PoookJPOo0000
<ooonfX004_ooo]Z1Ol0000]oookJP03o`000?oonf[ooo]Z09_ooo]Z0ol00006oiWQo@Co00002OnI
hOd3o`0000coVN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000goVN7m0_l00002oiWQo@?o00004OnI
hOd3o`0001CoVN7m0ol0000@oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00008oiWQo@03o`000?nI
hOgoVN7m00SoVN7m0ol00007oiWQo@;o00001_nIhOd3o`0000coVN7m00?o0000oookJ_oonfX07ooo
nfX8o`0003;ooo]Z001:oookJPKo0000;_oonfX00ol0003ooo]ZoookJP2GoookJP?o00001_nIhOd3
o`0000CoVN7m00?o0000oiWQoOnIhOd01?nIhOd2o`00013oVN7m0_l00002oiWQo@?o00004OnIhOd3
o`00017oVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00koVN7m0ol00003oiWQo@;o00002onIhOd3
o`0000SoVN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000coVN7m00?o0000oiWQoOnIhOd01?nIhOd4
o`0000_oVN7m00?o0000oiWQoOnIhOd00ol0000?oiWQo@?o00008?oonfX8o`00037ooo]Z001:oook
JPKo0000;ooonfX00ol0003ooo]ZoookJP2CoookJP?o00001_nIhOd3o`0000SoVN7m0_l000001?nI
hOgo0000o`000?l0000CoiWQo@?o00004OnIhOd3o`0000?oVN7m0_l0000<oiWQo@?o00001onIhOd2
o`0000_oVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00GoVN7m0ol0000<oiWQo@;o00000_nIhOd3
o`00013oVN7m00?o0000oiWQoOnIhOd00ol00004oiWQo@03o`000?nIhOgoVN7m00SoVN7m0ol0000?
oiWQo@?o00000onIhOd00ol0003ooo]ZoookJP0NoookJPOo0000<OoonfX004[ooo]Z1_l0000`oook
JP03o`000?oonf[ooo]Z08oooo]Z0ol00006oiWQo@?o00003?nIhOd3o`0001;oVN7m0ol00003oiWQ
o@;o00003?nIhOd3o`0000SoVN7m0_l00007oiWQo@?o00003?nIhOd2o`0000KoVN7m0ol0000<oiWQ
o@;o00000_nIhOd3o`00013oVN7m0ol0000CoiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@04oiWQ
o@?o00000onIhOd00ol0003oVN7moiWQo@09oiWQo@?o00001onIhOd2o`0001kooo]Z2?l0000`oook
JP00B_oonfX6o`00037ooo]Z0_l0002<oookJP?o00000onIhOd2o`000004oiWQoOl0003o0000o`00
00coVN7m0ol00003oiWQo@;o00003OnIhOd3o`0000SoVN7m0_l00007oiWQo@?o00003OnIhOd2o`00
00;oVN7m0ol0000AoiWQo@03o`000?nIhOgoVN7m00?o00004?nIhOd3o`00013oVN7m0ol00003oiWQ
o@03o`000?nIhOgoVN7m00goVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00KoVN7m00?o0000oiWQ
oOnIhOd00ol00007oiWQo@;o00001_nIhOd3o`0000coVN7m00?o0000oookJ_oonfX07?oonfX8o`00
00[ooo]Z2Ol007lLoookJP00B_oonfX5o`0003Cooo]Z00?o0000oookJ_oonfX0QooonfX2o`0000Ko
VN7m1?l0000;oiWQo@?o00002?nIhOd3o`0000OoVN7m0ol0000=oiWQo@;o00000_nIhOd3o`00017o
VN7m0ol0000DoiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000;oiWQo@?o00001onIhOd2o`0000[o
VN7m0ol00007oiWQo@;o00001_nIhOd3o`0000coVN7m00?o0000oiWQoOnIhOd00ol0000?oiWQo@?o
00007OoonfX7o`0000[ooo]Z2Ol007lLoookJP00B_oonfX5o`0003Gooo]Z00?o0000oookJ_oonfX0
PooonfX3o`0000GoVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00GoVN7m0ol0000>oiWQo@;o0000
0_nIhOd3o`00017oVN7m0ol0000AoiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0>oiWQo@?o0000
0onIhOd2o`0000_oVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00GoVN7m0ol0000<oiWQo@03o`00
0?nIhOgoVN7m00CoVN7m0ol0000<oiWQo@03o`000?nIhOgoVN7m00?o000000?oVN7mo`000?nIhOd0
3?nIhOd3o`0000ooVN7m0ol00003oiWQo@03o`000?oonf[ooo]Z01[ooo]Z2?l00009oookJPCo001o
8OoonfX004Wooo]Z1_l0000foookJP03o`000?oonf[ooo]Z083ooo]Z0_l00006oiWQo@;o00002?nI
hOd2o`0000;oVN7m0ol0000BoiWQo@?o00004OnIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd03?nI
hOd2o`0000OoVN7m0_l0000;oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nI
hOd2o`0000;oVN7m0ol0000@oiWQo@03o`000?nIhOgoVN7m00?o00003onIhOd3o`0000GoVN7m00?o
0000oiWQoOnIhOd01onIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd02OnIhOd3o`0000OoVN7m00?o
0000oookJ_oonfX06_oonfX7o`0000[ooo]Z1?l007lPoookJP00BOoonfX6o`0003Oooo]Z00?o0000
oookJ_oonfX0O?oonfX3o`0000GoVN7m0ol0000;oiWQo@?o00004_nIhOd3o`0000?oVN7m0_l0000<
oiWQo@?o00001onIhOd2o`0000WoVN7m0ol0000;oiWQo@;o00001_nIhOd3o`0000coVN7m0_l00002
oiWQo@?o00004?nIhOd3o`0001;oVN7m1?l0000?oiWQo@?o00000onIhOd2o`0000CoVN7m00?o0000
oiWQoOnIhOd00onIhOd3o`0000OoVN7m0_l00006oiWQo@?o00002onIhOd00ol0003ooo]ZoookJP0J
oookJPOo00002_oonfX5o`00Oakooo]Z000koookJPGo001o2OoonfX6o`0003Sooo]Z00?o0000oook
J_oonfX0NOoonfX3o`0000CoVN7m0ol0000;oiWQo@?o00000onIhOd2o`0000goVN7m0ol00008oiWQ
o@;o00001onIhOd3o`0000coVN7m0_l00005oiWQo@;o00004?nIhOd00ol0003oVN7moiWQo@03o`00
013oVN7m0ol0000@oiWQo@?o00000onIhOd2o`0000coVN7m1?l00004oiWQo@03o`000?nIhOgoVN7m
00WoVN7m0ol00008oiWQo@05o`000?nIhOgoVN7moiWQoOl000000_nIhOd3o`0000coVN7m00?o0000
oiWQoOnIhOd00ol0000?oiWQo@03o`000?oonf[ooo]Z01Wooo]Z2?l0000;oookJPCo001o7OoonfX0
03[ooo]Z1ol007l8oookJPKo0000>OoonfX00ol0003ooo]ZoookJP1eoookJP?o00000onIhOd4o`00
00_oVN7m0ol00008oiWQo@?o00001onIhOd3o`0000goVN7m0_l00002oiWQo@?o00004OnIhOd00ol0
003oVN7mo`000002o`0001;oVN7m0ol0000@oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00008oiWQ
o@03o`000?nIhOgoVN7m00KoVN7m0ol00009oiWQo@;o00001_nIhOd3o`0000coVN7m0_l000001?nI
hOgo0000o`000?l0000?oiWQo@?o00004OnIhOd4o`0001[ooo]Z1ol0000<oookJP?o001o7OoonfX0
03[ooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPGo0000>ooonfX00ol0003ooo]ZoookJP1a
oookJP?o00001?nIhOd3o`000004oiWQoOl0003o0000o`0000OoVN7m0ol0000>oiWQo@;o00000_nI
hOd3o`00017oVN7m0ol0000DoiWQo@?o00004OnIhOd3o`0000?oVN7m0_l0000;oiWQo@?o00002?nI
hOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nIhOd2o`0000;oVN7m1?l0000>oiWQo@03o`000?nI
hOgoVN7m00?o00004?nIhOd3o`000003oiWQoOl0003oVN7m00_oVN7m0ol00003oiWQo@03o`000?nI
hOgoVN7m00[oVN7m1?l00004oiWQo@03o`000?oonf[ooo]Z01Oooo]Z2?l0000<oookJP?o001o7?oo
nfX003Wooo]Z0ol007l3oookJP?o001o1ooonfX5o`0003cooo]Z00?o0000oookJ_oonfX0KOoonfX3
o`0000CoVN7m0ol00007oiWQo@;o00000_nIhOd3o`0001;oVN7m0ol0000AoiWQo@?o00000onIhOd0
0ol0003oVN7moiWQo@0>oiWQo@?o00000onIhOd2o`0000coVN7m0ol00008oiWQo@03o`000?nIhOgo
VN7m00GoVN7m0ol0000<oiWQo@;o00000_nIhOd3o`00013oVN7m0ol0000BoiWQo@?o00004?nIhOd3
o`0000?oVN7m0_l00009oiWQo@?o00001onIhOd2o`0000OoVN7m0ol00009oiWQo@03o`000?oonf[o
oo]Z01Oooo]Z2?l00005oookJP?o001o0ooonfX3o`00Oacooo]Z000ioookJP?o001o0ooonfX3o`00
O`Kooo]Z1_l0000moookJP03o`000?oonf[ooo]Z06Wooo]Z0ol00004oiWQo@?o00002onIhOd3o`00
01;oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000OoVN7m0_l0000;oiWQo@?o00002?nIhOd2o`00
00OoVN7m0ol0000<oiWQo@;o00000_nIhOd3o`00013oVN7m0ol0000@oiWQo@?o00000onIhOd00ol0
003oVN7moiWQo@0<oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00007oiWQo@;o00001OnIhOd3o`00
00coVN7m00?o0000oiWQoOnIhOd01?l0000=oiWQo@03o`000?oonf[ooo]Z01Oooo]Z1ol00005oook
JP?o001o0ooonfX3o`00Oacooo]Z000ioookJP?o001o0ooonfX3o`00O`Kooo]Z1_l0000noookJP03
o`000?oonf[ooo]Z06Gooo]Z0ol00005oiWQo@;o00002onIhOd3o`0000?oVN7m0_l0000=oiWQo@?o
00002?nIhOd2o`0000OoVN7m0ol0000<oiWQo@;o00001_nIhOd3o`0000goVN7m0_l00002oiWQo@?o
00004?nIhOd3o`00013oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000OoVN7m0_l00009oiWQo@?o
00002?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nIhOd00ol0003oVN7mo`000002o`0000oo
VN7m0ol0000@oiWQo@Co00005ooonfX8o`0000Cooo]Z1?l007l2oookJP?o001o7?oonfX003Wooo]Z
0ol007l3oookJP?o001o1_oonfX6o`0003oooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000?oVN7m
1Ol0000:oiWQo@?o00002?nIhOd3o`0000OoVN7m0ol0000=oiWQo@;o00000_nIhOd3o`00017oVN7m
00?o0000oiWQoOnIhOd00ol0000AoiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000;oiWQo@?o0000
2?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nIhOd00ol0003oVN7moiWQo@03oiWQo@?o0000
3?nIhOd2o`0000;oVN7m0ol0000?oiWQo@?o00003_nIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd0
2_nIhOd3o`0000CoVN7m0_l0000FoookJPSo00001?oonfX7o`00Oagooo]Z000ioookJP?o001o0ooo
nfX3o`00O`Kooo]Z1_l00010oookJP03o`000?oonf[ooo]Z05gooo]Z0ol00005oiWQo@Ko00001onI
hOd3o`0000koVN7m0_l00002oiWQo@?o00004OnIhOd3o`0001CoVN7m0ol0000AoiWQo@?o00000onI
hOd2o`0000_oVN7m0ol00008oiWQo@;o00001_nIhOd3o`0000coVN7m0_l00002oiWQo@?o00004?nI
hOd00ol0003oVN7mo`000002o`0000ooVN7m1?l0000?oiWQo@?o000000CoVN7mo`000?nIhOgo0000
2_nIhOd3o`0000OoVN7m0_l00006oiWQo@Co00002OnIhOd2o`0001Gooo]Z1ol00005oookJPGo001o
7_oonfX003Wooo]Z0ol007l3oookJP?o001o1_oonfX5o`0004;ooo]Z00?o0000oookJ_oonfX0FOoo
nfX3o`0000GoVN7m0ol00006oiWQo@;o00000_nIhOd3o`0001;oVN7m0ol0000AoiWQo@?o00000onI
hOd2o`0000ooVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000SoVN7m0_l00006oiWQo@?o00003OnI
hOd2o`000004oiWQoOl0003o0000o`00013oVN7m0ol0000BoiWQo@Co00003OnIhOd4o`0000CoVN7m
00?o0000oiWQoOnIhOd02OnIhOd3o`0000GoVN7m00?o0000oiWQoOl000001_nIhOd3o`0000coVN7m
00?o0000oiWQoOnIhOd00ol0000>oiWQo@?o00004ooonfX8o`0002Oooo]Z000ioookJP?o001o0ooo
nfX3o`00O`Kooo]Z1Ol00013oookJP03o`000?oonf[ooo]Z05Gooo]Z0ol00005oiWQo@?o00002_nI
hOd3o`0001;oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000SoVN7m0_l0000:oiWQo@?o00002?nI
hOd2o`0000OoVN7m0ol0000=oiWQo@;o000000CoVN7mo`000?l0003o00004OnIhOd3o`0000ooVN7m
0ol00003oiWQo@;o00003?nIhOd4o`0000CoVN7m0_l00008oiWQo@?o00002OnIhOd2o`0000KoVN7m
0ol00009oiWQo@03o`000?nIhOgo000000;oVN7m0ol0000?oiWQo@?o00003_nIhOd3o`0000?oVN7m
00?o0000oookJ_oonfX04OoonfX8o`0002Kooo]Z000joookJP?o001o00Cooo]Zo`00Ool007oo001o
1_oonfX6o`0004Cooo]Z0_l0001BoookJP?o00001OnIhOd3o`0000[oVN7m0ol00003oiWQo@;o0000
3OnIhOd3o`0000SoVN7m0ol00006oiWQo@?o00003OnIhOd00ol0003oVN7moiWQo@04oiWQo@?o0000
3OnIhOd2o`0000;oVN7m0ol0000AoiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000:oiWQo@?o0000
2?nIhOd00ol0003oVN7moiWQo@06oiWQo@?o00002_nIhOd2o`0000;oVN7m1?l0000>oiWQo@03o`00
0?nIhOgoVN7m00?o00003OnIhOd4o`0000ooVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00SoVN7m
0ol00007oiWQo@03o`000?oonf[ooo]Z017ooo]Z1ol0000VoookJP002ooonfX3o`00O`04oookJ_l0
07oo001oo`00O`Cooo]Z00?oEE=go`00OomVI7H08OoonfX7o`00O`Kooo]Z1_l00016oookJP03o`00
0?oonf[ooo]Z04cooo]Z0ol00003oiWQo@Go00002_nIhOd3o`0000SoVN7m0ol00007oiWQo@?o0000
3_nIhOd2o`000004oiWQoOl0003o0000o`00017oVN7m0_l000001?nIhOgo0000o`000?l0000AoiWQ
o@?o00004OnIhOd3o`0000?oVN7m0_l0000;oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@04oiWQ
o@?o00003?nIhOd2o`0000;oVN7m1?l0000>oiWQo@?o00004OnIhOd4o`0000koVN7m0ol00003oiWQ
o@03o`000?nIhOgoVN7m00WoVN7m0ol00007oiWQo@03o`000?nIhOgoVN7m00CoVN7m0ol0000;oiWQ
o@03o`000?oonf[ooo]Z013ooo]Z2?l0000UoookJP002_oonfX8o`00O`Cooo]Z0_l007l00om4@WWo
oo]ZoookJP0PoookJPGo001o1ooonfX6o`0004Oooo]Z00?o0000oookJ_oonfX0B?oonfX3o`0000Go
VN7m0ol000000onIhOgo0000o`000007oiWQo@?o00003_nIhOd2o`0000;oVN7m0ol0000BoiWQo@?o
00004onIhOd4o`00013oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000SoVN7m00?o0000oiWQoOnI
hOd01OnIhOd3o`0000coVN7m0_l000001?nIhOgo0000o`000?l0000@oiWQo@?o00003onIhOd3o`00
00?oVN7m0_l0000<oiWQo@?o00001?nIhOd00ol0003oVN7moiWQo@08oiWQo@?o00000onIhOd01?l0
003oVN7moiWQoOnIhOd2o`0000KoVN7m0ol0000;oiWQo@03o`000?nIhOgoVN7m00?o00003_nIhOd3
o`00017ooo]Z2?l0000ToookJP002OoonfX4o`00O`03oookJ_l007oo001o00;o001o1?oonfX00olQ
8Gco001oojVWL@0^oookJPKo0000B?oonfX00ol0003ooo]ZoookJP14oookJP?o00001_nIhOd2o`00
00KoVN7m0ol000001?nIhOgo0000o`000?l0000BoiWQo@?o00004_nIhOd3o`0000?oVN7m0_l0000=
oiWQo@Co00001?nIhOd2o`0000_oVN7m0ol00008oiWQo@;o00001onIhOd3o`0000coVN7m0_l00002
oiWQo@?o00004?nIhOd3o`0000ooVN7m0ol00003oiWQo@;o00002_nIhOd3o`0000SoVN7m00?o0000
oiWQoOnIhOd01OnIhOd4o`0000SoVN7m0_l00005oiWQo@?o00001onIhOd00ol0003oVN7moiWQo@02
oiWQo@03o`000?nIhOgoVN7m00?o00003OnIhOd4o`0000koVN7m0ol00003oiWQo@03o`000?oonf[o
oo]Z00oooo]Z1ol0000ToookJP002OoonfX3o`00O`?ooo]Z0ol007l4oookJP03oeECMol007ooV9Ib
02kooo]Z1Ol0001:oookJP03o`000?oonf[ooo]Z043ooo]Z0ol00006oiWQo@?o00002_nIhOd3o`00
017oVN7m0ol00003oiWQo@;o00003OnIhOd3o`0000SoVN7m0_l00008oiWQo@?o00002_nIhOd2o`00
00KoVN7m0ol0000=oiWQo@;o00000_nIhOd3o`00013oVN7m0ol0000@oiWQo@?o00000onIhOd2o`00
00[oVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00CoVN7m0ol0000<oiWQo@;o00000_nIhOd3o`00
00koVN7m00?o0000oiWQoOl000000_l0000;oiWQo@03o`000?nIhOgoVN7m00Co00003OnIhOd3o`00
00CoVN7m00?o0000oiWQoOnIhOd02?nIhOd3o`0000OoVN7m00?o0000oookJ_oonfX03_oonfX8o`00
02?ooo]Z0009oookJP?o001o0ooonfX3o`00O`Cooo]Z00?oV9Ibo`00OomEDgL0;_oonfX5o`0004_o
oo]Z00?o0000oookJ_oonfX0??oonfX3o`0000KoVN7m0ol0000:oiWQo@?o00000onIhOd2o`0000co
VN7m0ol00008oiWQo@?o00001onIhOd3o`0000goVN7m0_l00002oiWQo@Co00003onIhOd2o`000004
oiWQoOl0003o0000o`00017oVN7m0ol0000@oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00008oiWQ
o@03o`000?nIhOgoVN7m00CoVN7m0ol0000<oiWQo@;o000000CoVN7mo`000?l0003o00004?nIhOd3
o`00013oVN7m1?l0000=oiWQo@?o00001?nIhOd2o`0000OoVN7m1?l00008oiWQo@03o`000?nIhOgo
VN7m00CoVN7m0ol0000;oiWQo@03o`000?oonf[ooo]Z00kooo]Z2?l0000RoookJP002OoonfX3o`00
O`?ooo]Z0ol007l01Ooonf[o<S9joiRFL_oonf[ogMU/00;o001o;_oonfX5o`0004cooo]Z00?o0000
oookJ_oonfX0>?oonfX3o`0000?oVN7m1_l0000:oiWQo@?o00002?nIhOd3o`0000KoVN7m0ol0000>
oiWQo@;o00000_nIhOd3o`00017oVN7m0ol0000CoiWQo@Co00004?nIhOd3o`0000?oVN7m0_l0000;
oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00003?nIhOd2o`000004oiWQoOl0003o
0000o`00013oVN7m0ol0000?oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@0:oiWQo@?o00001?nI
hOd2o`0000OoVN7m1?l000000onIhOgo0000oiWQo@06oiWQo@;o00000_nIhOd3o`0000goVN7m00?o
0000oiWQoOnIhOd00ol0000=oiWQo@Co00003ooonfX7o`0002;ooo]Z0009oookJP?o001o0ooonfX3
o`00O`03oookJ_o<b6ko001o00Oo001o00?oIVAfoookJ_oonfX09ooonfX6o`0004gooo]Z00?o0000
oookJ_oonfX0=?oonfX3o`0000KoVN7m1Ol00008oiWQo@?o00003_nIhOd2o`000004oiWQoOl0003o
0000o`0001;oVN7m0ol0000AoiWQo@?o00000onIhOd2o`0000goVN7m1?l00004oiWQo@;o00002onI
hOd3o`0000SoVN7m0_l00006oiWQo@?o00003?nIhOd2o`0000;oVN7m0ol0000@oiWQo@?o00003onI
hOd3o`0000?oVN7m00?o0000oiWQoOnIhOd02OnIhOd3o`0000OoVN7m0_l00006oiWQo@Co00002OnI
hOd2o`0000;oVN7m0ol00006oiWQo@03o`000?nIhOgoVN7m00GoVN7m0ol0000?oiWQo@Co00003OnI
hOd3o`0000CoVN7m00?o0000oookJ_oonfX03?oonfX8o`00027ooo]Z0009oookJPCo001o00?ooo]Z
o`00Ool007l00_l007l2oookJP03olc8K_lb<W[o001o00Go001o00?o411moookJ_oonfX09ooonfX6
o`0004kooo]Z00?o0000oookJ_oonfX0<?oonfX3o`0000KoVN7m0ol00005oiWQo@?o00000_nIhOd3
o`0001;oVN7m0ol0000AoiWQo@?o00000onIhOd2o`0000coVN7m0ol00008oiWQo@;o00002?nIhOd3
o`0000[oVN7m0_l00006oiWQo@?o00003OnIhOd2o`000004oiWQoOl0003o0000o`00013oVN7m0ol0
000@oiWQo@?o00000onIhOd2o`0000[oVN7m0ol00007oiWQo@;o00001_nIhOd3o`0000coVN7m00?o
0000oiWQoOnIhOd00ol0000>oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@02oiWQo@?o00000onI
hOd00ol0003oVN7moiWQo@09oiWQo@?o00001?nIhOd2o`0000OoVN7m1?l00008oiWQo@03o`000?oo
nf[ooo]Z00cooo]Z2?l0000PoookJP002_oonfX8o`00OcCooo]Z1_l0001?oookJP03o`000?oonf[o
oo]Z02cooo]Z0ol00006oiWQo@?o00002_nIhOd3o`0001;oVN7m0ol00003oiWQo@;o00003?nIhOd3
o`0000SoVN7m0ol00006oiWQo@?o00003OnIhOd2o`0000;oVN7m1?l0000?oiWQo@;o000000CoVN7m
o`000?l0003o00004?nIhOd4o`0000ooVN7m0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m00?o
0000oiWQoOnIhOd01?nIhOd3o`0000coVN7m00?o0000oiWQoOnIhOd00ol0000?oiWQo@?o00003_nI
hOd3o`0000?oVN7m00?o0000oiWQoOnIhOd01onIhOd4o`0000OoVN7m00?o0000oiWQoOnIhOd01?nI
hOd4o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd00ol0003ooo]ZoookJP0<oookJPOo00008?oo
nfX000_ooo]Z0ol007l01?oonf[o001oo`00Ool007ldoookJPKo0000D?oonfX00ol0003ooo]Zoook
JP0YoookJP?o00001_nIhOd2o`0000[oVN7m0ol00003oiWQo@;o00003OnIhOd3o`0000SoVN7m0ol0
0006oiWQo@?o00003_nIhOd2o`000004oiWQoOl0003o0000o`00017oVN7m0ol0000CoiWQo@Co0000
3_nIhOd4o`0000CoVN7m0_l0000:oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o0000
3?nIhOd2o`000004oiWQoOl0003o0000o`0000ooVN7m0ol0000?oiWQo@?o00000onIhOd00ol0003o
VN7moiWQo@08oiWQo@?o00001onIhOd2o`0000GoVN7m1?l0000:oiWQo@03o`000?nIhOgoVN7m00?o
00003_nIhOd3o`0000ooVN7m1?l0000<oookJPSo00007ooonfX000oooo]Z0ol007ldoookJPGo0000
D_oonfX00ol0003ooo]ZoookJP0UoookJP?o00000onIhOd6o`0000WoVN7m0ol00008oiWQo@?o0000
1onIhOd3o`0000koVN7m0_l000001?nIhOgo0000o`000?l0000BoiWQo@?o00004?nIhOd3o`0000?o
VN7m0_l0000=oiWQo@Co00001?nIhOd3o`0000SoVN7m0ol0000:oiWQo@03o`000?nIhOgoVN7m00Co
VN7m0ol0000<oiWQo@;o00000_nIhOd3o`0000ooVN7m1?l0000>oiWQo@?o00000onIhOd2o`0000[o
VN7m0ol00007oiWQo@;o00001OnIhOd3o`0000coVN7m00?o0000oiWQoOl000000_l00004oiWQo@03
o`000?nIhOgoVN7m00OoVN7m0ol0000>oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@09oiWQo@?o
00001?nIhOd2o`0000_ooo]Z2?l0000NoookJP003ooonfX3o`00OcCooo]Z1Ol0001CoookJP03o`00
0?oonf[ooo]Z027ooo]Z0ol00006oiWQo@Go00001onIhOd3o`0000koVN7m0_l00002oiWQo@?o0000
4_nIhOd3o`00017oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m0_l00008oiWQo@?o0000
2onIhOd2o`0000;oVN7m1?l0000>oiWQo@;o000000CoVN7mo`000?l0003o00003onIhOd4o`0000ko
VN7m1?l00004oiWQo@03o`000?nIhOgoVN7m00SoVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00Co
VN7m0ol0000<oiWQo@03o`000?nIhOgo000000;o00003_nIhOd4o`0000KoVN7m00?o0000oiWQoOnI
hOd01?nIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd02?nIhOd3o`0000OoVN7m00?o0000oiWQoOnI
hOd01?nIhOd4o`0000WoVN7m00?o0000oookJ_oonfX02OoonfX7o`0001kooo]Z000?oookJP?o001o
<ooonfX6o`0005Cooo]Z00?o0000oookJ_oonfX07OoonfX3o`0000KoVN7m0ol00005oiWQo@?o0000
00CoVN7mo`000?l0003o00004_nIhOd3o`0001;oVN7m0ol00003oiWQo@;o00003?nIhOd3o`0000So
VN7m0_l00006oiWQo@?o00003OnIhOd2o`0000;oVN7m1?l0000?oiWQo@?o00004_nIhOd4o`0000ko
VN7m0ol00004oiWQo@?o00002?nIhOd3o`0000WoVN7m0_l00005oiWQo@?o00003?nIhOd2o`000004
oiWQoOl0003o0000o`0000koVN7m1?l0000=oiWQo@?o00001?nIhOd00ol0003oVN7moiWQo@04oiWQ
o@03o`000?nIhOgoVN7m00?o00001onIhOd2o`0000GoVN7m0ol0000;oiWQo@03o`000?nIhOgoVN7m
00?o00003?nIhOd3o`0000[ooo]Z2?l0000MoookJP00AOoonfX6o`0005Gooo]Z0_l0000JoookJP?o
00001_nIhOd3o`0000[oVN7m0ol0000AoiWQo@?o00000onIhOd3o`0000coVN7m0ol00008oiWQo@;o
00001onIhOd3o`0000goVN7m0_l000001?nIhOgo0000o`000?l0000AoiWQo@?o00004?nIhOd3o`00
00?oVN7m0_l0000=oiWQo@?o00001?nIhOd3o`0000OoVN7m1?l0000:oiWQo@;o00000_nIhOd4o`00
00koVN7m00?o0000oiWQoOl000000_l0000?oiWQo@Co00003OnIhOd3o`0000CoVN7m0_l00007oiWQ
o@Co00002?nIhOd00ol0003oVN7moiWQo@03oiWQo@?o00003?nIhOd00ol0003oVN7mo`000002o`00
00goVN7m1?l0000<oiWQo@?o00000onIhOd00ol0003ooo]ZoookJP08oookJPSo00007?oonfX004Go
oo]Z1_l0001GoookJP03o`000?oonf[ooo]Z01Gooo]Z0ol00005oiWQo@?o00002_nIhOd3o`0000?o
VN7m0_l0000<oiWQo@?o00002OnIhOd2o`0000OoVN7m0ol0000=oiWQo@;o00000_nIhOd3o`00017o
VN7m0ol0000@oiWQo@?o00000onIhOd2o`0000_oVN7m0ol00008oiWQo@;o00001onIhOd4o`0000[o
VN7m0_l00002oiWQo@?o00003onIhOd3o`00017oVN7m1?l0000>oiWQo@?o00001?nIhOd2o`0000Oo
VN7m1?l00009oiWQo@;o00000_nIhOd3o`0000goVN7m00?o0000oiWQoOl000000_l00002oiWQo@03
o`000?nIhOgoVN7m00WoVN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000KoVN7m1?l00007oiWQo@03
o`000?oonf[ooo]Z00Sooo]Z1ol0000LoookJP00AOoonfX6o`0005Sooo]Z00?o0000oookJ_oonfX0
4OoonfX3o`0000?oVN7m1Ol0000:oiWQo@?o00002?nIhOd3o`0000KoVN7m0ol0000>oiWQo@?o0000
00CoVN7mo`000?l0003o00004OnIhOd3o`00017oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000So
VN7m0_l00006oiWQo@?o00003OnIhOd2o`0000;oVN7m0ol0000?oiWQo@?o00003onIhOd3o`0000?o
VN7m0_l0000<oiWQo@?o00001?nIhOd3o`0000OoVN7m1?l00009oiWQo@;o00000_nIhOd3o`0000ko
VN7m0ol0000?oiWQo@Co00001?nIhOd00ol0003oVN7moiWQo@06oiWQo@?o00001?nIhOd2o`0000Ko
VN7m1?l00009oiWQo@03o`000?nIhOgoVN7m00?o00003?nIhOd00ol0003ooo]ZoookJP07oookJPSo
00006ooonfX004Gooo]Z1Ol0001JoookJP03o`000?oonf[ooo]Z00gooo]Z0ol00006oiWQo@Go0000
1onIhOd3o`0000koVN7m0_l000001?nIhOgo0000o`000?l0000CoiWQo@?o00004?nIhOd3o`0000?o
VN7m0_l0000<oiWQo@?o00002?nIhOd2o`0000KoVN7m0ol0000=oiWQo@;o000000CoVN7mo`000?l0
003o00004OnIhOd3o`0000ooVN7m0ol00003oiWQo@;o00002_nIhOd3o`0000SoVN7m00?o0000oiWQ
oOnIhOd01OnIhOd4o`0000[oVN7m0_l00002oiWQo@?o00003_nIhOd3o`0000koVN7m0ol00003oiWQ
o@03o`000?nIhOgoVN7m00WoVN7m0ol00004oiWQo@;o00000onIhOd01?l0003oVN7moiWQoOnIhOd4
o`0000WoVN7m00?o0000oiWQoOnIhOd00ol0000=oiWQo@?o00003_nIhOd4o`0000Sooo]Z1ol0000K
oookJP00AOoonfX5o`0005_ooo]Z00?o0000oookJ_oonfX02OoonfX3o`0000KoVN7m0ol00005oiWQ
o@;o00000_nIhOd3o`0001;oVN7m0ol0000BoiWQo@?o00000onIhOd2o`0000_oVN7m0ol00008oiWQ
o@?o00001_nIhOd3o`0000goVN7m0_l000001?nIhOgo0000o`000?l0000AoiWQo@?o00004?nIhOd3
o`0000?oVN7m0_l0000:oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@04oiWQo@?o00003?nIhOd2
o`0000;oVN7m0ol0000?oiWQo@?o00003_nIhOd3o`0000?oVN7m00?o0000oiWQoOnIhOd02?nIhOd3
o`0000OoVN7m00?o0000oiWQoOnIhOd01?nIhOd4o`0000WoVN7m0_l00002oiWQo@?o00003?nIhOd4
o`0000goVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00SoVN7m0ol00004oiWQo@;o00001ooonfX7
o`0001[ooo]Z0014oookJPKo0000G?oonfX00ol0003ooo]ZoookJP05oookJP?o00001_nIhOd3o`00
00WoVN7m0ol0000BoiWQo@?o00000onIhOd2o`0000goVN7m0ol00008oiWQo@;o00001_nIhOd3o`00
00koVN7m0_l000001?nIhOgo0000o`000?l0000AoiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000;
oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@04oiWQo@?o00003?nIhOd2o`000004oiWQoOl0003o
0000o`0000ooVN7m1?l0000?oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@08oiWQo@?o00001onI
hOd2o`0000GoVN7m0ol0000;oiWQo@03o`000?nIhOgoVN7m00?o00003OnIhOd5o`0000_oVN7m0ol0
0004oiWQo@03o`000?nIhOgoVN7m00OoVN7m0ol00007oiWQo@03o`000?nIhOgoVN7m00CoVN7m0ol0
0009oiWQo@03o`000?oonf[ooo]Z00Cooo]Z2?l0000IoookJP00A?oonfX6o`0005gooo]Z00Co0000
oookJ_oonf[ooo]Z0ol00006oiWQo@?o00002OnIhOd3o`0000?oVN7m0ol0000<oiWQo@?o00002?nI
hOd3o`0000OoVN7m0ol0000=oiWQo@;o000000CoVN7mo`000?l0003o00004_nIhOd3o`00013oVN7m
0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m0_l00006oiWQo@?o00003?nIhOd2o`000004oiWQ
oOl0003o0000o`0000ooVN7m1?l0000>oiWQo@?o00001?nIhOd2o`0000[oVN7m0ol00007oiWQo@;o
00001OnIhOd3o`0000coVN7m00?o0000oiWQoOl000000_l0000=oiWQo@Co00003OnIhOd3o`0000Co
VN7m0_l00006oiWQo@Co00002?nIhOd00ol0003oVN7moiWQo@03oiWQo@?o00002onIhOd00ol0003o
VN7moiWQo@03o`0000_oVN7m1?l00005oookJPOo00006OoonfX004Cooo]Z1_l0001NoookJP?o0000
0onIhOd6o`0000WoVN7m0ol00009oiWQo@;o00001onIhOd3o`0000koVN7m0_l00002oiWQo@?o0000
4OnIhOd3o`00017oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m0_l00006oiWQo@?o0000
3OnIhOd2o`000004oiWQoOl0003o0000o`0000ooVN7m1?l0000>oiWQo@?o00001?nIhOd3o`0000Oo
VN7m1?l00009oiWQo@03o`000?nIhOgoVN7m00CoVN7m0ol0000<oiWQo@03o`000?nIhOgo000000;o
00003_nIhOd4o`0000coVN7m0ol00004oiWQo@;o00001onIhOd4o`0000WoVN7m00?o0000oiWQoOnI
hOd00ol0000=oiWQo@03o`000?nIhOgo000000;o00003OnIhOd4o`0000_oVN7m0ol00004oiWQo@03
o`000?oonf[ooo]Z00;ooo]Z2?l0000<oookJPGo001o1ooonfX000Cooo]Z7Ol007lSoookJPKo0000
FooonfX3o`0000KoVN7m1Ol00007oiWQo@?o00003_nIhOd3o`000004oiWQoOl0003o0000o`0001;o
VN7m0ol0000AoiWQo@?o00000onIhOd2o`0000coVN7m0ol00008oiWQo@;o00001_nIhOd3o`0000go
VN7m0_l000001?nIhOgo0000o`000?l0000@oiWQo@Co00003_nIhOd3o`0000CoVN7m0ol00008oiWQ
o@?o00002_nIhOd2o`0000;oVN7m0ol0000>oiWQo@;o000000CoVN7mo`000?l0003o00003_nIhOd4
o`0000goVN7m0ol00004oiWQo@;o00001onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd3
o`0000ooVN7m1?l0000<oiWQo@?o00001?nIhOd00ol0003oVN7moiWQo@04oiWQo@Co00002?nIhOd0
0ol0003ooo]ZoookJP02oookJPSo00002_oonfX7o`00O`Kooo]Z0014oookJPGo0000FOoonfX3o`00
00KoVN7m0ol00005oiWQo@?o000000CoVN7mo`000?l0003o00004onIhOd3o`00017oVN7m0ol00003
oiWQo@;o00003?nIhOd3o`0000SoVN7m0ol00006oiWQo@?o00003OnIhOd2o`000004oiWQoOl0003o
0000o`00013oVN7m1?l0000?oiWQo@?o00001?nIhOd3o`0000OoVN7m1?l0000:oiWQo@?o00000_nI
hOd3o`0000koVN7m0ol0000AoiWQo@Co00003OnIhOd3o`0000CoVN7m0_l00007oiWQo@Co00002OnI
hOd2o`0000;oVN7m0ol0000=oiWQo@?o00003OnIhOd3o`000004oiWQoOl0003oVN7mo`0000_oVN7m
0ol00004oiWQo@;o00001_nIhOd4o`0000SoVN7m00?o0000oiWQoOnIhOd00ol0000;oiWQo@Co0000
0ooonfX7o`0000Wooo]Z0ol007l3oookJP?o001o1OoonfX004Cooo]Z1Ol0001FoookJP?o00001_nI
hOd3o`0000[oVN7m0ol0000BoiWQo@?o00000onIhOd2o`0000coVN7m0ol00008oiWQo@?o00001_nI
hOd3o`0000koVN7m0_l000001?nIhOgo0000o`000?l0000@oiWQo@Co00003onIhOd3o`0000CoVN7m
0ol00008oiWQo@Co00002_nIhOd2o`0000;oVN7m0ol0000@oiWQo@?o00003_nIhOd3o`0000?oVN7m
0_l0000<oiWQo@?o00001?nIhOd2o`0000OoVN7m1?l00009oiWQo@;o00000_nIhOd3o`0000koVN7m
0ol0000=oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@07oiWQo@?o00001OnIhOd00ol0003oVN7m
o`000006oiWQo@Co00002OnIhOd00ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000;oiWQo@?o0000
1?nIhOd2o`000003oookJ_l0003o000000Ko00002?oonfX3o`00O`?ooo]Z0ol007l5oookJP00A?oo
nfX5o`0005Cooo]Z0ol00006oiWQo@;o00002_nIhOd3o`0000?oVN7m0ol0000<oiWQo@?o00002?nI
hOd3o`0000KoVN7m0ol0000>oiWQo@;o000000CoVN7mo`000?l0003o00004OnIhOd5o`0000koVN7m
0ol00004oiWQo@?o00002?nIhOd4o`0000[oVN7m0ol00002oiWQo@?o00003onIhOd3o`00013oVN7m
0ol00003oiWQo@;o00002OnIhOd3o`0000SoVN7m00?o0000oiWQoOnIhOd01OnIhOd4o`0000WoVN7m
0_l00002oiWQo@?o00003OnIhOd4o`0000koVN7m0ol00003oiWQo@03o`000?nIhOgoVN7m00OoVN7m
0ol00007oiWQo@;o00001OnIhOd2o`0000WoVN7m00?o0000oiWQoOl000000_nIhOd3o`0000coVN7m
1?l0000;oiWQo@?o00001?nIhOd2o`0000KoVN7m0ol00009oiWQo@03o`000?oonf[o000000Oo0000
3OoonfX3o`00O`Gooo]Z0013oookJPKo0000DOoonfX3o`0000?oVN7m1_l00009oiWQo@?o00002OnI
hOd2o`0000OoVN7m0ol0000>oiWQo@;o000000CoVN7mo`000?l0003o00004OnIhOd5o`0000ooVN7m
0ol00005oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00004?nIhOd3o`0000ooVN7m
0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m00?o0000oiWQoOnIhOd01?nIhOd2o`0000coVN7m
0_l00002oiWQo@?o00003OnIhOd4o`0000goVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00SoVN7m
0ol00007oiWQo@03o`000?nIhOgoVN7m00?oVN7m0ol0000<oiWQo@03o`000?nIhOgo000000;o0000
3?nIhOd4o`0000coVN7m0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd0
0ol0000;oiWQo@?o000000?ooo]Zo`000?l000001Ol0000=oookJP?o001o1OoonfX004?ooo]Z1_l0
001>oookJP?o00001_nIhOd6o`0000OoVN7m0_l0000>oiWQo@?o000000CoVN7mo`000?l0003o0000
4OnIhOd5o`0000ooVN7m0ol00005oiWQo@?o00002?nIhOd4o`0000_oVN7m0ol00002oiWQo@?o0000
3onIhOd3o`00013oVN7m0ol00003oiWQo@;o00002_nIhOd3o`0000SoVN7m0_l00006oiWQo@?o0000
3?nIhOd2o`000004oiWQoOl0003o0000o`0000koVN7m1?l0000=oiWQo@?o00001?nIhOd2o`0000Oo
VN7m1?l00008oiWQo@;o00001OnIhOd3o`0000_oVN7m00?o0000oiWQoOl000000_l0000>oiWQo@Co
00002onIhOd4o`0000?oVN7m0_l00007oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@03o`0000_o
VN7m1?l0000;oiWQo@?o00000onIhOd9o`0000[ooo]Z1?l007l6oookJP00@ooonfX6o`0004cooo]Z
0_l00006oiWQo@?o00001_nIhOd3o`000004oiWQoOl0003o0000o`00017oVN7m1Ol0000?oiWQo@?o
00001OnIhOd3o`0000WoVN7m0ol0000;oiWQo@?o00000_nIhOd3o`00017oVN7m0ol0000?oiWQo@?o
00000onIhOd2o`0000_oVN7m0ol00008oiWQo@;o00001_nIhOd2o`0000goVN7m0_l000001?nIhOgo
0000o`000?l0000?oiWQo@Co00003OnIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002OnIhOd2o`00
00;oVN7m0ol0000>oiWQo@03o`000?nIhOgo000000;o00003OnIhOd4o`0000goVN7m0ol00004oiWQ
o@;o00001_nIhOd3o`0000CoVN7m00?o0000oiWQoOnIhOd00_nIhOd2o`0000;oVN7m0ol0000;oiWQ
o@Co00002onIhOd3o`0000CoVN7m0_l00006oiWQo@?o00001onIhOd9o`0000Wooo]Z0ol007l7oook
JP00@ooonfX6o`0004Wooo]Z0ol00005oiWQo@?o00002_nIhOd5o`0000ooVN7m0ol00005oiWQo@?o
00002OnIhOd3o`0000_oVN7m0ol00003oiWQo@?o00004?nIhOd3o`00017oVN7m0ol00003oiWQo@;o
00002_nIhOd3o`0000SoVN7m0_l00006oiWQo@?o00003OnIhOd2o`000004oiWQoOl0003o0000o`00
00ooVN7m1?l0000>oiWQo@?o00001?nIhOd2o`0000OoVN7m1?l0000:oiWQo@;o00000_nIhOd3o`00
00goVN7m0ol0000@oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l00007oiWQo@Co00002OnIhOd00ol0
003oVN7moiWQo@03o`0000SoVN7m00Co0000oiWQoOnIhOgoVN7m1?l0000;oiWQo@?o00001?nIhOd2
o`0000KoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00002onIhOd8o`0000_ooo]Z0_l007l6
oookJP00@ooonfX5o`0004Oooo]Z1Ol00003oiWQo@?o00002_nIhOd3o`0000GoVN7m0ol00008oiWQ
o@Co00002onIhOd3o`0000?oVN7m0ol0000AoiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000<oiWQ
o@?o00002?nIhOd2o`0000KoVN7m0_l0000=oiWQo@;o000000CoVN7mo`000?l0003o00004?nIhOd4
o`0000koVN7m0ol00004oiWQo@?o00001onIhOd4o`0000WoVN7m0_l00002oiWQo@?o00003onIhOd3
o`0000goVN7m0ol00003oiWQo@;o00002onIhOd3o`0000CoVN7m0_l00007oiWQo@?o00002OnIhOd2
o`0000;oVN7m0ol0000<oiWQo@Co00002onIhOd4o`0000CoVN7m0_l00006oiWQo@?o00002OnIhOd0
0ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000=oiWQo@Wo00001OoonfX3o`00O`?ooo]Z0ol007l5
oookJP00@ooonfX5o`0004Cooo]Z0ol00005oiWQo@?o00002OnIhOd4o`0000_oVN7m0ol00002oiWQ
o@?o00004_nIhOd3o`00017oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m0ol00006oiWQ
o@?o00003OnIhOd2o`000004oiWQoOl0003o0000o`0000ooVN7m1?l0000?oiWQo@?o00001?nIhOd3
o`0000OoVN7m1?l0000:oiWQo@;o00000_nIhOd3o`0000koVN7m0ol0000?oiWQo@?o00000onIhOd0
0ol0003oVN7moiWQo@07oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@05oiWQo@?o00002OnIhOd2
o`0000;oVN7m0ol0000<oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l00006oiWQo@Go00002?nIhOd0
0ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000;oiWQo@?o00000onIhOd00ol0003oVN7moiWQo@08
oiWQo@?o00001?nIhOd5o`0000Gooo]Z0ol007l3oookJP?o001o1OoonfX000Wooo]Z0ol007l01?oo
nf[o001oo`00Ool007l4oookJP03oiRFL_m4@WWo001o00;o001o00?oA49ioiRFL_oonfX09_oonfX6
o`00043ooo]Z1?l00006oiWQo@;o00000onIhOd3o`0000?oVN7m0ol0000AoiWQo@?o00004_nIhOd3
o`0000?oVN7m0_l0000<oiWQo@?o00002?nIhOd3o`0000KoVN7m0_l0000>oiWQo@;o000000CoVN7m
o`000?l0003o00004?nIhOd4o`0000koVN7m0ol00004oiWQo@?o00002?nIhOd4o`0000[oVN7m0_l0
0002oiWQo@?o00003onIhOd3o`0000koVN7m0ol00003oiWQo@;o00002_nIhOd3o`0000OoVN7m0_l0
0005oiWQo@;o00003?nIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l0
0007oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@03o`0000GoVN7m00?o0000oiWQoOnIhOd01?nI
hOd4o`0000_oVN7m0ol00004oiWQo@03o`000?nIhOgoVN7m00CoVN7m1?l00007oiWQo@03o`000?nI
hOgoVN7m00CoVN7m0ol00008oiWQo@Co00001_oonfX7o`00O`Kooo]Z0008oookJPSo001o0_oonfX0
2oo^jV_o<S9jo`00OomEDgOogMU/oookJ_o<b6ko8B5lo`00Oolb<W[ok^Y[02Gooo]Z1_l0000moook
JP?o00001onIhOd3o`0000SoVN7m0ol0000AoiWQo@?o00000onIhOd3o`0000coVN7m0ol00008oiWQ
o@?o00001_nIhOd3o`0000koVN7m0_l000001?nIhOgo0000o`000?l0000@oiWQo@Co00003onIhOd3
o`0000CoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000?oiWQo@?o00003onIhOd3
o`0000?oVN7m0_l00009oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@04oiWQo@?o00003?nIhOd0
0ol0003oVN7mo`000002o`0000koVN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000OoVN7m0ol00009
oiWQo@;o00000_nIhOd3o`0000_oVN7m1?l00009oiWQo@03o`000?nIhOgoVN7m00?o00001?nIhOd0
0ol0003oVN7moiWQo@04oiWQo@Co00002?nIhOd00ol0003oVN7moiWQo@03o`0000coVN7m00?o0000
oiWQoOnIhOd00ol0000:oiWQo@?o00002OoonfX5o`00O`Oooo]Z0007oookJPCo001o00?ooo]Zo`00
Ool007l00_l007l2oookJP03oc8bN_l007oo411m00Cooo]Z00Cok^Y[oa0@OOl007oo<S9j9OoonfX6
o`0003[ooo]Z0ol00007oiWQo@?o00002?nIhOd3o`0000?oVN7m0ol0000;oiWQo@?o00002OnIhOd2
o`0000OoVN7m0ol0000>oiWQo@;o000000CoVN7mo`000?l0003o00004OnIhOd4o`0000ooVN7m0ol0
0004oiWQo@?o00002?nIhOd4o`0000[oVN7m0ol00002oiWQo@?o00003onIhOd3o`0000ooVN7m0ol0
0003oiWQo@;o00002_nIhOd3o`0000SoVN7m00?o0000oiWQoOnIhOd01?nIhOd2o`0000coVN7m0_l0
00001?nIhOgo0000o`000?l0000>oiWQo@Co00003OnIhOd3o`0000CoVN7m0_l00007oiWQo@?o0000
2OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00002onIhOd3o`0000CoVN7m0_l00006oiWQo@Co0000
2?nIhOd00ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000>oiWQo@Co00002_nIhOd3o`0000;ooo]Z
00?o0000oookJ_oonfX04ooonfX000Oooo]Z0ol007l3oookJP?o001o00Gooo]ZoiRFL_l007oo001o
oiRFLP05oookJP04ohN5Lol007oo001ooiRFLRCooo]Z1_l0000goookJP?o00000onIhOd3o`000004
oiWQoOl0003o0000o`0000SoVN7m0ol00009oiWQo@;o00001onIhOd2o`0000koVN7m0ol000001?nI
hOgo0000o`000?l0000AoiWQo@Go00003onIhOd3o`0000CoVN7m0ol00008oiWQo@Co00002_nIhOd3
o`0000;oVN7m0ol0000@oiWQo@?o00003onIhOd3o`0000?oVN7m0_l0000:oiWQo@?o00002?nIhOd0
0ol0003oVN7moiWQo@04oiWQo@?o00003?nIhOd2o`000004oiWQoOl0003o0000o`0000koVN7m1?l0
000=oiWQo@?o00001?nIhOd2o`0000OoVN7m1?l00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0
000<oiWQo@?o00001?nIhOd2o`0000KoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00000_nI
hOd00ol0003oVN7moiWQo@06oiWQo@Co00002onIhOd3o`0000CoVN7m00?o0000oiWQoOnIhOd02?nI
hOd3o`0000CoVN7m00?o0000oiWQoOnIhOd01?nIhOd3o`0000Kooo]Z00?o0000oookJ_oonfX04_oo
nfX000Oooo]Z0ol007l3oookJP?o001o00Gooo]ZodA2NOl007oo001oolc8KP05oookJP04olc8K_l0
07oo001oodA2NACooo]Z2Ol007l7oookJPGo0000=OoonfX3o`0000OoVN7m1?l00007oiWQo@?o0000
3_nIhOd3o`000004oiWQoOl0003o0000o`0001;oVN7m1?l0000?oiWQo@?o00001OnIhOd3o`0000So
VN7m1?l0000:oiWQo@?o00000_nIhOd3o`00013oVN7m0ol0000@oiWQo@?o00000onIhOd2o`0000[o
VN7m0ol00008oiWQo@;o00001_nIhOd2o`0000coVN7m0_l000001?nIhOgo0000o`000?l0000?oiWQ
o@Co00003OnIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000=oiWQ
o@Co00003?nIhOd3o`0000CoVN7m0_l00006oiWQo@Co00002OnIhOd00ol0003oVN7moiWQo@03o`00
00_oVN7m1?l00006oiWQo@03o`000?nIhOgoVN7m00;oVN7m0ol00004oiWQo@;o00001_nIhOd3o`00
00SoVN7m00?o0000oiWQoOnIhOd01?nIhOd3o`0000SoVN7m00?o0000oiWQoOnIhOd00ol00009oook
JP03o`000?oonf[ooo]Z01;ooo]Z0007oookJP?o001o0ooonfX3o`00O`0;oookJ_l007oo001oo`00
Oooonf[o001oomgIK?oonf[ogMU/o`00OooonfX00ol007lDoookJPWo001o1ooonfX5o`0003;ooo]Z
0ol00007oiWQo@?o00001?nIhOd3o`000004oiWQoOl0003o0000o`0001?oVN7m0ol0000AoiWQo@?o
00001?nIhOd3o`0000SoVN7m1?l0000;oiWQo@?o00000_nIhOd3o`00013oVN7m0ol0000@oiWQo@?o
00000onIhOd2o`0000_oVN7m0ol00008oiWQo@;o00001_nIhOd2o`0000goVN7m0_l000001?nIhOgo
0000o`000?l0000>oiWQo@Co00003_nIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002_nIhOd2o`00
00;oVN7m0ol0000<oiWQo@Co00003OnIhOd3o`0000CoVN7m0_l00006oiWQo@Co00002OnIhOd00ol0
003oVN7moiWQo@03o`0000coVN7m1?l0000;oiWQo@?o00001?nIhOd2o`0000GoVN7m1?l00009oiWQ
o@03o`000?nIhOgoVN7m00?o00003?nIhOd00ol0003oVN7moiWQo@03o`0000[oVN7m1?l0000<oook
JP03o`000?oonf[ooo]Z01;ooo]Z0007oookJP?o001o0ooonfX3o`00O`05oookJ_l007oo001oo`00
OooonfX01Ol007l01?oonf[o001oo`00Ool007lDoookJPCo001o2ooonfX6o`0002oooo]Z0ol00007
oiWQo@?o00002OnIhOd3o`0001;oVN7m0ol00003oiWQo@?o00002onIhOd3o`0000[oVN7m0ol00002
oiWQo@?o00004OnIhOd3o`00013oVN7m0ol00003oiWQo@;o00002onIhOd3o`0000SoVN7m0_l00006
oiWQo@?o00003OnIhOd2o`000004oiWQoOl0003o0000o`0000ooVN7m1?l0000=oiWQo@?o00001?nI
hOd3o`0000SoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000<oiWQo@?o00001?nI
hOd2o`0000OoVN7m1?l00009oiWQo@03o`000?nIhOgoVN7m00?o00003?nIhOd4o`0000coVN7m0ol0
0004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd00ol0000;oiWQo@Co00003_nI
hOd4o`0000[oVN7m0ol0000@oookJP03o`000?oonf[ooo]Z01;ooo]Z0007oookJPCo001o00?ooo]Z
o`00Ool007l00_l007l01Ooonf[o001oo`00Ool007oooo]Z00Go001o00Cooo]Zo`00Ool007oo001o
5OoonfX4o`00O`[ooo]Z1_l0000]oookJP?o00001onIhOd2o`0000WoVN7m0ol00003oiWQo@?o0000
3?nIhOd3o`0000WoVN7m0_l00007oiWQo@;o00003onIhOd3o`00017oVN7m0ol00003oiWQo@;o0000
2onIhOd3o`0000SoVN7m0ol00006oiWQo@;o00003OnIhOd2o`000004oiWQoOl0003o0000o`00013o
VN7m1?l0000>oiWQo@?o00001?nIhOd3o`0000OoVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000go
VN7m1?l0000=oiWQo@?o00001?nIhOd2o`0000OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000co
VN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000OoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o
00002onIhOd4o`0000?oVN7m00?o0000oiWQoOnIhOd01OnIhOd3o`0000CoVN7m0_l00007oiWQo@Go
00001?nIhOd00ol0003oVN7moiWQo@04oiWQo@?o00004ooonfX00ol0003ooo]ZoookJP0BoookJP00
2?oonfX8o`00O`0;oookJ_m4@WWo001oo`00OooMfFco001oolc8K_oonf[oc<Q^o`00Ooo<b6h00_l0
07l00om4@WWooo]ZoookJP0DoookJPGo001o2?oonfX6o`0002[ooo]Z0ol00003oiWQo@?o000000Co
VN7mo`000?l0003o00002?nIhOd3o`0000WoVN7m0_l00007oiWQo@?o00003_nIhOd3o`000004oiWQ
oOl0003o0000o`0000koVN7m0ol00003oiWQo@?o00002onIhOd3o`0000SoVN7m0ol00006oiWQo@;o
00003_nIhOd2o`000004oiWQoOl0003o0000o`0000ooVN7m1?l0000?oiWQo@?o00001?nIhOd3o`00
00OoVN7m1?l0000:oiWQo@;o00000_nIhOd3o`0000koVN7m1?l0000=oiWQo@?o00001?nIhOd2o`00
00OoVN7m1?l00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o00001?nIhOd2o`00
00OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000_oVN7m1?l0000;oiWQo@?o00001?nIhOd2o`00
00;oVN7m00Co0000oiWQoOnIhOgoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00Co00002_nIhOd0
0ol0003oVN7moiWQo@03o`0001Kooo]Z00?o0000oookJ_oonfX04_oonfX000Wooo]Z0ol007l01_oo
nf[o001oo`00Ool007oooo]ZoiRFLP;o001o00?oV9IboookJ_oonfX00ooonfX01?n7QG?o001oo`00
Oonj^6lHoookJPCo001o1ooonfX6o`0002Oooo]Z0ol00007oiWQo@Go00001onIhOd2o`0000koVN7m
0ol000001?nIhOgo0000o`000?l0000BoiWQo@Go00003?nIhOd3o`0000WoVN7m0_l00007oiWQo@;o
00003_nIhOd2o`000004oiWQoOl0003o0000o`00013oVN7m1?l0000>oiWQo@?o00001?nIhOd3o`00
00SoVN7m1?l0000:oiWQo@;o00000_nIhOd3o`0000koVN7m1?l0000>oiWQo@?o00001?nIhOd2o`00
00OoVN7m1?l00009oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000<oiWQo@?o00001?nIhOd2o`00
00OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000;oiWQo@?o00001?nIhOd2o`00
00KoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00002onIhOd4o`0000goVN7m1?l0000Ioook
JP03o`000?oonf[ooo]Z01;ooo]Z000=oookJP?o001o0_oonfX01?lb<W[o001ooa0@OOo^jV/4oook
JP03oa0@OOl007ooA49i01[ooo]Z0ol007l7oookJPGo00009_oonfX2o`0000OoVN7m0ol00005oiWQ
o@?o000000CoVN7mo`000?l0003o00004OnIhOd5o`00013oVN7m0ol00005oiWQo@?o00001onIhOd2
o`0000koVN7m0ol000001?nIhOgo0000o`000?l0000@oiWQo@Co00003onIhOd3o`0000CoVN7m0ol0
0008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000>oiWQo@Co00003_nIhOd3o`0000CoVN7m0ol0
0007oiWQo@Co00002OnIhOd2o`0000;oVN7m0ol0000=oiWQo@Co00003OnIhOd3o`0000CoVN7m0_l0
0007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l0
0006oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@03o`0000_oVN7m1Ol0000:oiWQo@?o00001?nI
hOd2o`0000OoVN7m1?l0000NoookJP03o`000?oonf[ooo]Z017ooo]Z000=oookJP?o001o0_oonfX0
2oo^jV_o<S9jo`00Oolb<W[oc<Q^oookJ_oMfFcoA49io`00Oolb<W[ok^Y[01_ooo]Z0ol007l6oook
JPGo00008ooonfX3o`0000KoVN7m0ol00009oiWQo@Go00003onIhOd3o`0000GoVN7m0ol00009oiWQ
o@Co00002onIhOd3o`000004oiWQoOl0003o0000o`00017oVN7m1Ol0000>oiWQo@?o00001?nIhOd3
o`0000SoVN7m1?l0000:oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000>oiWQo@?o00001?nIhOd3
o`0000SoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000=oiWQo@?o00001?nIhOd3
o`0000OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o00001?nIhOd2
o`0000OoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00002onIhOd4o`0000_oVN7m0ol00004
oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd01?l0000RoookJP03o`000?oonf[o
oo]Z017ooo]Z000=oookJP?o001o1?oonfX00onHUW;oA49io`00O`02o`00O`03oc8bN_nHUW;ooo]Z
01Kooo]Z0ol007l3oookJP?o001o1OoonfX6o`00027ooo]Z1?l00004oiWQo@?o00002OnIhOd3o`00
00GoVN7m0ol00009oiWQo@?o00002onIhOd3o`0000?oVN7m0ol0000@oiWQo@Go00003onIhOd3o`00
00GoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000?oiWQo@Co00003_nIhOd3o`00
00CoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000=oiWQo@Co00003OnIhOd3o`00
00CoVN7m0ol00007oiWQo@?o00002_nIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003?nIhOd3o`00
00CoVN7m0_l00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000;oiWQo@Co00002onIhOd3o`00
00CoVN7m0_l00006oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000Voook
JP03o`000?oonf[ooo]Z017ooo]Z000boookJP?o001o0ooonfX3o`00O`Gooo]Z1_l0000NoookJP?o
00001?nIhOd4o`0000SoVN7m1?l0000;oiWQo@?o00000onIhOd3o`00017oVN7m1?l0000?oiWQo@?o
00001OnIhOd3o`0000SoVN7m1?l0000;oiWQo@?o00000_nIhOd3o`0000ooVN7m1?l0000>oiWQo@?o
00001?nIhOd3o`0000SoVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000=oiWQo@?o
00001?nIhOd3o`0000OoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000<oiWQo@?o
00001?nIhOd2o`0000OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000;oiWQo@?o
00001?nIhOd2o`0000KoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00002onIhOd4o`0000_o
VN7m0ol0000ZoookJP03o`000?oonf[ooo]Z017ooo]Z000boookJPCo001o0_oonfX3o`00O`Gooo]Z
1_l0000KoookJP?o00001_nIhOd2o`0000;oVN7m0ol00003oiWQo@?o00004_nIhOd3o`00017oVN7m
0ol00004oiWQo@?o00002OnIhOd3o`0000_oVN7m0ol00002oiWQo@?o00004OnIhOd3o`0000ooVN7m
0ol00004oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003onIhOd3o`0000koVN7m
0ol00004oiWQo@?o00001onIhOd3o`0000[oVN7m0_l00002oiWQo@?o00003OnIhOd4o`0000goVN7m
0ol00004oiWQo@;o00001onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003?nIhOd4o`0000coVN7m
0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd00ol0000<oiWQo@?o0000
2onIhOd3o`0000;oVN7m00Co0000oiWQoOl0003o00001_nIhOd3o`0002gooo]Z00?o0000oookJ_oo
nfX04OoonfX003?ooo]Z1ol007l6oookJPKo00006?oonfX3o`0000KoVN7m0ol00007oiWQo@?o0000
4_nIhOd3o`0000?oVN7m0ol0000;oiWQo@?o00002_nIhOd3o`0000?oVN7m0ol0000@oiWQo@?o0000
4OnIhOd3o`0000?oVN7m0_l0000:oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000?oiWQo@?o0000
3onIhOd3o`0000?oVN7m0ol00008oiWQo@?o00002_nIhOd2o`0000;oVN7m0ol0000=oiWQo@Co0000
3OnIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Co0000
3?nIhOd3o`0000CoVN7m0_l00007oiWQo@?o00002OnIhOd00ol0003oVN7moiWQo@03o`0000coVN7m
0ol0000<oiWQo@?o00000onIhOd2o`0000KoVN7m0ol00006oiWQo@04o`000?nIhOgoVN7mo`0000;o
VN7m0ol0000`oookJP03o`000?oonf[ooo]Z017ooo]Z000doookJPGo001o1ooonfX5o`0001Kooo]Z
0ol00006oiWQo@?o00001onIhOd3o`0000?oVN7m0ol0000<oiWQo@?o00002OnIhOd2o`0000OoVN7m
0_l0000@oiWQo@?o00004?nIhOd3o`0000?oVN7m0_l0000<oiWQo@?o00002?nIhOd2o`0000KoVN7m
0_l0000?oiWQo@?o00003onIhOd3o`0000?oVN7m0_l0000:oiWQo@?o00002OnIhOd3o`0000;oVN7m
0ol0000>oiWQo@?o00003OnIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002_nIhOd2o`0000;oVN7m
0ol0000<oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l00007oiWQo@?o00002OnIhOd2o`0000;oVN7m
0ol0000<oiWQo@?o00003?nIhOd3o`0000?oVN7m0_l00007oiWQo@?o00002?nIhOd00ol0003oVN7m
oiWQo@03o`0000[oVN7m1Ol0000coookJP03o`000?oonf[ooo]Z017ooo]Z0010oookJPGo00004ooo
nfX5o`0000CoVN7m0ol00007oiWQo@?o00002OnIhOd3o`0000OoVN7m0_l0000>oiWQo@?o000000Co
VN7mo`000?l0003o00003onIhOd3o`0000?oVN7m0_l0000;oiWQo@?o00002?nIhOd3o`0000KoVN7m
0ol0000=oiWQo@;o000000CoVN7mo`000?l0003o00003_nIhOd3o`0000?oVN7m0_l0000:oiWQo@?o
00002?nIhOd2o`0000KoVN7m0_l0000>oiWQo@?o00003_nIhOd3o`0000?oVN7m0ol00007oiWQo@?o
00002_nIhOd2o`0000;oVN7m0ol0000=oiWQo@Co00003?nIhOd3o`0000CoVN7m0_l00007oiWQo@?o
00002OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00003?nIhOd3o`0000?oVN7m0_l00007oiWQo@?o
00002?nIhOd2o`0000;oVN7m0ol0000;oiWQo@?o00002onIhOd3o`0003Sooo]Z00?o0000oookJ_oo
nfX04?oonfX0043ooo]Z1Ol0000@oookJP?o00001OnIhOd4o`0000SoVN7m0_l0000?oiWQo@?o0000
00CoVN7mo`000?l0003o00004OnIhOd5o`0000goVN7m0ol00008oiWQo@?o00001_nIhOd2o`0000ko
VN7m0_l000001?nIhOgo0000o`000?l0000@oiWQo@Go00003?nIhOd3o`0000SoVN7m0_l00006oiWQ
o@;o00003OnIhOd2o`000004oiWQoOl0003o0000o`0000goVN7m0ol00003oiWQo@;o00002OnIhOd3
o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd4o`0000goVN7m0ol00004oiWQo@;o00001onIhOd3
o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd3o`0000coVN7m0ol00004oiWQo@;o00001onIhOd3
o`0000SoVN7m0_l00002oiWQo@?o00002onIhOd4o`0000_oVN7m0ol00003oiWQo@;o00001_nIhOd3
o`0000?ooo]Z00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0@oookJP00?ooonfX6o`00
00gooo]Z0ol00006oiWQo@?o00000onIhOd3o`0000;oVN7m0ol0000BoiWQo@Go00003onIhOd3o`00
00GoVN7m0ol00008oiWQo@;o00003_nIhOd2o`000004oiWQoOl0003o0000o`00013oVN7m1Ol0000>
oiWQo@?o00001OnIhOd3o`0000OoVN7m0_l0000=oiWQo@;o000000CoVN7mo`000?l0003o00003onI
hOd4o`0000coVN7m0ol00008oiWQo@03o`000?nIhOgoVN7m00CoVN7m0_l0000=oiWQo@?o00003OnI
hOd3o`0000CoVN7m0ol00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000=oiWQo@?o00003OnI
hOd3o`0000?oVN7m0_l00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000;oiWQo@Co00002onI
hOd3o`0000CoVN7m0_l00006oiWQo@?o00002?nIhOd00ol0003oVN7moiWQo@03o`0000Oooo]Z00?o
0000oookJ_oonfX0=?oonfX00ol0003ooo]ZoookJP0@oookJP00?ooonfX6o`0000[ooo]Z0ol00006
oiWQo@?o00002?nIhOd5o`00013oVN7m0ol00005oiWQo@?o00002OnIhOd3o`0000_oVN7m0ol00002
oiWQo@?o00004?nIhOd5o`0000koVN7m0ol00005oiWQo@?o00002?nIhOd3o`0000_oVN7m0ol00000
1?nIhOgo0000o`000?l0000?oiWQo@Co00003_nIhOd3o`0000CoVN7m0ol00007oiWQo@;o00003?nI
hOd2o`000004oiWQoOl0003o0000o`0000coVN7m0ol00003oiWQo@?o00001onIhOd3o`0000[oVN7m
0_l00002oiWQo@?o00003OnIhOd3o`0000goVN7m0ol00003oiWQo@?o00001onIhOd3o`0000SoVN7m
0_l00002oiWQo@?o00003?nIhOd4o`0000_oVN7m0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m
00?o0000oiWQoOnIhOd00ol0000;oiWQo@?o00002ooonfX00ol0003ooo]ZoookJP0coookJP03o`00
0?oonf[ooo]Z013ooo]Z000ooookJPKo00001ooonfX4o`0000GoVN7m0ol00008oiWQo@?o00001OnI
hOd4o`0000WoVN7m0ol0000;oiWQo@?o00000onIhOd3o`00013oVN7m1Ol0000>oiWQo@?o00001OnI
hOd3o`0000SoVN7m0ol0000;oiWQo@?o00000_nIhOd3o`0000ooVN7m1?l0000>oiWQo@?o00001?nI
hOd3o`0000SoVN7m0ol0000:oiWQo@?o000000CoVN7mo`000?l0003o00003_nIhOd4o`0000coVN7m
0_l00009oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000=oiWQo@?o00000onIhOd3o`0000OoVN7m
0ol00009oiWQo@;o00000_nIhOd3o`0000_oVN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000KoVN7m
0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00002onIhOd4o`0000_oVN7m0ol0000>oookJP03o`00
0?oonf[ooo]Z03?ooo]Z00?o0000oookJ_oonfX04?oonfX003oooo]Z1_l00004oookJP?o00001?nI
hOd5o`0000SoVN7m0ol0000<oiWQo@?o00000onIhOd3o`00013oVN7m1Ol0000?oiWQo@?o00001OnI
hOd3o`0000SoVN7m0ol0000;oiWQo@?o00000_nIhOd3o`0000ooVN7m1Ol0000>oiWQo@?o00001?nI
hOd3o`0000SoVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000=oiWQo@?o00001?nI
hOd3o`0000OoVN7m0_l0000<oiWQo@?o00003OnIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002OnI
hOd2o`0000;oVN7m0ol0000<oiWQo@Co00002onIhOd3o`0000CoVN7m0_l00007oiWQo@?o00002OnI
hOd00ol0003oVN7moiWQo@03o`0000_oVN7m1?l0000;oiWQo@?o00001?nIhOd2o`0000KoVN7m0ol0
000BoookJP03o`000?oonf[ooo]Z03;ooo]Z00?o0000oookJ_oonfX04?oonfX003oooo]Z1Ol00002
oookJP?o00001onIhOd3o`000004oiWQoOl0003o0000o`0000?oVN7m0ol0000BoiWQo@Co00003onI
hOd3o`0000GoVN7m0ol00009oiWQo@?o00002onIhOd3o`0000;oVN7m0ol0000?oiWQo@Go00003_nI
hOd3o`0000GoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000>oiWQo@Co00003_nI
hOd3o`0000CoVN7m0ol00007oiWQo@?o00002_nIhOd3o`000004oiWQoOl0003o0000o`0000_oVN7m
0ol00003oiWQo@?o00001onIhOd3o`0000[oVN7m0_l00002oiWQo@?o00003?nIhOd4o`0000coVN7m
0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m0_l00002oiWQo@?o00002onIhOd4o`0000_oVN7m
0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd00ol0000FoookJP03o`00
0?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX04?oonfX003oooo]Z1ol00007oiWQo@?o00001onI
hOd3o`0001;oVN7m0ol00004oiWQo@?o00002OnIhOd3o`0000_oVN7m0ol00003oiWQo@?o00003onI
hOd5o`0000koVN7m0ol00005oiWQo@?o00002?nIhOd3o`0000_oVN7m0ol00002oiWQo@?o00003_nI
hOd4o`0000koVN7m0ol00004oiWQo@?o00002?nIhOd3o`0000[oVN7m0_l00002oiWQo@?o00003_nI
hOd5o`0000WoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000goVN7m1?l0000<oiWQo@?o00001?nI
hOd2o`0000OoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00003?nIhOd4o`0000_oVN7m0ol0
0004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd00ol0000;oiWQo@Co00006Ooo
nfX00ol0003ooo]ZoookJP0boookJP03o`000?oonf[ooo]Z00oooo]Z000noookJPKo00001_nIhOd3
o`0000OoVN7m0ol00003oiWQo@?o00003?nIhOd3o`0000[oVN7m0ol00003oiWQo@?o00004OnIhOd4
o`0000koVN7m0ol00005oiWQo@?o00002?nIhOd3o`0000_oVN7m0ol00002oiWQo@?o00003onIhOd4
o`0000koVN7m0ol00004oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003_nIhOd3
o`0000koVN7m0ol00005oiWQo@?o00000onIhOd3o`0000goVN7m0ol0000=oiWQo@?o00001?nIhOd2
o`0000OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m0ol0000<oiWQo@?o00001?nIhOd2
o`0000KoVN7m0ol00009oiWQo@03o`000?nIhOgoVN7m00?o00003?nIhOd3o`0000WoVN7m1Ol0000N
oookJP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX03ooonfX003kooo]Z1Ol00004oiWQ
o@?o00001onIhOd3o`0000WoVN7m0ol00007oiWQo@;o00004?nIhOd3o`00017oVN7m0ol00004oiWQ
o@?o00002?nIhOd3o`0000_oVN7m0ol00002oiWQo@?o00004?nIhOd4o`0000koVN7m0ol00004oiWQ
o@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003_nIhOd4o`0000koVN7m0ol00003oiWQ
o@?o00002?nIhOd3o`0000[oVN7m1?l0000=oiWQo@?o00000onIhOd3o`0000OoVN7m0ol00009oiWQ
o@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00009oiWQ
o@03o`000?nIhOgoVN7m00?o00003?nIhOd3o`0000coVN7m0ol00003oiWQo@?o00000_nIhOd4o`00
02Cooo]Z00?o0000oookJ_oonfX0<?oonfX00ol0003ooo]ZoookJP0?oookJP00?_oonfX9o`0000So
VN7m0_l0000?oiWQo@?o000000CoVN7mo`000?l0003o00003onIhOd3o`0000?oVN7m0ol0000;oiWQ
o@?o00002_nIhOd3o`0000;oVN7m0ol0000@oiWQo@Co00003onIhOd3o`0000CoVN7m0ol00008oiWQ
o@?o00002_nIhOd3o`0000;oVN7m0ol0000?oiWQo@?o00003_nIhOd3o`0000CoVN7m0ol00008oiWQ
o@?o00002OnIhOd3o`0000;oVN7m0ol0000:oiWQo@?o00001?nIhOd3o`0000OoVN7m0ol00009oiWQ
o@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000OoVN7m0ol00008oiWQ
o@;o00000_nIhOd3o`0000coVN7m0ol0000<oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00008oiWQ
o@?o0000:OoonfX00ol0003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z00oooo]Z000noookJPKo
00000ooonfX3o`0000;oVN7m0ol0000BoiWQo@Go00003OnIhOd3o`0000WoVN7m0_l00007oiWQo@;o
00003onIhOd3o`00013oVN7m0ol00004oiWQo@?o00002OnIhOd3o`0000[oVN7m0ol00002oiWQo@?o
00003onIhOd4o`0000koVN7m0ol00003oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o
00003OnIhOd5o`0000WoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o
00001?nIhOd2o`0000OoVN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m0ol0000<oiWQo@?o
00000onIhOd2o`0000OoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000SoVN7m0ol0000/oookJP03
o`000?oonf[ooo]Z02oooo]Z00?o0000oookJ_oonfX03ooonfX003kooo]Z1Ol00007oookJPCo0000
4?nIhOd3o`0000GoVN7m0ol00008oiWQo@;o00003_nIhOd3o`000004oiWQoOl0003o0000o`0000ko
VN7m0ol00003oiWQo@?o00002onIhOd2o`0000[oVN7m0ol00003oiWQo@?o00003_nIhOd5o`0000ko
VN7m0ol00004oiWQo@?o00002?nIhOd3o`0000WoVN7m0ol00002oiWQo@?o00003_nIhOd4o`0000go
VN7m0ol00005oiWQo@?o00000onIhOd3o`0000goVN7m1?l0000<oiWQo@?o00001?nIhOd2o`0000Oo
VN7m0ol00009oiWQo@;o00000_nIhOd3o`0000coVN7m1?l0000<oiWQo@?o00000onIhOd2o`0000Oo
VN7m0ol00008oiWQo@;o00000_nIhOd3o`0000_oVN7m1?l00008oiWQo@?o0000<?oonfX00ol0003o
oo]ZoookJP0^oookJP03o`000?oonf[ooo]Z00oooo]Z000noookJPGo00002ooonfX4o`0000WoVN7m
0ol0000;oiWQo@?o00000_nIhOd3o`00017oVN7m1Ol0000=oiWQo@;o00002OnIhOd2o`0000OoVN7m
0_l0000?oiWQo@?o00003_nIhOd3o`0000GoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m
0ol0000>oiWQo@?o00003_nIhOd3o`0000CoVN7m0ol00007oiWQo@?o00002_nIhOd4o`0000goVN7m
0ol00004oiWQo@;o00001onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd3o`0000coVN7m
0ol00004oiWQo@;o00001onIhOd3o`0000SoVN7m0_l00002oiWQo@?o00002onIhOd4o`0000WoVN7m
1Ol00004oiWQo@?o00000_nIhOd3o`0003Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]Z
oookJP0?oookJP00?_oonfX6o`0000kooo]Z0ol00003oiWQo@?o00004?nIhOd5o`0000ooVN7m0ol0
0005oiWQo@?o00002?nIhOd2o`0000goVN7m0ol000001?nIhOgo0000o`000?l0000>oiWQo@?o0000
0onIhOd3o`0000SoVN7m0ol0000;oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000>oiWQo@?o0000
0onIhOd3o`0000SoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000[oVN7m0ol00004oiWQo@?o0000
1onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd3o`0000goVN7m0ol00003oiWQo@;o0000
1onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00002onIhOd5o`0000WoVN7m1?l00004oiWQo@?o0000
0_nIhOd4o`0000_oVN7m0ol0000hoookJP03o`000?oonf[ooo]Z02gooo]Z00?o0000oookJ_oonfX0
3_oonfX004Cooo]Z00?o0000oookJ_oonfX03_oonfX4o`0000ooVN7m0ol00005oiWQo@?o00002OnI
hOd3o`0000_oVN7m0ol00002oiWQo@?o00004?nIhOd5o`0000coVN7m0ol00009oiWQo@?o00000_nI
hOd3o`0000ooVN7m1?l0000>oiWQo@?o00001?nIhOd3o`0000SoVN7m0ol00009oiWQo@?o00000_nI
hOd3o`0000koVN7m1?l00009oiWQo@?o00002_nIhOd2o`0000;oVN7m0ol0000=oiWQo@?o00003OnI
hOd3o`0000?oVN7m0ol00007oiWQo@?o00002?nIhOd2o`0000;oVN7m0ol0000<oiWQo@Go00002OnI
hOd4o`0000GoVN7m0ol00002oiWQo@Co00002_nIhOd3o`0000coVN7m0ol0000koookJP03o`000?oo
nf[ooo]Z02gooo]Z00?o0000oookJ_oonfX03_oonfX004Gooo]Z0_l0000BoookJP?o00002OnIhOd3
o`0000_oVN7m0ol00003oiWQo@?o00004?nIhOd5o`0000koVN7m0ol00005oiWQo@?o00001onIhOd2
o`0000koVN7m1?l0000>oiWQo@?o00001?nIhOd3o`0000SoVN7m0ol0000:oiWQo@?o00000_nIhOd3
o`0000koVN7m0ol0000>oiWQo@?o00001?nIhOd3o`0000?oVN7m0ol0000>oiWQo@?o00003OnIhOd3
o`0000?oVN7m0ol00007oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Co00002_nIhOd4
o`0000GoVN7m0ol00002oiWQo@Co00002_nIhOd4o`0000_oVN7m0ol00003oiWQo@;o00001onIhOd3
o`0003oooo]Z00?o0000oookJ_oonfX0;?oonfX00ol0003ooo]ZoookJP0>oookJP00AooonfX00ol0
003ooo]ZoookJP0BoookJP?o00000onIhOd3o`00013oVN7m1Ol0000?oiWQo@?o00001OnIhOd3o`00
00SoVN7m0ol0000;oiWQo@?o000000CoVN7mo`000?l0003o00003OnIhOd3o`0000CoVN7m0ol00008
oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000>oiWQo@Co00003_nIhOd3o`0000?oVN7m0ol00008
oiWQo@?o00002_nIhOd3o`0000koVN7m0ol00003oiWQo@?o00001onIhOd3o`0000WoVN7m0_l00002
oiWQo@?o00003OnIhOd3o`0000coVN7m0ol00004oiWQo@?o00000onIhOd4o`0000[oVN7m1?l0000;
oiWQo@?o00001?nIhOd2o`0000KoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0004?ooo]Z00?o0000
oookJ_oonfX0:ooonfX00ol0003ooo]ZoookJP0>oookJP00B?oonfX00ol0003ooo]ZoookJP0Doook
JPCo00003onIhOd3o`0000GoVN7m0ol00009oiWQo@?o00002onIhOd3o`0000;oVN7m0ol0000?oiWQ
o@Go00002onIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003onIhOd3o`0000koVN7m0ol00004oiWQ
o@?o00002?nIhOd3o`0000WoVN7m0ol00002oiWQo@?o00002_nIhOd3o`0000?oVN7m0ol00008oiWQ
o@?o00002OnIhOd2o`0000;oVN7m0ol0000=oiWQo@?o00003OnIhOd3o`0000?oVN7m0_l00007oiWQ
o@?o00002OnIhOd4o`0000_oVN7m0ol00004oiWQo@;o00001_nIhOd3o`0000WoVN7m00?o0000oiWQ
oOnIhOd00ol0000;oiWQo@Co0000A_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z
00kooo]Z0019oookJP03o`000?oonf[ooo]Z01Oooo]Z0ol00009oiWQo@?o00002onIhOd3o`0000?o
VN7m0ol0000@oiWQo@Co00003_nIhOd3o`0000GoVN7m1Ol00003oiWQo@?o00003onIhOd4o`0000ko
VN7m0ol00003oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003OnIhOd5o`0000Wo
VN7m0ol00009oiWQo@?o00000_nIhOd3o`0000goVN7m0ol0000=oiWQo@?o00000onIhOd3o`0000Oo
VN7m0ol00008oiWQo@;o00000_nIhOd3o`0000WoVN7m0ol00004oiWQo@;o00001_nIhOd3o`0000Wo
VN7m00?o0000oiWQoOnIhOd00ol0000<oiWQo@?o00002onIhOd3o`0004_ooo]Z00?o0000oookJ_oo
nfX0:_oonfX00ol0003ooo]ZoookJP0>oookJP00B_oonfX2o`0001[ooo]Z0ol00003oiWQo@?o0000
4?nIhOd5o`0000ooVN7m0ol00004oiWQo@?o00002?nIhOd3o`0000goVN7m1?l0000>oiWQo@?o0000
1?nIhOd3o`0000SoVN7m0ol00009oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000=oiWQo@?o0000
1OnIhOd3o`0000?oVN7m0ol0000=oiWQo@Co00003OnIhOd3o`0000?oVN7m0ol00007oiWQo@?o0000
2OnIhOd2o`0000;oVN7m0ol0000;oiWQo@Go00002?nIhOd3o`0000WoVN7m00?o0000oiWQoOnIhOd0
0ol0000<oiWQo@?o00003?nIhOd3o`0000?oVN7m0_l00006oiWQo@?o0000CooonfX00ol0003ooo]Z
oookJP0YoookJP03o`000?oonf[ooo]Z00kooo]Z001<oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0
000?oiWQo@?o00001OnIhOd3o`0000WoVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000goVN7m0ol0
0004oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00003_nIhOd3o`0000koVN7m0ol0
0004oiWQo@?o00001onIhOd3o`0000_oVN7m0ol0000=oiWQo@?o00001?nIhOd3o`0000OoVN7m0ol0
0009oiWQo@;o00000_nIhOd3o`0000coVN7m1Ol00009oiWQo@Co00001OnIhOd3o`0000;oVN7m0ol0
000<oiWQo@?o00003?nIhOd3o`0000?oVN7m0_l00007oiWQo@?o00002?nIhOd00ol0003oVN7moiWQ
o@03o`0005?ooo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0=oookJP00COoonfX0
0ol0003ooo]ZoookJP0MoookJP?o00002OnIhOd3o`0000_oVN7m0ol00003oiWQo@?o00003onIhOd4
o`0000coVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000koVN7m1?l0000>oiWQo@?o00000onIhOd3
o`0000SoVN7m0ol0000:oiWQo@;o00000_nIhOd3o`0000_oVN7m0ol00003oiWQo@?o00001onIhOd3
o`0000[oVN7m0_l00002oiWQo@?o00003OnIhOd4o`0000WoVN7m1Ol00005oiWQo@?o00000_nIhOd4
o`0000_oVN7m0ol0000<oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00008oiWQo@;o00000_nIhOd3
o`0000[oVN7m1?l0001FoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX03OoonfX0
04kooo]Z00?o0000oookJ_oonfX07ooonfX3o`0000?oVN7m0ol0000@oiWQo@Go00003_nIhOd3o`00
00CoVN7m0ol00007oiWQo@;o00003_nIhOd4o`0000koVN7m0ol00004oiWQo@?o00002?nIhOd3o`00
00WoVN7m0ol00002oiWQo@?o00003OnIhOd5o`0000[oVN7m0ol00009oiWQo@;o00000_nIhOd3o`00
00goVN7m1?l0000=oiWQo@?o00001?nIhOd3o`0000;oVN7m1?l0000<oiWQo@?o00003?nIhOd3o`00
00?oVN7m0_l00007oiWQo@?o00002?nIhOd2o`0000;oVN7m0ol0000;oiWQo@Co00002OnIhOd4o`00
05_ooo]Z00?o0000oookJ_oonfX0:?oonfX00ol0003ooo]ZoookJP0=oookJP00CooonfX2o`0002;o
oo]Z1?l0000?oiWQo@?o00001OnIhOd3o`0000SoVN7m0ol0000:oiWQo@?o000000CoVN7mo`000?l0
003o00003OnIhOd3o`0000CoVN7m0ol00008oiWQo@?o00002_nIhOd3o`0000;oVN7m0ol0000>oiWQ
o@Co00002onIhOd4o`0000GoVN7m1?l00003oiWQo@?o00003OnIhOd3o`0000goVN7m0ol00004oiWQ
o@?o00001onIhOd3o`0000WoVN7m0ol0000=oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00008oiWQ
o@;o00000_nIhOd3o`0000_oVN7m1Ol00009oiWQo@Co00001?nIhOd3o`0000;oVN7m1?l0001Poook
JP03o`000?oonf[ooo]Z02Oooo]Z00?o0000oookJ_oonfX03OoonfX0057ooo]Z00?o0000oookJ_oo
nfX08ooonfX3o`0000WoVN7m0ol0000;oiWQo@?o00000_nIhOd3o`0000ooVN7m1?l0000;oiWQo@?o
00002_nIhOd3o`0000;oVN7m0ol0000?oiWQo@?o00003_nIhOd3o`0000CoVN7m1?l00003oiWQo@Co
00003OnIhOd3o`0000goVN7m0ol00003oiWQo@?o00001onIhOd3o`0000[oVN7m0_l00002oiWQo@?o
00002OnIhOd3o`0000?oVN7m0ol00007oiWQo@?o00002?nIhOd2o`0000;oVN7m0ol0000;oiWQo@Go
00002OnIhOd4o`0000GoVN7m0ol00002oiWQo@Co00002_nIhOd3o`0006Gooo]Z00?o0000oookJ_oo
nfX09_oonfX00ol0003ooo]ZoookJP0=oookJP00D_oonfX00ol0003ooo]ZoookJP0UoookJP?o0000
0onIhOd3o`00013oVN7m1?l0000>oiWQo@?o00001?nIhOd5o`0000?oVN7m0ol0000?oiWQo@Co0000
3_nIhOd3o`0000?oVN7m0ol00008oiWQo@?o00002onIhOd3o`0000koVN7m0ol00003oiWQo@?o0000
1onIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd5o`0000SoVN7m0ol00009oiWQo@;o0000
0_nIhOd3o`0000coVN7m1?l00009oiWQo@Co00001OnIhOd3o`0000;oVN7m1?l0000;oiWQo@?o0000
2onIhOd3o`0006Sooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0=oookJP00Dooo
nfX00ol0003ooo]ZoookJP0WoookJPCo00003onIhOd3o`0000CoVN7m0ol00008oiWQo@?o00003?nI
hOd4o`0000koVN7m0ol00004oiWQo@?o00002?nIhOd3o`0000WoVN7m0ol00002oiWQo@?o00002onI
hOd3o`0000?oVN7m0ol00008oiWQo@?o00002OnIhOd2o`0000;oVN7m0ol0000=oiWQo@Co00002_nI
hOd5o`0000GoVN7m0ol00002oiWQo@?o00003OnIhOd3o`0000coVN7m0ol00004oiWQo@?o00000_nI
hOd4o`0000_oVN7m0ol0000<oiWQo@?o00000onIhOd2o`0000KoVN7m0ol0001/oookJP03o`000?oo
nf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX03OoonfX005Cooo]Z00?o0000oookJ_oonfX0:_oonfX3
o`0000WoVN7m0ol0000:oiWQo@?o00000_nIhOd3o`0000coVN7m0ol00004oiWQo@?o00002?nIhOd3
o`0000[oVN7m0ol00002oiWQo@?o00003_nIhOd4o`0000[oVN7m0ol00009oiWQo@?o00000_nIhOd3
o`0000goVN7m0ol0000=oiWQo@?o00001?nIhOd3o`0000?oVN7m1?l0000<oiWQo@?o00003OnIhOd3
o`0000?oVN7m0_l00007oiWQo@?o00002OnIhOd3o`0000coVN7m0ol00003oiWQo@;o00001onIhOd3
o`0000SoVN7m00?o0000oiWQoOnIhOd00ol0001`oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000
oookJ_oonfX03?oonfX005Gooo]Z0_l0000]oookJP?o00000onIhOd3o`0000ooVN7m1?l0000;oiWQ
o@?o00002_nIhOd3o`0000;oVN7m0ol0000>oiWQo@Co00003_nIhOd3o`0000CoVN7m1?l00003oiWQ
o@?o00003_nIhOd3o`0000goVN7m0ol00003oiWQo@?o00001onIhOd3o`0000[oVN7m0ol0000=oiWQ
o@?o00000onIhOd3o`0000OoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000WoVN7m0ol00003oiWQ
o@;o00001onIhOd3o`0000SoVN7m0_l00002oiWQo@?o00002_nIhOd4o`0007?ooo]Z00?o0000oook
J_oonfX09OoonfX00ol0003ooo]ZoookJP0<oookJP00EooonfX00ol0003ooo]ZoookJP0]oookJPCo
00003_nIhOd3o`0000CoVN7m1Ol00003oiWQo@?o00003onIhOd3o`0000koVN7m0ol00004oiWQo@?o
00002?nIhOd3o`0000_oVN7m0ol0000>oiWQo@?o00000onIhOd3o`0000OoVN7m0ol00009oiWQo@;o
00000_nIhOd3o`0000[oVN7m0ol00003oiWQo@?o00001onIhOd3o`0000WoVN7m0_l00002oiWQo@?o
00002onIhOd5o`0000SoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000_oVN7m1Ol00008oiWQo@Co
0000N?oonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00cooo]Z001HoookJP03o`00
0?oonf[ooo]Z033ooo]Z0ol00008oiWQo@?o00003?nIhOd4o`0000koVN7m0ol00003oiWQo@?o0000
2?nIhOd3o`0000[oVN7m0ol00002oiWQo@?o00002onIhOd3o`0000?oVN7m0ol00008oiWQo@?o0000
2OnIhOd2o`0000;oVN7m0ol0000<oiWQo@Go00002OnIhOd3o`0000WoVN7m0_l00002oiWQo@?o0000
3?nIhOd5o`0000WoVN7m1?l00005oiWQo@?o00000_nIhOd3o`0000coVN7m1?l00009oiWQo@Co0000
1OnIhOd3o`0000;oVN7m0ol0001moookJP03o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0
3?oonfX005Wooo]Z00?o0000oookJ_oonfX0<_oonfX3o`0000;oVN7m0ol0000<oiWQo@?o00001?nI
hOd3o`0000SoVN7m0ol00009oiWQo@?o00000_nIhOd3o`0000koVN7m1Ol0000:oiWQo@?o00002OnI
hOd3o`0000;oVN7m0ol0000<oiWQo@Go00002_nIhOd4o`0000GoVN7m0ol00003oiWQo@?o00003OnI
hOd4o`0000[oVN7m1?l00005oiWQo@?o00000_nIhOd4o`0000_oVN7m0ol0000<oiWQo@?o00001?nI
hOd3o`0000;oVN7m1?l0000;oiWQo@?o0000POoonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z00cooo]Z001JoookJP;o0000=OoonfX3o`0000_oVN7m0ol0000:oiWQo@?o00000_nIhOd3
o`0000koVN7m1?l0000<oiWQo@Co00001OnIhOd4o`0000?oVN7m0ol0000>oiWQo@Co00002_nIhOd4
o`0000GoVN7m0ol00003oiWQo@Co00003?nIhOd3o`0000goVN7m0ol00004oiWQo@?o00000onIhOd4
o`0000_oVN7m0ol0000<oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00009oiWQo@?o00003?nIhOd3
o`0008Cooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0<oookJP00G?oonfX00ol0
003ooo]ZoookJP0eoookJPGo00000onIhOd3o`0000ooVN7m0ol0000>oiWQo@?o00001?nIhOd5o`00
00?oVN7m1?l0000=oiWQo@?o00003_nIhOd3o`0000CoVN7m0ol00003oiWQo@Co00003?nIhOd3o`00
00goVN7m0ol00003oiWQo@?o00001onIhOd3o`0000[oVN7m0ol0000<oiWQo@?o00000onIhOd3o`00
00KoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000WoVN7m0ol00003oiWQo@;o00001onIhOd3o`00
08Sooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]ZoookJP0<oookJP00GOoonfX00ol0003o
oo]ZoookJP0ioookJPCo00003_nIhOd3o`0000?oVN7m0ol00008oiWQo@?o00003?nIhOd3o`0000ko
VN7m0ol00003oiWQo@?o00002?nIhOd3o`0000[oVN7m0ol0000=oiWQo@?o00000onIhOd3o`0000Oo
VN7m0ol00009oiWQo@;o00000_nIhOd3o`0000[oVN7m0ol00003oiWQo@;o00001onIhOd3o`0000Wo
VN7m0_l000001?nIhOgo0000o`000?l0000;oiWQo@Go00002?nIhOd3o`0000SoVN7m0_l00002oiWQ
o@?o0000S?oonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z00_ooo]Z001NoookJP03
o`000?oonf[ooo]Z03cooo]Z0ol00008oiWQo@?o00002OnIhOd3o`0000;oVN7m0ol0000<oiWQo@?o
00000onIhOd3o`0000SoVN7m0ol00009oiWQo@?o00000_nIhOd3o`0000[oVN7m0ol00003oiWQo@?o
00001onIhOd3o`0000WoVN7m0ol000001?nIhOgo0000o`000?l0000<oiWQo@Go00002OnIhOd3o`00
00SoVN7m0_l00002oiWQo@?o00003?nIhOd5o`0000SoVN7m1?l00005oiWQo@?o00000_nIhOd3o`00
00_oVN7m1?l0002@oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX02ooonfX005oo
oo]Z0_l0000ooookJP?o00000_nIhOd3o`0000goVN7m1Ol0000;oiWQo@?o00002OnIhOd3o`0000;o
VN7m0ol0000=oiWQo@Go00002OnIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003OnIhOd5o`0000Wo
VN7m1?l00005oiWQo@?o00000onIhOd3o`0000_oVN7m1Ol0000:oiWQo@Co00001OnIhOd3o`0000;o
VN7m0ol0000:oiWQo@Go00002OnIhOd4o`0009Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003o
oo]ZoookJP0;oookJP00HOoonfX00ol0003ooo]ZoookJP0ooookJP?o00002onIhOd4o`0000GoVN7m
1Ol00003oiWQo@?o00003_nIhOd4o`0000_oVN7m1?l00005oiWQo@?o00000onIhOd3o`0000goVN7m
1?l0000;oiWQo@Co00001OnIhOd3o`0000?oVN7m0ol0000<oiWQo@Co00002OnIhOd4o`0000GoVN7m
0ol00003oiWQo@Co00002onIhOd4o`0000SoVN7m1?l00005oiWQo@?o00000_nIhOd4o`0009Wooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0;oookJP00H_oonfX00ol0003ooo]Zoook
JP11oookJPCo00000onIhOd4o`0000koVN7m0ol0000>oiWQo@?o00001?nIhOd4o`0000?oVN7m1?l0
000<oiWQo@?o00003OnIhOd3o`0000CoVN7m1?l00003oiWQo@Co00003?nIhOd3o`0000coVN7m0ol0
0004oiWQo@?o00000onIhOd3o`0000coVN7m0ol0000<oiWQo@?o00001?nIhOd3o`0000;oVN7m0ol0
000;oiWQo@?o0000W_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z00_ooo]Z001S
oookJP03o`000?oonf[ooo]Z04Cooo]Z1?l0000>oiWQo@?o00000onIhOd3o`0000SoVN7m0ol0000;
oiWQo@?o00003OnIhOd3o`0000?oVN7m0ol00007oiWQo@?o00002onIhOd3o`0000goVN7m0ol00003
oiWQo@;o00001onIhOd3o`0000[oVN7m0ol0000<oiWQo@?o00000onIhOd2o`0000OoVN7m0ol00009
oiWQo@?o00002onIhOd3o`000:;ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0;
oookJP00I?oonfX2o`0004Sooo]Z0ol00008oiWQo@?o00002OnIhOd3o`0000;oVN7m0ol0000;oiWQ
o@?o00000onIhOd3o`0000OoVN7m0ol00009oiWQo@?o000000CoVN7mo`000?l0003o00002onIhOd3
o`0000?oVN7m0ol00007oiWQo@?o00002?nIhOd2o`0000;oVN7m0ol0000:oiWQo@?o00000onIhOd2
o`0000OoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000WoVN7m0ol00003oiWQo@;o00001_nIhOd3
o`000:Gooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0;oookJP00I_oonfX00ol0
003ooo]ZoookJP18oookJP?o00000_nIhOd3o`0000goVN7m1Ol0000:oiWQo@?o00002OnIhOd2o`00
00;oVN7m0ol0000=oiWQo@Go00002OnIhOd3o`0000WoVN7m0_l00002oiWQo@?o00002onIhOd5o`00
00WoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000_oVN7m1Ol00008oiWQo@?o00002?nIhOd2o`00
0004oiWQoOl0003o0000o`000:Wooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0;
oookJP00IooonfX00ol0003ooo]ZoookJP1:oookJP?o00002onIhOd4o`0000GoVN7m1?l00003oiWQ
o@?o00003OnIhOd4o`0000_oVN7m1?l00005oiWQo@?o00000onIhOd3o`0000coVN7m1Ol00009oiWQ
o@Co00001OnIhOd3o`0000?oVN7m0ol0000;oiWQo@Go00002OnIhOd4o`0000GoVN7m0ol00002oiWQ
o@?o00002onIhOd3o`000:gooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0:oook
JP00J?oonfX00ol0003ooo]ZoookJP1<oookJPCo00000onIhOd4o`0000goVN7m0ol0000=oiWQo@?o
00001?nIhOd4o`0000?oVN7m1?l0000<oiWQo@Co00002_nIhOd4o`0000GoVN7m0ol00003oiWQo@?o
00003?nIhOd4o`0000WoVN7m1?l00005oiWQo@?o00000onIhOd3o`0000[oVN7m1Ol00009oiWQo@Co
0000/?oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z00[ooo]Z001YoookJP;o0000
D?oonfX3o`0000koVN7m0ol00003oiWQo@?o00001onIhOd3o`0000_oVN7m0ol0000=oiWQo@?o0000
1?nIhOd3o`0000?oVN7m1?l0000<oiWQo@?o00003?nIhOd3o`0000CoVN7m0ol00003oiWQo@?o0000
3?nIhOd4o`0000SoVN7m1?l00005oiWQo@?o00000_nIhOd4o`000;Gooo]Z00?o0000oookJ_oonfX0
6ooonfX00ol0003ooo]ZoookJP0:oookJP00JooonfX00ol0003ooo]ZoookJP1@oookJP?o00002?nI
hOd3o`0000WoVN7m0ol000001?nIhOgo0000o`000?l0000;oiWQo@?o00000onIhOd3o`0000OoVN7m
0ol0000:oiWQo@?o00003OnIhOd3o`0000?oVN7m0ol00006oiWQo@?o00002_nIhOd3o`0000coVN7m
0ol00004oiWQo@?o00000_nIhOd3o`0000_oVN7m0ol0002joookJP03o`000?oonf[ooo]Z01[ooo]Z
00?o0000oookJ_oonfX02_oonfX006cooo]Z00?o0000oookJ_oonfX0D_oonfX3o`0000;oVN7m0ol0
000=oiWQo@Go00002OnIhOd3o`0000WoVN7m0_l00002oiWQo@?o00002_nIhOd3o`0000?oVN7m0ol0
0007oiWQo@?o00002OnIhOd2o`000004oiWQoOl0003o0000o`0000[oVN7m0ol00003oiWQo@;o0000
1onIhOd3o`0000WoVN7m0ol0000;oiWQo@?o0000__oonfX00ol0003ooo]ZoookJP0IoookJP03o`00
0?oonf[ooo]Z00[ooo]Z001]oookJP03o`000?oonf[ooo]Z05Cooo]Z0ol0000;oiWQo@Co00001OnI
hOd3o`0000?oVN7m0ol0000<oiWQo@Go00002OnIhOd3o`0000WoVN7m0_l00002oiWQo@?o00003?nI
hOd5o`0000SoVN7m0ol00008oiWQo@;o00000_nIhOd3o`0000WoVN7m0ol00003oiWQo@;o00001_nI
hOd3o`000<7ooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0:oookJP00K_oonfX2
o`0005Oooo]Z1?l00003oiWQo@Co00003?nIhOd4o`0000[oVN7m1?l00005oiWQo@Co00000_nIhOd3
o`0000coVN7m1Ol0000:oiWQo@Co00001OnIhOd3o`0000;oVN7m0ol0000;oiWQo@Go00002?nIhOd3
o`0000SoVN7m0_l000001?nIhOgo0000o`000?l00035oookJP03o`000?oonf[ooo]Z01Sooo]Z00?o
0000oookJ_oonfX02_oonfX0073ooo]Z00?o0000oookJ_oonfX0F?oonfX3o`0000goVN7m0ol00004
oiWQo@Co00000onIhOd3o`0000goVN7m1?l00009oiWQo@Co00001OnIhOd3o`0000?oVN7m1?l0000:
oiWQo@Go00002OnIhOd4o`0000GoVN7m0ol00002oiWQo@?o00002onIhOd3o`000<Wooo]Z00?o0000
oookJ_oonfX06?oonfX00ol0003ooo]ZoookJP09oookJP00LOoonfX00ol0003ooo]ZoookJP1Joook
JP?o00001onIhOd3o`0000_oVN7m0ol0000=oiWQo@?o00001?nIhOd3o`0000?oVN7m0ol0000;oiWQ
o@Go00002OnIhOd4o`0000GoVN7m0ol00003oiWQo@?o00002_nIhOd5o`0000WoVN7m1?l0003=oook
JP03o`000?oonf[ooo]Z01Oooo]Z00?o0000oookJ_oonfX02OoonfX007;ooo]Z00?o0000oookJ_oo
nfX0G?oonfX3o`000004oiWQoOl0003o0000o`0000_oVN7m0ol00003oiWQo@?o00001onIhOd3o`00
00[oVN7m1?l00009oiWQo@Co00001OnIhOd3o`0000?oVN7m0ol0000;oiWQo@Go00002?nIhOd4o`00
00GoVN7m0ol00003oiWQo@?o0000dOoonfX00ol0003ooo]ZoookJP0GoookJP03o`000?oonf[ooo]Z
00Wooo]Z001coookJP03o`000?oonf[ooo]Z05kooo]Z0ol00009oiWQo@?o00002OnIhOd2o`0000;o
VN7m0ol0000:oiWQo@?o00001?nIhOd3o`0000?oVN7m0ol0000<oiWQo@Co00002OnIhOd4o`0000Go
VN7m0ol00002oiWQo@?o00002onIhOd4o`000=Gooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP09oookJP00M?oonfX2o`00067ooo]Z1?l00002oiWQo@?o00003?nIhOd5o`0000WoVN7m
0ol0000:oiWQo@?o00003?nIhOd3o`0000CoVN7m0ol00003oiWQo@?o00002onIhOd4o`0000WoVN7m
1?l0003JoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02OoonfX007Kooo]Z00?o
0000oookJ_oonfX0H_oonfX4o`0000WoVN7m1?l00005oiWQo@Co00000_nIhOd3o`0000[oVN7m0ol0
0003oiWQo@?o00001_nIhOd3o`0000[oVN7m0ol0000;oiWQo@?o00001?nIhOd3o`0000?oVN7m0ol0
003NoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX02OoonfX007Oooo]Z00?o0000
oookJ_oonfX0IOoonfX3o`0000?oVN7m0ol0000<oiWQo@Go00002?nIhOd3o`0000WoVN7m0_l00000
1?nIhOgo0000o`000?l0000:oiWQo@?o00000onIhOd2o`0000KoVN7m0ol0000:oiWQo@?o0000h_oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00Wooo]Z001hoookJP03o`000?oonf[o
oo]Z06Oooo]Z1?l0000:oiWQo@Co00001OnIhOd3o`0000;oVN7m0ol0000<oiWQo@Go00002?nIhOd3
o`0000SoVN7m0_l000001?nIhOgo0000o`000?l0000:oiWQo@?o0000i_oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z00Sooo]Z001ioookJP;o0000JooonfX3o`0000?oVN7m1?l0000;
oiWQo@Go00002OnIhOd4o`0000GoVN7m0ol00002oiWQo@?o00002onIhOd5o`0000SoVN7m0ol0003Z
oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oookJ_oonfX02?oonfX007_ooo]Z00?o0000oook
J_oonfX0JooonfX4o`0000[oVN7m1?l00005oiWQo@?o00000onIhOd3o`0000[oVN7m1Ol00009oiWQ
o@Co00001OnIhOd3o`0000;oVN7m0ol0003]oookJP03o`000?oonf[ooo]Z01?ooo]Z00?o0000oook
J_oonfX02?oonfX007cooo]Z00?o0000oookJ_oonfX0K_oonfX3o`0000?oVN7m1?l0000;oiWQo@Go
00002?nIhOd4o`0000GoVN7m0ol00003oiWQo@?o00002_nIhOd4o`000?7ooo]Z00?o0000oookJ_oo
nfX04_oonfX00ol0003ooo]ZoookJP08oookJP00OOoonfX00ol0003ooo]ZoookJP1`oookJPCo0000
2_nIhOd4o`0000GoVN7m0ol00002oiWQo@?o00002onIhOd5o`0000SoVN7m1?l0003foookJP03o`00
0?oonf[ooo]Z017ooo]Z00?o0000oookJ_oonfX02?oonfX007kooo]Z0_l0001doookJP?o00000onI
hOd4o`0000[oVN7m1Ol00009oiWQo@Co00001OnIhOd3o`0000;oVN7m0ol0003koookJP03o`000?oo
nf[ooo]Z013ooo]Z00?o0000oookJ_oonfX02?oonfX0083ooo]Z00?o0000oookJ_oonfX0M?oonfX4
o`0000WoVN7m1?l00005oiWQo@?o00000onIhOd3o`0000[oVN7m1?l0003noookJP03o`000?oonf[o
oo]Z013ooo]Z00?o0000oookJ_oonfX02?oonfX0087ooo]Z00?o0000oookJ_oonfX0MooonfX3o`00
00?oVN7m0ol0000;oiWQo@Go00002OnIhOd3o`000?oooo]Z1?oonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z00Oooo]Z0022oookJP03o`000?oonf[ooo]Z07Wooo]Z1?l00009oiWQo@Co
00001OnIhOd3o`0000?oVN7m0ol0003ooookJPSooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003o
oo]ZoookJP07oookJP00PooonfX2o`0007gooo]Z0ol00003oiWQo@?o00002onIhOd4o`000?oooo]Z
2ooonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z00Oooo]Z0025oookJP03o`000?oo
nf[ooo]Z07gooo]Z1?l00009oiWQo@Co0000oooonfX@oookJP03o`000?oonf[ooo]Z00kooo]Z00?o
0000oookJ_oonfX01ooonfX008Kooo]Z00?o0000oookJ_oonfX0P?oonfX3o`0000?oVN7m0ol0003o
oookJQGooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]ZoookJP07oookJP00QooonfX00ol0
003ooo]ZoookJP22oookJP?o0000oooonfXIoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oook
J_oonfX01ooonfX008Sooo]Z0_l00023oookJP03o`000?oonf[ooo]Z0?oooo]Z6?oonfX00ol0003o
oo]ZoookJP0<oookJP03o`000?oonf[ooo]Z00Oooo]Z002:oookJP03o`000?oonf[ooo]Z083ooo]Z
00?o0000oookJ_oonfX0oooonfXIoookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX0
1_oonfX008_ooo]Z00?o0000oookJ_oonfX0OooonfX00ol0003ooo]ZoookJP3ooookJQ[ooo]Z00?o
0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP06oookJP00S?oonfX00ol0003ooo]ZoookJP1n
oookJP03o`000?oonf[ooo]Z0?oooo]Z6ooonfX00ol0003ooo]ZoookJP0:oookJP03o`000?oonf[o
oo]Z00Kooo]Z002=oookJP;o0000O_oonfX00ol0003ooo]ZoookJP3ooookJQ_ooo]Z00?o0000oook
J_oonfX02_oonfX00ol0003ooo]ZoookJP06oookJP00SooonfX00ol0003ooo]ZoookJP1koookJP03
o`000?oonf[ooo]Z0?oooo]Z7?oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z00Ko
oo]Z002@oookJP03o`000?oonf[ooo]Z07[ooo]Z00?o0000oookJ_oonfX0oooonfXMoookJP03o`00
0?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX01_oonfX0097ooo]Z00?o0000oookJ_oonfX0NOoo
nfX00ol0003ooo]ZoookJP3ooookJQkooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]Zoook
JP06oookJP00T_oonfX2o`0007Wooo]Z00?o0000oookJ_oonfX0oooonfXNoookJP03o`000?oonf[o
oo]Z00Sooo]Z00?o0000oookJ_oonfX01OoonfX009Cooo]Z00?o0000oookJ_oonfX0M_oonfX00ol0
003ooo]ZoookJP3ooookJQoooo]Z00?o0000oookJ_oonfX01ooonfX00ol0003ooo]ZoookJP05oook
JP00UOoonfX00ol0003ooo]ZoookJP1eoookJP03o`000?oonf[ooo]Z0?oooo]Z8?oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00Gooo]Z002FoookJP03o`000?oonf[ooo]Z07?ooo]Z
00?o0000oookJ_oonfX0oooonfXQoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX0
1OoonfX009Oooo]Z00?o0000oookJ_oonfX0L_oonfX00ol0003ooo]ZoookJP3ooookJR;ooo]Z00?o
0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP05oookJP00V?oonfX2o`0007;ooo]Z00?o0000
oookJ_oonfX0oooonfXSoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX01OoonfX0
09[ooo]Z00?o0000oookJ_oonfX0KooonfX00ol0003ooo]ZoookJP3ooookJRCooo]Z00?o0000oook
J_oonfX00ooonfX00ol0003ooo]ZoookJP05oookJP00VooonfX00ol0003ooo]ZoookJP1^oookJP03
o`000?oonf[ooo]Z0?oooo]Z9?oonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z00Co
oo]Z002LoookJP03o`000?oonf[ooo]Z06gooo]Z00?o0000oookJ_oonfX0oooonfXUoookJP03o`00
0?oonf[ooo]Z00?ooo]Z00?o0000oookJ_oonfX01?oonfX009gooo]Z0_l0001]oookJP03o`000?oo
nf[ooo]Z0?oooo]Z9_oonfX00ol0003ooo]ZoookJP02oookJP03o`000?oonf[ooo]Z00Cooo]Z002O
oookJP03o`000?oonf[ooo]Z06[ooo]Z00?o0000oookJ_oonfX0oooonfXWoookJP05o`000?oonf[o
oo]ZoookJ_l000001_oonfX00:3ooo]Z00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP3o
oookJROooo]Z00Go0000oookJ_oonf[ooo]Zo`000006oookJP00XOoonfX00ol0003ooo]ZoookJP1X
oookJP03o`000?oonf[ooo]Z0?oooo]Z:?oonfX01?l0003ooo]ZoookJ_l00006oookJP00X_oonfX2
o`0006Sooo]Z00?o0000oookJ_oonfX0oooonfXYoookJP03o`000?oonf[o000000Kooo]Z002Toook
JP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0oooonfXYoookJP04o`000?oonf[ooo]Z
o`0000Gooo]Z002UoookJP03o`000?oonf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0oooonfXZoook
JP03o`000?oonf[o000000Gooo]Z002VoookJP03o`000?oonf[ooo]Z06?ooo]Z00?o0000oookJ_oo
nfX0oooonfX[oookJP;o00001OoonfX00:Oooo]Z0_l0001SoookJP03o`000?oonf[ooo]Z0?oooo]Z
:_oonfX3o`0000Gooo]Z002YoookJP03o`000?oonf[ooo]Z063ooo]Z00?o0000oookJ_oonfX0oooo
nfXVoookJPCo00002?oonfX00:[ooo]Z00?o0000oookJ_oonfX0GooonfX00ol0003ooo]ZoookJP3o
oookJR;ooo]Z1?l0000<oookJP00ZooonfX00ol0003ooo]ZoookJP1NoookJP03o`000?oonf[ooo]Z
0?oooo]Z7_oonfX4o`00013ooo]Z002/oookJP;o0000G_oonfX00ol0003ooo]ZoookJP3ooookJQ_o
oo]Z0ol0000DoookJP00[_oonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oonf[ooo]Z0?oooo]Z
5ooonfX4o`0001Oooo]Z002_oookJP03o`000?oonf[ooo]Z05[ooo]Z00?o0000oookJ_oonfX0oooo
nfXCoookJPCo00006ooonfX00;3ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP3o
oookJPoooo]Z1?l0000OoookJP00/OoonfX2o`0005Wooo]Z00?o0000oookJ_oonfX0oooonfX;oook
JPCo00008ooonfX00;?ooo]Z00?o0000oookJ_oonfX0E_oonfX00ol0003ooo]ZoookJP3ooookJPOo
oo]Z1?l0000WoookJP00]?oonfX00ol0003ooo]ZoookJP1EoookJP03o`000?oonf[ooo]Z0?oooo]Z
0ooonfX4o`0002_ooo]Z002eoookJP03o`000?oonf[ooo]Z05Cooo]Z00?o0000oookJ_oonfX0oooo
nfX3o`0002oooo]Z002foookJP03o`000?oonf[ooo]Z05?ooo]Z00?o0000oookJ_oonfX0nooonfX4
o`0003;ooo]Z002goookJP;o0000D_oonfX00ol0003ooo]ZoookJP3hoookJPCo0000=_oonfX00;Wo
oo]Z00?o0000oookJ_oonfX0CooonfX00ol0003ooo]ZoookJP3doookJPCo0000>_oonfX00;[ooo]Z
00?o0000oookJ_oonfX0C_oonfX00ol0003ooo]ZoookJP3`oookJPCo0000?_oonfX00;_ooo]Z00?o
0000oookJ_oonfX0COoonfX00ol0003ooo]ZoookJP3/oookJPCo0000@_oonfX00;cooo]Z0_l0001=
oookJP03o`000?oonf[ooo]Z0>Sooo]Z1?l00016oookJP00__oonfX00ol0003ooo]ZoookJP1:oook
JP03o`000?oonf[ooo]Z0>Gooo]Z0ol0001:oookJP00_ooonfX00ol0003ooo]ZoookJP19oookJP03
o`000?oonf[ooo]Z0>7ooo]Z1?l0001=oookJP00`?oonfX00ol0003ooo]ZoookJP18oookJP03o`00
0?oonf[ooo]Z0=gooo]Z1?l0001AoookJP00`OoonfX2o`0004Sooo]Z00?o0000oookJ_oonfX0fOoo
nfX4o`0005Gooo]Z0033oookJP03o`000?oonf[ooo]Z04Gooo]Z00?o0000oookJ_oonfX0eOoonfX4
o`0005Wooo]Z0034oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX0dOoonfX4o`00
05gooo]Z0035oookJP03o`000?oonf[ooo]Z04?ooo]Z00?o0000oookJ_oonfX0cOoonfX4o`00067o
oo]Z0036oookJP;o0000@ooonfX00ol0003ooo]ZoookJP3:oookJP?o0000IOoonfX00<Sooo]Z00?o
0000oookJ_oonfX0@?oonfX00ol0003ooo]ZoookJP36oookJPCo0000J?oonfX00<Wooo]Z00?o0000
oookJ_oonfX0?ooonfX00ol0003ooo]ZoookJP32oookJPCo0000K?oonfX00<[ooo]Z00?o0000oook
J_oonfX0?_oonfX00ol0003ooo]ZoookJP2noookJPCo0000L?oonfX00<_ooo]Z0_l0000noookJP03
o`000?oonf[ooo]Z0;[ooo]Z1?l0001doookJP00cOoonfX00ol0003ooo]ZoookJP0koookJP03o`00
0?oonf[ooo]Z0;Kooo]Z1?l0001hoookJP00c_oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oo
nf[ooo]Z0;;ooo]Z1?l0001loookJP00cooonfX00ol0003ooo]ZoookJP0ioookJP03o`000?oonf[o
oo]Z0:oooo]Z0ol00020oookJP00d?oonfX2o`0003Wooo]Z00?o0000oookJ_oonfX0ZooonfX4o`00
08?ooo]Z003BoookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oonfX0YooonfX4o`0008Oo
oo]Z003CoookJP03o`000?oonf[ooo]Z03Gooo]Z00?o0000oookJ_oonfX0XooonfX4o`0008_ooo]Z
003DoookJP03o`000?oonf[ooo]Z03Cooo]Z00?o0000oookJ_oonfX0WooonfX4o`0008oooo]Z003E
oookJP;o0000=?oonfX00ol0003ooo]ZoookJP2KoookJPCo0000TooonfX00=Oooo]Z00?o0000oook
J_oonfX0<OoonfX00ol0003ooo]ZoookJP2GoookJPCo0000UooonfX00=Sooo]Z00?o0000oookJ_oo
nfX0<?oonfX00ol0003ooo]ZoookJP2CoookJPCo0000VooonfX00=Wooo]Z00?o0000oookJ_oonfX0
;_oonfX00ol0003ooo]ZoookJP2AoookJP?o0000WooonfX00=[ooo]Z00?o0000oookJ_oonfX0;Ooo
nfX00ol0003ooo]ZoookJP2=oookJPCo0000X_oonfX00=_ooo]Z0_l0000]oookJP03o`000?oonf[o
oo]Z08Wooo]Z1?l0002VoookJP00gOoonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
08Gooo]Z1?l0002ZoookJP00g_oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z087o
oo]Z1?l0002^oookJP00gooonfX00ol0003ooo]ZoookJP0XoookJP03o`000?oonf[ooo]Z07gooo]Z
1?l0002boookJP00h?oonfX2o`0002Sooo]Z00?o0000oookJ_oonfX0NOoonfX4o`000;Kooo]Z003R
oookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0M_oonfX3o`000;[ooo]Z003Soook
JP03o`000?oonf[ooo]Z02Cooo]Z00?o0000oookJ_oonfX0L_oonfX4o`000;gooo]Z003ToookJP03
o`000?oonf[ooo]Z02?ooo]Z00?o0000oookJ_oonfX0K_oonfX4o`000<7ooo]Z003UoookJP;o0000
8ooonfX00ol0003ooo]ZoookJP1ZoookJPCo0000aOoonfX00>Oooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP1VoookJPCo0000bOoonfX00>Sooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP1RoookJPCo0000cOoonfX00>Wooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP1NoookJPCo0000dOoonfX00>[ooo]Z0_l0000NoookJP03o`000?oonf[ooo]Z05_o
oo]Z0ol0003EoookJP00k?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z05Oooo]Z
1?l0003HoookJP00kOoonfX00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z05?ooo]Z1?l0
003LoookJP00k_oonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z04oooo]Z1?l0003P
oookJP00kooonfX2o`0001Wooo]Z00?o0000oookJ_oonfX0BooonfX4o`000>Cooo]Z003aoookJP03
o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX0AooonfX4o`000>Sooo]Z003boookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX0@ooonfX4o`000>cooo]Z003coookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0@?oonfX3o`000?3ooo]Z003doookJP;o00005?oonfX0
0ol0003ooo]ZoookJP0loookJPCo0000looonfX00?Kooo]Z00?o0000oookJ_oonfX04OoonfX00ol0
003ooo]ZoookJP0hoookJPCo0000mooonfX00?Oooo]Z00?o0000oookJ_oonfX04?oonfX00ol0003o
oo]ZoookJP0doookJPCo0000nooonfX00?Sooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]Z
oookJP0`oookJPCo0000oooonfX00?Wooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Zoook
JP0/oookJPCo0000oooonfX4oookJP00n_oonfX2o`0000gooo]Z00?o0000oookJ_oonfX0:OoonfX4
o`000?oooo]Z2?oonfX00?cooo]Z00?o0000oookJ_oonfX02_oonfX00ol0003ooo]ZoookJP0Voook
JP?o0000oooonfX<oookJP00oOoonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z02;o
oo]Z1?l0003ooookJPoooo]Z003noookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX0
7_oonfX4o`000?oooo]Z4ooonfX00?oooo]Z0_l00008oookJP03o`000?oonf[ooo]Z01[ooo]Z1?l0
003ooookJQOooo]Z003ooookJP;ooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]ZoookJP0F
oookJPCo0000oooonfXKoookJP00oooonfX3oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oook
J_oonfX04_oonfX4o`000?oooo]Z7ooonfX00?oooo]Z1?oonfX00ol0003ooo]ZoookJP03oookJP03
o`000?oonf[ooo]Z00kooo]Z1?l0003ooookJR?ooo]Z003ooookJPGooo]Z0_l00003oookJP03o`00
0?oonf[ooo]Z00_ooo]Z0ol0003ooookJROooo]Z003ooookJPOooo]Z00Co0000oookJ_oonf[o0000
2OoonfX4o`000?oooo]Z:_oonfX00?oooo]Z2?oonfX00ol0003ooo]Zo`000005oookJPCo0000oooo
nfX^oookJP00oooonfX9oookJP;o000000?ooo]Zo`000?l000000_l0003ooookJS;ooo]Z003ooook
JP[ooo]Z0_l0003ooookJSKooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooo
nf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;o
oo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooook
J_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.121075, -0.011929, \
0.00188313, 0.00188313}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Plot the vector (d\[Tau],d\[CapitalTheta]) = d\[Tau](1, ",
  Cell[BoxData[
      \(d\[CapitalTheta]\/d\[Tau]\)]],
  ") at each point:",
  "\n",
  "We want to make a plot of",
  Cell[BoxData[
      \(d\[CapitalTheta]\/d\[Tau]\)]],
  "in the \[CapitalTheta]-\[Tau] plane. We can do so by plotting vectors of \
the form {d\[Tau], d\[CapitalTheta]} = d\[Tau]{1, ",
  Cell[BoxData[
      \(d\[CapitalTheta]\/d\[Tau]\)]],
  "} which will be proportional to the vector {1, 1-\[CapitalTheta]}. This is \
done as follows:"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input",
  CellTags->"mmtag:19:Graphics_Package__PlotVectorField[]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField[{1, 1 - \[CapitalTheta]}, {tau, \ 0, 
        4}, \ {\[CapitalTheta], \(-2\), 4}, Axes \[Rule] True, 
      AxesLabel \[Rule] {"\<\[Tau]\>", "\<\[CapitalTheta]\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.46687 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.232836 0.500597 0.232836 [
[.25665 .4881 -7 -20 ]
[.25665 .4881 7 0 ]
[.48948 .4881 -7 -20 ]
[.48948 .4881 7 0 ]
[.72232 .4881 -7 -20 ]
[.72232 .4881 7 0 ]
[.95515 .4881 -7 -20 ]
[.95515 .4881 7 0 ]
[1.025 .5006 0 -10 ]
[1.025 .5006 13.1875 10 ]
[.01131 .03493 -26.9375 -10 ]
[.01131 .03493 0 10 ]
[.01131 .26776 -26.9375 -10 ]
[.01131 .26776 0 10 ]
[.01131 .73343 -14 -10 ]
[.01131 .73343 0 10 ]
[.01131 .96627 -14 -10 ]
[.01131 .96627 0 10 ]
[.01131 1.19911 -14 -10 ]
[.01131 1.19911 0 10 ]
[.01131 1.43194 -14 -10 ]
[.01131 1.43194 0 10 ]
[.02381 1.49187 -8.5625 0 ]
[.02381 1.49187 8.5625 20 ]
[ 0 0 0 0 ]
[ 1 1.46687 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25665 .5006 m
.25665 .50685 L
s
gsave
.25665 .4881 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.48948 .5006 m
.48948 .50685 L
s
gsave
.48948 .4881 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.72232 .5006 m
.72232 .50685 L
s
gsave
.72232 .4881 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.95515 .5006 m
.95515 .50685 L
s
gsave
.95515 .4881 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.07038 .5006 m
.07038 .50435 L
s
.11694 .5006 m
.11694 .50435 L
s
.16351 .5006 m
.16351 .50435 L
s
.21008 .5006 m
.21008 .50435 L
s
.30321 .5006 m
.30321 .50435 L
s
.34978 .5006 m
.34978 .50435 L
s
.39635 .5006 m
.39635 .50435 L
s
.44291 .5006 m
.44291 .50435 L
s
.53605 .5006 m
.53605 .50435 L
s
.58262 .5006 m
.58262 .50435 L
s
.62918 .5006 m
.62918 .50435 L
s
.67575 .5006 m
.67575 .50435 L
s
.76888 .5006 m
.76888 .50435 L
s
.81545 .5006 m
.81545 .50435 L
s
.86202 .5006 m
.86202 .50435 L
s
.90859 .5006 m
.90859 .50435 L
s
.25 Mabswid
0 .5006 m
1 .5006 L
s
gsave
1.025 .5006 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
72.188 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03493 m
.03006 .03493 L
s
gsave
.01131 .03493 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .26776 m
.03006 .26776 L
s
gsave
.01131 .26776 -87.9375 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .73343 m
.03006 .73343 L
s
gsave
.01131 .73343 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .96627 m
.03006 .96627 L
s
gsave
.01131 .96627 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 1.19911 m
.03006 1.19911 L
s
gsave
.01131 1.19911 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.02381 1.43194 m
.03006 1.43194 L
s
gsave
.01131 1.43194 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .08149 m
.02756 .08149 L
s
.02381 .12806 m
.02756 .12806 L
s
.02381 .17463 m
.02756 .17463 L
s
.02381 .22119 m
.02756 .22119 L
s
.02381 .31433 m
.02756 .31433 L
s
.02381 .3609 m
.02756 .3609 L
s
.02381 .40746 m
.02756 .40746 L
s
.02381 .45403 m
.02756 .45403 L
s
.02381 .54716 m
.02756 .54716 L
s
.02381 .59373 m
.02756 .59373 L
s
.02381 .6403 m
.02756 .6403 L
s
.02381 .68687 m
.02756 .68687 L
s
.02381 .78 m
.02756 .78 L
s
.02381 .82657 m
.02756 .82657 L
s
.02381 .87314 m
.02756 .87314 L
s
.02381 .9197 m
.02756 .9197 L
s
.02381 1.01284 m
.02756 1.01284 L
s
.02381 1.0594 m
.02756 1.0594 L
s
.02381 1.10597 m
.02756 1.10597 L
s
.02381 1.15254 m
.02756 1.15254 L
s
.02381 1.24567 m
.02756 1.24567 L
s
.02381 1.29224 m
.02756 1.29224 L
s
.02381 1.33881 m
.02756 1.33881 L
s
.02381 1.38537 m
.02756 1.38537 L
s
.25 Mabswid
.02381 0 m
.02381 1.46687 L
s
gsave
.02381 1.49187 -69.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Q) show
76.125 19.000 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .03493 m
.04485 .09804 L
s
% Start of user PostScript
0. -2. 0.09035079 -1.7289476 MAarrowhead1
% End of user PostScript
.02381 .13471 m
.04485 .18881 L
s
% Start of user PostScript
0. -1.5714286 0.09035079 -1.339098 MAarrowhead1
% End of user PostScript
.02381 .2345 m
.04485 .27958 L
s
% Start of user PostScript
0. -1.1428571 0.09035079 -0.94924831 MAarrowhead1
% End of user PostScript
.02381 .33429 m
.04485 .37035 L
s
% Start of user PostScript
0. -0.71428571 0.09035079 -0.55939865 MAarrowhead1
% End of user PostScript
.02381 .43407 m
.04485 .46112 L
s
% Start of user PostScript
0. -0.28571429 0.09035079 -0.16954898 MAarrowhead1
% End of user PostScript
.02381 .53386 m
.04485 .55189 L
s
% Start of user PostScript
0. 0.14285714 0.09035079 0.22030068 MAarrowhead1
% End of user PostScript
.02381 .63365 m
.04485 .64266 L
s
% Start of user PostScript
0. 0.57142857 0.09035079 0.61015034 MAarrowhead1
% End of user PostScript
.02381 .73343 m
.04485 .73343 L
s
% Start of user PostScript
0. 1. 0.09035079 1. MAarrowhead1
% End of user PostScript
.02381 .83322 m
.04485 .8242 L
s
% Start of user PostScript
0. 1.4285714 0.09035079 1.3898497 MAarrowhead1
% End of user PostScript
.02381 .93301 m
.04485 .91498 L
s
% Start of user PostScript
0. 1.8571429 0.09035079 1.7796993 MAarrowhead1
% End of user PostScript
.02381 1.03279 m
.04485 1.00575 L
s
% Start of user PostScript
0. 2.2857143 0.09035079 2.169549 MAarrowhead1
% End of user PostScript
.02381 1.13258 m
.04485 1.09652 L
s
% Start of user PostScript
0. 2.7142857 0.09035079 2.5593986 MAarrowhead1
% End of user PostScript
.02381 1.23237 m
.04485 1.18729 L
s
% Start of user PostScript
0. 3.1428571 0.09035079 2.9492483 MAarrowhead1
% End of user PostScript
.02381 1.33215 m
.04485 1.27806 L
s
% Start of user PostScript
0. 3.5714286 0.09035079 3.339098 MAarrowhead1
% End of user PostScript
.02381 1.43194 m
.04485 1.36883 L
s
% Start of user PostScript
0. 4. 0.09035079 3.7289476 MAarrowhead1
% End of user PostScript
.09033 .03493 m
.11137 .09804 L
s
% Start of user PostScript
0.28571429 -2. 0.37606508 -1.7289476 MAarrowhead1
% End of user PostScript
.09033 .13471 m
.11137 .18881 L
s
% Start of user PostScript
0.28571429 -1.5714286 0.37606508 -1.339098 MAarrowhead1
% End of user PostScript
.09033 .2345 m
.11137 .27958 L
s
% Start of user PostScript
0.28571429 -1.1428571 0.37606508 -0.94924831 MAarrowhead1
% End of user PostScript
.09033 .33429 m
.11137 .37035 L
s
% Start of user PostScript
0.28571429 -0.71428571 0.37606508 -0.55939865 MAarrowhead1
% End of user PostScript
.09033 .43407 m
.11137 .46112 L
s
% Start of user PostScript
0.28571429 -0.28571429 0.37606508 -0.16954898 MAarrowhead1
% End of user PostScript
.09033 .53386 m
.11137 .55189 L
s
% Start of user PostScript
0.28571429 0.14285714 0.37606508 0.22030068 MAarrowhead1
% End of user PostScript
.09033 .63365 m
.11137 .64266 L
s
% Start of user PostScript
0.28571429 0.57142857 0.37606508 0.61015034 MAarrowhead1
% End of user PostScript
.09033 .73343 m
.11137 .73343 L
s
% Start of user PostScript
0.28571429 1. 0.37606508 1. MAarrowhead1
% End of user PostScript
.09033 .83322 m
.11137 .8242 L
s
% Start of user PostScript
0.28571429 1.4285714 0.37606508 1.3898497 MAarrowhead1
% End of user PostScript
.09033 .93301 m
.11137 .91498 L
s
% Start of user PostScript
0.28571429 1.8571429 0.37606508 1.7796993 MAarrowhead1
% End of user PostScript
.09033 1.03279 m
.11137 1.00575 L
s
% Start of user PostScript
0.28571429 2.2857143 0.37606508 2.169549 MAarrowhead1
% End of user PostScript
.09033 1.13258 m
.11137 1.09652 L
s
% Start of user PostScript
0.28571429 2.7142857 0.37606508 2.5593986 MAarrowhead1
% End of user PostScript
.09033 1.23237 m
.11137 1.18729 L
s
% Start of user PostScript
0.28571429 3.1428571 0.37606508 2.9492483 MAarrowhead1
% End of user PostScript
.09033 1.33215 m
.11137 1.27806 L
s
% Start of user PostScript
0.28571429 3.5714286 0.37606508 3.339098 MAarrowhead1
% End of user PostScript
.09033 1.43194 m
.11137 1.36883 L
s
% Start of user PostScript
0.28571429 4. 0.37606508 3.7289476 MAarrowhead1
% End of user PostScript
.15686 .03493 m
.1779 .09804 L
s
% Start of user PostScript
0.57142857 -2. 0.66177936 -1.7289476 MAarrowhead1
% End of user PostScript
.15686 .13471 m
.1779 .18881 L
s
% Start of user PostScript
0.57142857 -1.5714286 0.66177936 -1.339098 MAarrowhead1
% End of user PostScript
.15686 .2345 m
.1779 .27958 L
s
% Start of user PostScript
0.57142857 -1.1428571 0.66177936 -0.94924831 MAarrowhead1
% End of user PostScript
.15686 .33429 m
.1779 .37035 L
s
% Start of user PostScript
0.57142857 -0.71428571 0.66177936 -0.55939865 MAarrowhead1
% End of user PostScript
.15686 .43407 m
.1779 .46112 L
s
% Start of user PostScript
0.57142857 -0.28571429 0.66177936 -0.16954898 MAarrowhead1
% End of user PostScript
.15686 .53386 m
.1779 .55189 L
s
% Start of user PostScript
0.57142857 0.14285714 0.66177936 0.22030068 MAarrowhead1
% End of user PostScript
.15686 .63365 m
.1779 .64266 L
s
% Start of user PostScript
0.57142857 0.57142857 0.66177936 0.61015034 MAarrowhead1
% End of user PostScript
.15686 .73343 m
.1779 .73343 L
s
% Start of user PostScript
0.57142857 1. 0.66177936 1. MAarrowhead1
% End of user PostScript
.15686 .83322 m
.1779 .8242 L
s
% Start of user PostScript
0.57142857 1.4285714 0.66177936 1.3898497 MAarrowhead1
% End of user PostScript
.15686 .93301 m
.1779 .91498 L
s
% Start of user PostScript
0.57142857 1.8571429 0.66177936 1.7796993 MAarrowhead1
% End of user PostScript
.15686 1.03279 m
.1779 1.00575 L
s
% Start of user PostScript
0.57142857 2.2857143 0.66177936 2.169549 MAarrowhead1
% End of user PostScript
.15686 1.13258 m
.1779 1.09652 L
s
% Start of user PostScript
0.57142857 2.7142857 0.66177936 2.5593986 MAarrowhead1
% End of user PostScript
.15686 1.23237 m
.1779 1.18729 L
s
% Start of user PostScript
0.57142857 3.1428571 0.66177936 2.9492483 MAarrowhead1
% End of user PostScript
.15686 1.33215 m
.1779 1.27806 L
s
% Start of user PostScript
0.57142857 3.5714286 0.66177936 3.339098 MAarrowhead1
% End of user PostScript
.15686 1.43194 m
.1779 1.36883 L
s
% Start of user PostScript
0.57142857 4. 0.66177936 3.7289476 MAarrowhead1
% End of user PostScript
.22338 .03493 m
.24442 .09804 L
s
% Start of user PostScript
0.85714286 -2. 0.94749365 -1.7289476 MAarrowhead1
% End of user PostScript
.22338 .13471 m
.24442 .18881 L
s
% Start of user PostScript
0.85714286 -1.5714286 0.94749365 -1.339098 MAarrowhead1
% End of user PostScript
.22338 .2345 m
.24442 .27958 L
s
% Start of user PostScript
0.85714286 -1.1428571 0.94749365 -0.94924831 MAarrowhead1
% End of user PostScript
.22338 .33429 m
.24442 .37035 L
s
% Start of user PostScript
0.85714286 -0.71428571 0.94749365 -0.55939865 MAarrowhead1
% End of user PostScript
.22338 .43407 m
.24442 .46112 L
s
% Start of user PostScript
0.85714286 -0.28571429 0.94749365 -0.16954898 MAarrowhead1
% End of user PostScript
.22338 .53386 m
.24442 .55189 L
s
% Start of user PostScript
0.85714286 0.14285714 0.94749365 0.22030068 MAarrowhead1
% End of user PostScript
.22338 .63365 m
.24442 .64266 L
s
% Start of user PostScript
0.85714286 0.57142857 0.94749365 0.61015034 MAarrowhead1
% End of user PostScript
.22338 .73343 m
.24442 .73343 L
s
% Start of user PostScript
0.85714286 1. 0.94749365 1. MAarrowhead1
% End of user PostScript
.22338 .83322 m
.24442 .8242 L
s
% Start of user PostScript
0.85714286 1.4285714 0.94749365 1.3898497 MAarrowhead1
% End of user PostScript
.22338 .93301 m
.24442 .91498 L
s
% Start of user PostScript
0.85714286 1.8571429 0.94749365 1.7796993 MAarrowhead1
% End of user PostScript
.22338 1.03279 m
.24442 1.00575 L
s
% Start of user PostScript
0.85714286 2.2857143 0.94749365 2.169549 MAarrowhead1
% End of user PostScript
.22338 1.13258 m
.24442 1.09652 L
s
% Start of user PostScript
0.85714286 2.7142857 0.94749365 2.5593986 MAarrowhead1
% End of user PostScript
.22338 1.23237 m
.24442 1.18729 L
s
% Start of user PostScript
0.85714286 3.1428571 0.94749365 2.9492483 MAarrowhead1
% End of user PostScript
.22338 1.33215 m
.24442 1.27806 L
s
% Start of user PostScript
0.85714286 3.5714286 0.94749365 3.339098 MAarrowhead1
% End of user PostScript
.22338 1.43194 m
.24442 1.36883 L
s
% Start of user PostScript
0.85714286 4. 0.94749365 3.7289476 MAarrowhead1
% End of user PostScript
.28991 .03493 m
.31094 .09804 L
s
% Start of user PostScript
1.1428571 -2. 1.2332079 -1.7289476 MAarrowhead1
% End of user PostScript
.28991 .13471 m
.31094 .18881 L
s
% Start of user PostScript
1.1428571 -1.5714286 1.2332079 -1.339098 MAarrowhead1
% End of user PostScript
.28991 .2345 m
.31094 .27958 L
s
% Start of user PostScript
1.1428571 -1.1428571 1.2332079 -0.94924831 MAarrowhead1
% End of user PostScript
.28991 .33429 m
.31094 .37035 L
s
% Start of user PostScript
1.1428571 -0.71428571 1.2332079 -0.55939865 MAarrowhead1
% End of user PostScript
.28991 .43407 m
.31094 .46112 L
s
% Start of user PostScript
1.1428571 -0.28571429 1.2332079 -0.16954898 MAarrowhead1
% End of user PostScript
.28991 .53386 m
.31094 .55189 L
s
% Start of user PostScript
1.1428571 0.14285714 1.2332079 0.22030068 MAarrowhead1
% End of user PostScript
.28991 .63365 m
.31094 .64266 L
s
% Start of user PostScript
1.1428571 0.57142857 1.2332079 0.61015034 MAarrowhead1
% End of user PostScript
.28991 .73343 m
.31094 .73343 L
s
% Start of user PostScript
1.1428571 1. 1.2332079 1. MAarrowhead1
% End of user PostScript
.28991 .83322 m
.31094 .8242 L
s
% Start of user PostScript
1.1428571 1.4285714 1.2332079 1.3898497 MAarrowhead1
% End of user PostScript
.28991 .93301 m
.31094 .91498 L
s
% Start of user PostScript
1.1428571 1.8571429 1.2332079 1.7796993 MAarrowhead1
% End of user PostScript
.28991 1.03279 m
.31094 1.00575 L
s
% Start of user PostScript
1.1428571 2.2857143 1.2332079 2.169549 MAarrowhead1
% End of user PostScript
.28991 1.13258 m
.31094 1.09652 L
s
% Start of user PostScript
1.1428571 2.7142857 1.2332079 2.5593986 MAarrowhead1
% End of user PostScript
.28991 1.23237 m
.31094 1.18729 L
s
% Start of user PostScript
1.1428571 3.1428571 1.2332079 2.9492483 MAarrowhead1
% End of user PostScript
.28991 1.33215 m
.31094 1.27806 L
s
% Start of user PostScript
1.1428571 3.5714286 1.2332079 3.339098 MAarrowhead1
% End of user PostScript
.28991 1.43194 m
.31094 1.36883 L
s
% Start of user PostScript
1.1428571 4. 1.2332079 3.7289476 MAarrowhead1
% End of user PostScript
.35643 .03493 m
.37747 .09804 L
s
% Start of user PostScript
1.4285714 -2. 1.5189222 -1.7289476 MAarrowhead1
% End of user PostScript
.35643 .13471 m
.37747 .18881 L
s
% Start of user PostScript
1.4285714 -1.5714286 1.5189222 -1.339098 MAarrowhead1
% End of user PostScript
.35643 .2345 m
.37747 .27958 L
s
% Start of user PostScript
1.4285714 -1.1428571 1.5189222 -0.94924831 MAarrowhead1
% End of user PostScript
.35643 .33429 m
.37747 .37035 L
s
% Start of user PostScript
1.4285714 -0.71428571 1.5189222 -0.55939865 MAarrowhead1
% End of user PostScript
.35643 .43407 m
.37747 .46112 L
s
% Start of user PostScript
1.4285714 -0.28571429 1.5189222 -0.16954898 MAarrowhead1
% End of user PostScript
.35643 .53386 m
.37747 .55189 L
s
% Start of user PostScript
1.4285714 0.14285714 1.5189222 0.22030068 MAarrowhead1
% End of user PostScript
.35643 .63365 m
.37747 .64266 L
s
% Start of user PostScript
1.4285714 0.57142857 1.5189222 0.61015034 MAarrowhead1
% End of user PostScript
.35643 .73343 m
.37747 .73343 L
s
% Start of user PostScript
1.4285714 1. 1.5189222 1. MAarrowhead1
% End of user PostScript
.35643 .83322 m
.37747 .8242 L
s
% Start of user PostScript
1.4285714 1.4285714 1.5189222 1.3898497 MAarrowhead1
% End of user PostScript
.35643 .93301 m
.37747 .91498 L
s
% Start of user PostScript
1.4285714 1.8571429 1.5189222 1.7796993 MAarrowhead1
% End of user PostScript
.35643 1.03279 m
.37747 1.00575 L
s
% Start of user PostScript
1.4285714 2.2857143 1.5189222 2.169549 MAarrowhead1
% End of user PostScript
.35643 1.13258 m
.37747 1.09652 L
s
% Start of user PostScript
1.4285714 2.7142857 1.5189222 2.5593986 MAarrowhead1
% End of user PostScript
.35643 1.23237 m
.37747 1.18729 L
s
% Start of user PostScript
1.4285714 3.1428571 1.5189222 2.9492483 MAarrowhead1
% End of user PostScript
.35643 1.33215 m
.37747 1.27806 L
s
% Start of user PostScript
1.4285714 3.5714286 1.5189222 3.339098 MAarrowhead1
% End of user PostScript
.35643 1.43194 m
.37747 1.36883 L
s
% Start of user PostScript
1.4285714 4. 1.5189222 3.7289476 MAarrowhead1
% End of user PostScript
.42296 .03493 m
.44399 .09804 L
s
% Start of user PostScript
1.7142857 -2. 1.8046365 -1.7289476 MAarrowhead1
% End of user PostScript
.42296 .13471 m
.44399 .18881 L
s
% Start of user PostScript
1.7142857 -1.5714286 1.8046365 -1.339098 MAarrowhead1
% End of user PostScript
.42296 .2345 m
.44399 .27958 L
s
% Start of user PostScript
1.7142857 -1.1428571 1.8046365 -0.94924831 MAarrowhead1
% End of user PostScript
.42296 .33429 m
.44399 .37035 L
s
% Start of user PostScript
1.7142857 -0.71428571 1.8046365 -0.55939865 MAarrowhead1
% End of user PostScript
.42296 .43407 m
.44399 .46112 L
s
% Start of user PostScript
1.7142857 -0.28571429 1.8046365 -0.16954898 MAarrowhead1
% End of user PostScript
.42296 .53386 m
.44399 .55189 L
s
% Start of user PostScript
1.7142857 0.14285714 1.8046365 0.22030068 MAarrowhead1
% End of user PostScript
.42296 .63365 m
.44399 .64266 L
s
% Start of user PostScript
1.7142857 0.57142857 1.8046365 0.61015034 MAarrowhead1
% End of user PostScript
.42296 .73343 m
.44399 .73343 L
s
% Start of user PostScript
1.7142857 1. 1.8046365 1. MAarrowhead1
% End of user PostScript
.42296 .83322 m
.44399 .8242 L
s
% Start of user PostScript
1.7142857 1.4285714 1.8046365 1.3898497 MAarrowhead1
% End of user PostScript
.42296 .93301 m
.44399 .91498 L
s
% Start of user PostScript
1.7142857 1.8571429 1.8046365 1.7796993 MAarrowhead1
% End of user PostScript
.42296 1.03279 m
.44399 1.00575 L
s
% Start of user PostScript
1.7142857 2.2857143 1.8046365 2.169549 MAarrowhead1
% End of user PostScript
.42296 1.13258 m
.44399 1.09652 L
s
% Start of user PostScript
1.7142857 2.7142857 1.8046365 2.5593986 MAarrowhead1
% End of user PostScript
.42296 1.23237 m
.44399 1.18729 L
s
% Start of user PostScript
1.7142857 3.1428571 1.8046365 2.9492483 MAarrowhead1
% End of user PostScript
.42296 1.33215 m
.44399 1.27806 L
s
% Start of user PostScript
1.7142857 3.5714286 1.8046365 3.339098 MAarrowhead1
% End of user PostScript
.42296 1.43194 m
.44399 1.36883 L
s
% Start of user PostScript
1.7142857 4. 1.8046365 3.7289476 MAarrowhead1
% End of user PostScript
.48948 .03493 m
.51052 .09804 L
s
% Start of user PostScript
2. -2. 2.0903508 -1.7289476 MAarrowhead1
% End of user PostScript
.48948 .13471 m
.51052 .18881 L
s
% Start of user PostScript
2. -1.5714286 2.0903508 -1.339098 MAarrowhead1
% End of user PostScript
.48948 .2345 m
.51052 .27958 L
s
% Start of user PostScript
2. -1.1428571 2.0903508 -0.94924831 MAarrowhead1
% End of user PostScript
.48948 .33429 m
.51052 .37035 L
s
% Start of user PostScript
2. -0.71428571 2.0903508 -0.55939865 MAarrowhead1
% End of user PostScript
.48948 .43407 m
.51052 .46112 L
s
% Start of user PostScript
2. -0.28571429 2.0903508 -0.16954898 MAarrowhead1
% End of user PostScript
.48948 .53386 m
.51052 .55189 L
s
% Start of user PostScript
2. 0.14285714 2.0903508 0.22030068 MAarrowhead1
% End of user PostScript
.48948 .63365 m
.51052 .64266 L
s
% Start of user PostScript
2. 0.57142857 2.0903508 0.61015034 MAarrowhead1
% End of user PostScript
.48948 .73343 m
.51052 .73343 L
s
% Start of user PostScript
2. 1. 2.0903508 1. MAarrowhead1
% End of user PostScript
.48948 .83322 m
.51052 .8242 L
s
% Start of user PostScript
2. 1.4285714 2.0903508 1.3898497 MAarrowhead1
% End of user PostScript
.48948 .93301 m
.51052 .91498 L
s
% Start of user PostScript
2. 1.8571429 2.0903508 1.7796993 MAarrowhead1
% End of user PostScript
.48948 1.03279 m
.51052 1.00575 L
s
% Start of user PostScript
2. 2.2857143 2.0903508 2.169549 MAarrowhead1
% End of user PostScript
.48948 1.13258 m
.51052 1.09652 L
s
% Start of user PostScript
2. 2.7142857 2.0903508 2.5593986 MAarrowhead1
% End of user PostScript
.48948 1.23237 m
.51052 1.18729 L
s
% Start of user PostScript
2. 3.1428571 2.0903508 2.9492483 MAarrowhead1
% End of user PostScript
.48948 1.33215 m
.51052 1.27806 L
s
% Start of user PostScript
2. 3.5714286 2.0903508 3.339098 MAarrowhead1
% End of user PostScript
.48948 1.43194 m
.51052 1.36883 L
s
% Start of user PostScript
2. 4. 2.0903508 3.7289476 MAarrowhead1
% End of user PostScript
.55601 .03493 m
.57704 .09804 L
s
% Start of user PostScript
2.2857143 -2. 2.3760651 -1.7289476 MAarrowhead1
% End of user PostScript
.55601 .13471 m
.57704 .18881 L
s
% Start of user PostScript
2.2857143 -1.5714286 2.3760651 -1.339098 MAarrowhead1
% End of user PostScript
.55601 .2345 m
.57704 .27958 L
s
% Start of user PostScript
2.2857143 -1.1428571 2.3760651 -0.94924831 MAarrowhead1
% End of user PostScript
.55601 .33429 m
.57704 .37035 L
s
% Start of user PostScript
2.2857143 -0.71428571 2.3760651 -0.55939865 MAarrowhead1
% End of user PostScript
.55601 .43407 m
.57704 .46112 L
s
% Start of user PostScript
2.2857143 -0.28571429 2.3760651 -0.16954898 MAarrowhead1
% End of user PostScript
.55601 .53386 m
.57704 .55189 L
s
% Start of user PostScript
2.2857143 0.14285714 2.3760651 0.22030068 MAarrowhead1
% End of user PostScript
.55601 .63365 m
.57704 .64266 L
s
% Start of user PostScript
2.2857143 0.57142857 2.3760651 0.61015034 MAarrowhead1
% End of user PostScript
.55601 .73343 m
.57704 .73343 L
s
% Start of user PostScript
2.2857143 1. 2.3760651 1. MAarrowhead1
% End of user PostScript
.55601 .83322 m
.57704 .8242 L
s
% Start of user PostScript
2.2857143 1.4285714 2.3760651 1.3898497 MAarrowhead1
% End of user PostScript
.55601 .93301 m
.57704 .91498 L
s
% Start of user PostScript
2.2857143 1.8571429 2.3760651 1.7796993 MAarrowhead1
% End of user PostScript
.55601 1.03279 m
.57704 1.00575 L
s
% Start of user PostScript
2.2857143 2.2857143 2.3760651 2.169549 MAarrowhead1
% End of user PostScript
.55601 1.13258 m
.57704 1.09652 L
s
% Start of user PostScript
2.2857143 2.7142857 2.3760651 2.5593986 MAarrowhead1
% End of user PostScript
.55601 1.23237 m
.57704 1.18729 L
s
% Start of user PostScript
2.2857143 3.1428571 2.3760651 2.9492483 MAarrowhead1
% End of user PostScript
.55601 1.33215 m
.57704 1.27806 L
s
% Start of user PostScript
2.2857143 3.5714286 2.3760651 3.339098 MAarrowhead1
% End of user PostScript
.55601 1.43194 m
.57704 1.36883 L
s
% Start of user PostScript
2.2857143 4. 2.3760651 3.7289476 MAarrowhead1
% End of user PostScript
.62253 .03493 m
.64357 .09804 L
s
% Start of user PostScript
2.5714286 -2. 2.6617794 -1.7289476 MAarrowhead1
% End of user PostScript
.62253 .13471 m
.64357 .18881 L
s
% Start of user PostScript
2.5714286 -1.5714286 2.6617794 -1.339098 MAarrowhead1
% End of user PostScript
.62253 .2345 m
.64357 .27958 L
s
% Start of user PostScript
2.5714286 -1.1428571 2.6617794 -0.94924831 MAarrowhead1
% End of user PostScript
.62253 .33429 m
.64357 .37035 L
s
% Start of user PostScript
2.5714286 -0.71428571 2.6617794 -0.55939865 MAarrowhead1
% End of user PostScript
.62253 .43407 m
.64357 .46112 L
s
% Start of user PostScript
2.5714286 -0.28571429 2.6617794 -0.16954898 MAarrowhead1
% End of user PostScript
.62253 .53386 m
.64357 .55189 L
s
% Start of user PostScript
2.5714286 0.14285714 2.6617794 0.22030068 MAarrowhead1
% End of user PostScript
.62253 .63365 m
.64357 .64266 L
s
% Start of user PostScript
2.5714286 0.57142857 2.6617794 0.61015034 MAarrowhead1
% End of user PostScript
.62253 .73343 m
.64357 .73343 L
s
% Start of user PostScript
2.5714286 1. 2.6617794 1. MAarrowhead1
% End of user PostScript
.62253 .83322 m
.64357 .8242 L
s
% Start of user PostScript
2.5714286 1.4285714 2.6617794 1.3898497 MAarrowhead1
% End of user PostScript
.62253 .93301 m
.64357 .91498 L
s
% Start of user PostScript
2.5714286 1.8571429 2.6617794 1.7796993 MAarrowhead1
% End of user PostScript
.62253 1.03279 m
.64357 1.00575 L
s
% Start of user PostScript
2.5714286 2.2857143 2.6617794 2.169549 MAarrowhead1
% End of user PostScript
.62253 1.13258 m
.64357 1.09652 L
s
% Start of user PostScript
2.5714286 2.7142857 2.6617794 2.5593986 MAarrowhead1
% End of user PostScript
.62253 1.23237 m
.64357 1.18729 L
s
% Start of user PostScript
2.5714286 3.1428571 2.6617794 2.9492483 MAarrowhead1
% End of user PostScript
.62253 1.33215 m
.64357 1.27806 L
s
% Start of user PostScript
2.5714286 3.5714286 2.6617794 3.339098 MAarrowhead1
% End of user PostScript
.62253 1.43194 m
.64357 1.36883 L
s
% Start of user PostScript
2.5714286 4. 2.6617794 3.7289476 MAarrowhead1
% End of user PostScript
.68906 .03493 m
.71009 .09804 L
s
% Start of user PostScript
2.8571429 -2. 2.9474936 -1.7289476 MAarrowhead1
% End of user PostScript
.68906 .13471 m
.71009 .18881 L
s
% Start of user PostScript
2.8571429 -1.5714286 2.9474936 -1.339098 MAarrowhead1
% End of user PostScript
.68906 .2345 m
.71009 .27958 L
s
% Start of user PostScript
2.8571429 -1.1428571 2.9474936 -0.94924831 MAarrowhead1
% End of user PostScript
.68906 .33429 m
.71009 .37035 L
s
% Start of user PostScript
2.8571429 -0.71428571 2.9474936 -0.55939865 MAarrowhead1
% End of user PostScript
.68906 .43407 m
.71009 .46112 L
s
% Start of user PostScript
2.8571429 -0.28571429 2.9474936 -0.16954898 MAarrowhead1
% End of user PostScript
.68906 .53386 m
.71009 .55189 L
s
% Start of user PostScript
2.8571429 0.14285714 2.9474936 0.22030068 MAarrowhead1
% End of user PostScript
.68906 .63365 m
.71009 .64266 L
s
% Start of user PostScript
2.8571429 0.57142857 2.9474936 0.61015034 MAarrowhead1
% End of user PostScript
.68906 .73343 m
.71009 .73343 L
s
% Start of user PostScript
2.8571429 1. 2.9474936 1. MAarrowhead1
% End of user PostScript
.68906 .83322 m
.71009 .8242 L
s
% Start of user PostScript
2.8571429 1.4285714 2.9474936 1.3898497 MAarrowhead1
% End of user PostScript
.68906 .93301 m
.71009 .91498 L
s
% Start of user PostScript
2.8571429 1.8571429 2.9474936 1.7796993 MAarrowhead1
% End of user PostScript
.68906 1.03279 m
.71009 1.00575 L
s
% Start of user PostScript
2.8571429 2.2857143 2.9474936 2.169549 MAarrowhead1
% End of user PostScript
.68906 1.13258 m
.71009 1.09652 L
s
% Start of user PostScript
2.8571429 2.7142857 2.9474936 2.5593986 MAarrowhead1
% End of user PostScript
.68906 1.23237 m
.71009 1.18729 L
s
% Start of user PostScript
2.8571429 3.1428571 2.9474936 2.9492483 MAarrowhead1
% End of user PostScript
.68906 1.33215 m
.71009 1.27806 L
s
% Start of user PostScript
2.8571429 3.5714286 2.9474936 3.339098 MAarrowhead1
% End of user PostScript
.68906 1.43194 m
.71009 1.36883 L
s
% Start of user PostScript
2.8571429 4. 2.9474936 3.7289476 MAarrowhead1
% End of user PostScript
.75558 .03493 m
.77662 .09804 L
s
% Start of user PostScript
3.1428571 -2. 3.2332079 -1.7289476 MAarrowhead1
% End of user PostScript
.75558 .13471 m
.77662 .18881 L
s
% Start of user PostScript
3.1428571 -1.5714286 3.2332079 -1.339098 MAarrowhead1
% End of user PostScript
.75558 .2345 m
.77662 .27958 L
s
% Start of user PostScript
3.1428571 -1.1428571 3.2332079 -0.94924831 MAarrowhead1
% End of user PostScript
.75558 .33429 m
.77662 .37035 L
s
% Start of user PostScript
3.1428571 -0.71428571 3.2332079 -0.55939865 MAarrowhead1
% End of user PostScript
.75558 .43407 m
.77662 .46112 L
s
% Start of user PostScript
3.1428571 -0.28571429 3.2332079 -0.16954898 MAarrowhead1
% End of user PostScript
.75558 .53386 m
.77662 .55189 L
s
% Start of user PostScript
3.1428571 0.14285714 3.2332079 0.22030068 MAarrowhead1
% End of user PostScript
.75558 .63365 m
.77662 .64266 L
s
% Start of user PostScript
3.1428571 0.57142857 3.2332079 0.61015034 MAarrowhead1
% End of user PostScript
.75558 .73343 m
.77662 .73343 L
s
% Start of user PostScript
3.1428571 1. 3.2332079 1. MAarrowhead1
% End of user PostScript
.75558 .83322 m
.77662 .8242 L
s
% Start of user PostScript
3.1428571 1.4285714 3.2332079 1.3898497 MAarrowhead1
% End of user PostScript
.75558 .93301 m
.77662 .91498 L
s
% Start of user PostScript
3.1428571 1.8571429 3.2332079 1.7796993 MAarrowhead1
% End of user PostScript
.75558 1.03279 m
.77662 1.00575 L
s
% Start of user PostScript
3.1428571 2.2857143 3.2332079 2.169549 MAarrowhead1
% End of user PostScript
.75558 1.13258 m
.77662 1.09652 L
s
% Start of user PostScript
3.1428571 2.7142857 3.2332079 2.5593986 MAarrowhead1
% End of user PostScript
.75558 1.23237 m
.77662 1.18729 L
s
% Start of user PostScript
3.1428571 3.1428571 3.2332079 2.9492483 MAarrowhead1
% End of user PostScript
.75558 1.33215 m
.77662 1.27806 L
s
% Start of user PostScript
3.1428571 3.5714286 3.2332079 3.339098 MAarrowhead1
% End of user PostScript
.75558 1.43194 m
.77662 1.36883 L
s
% Start of user PostScript
3.1428571 4. 3.2332079 3.7289476 MAarrowhead1
% End of user PostScript
.8221 .03493 m
.84314 .09804 L
s
% Start of user PostScript
3.4285714 -2. 3.5189222 -1.7289476 MAarrowhead1
% End of user PostScript
.8221 .13471 m
.84314 .18881 L
s
% Start of user PostScript
3.4285714 -1.5714286 3.5189222 -1.339098 MAarrowhead1
% End of user PostScript
.8221 .2345 m
.84314 .27958 L
s
% Start of user PostScript
3.4285714 -1.1428571 3.5189222 -0.94924831 MAarrowhead1
% End of user PostScript
.8221 .33429 m
.84314 .37035 L
s
% Start of user PostScript
3.4285714 -0.71428571 3.5189222 -0.55939865 MAarrowhead1
% End of user PostScript
.8221 .43407 m
.84314 .46112 L
s
% Start of user PostScript
3.4285714 -0.28571429 3.5189222 -0.16954898 MAarrowhead1
% End of user PostScript
.8221 .53386 m
.84314 .55189 L
s
% Start of user PostScript
3.4285714 0.14285714 3.5189222 0.22030068 MAarrowhead1
% End of user PostScript
.8221 .63365 m
.84314 .64266 L
s
% Start of user PostScript
3.4285714 0.57142857 3.5189222 0.61015034 MAarrowhead1
% End of user PostScript
.8221 .73343 m
.84314 .73343 L
s
% Start of user PostScript
3.4285714 1. 3.5189222 1. MAarrowhead1
% End of user PostScript
.8221 .83322 m
.84314 .8242 L
s
% Start of user PostScript
3.4285714 1.4285714 3.5189222 1.3898497 MAarrowhead1
% End of user PostScript
.8221 .93301 m
.84314 .91498 L
s
% Start of user PostScript
3.4285714 1.8571429 3.5189222 1.7796993 MAarrowhead1
% End of user PostScript
.8221 1.03279 m
.84314 1.00575 L
s
% Start of user PostScript
3.4285714 2.2857143 3.5189222 2.169549 MAarrowhead1
% End of user PostScript
.8221 1.13258 m
.84314 1.09652 L
s
% Start of user PostScript
3.4285714 2.7142857 3.5189222 2.5593986 MAarrowhead1
% End of user PostScript
.8221 1.23237 m
.84314 1.18729 L
s
% Start of user PostScript
3.4285714 3.1428571 3.5189222 2.9492483 MAarrowhead1
% End of user PostScript
.8221 1.33215 m
.84314 1.27806 L
s
% Start of user PostScript
3.4285714 3.5714286 3.5189222 3.339098 MAarrowhead1
% End of user PostScript
.8221 1.43194 m
.84314 1.36883 L
s
% Start of user PostScript
3.4285714 4. 3.5189222 3.7289476 MAarrowhead1
% End of user PostScript
.88863 .03493 m
.90967 .09804 L
s
% Start of user PostScript
3.7142857 -2. 3.8046365 -1.7289476 MAarrowhead1
% End of user PostScript
.88863 .13471 m
.90967 .18881 L
s
% Start of user PostScript
3.7142857 -1.5714286 3.8046365 -1.339098 MAarrowhead1
% End of user PostScript
.88863 .2345 m
.90967 .27958 L
s
% Start of user PostScript
3.7142857 -1.1428571 3.8046365 -0.94924831 MAarrowhead1
% End of user PostScript
.88863 .33429 m
.90967 .37035 L
s
% Start of user PostScript
3.7142857 -0.71428571 3.8046365 -0.55939865 MAarrowhead1
% End of user PostScript
.88863 .43407 m
.90967 .46112 L
s
% Start of user PostScript
3.7142857 -0.28571429 3.8046365 -0.16954898 MAarrowhead1
% End of user PostScript
.88863 .53386 m
.90967 .55189 L
s
% Start of user PostScript
3.7142857 0.14285714 3.8046365 0.22030068 MAarrowhead1
% End of user PostScript
.88863 .63365 m
.90967 .64266 L
s
% Start of user PostScript
3.7142857 0.57142857 3.8046365 0.61015034 MAarrowhead1
% End of user PostScript
.88863 .73343 m
.90967 .73343 L
s
% Start of user PostScript
3.7142857 1. 3.8046365 1. MAarrowhead1
% End of user PostScript
.88863 .83322 m
.90967 .8242 L
s
% Start of user PostScript
3.7142857 1.4285714 3.8046365 1.3898497 MAarrowhead1
% End of user PostScript
.88863 .93301 m
.90967 .91498 L
s
% Start of user PostScript
3.7142857 1.8571429 3.8046365 1.7796993 MAarrowhead1
% End of user PostScript
.88863 1.03279 m
.90967 1.00575 L
s
% Start of user PostScript
3.7142857 2.2857143 3.8046365 2.169549 MAarrowhead1
% End of user PostScript
.88863 1.13258 m
.90967 1.09652 L
s
% Start of user PostScript
3.7142857 2.7142857 3.8046365 2.5593986 MAarrowhead1
% End of user PostScript
.88863 1.23237 m
.90967 1.18729 L
s
% Start of user PostScript
3.7142857 3.1428571 3.8046365 2.9492483 MAarrowhead1
% End of user PostScript
.88863 1.33215 m
.90967 1.27806 L
s
% Start of user PostScript
3.7142857 3.5714286 3.8046365 3.339098 MAarrowhead1
% End of user PostScript
.88863 1.43194 m
.90967 1.36883 L
s
% Start of user PostScript
3.7142857 4. 3.8046365 3.7289476 MAarrowhead1
% End of user PostScript
.95515 .03493 m
.97619 .09804 L
s
% Start of user PostScript
4. -2. 4.0903508 -1.7289476 MAarrowhead1
% End of user PostScript
.95515 .13471 m
.97619 .18881 L
s
% Start of user PostScript
4. -1.5714286 4.0903508 -1.339098 MAarrowhead1
% End of user PostScript
.95515 .2345 m
.97619 .27958 L
s
% Start of user PostScript
4. -1.1428571 4.0903508 -0.94924831 MAarrowhead1
% End of user PostScript
.95515 .33429 m
.97619 .37035 L
s
% Start of user PostScript
4. -0.71428571 4.0903508 -0.55939865 MAarrowhead1
% End of user PostScript
.95515 .43407 m
.97619 .46112 L
s
% Start of user PostScript
4. -0.28571429 4.0903508 -0.16954898 MAarrowhead1
% End of user PostScript
.95515 .53386 m
.97619 .55189 L
s
% Start of user PostScript
4. 0.14285714 4.0903508 0.22030068 MAarrowhead1
% End of user PostScript
.95515 .63365 m
.97619 .64266 L
s
% Start of user PostScript
4. 0.57142857 4.0903508 0.61015034 MAarrowhead1
% End of user PostScript
.95515 .73343 m
.97619 .73343 L
s
% Start of user PostScript
4. 1. 4.0903508 1. MAarrowhead1
% End of user PostScript
.95515 .83322 m
.97619 .8242 L
s
% Start of user PostScript
4. 1.4285714 4.0903508 1.3898497 MAarrowhead1
% End of user PostScript
.95515 .93301 m
.97619 .91498 L
s
% Start of user PostScript
4. 1.8571429 4.0903508 1.7796993 MAarrowhead1
% End of user PostScript
.95515 1.03279 m
.97619 1.00575 L
s
% Start of user PostScript
4. 2.2857143 4.0903508 2.169549 MAarrowhead1
% End of user PostScript
.95515 1.13258 m
.97619 1.09652 L
s
% Start of user PostScript
4. 2.7142857 4.0903508 2.5593986 MAarrowhead1
% End of user PostScript
.95515 1.23237 m
.97619 1.18729 L
s
% Start of user PostScript
4. 3.1428571 4.0903508 2.9492483 MAarrowhead1
% End of user PostScript
.95515 1.33215 m
.97619 1.27806 L
s
% Start of user PostScript
4. 3.5714286 4.0903508 3.339098 MAarrowhead1
% End of user PostScript
.95515 1.43194 m
.97619 1.36883 L
s
% Start of user PostScript
4. 4. 4.0903508 3.7289476 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.46687 L
0 1.46687 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{392.625, 575.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000680002?b000`400?l00000o`00003ooooonfZ9
oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9
oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9
oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9
oookJP00oooonfZ9oookJP00oooonfZ9oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYW
oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP003_oonfX9o`00O`Sooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00
3_oonfX9o`00O`Sooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP003_oonfX4o`00O`gooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP000ooonfX:o`00O`;ooo]Z1?l007l<oookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX000?ooo]Z2_l007l3oookJPGo001o2_oonfX3o`0001Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0SoookJP004_oonfX4o`00O`Wooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z000CoookJP?o001o
2OoonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0RoookJP005?oo
nfX3o`00O`Sooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08_oo
nfX000kooo]Z0ol007l3oookJP?o001o2?oonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0RoookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJP03o`000?oonf[o0000
01Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0QoookJP003_oonfX4o`00O`;o
oo]Z0ol007l8oookJP03o`000?oonf[o000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0QoookJP003ooonfX7o`00O`Wooo]Z00?o0000oookJ_l000005_oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000@oookJPGo001o2_oonfX01?l0003ooo]Zoook
J_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08?oonfX001oooo]Z00Co
0000oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z023ooo]Z
000OoookJP04o`000?oonf[ooo]Zo`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0PoookJP007ooonfX01Ol0003ooo]ZoookJ_oonf[o000001Kooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0OoookJP007ooonfX01Ol0003ooo]ZoookJ_oonf[o000001Kooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0OoookJP007ooonfX01Ol0003ooo]Zoook
J_oonf[o000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0OoookJP007ooo
nfX00ol0003ooo]ZoookJP02oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000OoookJP007ooonfX0
0ol0003ooo]ZoookJP05o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000C
oookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000C
oookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00007ooonfX001oooo]Z0_l000000ooo
nf[o0000o`000003o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00007ooonfX001oooo]Z00Co0000oookJ_oo
nf[ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00005?oonfX3o`00
01Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`00
01Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001oooo]Z000OoookJP03o`000?oonf[ooo]Z00;o
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z000OoookJP03o`000?oonf[ooo]Z00;ooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005OoonfX2o`0001Gooo]Z
0_l0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z000OoookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000FoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001kooo]Z000OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01cooo]Z000Ooook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0
oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z0_l0003ooookJVSooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0SoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0RoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0RoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0RoookJP007ooonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX08OoonfX001oooo]Z00?o0000oookJ_l000005_oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[o000001Kooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX01?l0003ooo]ZoookJ_l0000F
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08?oonfX001oooo]Z00Co0000oook
J_oonf[o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z023ooo]Z000Ooook
JP05o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01oooo]Z000OoookJP05o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01oooo]Z000OoookJP04o`000?oonf[ooo]ZoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000OoookJP007ooonfX00ol0003ooo]ZoookJP04o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX5o`0001;ooo]Z1Ol0000Boook
JPGo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00007ooonfX001oooo]Z0_l000000ooonf[o0000o`000002o`0001?ooo]Z1?l0000CoookJPCo
00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX5o`0001;ooo]Z1Ol0000BoookJPGo
00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo
00007ooonfX001oooo]Z00Co0000oookJ_oonf[ooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z1?l0000CoookJPCo00004ooonfX4o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001oo
oo]Z000OoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00004ooonfX4o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z
000OoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z000O
oookJP03o`000?oonf[ooo]Z00?ooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000E
oookJP;o00005OoonfX2o`0001Gooo]Z0_l0000FoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000E
oookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001kooo]Z000Ooook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z
00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoook
JP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
IooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l0003ooookJVSo
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05Ooo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0RoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]Zo`00000FoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z00?o0000oookJ_l000005_oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP04o`000?oonf[ooo]Zo`0001Ko
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0PoookJP004_oonfX3o`00O`[ooo]Z
00Co0000oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z023o
oo]Z000BoookJP?o001o2_oonfX01?l0003ooo]ZoookJ_oonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005?oonfX3o`0001Cooo]Z0ol0000EoookJP;o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o
00007ooonfX001;ooo]Z0ol007l:oookJP04o`000?oonf[ooo]ZoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00004ooonfX4o`0001?o
oo]Z1?l0000OoookJP000ooonfX:o`00O`Gooo]Z0ol007l:oookJP03o`000?oonf[ooo]Z00Co0000
4ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo0000
4ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPGo0000
4_oonfX5o`0001;ooo]Z1Ol0000OoookJP000ooonfX:o`00O`Gooo]Z0ol007l:oookJPOo00004ooo
nfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00005?oo
nfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooo
nfX4o`0001?ooo]Z1?l0000OoookJP004_oonfX3o`00O`[ooo]Z00Co0000oookJ_oonf[ooo]Z1?l0
000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z1?l0
000CoookJPCo00004ooonfX4o`0001kooo]Z000BoookJP?o001o2_oonfX00ol0003ooo]ZoookJP02
oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000D
oookJP?o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000E
oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000NoookJP004_oonfX3o`00O`[ooo]Z00?o0000oook
J_oonfX00ooonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000Eoook
JP;o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000Eoook
JP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00007_oonfX001;ooo]Z0ol007l:oookJP03
o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01cooo]Z000?oookJPKo001o2_oonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000?oookJPKo001o2_oonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000AoookJPCo001o2_oonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000BoookJP?o001o2_oonfX00ol0003ooo]ZoookJP3ooook
JVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0
oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l0
003ooookJVSooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z0_l0000FoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z0_l0000FoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_l000005_oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[o0000
01Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003o
oo]ZoookJP03o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005?oonfX3o`0001Cooo]Z00?o0000oookJ_l000005?oonfX01?l0003ooo]Zo`000?l0000Coook
JP04o`000?oonf[o0000o`0001?ooo]Z00Co0000oookJ_l0003o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`00023ooo]Z000OoookJP03o`000?oonf[ooo]Z00?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005OoonfX2
o`0001Gooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000PoookJP007ooonfX00ol0003ooo]Zo`000003o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001Cooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00008?oonfX001oooo]Z00?o0000oookJ_oonfX01?l0000CoookJPCo00004ooonfX4o`0001?o
oo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000DoookJP?o00005?oonfX4o`0001?o
oo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001oo
oo]Z000OoookJP;o00000_oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Gooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00007ooonfX001oooo]Z00?o
0000oookJ_oonfX00_oonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00007ooonfX001oooo]Z00?o0000
oookJ_oonfX00ooonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000E
oookJP;o00005OoonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX2o`0001Gooo]Z0_l0000E
oookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001kooo]Z000Ooook
JP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z
00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoook
JP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
IooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP;o0000oooo
nfYXoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000
oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX2o`0001Kooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]Zo`000002o`00
01Cooo]Z0ol0000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l000005?oonfX00ol0
003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00Co0000oookJ_l0003o00004ooonfX0
1?l0003ooo]Zo`000?l0000CoookJP04o`000?oonf[o0000o`0001?ooo]Z00Co0000oookJ_l0003o
00004ooonfX01?l0003ooo]Zo`000?l0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000Doook
JP?o00008OoonfX001oooo]Z00?o0000oookJ_l000000_l0000DoookJP?o00005OoonfX2o`0001Go
oo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Co
oo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`00027o
oo]Z000OoookJPKo00004_oonfX5o`0001?ooo]Z1?l0000CoookJPCo00001OoonfX3o`00O`_ooo]Z
1?l0000CoookJPCo00004ooonfX5o`0000_ooo]Z1ol007l5o`0001;ooo]Z1Ol0000BoookJPGo0000
4_oonfX5o`0000;ooo]Z1Ol007l;oookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000AoookJP03o`00
Ool0003o000000?o00008?oonfX001oooo]Z00?o0000oookJ_oonfX00ol0000DoookJP?o00005Ooo
nfX2o`0001Gooo]Z0_l00005oookJP?o001o3OoonfX2o`0001Gooo]Z0_l0000EoookJP?o00002ooo
nfX9o`00O`?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o000000?ooo]Zo`00Ool007l01Ol0
07l<oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000AoookJP?o001o0ol0000PoookJP007ooonfX2
o`0000;ooo]Z0ol0000DoookJP?o00005OoonfX2o`0001Gooo]Z0_l00004oookJP?o001o3_oonfX2
o`0001Gooo]Z0_l0000EoookJP;o00002ooonfX4o`00O`Kooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol00002o`00O`?ooo]Z0ol007l<oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000@
oookJP?o001o00Cooo]Zo`000?l0003o00007ooonfX001oooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP02oookJP?o001o3ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z0_l0000;oookJPCo001o1ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o001oo`00O`03oookJP?o001o3_oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX02OoonfX9
o`00O`;ooo]Z00?o0000oookJ_oonfX07OoonfX001oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX01?l0
003ooo]ZoookJ_oonfX3o`00Oa3ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z00[ooo]Z1Ol007l6oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol007l?
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP08
oookJPWo001o0ooonfX00ol0003ooo]ZoookJP0LoookJP007ooonfX00ol0003ooo]ZoookJP1=oook
JP?o001oCOoonfX4o`00Odoooo]Z0ol007m8oookJP;o001o0ooonfX3o`00Ob?ooo]Z000OoookJP03
o`000?oonf[ooo]Z04gooo]Z0ol007m>oookJP?o001oCOoonfX4o`00Od[ooo]Z0_l007l2oookJP?o
001o8ooonfX001oooo]Z00?o0000oookJ_oonfX0COoonfX3o`00Odoooo]Z0ol007m<oookJP?o001o
BooonfX3o`00O`04oookJ_l007oo001oo`00Ob?ooo]Z000OoookJP03o`000?oonf[ooo]Z04gooo]Z
0ol007m9oookJP?o001o0ooonfX3o`00Odkooo]Z0_l007m;oookJP;o001o00Cooo]Zo`00Ool007oo
001o8ooonfX001oooo]Z00?o0000oookJ_oonfX0B_oonfX6o`00OdWooo]Z0ol007l3oookJP?o001o
B?oonfX3o`00O`?ooo]Z0ol007m;oookJPGo001o8ooonfX001oooo]Z00?o0000oookJ_oonfX0B_oo
nfX6o`00OdWooo]Z1?l007l2oookJP?o001oB?oonfX3o`00O`?ooo]Z0ol007m;oookJPGo001o8ooo
nfX001oooo]Z00?o0000oookJ_oonfX0C?oonfX4o`00Od[ooo]Z1ol007m:oookJPOo001oCOoonfX4
o`00Ob?ooo]Z000OoookJP03o`000?oonf[ooo]Z04gooo]Z0ol007m;oookJPGo001oC?oonfX5o`00
Odoooo]Z0ol007lSoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZG_oonfX00omEDgOo001oofITMP06oookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJUkooo]Z0_l007l00om4@WWooo]ZoookJP04oookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJUkooo]Z00?o8B5lo`00OonYYg401_oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYNoook
JP03oeECMol007ooV9Ib00Kooo]Z000GoookJ_oo0000G?l0000=oookJP03oiRFL_l007ooEE=g00Ko
oo]Z000OoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03_oonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0>oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0=oookJP03o`000?oonf[ooo]Z00kooo]Z00?o0000oookJ_oonfX03OoonfX00ol0003ooo]Z
oookJP0GoookJP04oc8bN_nHUW;ooo]ZomgIK0;o001o1_oonfX001oooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP1=oookJP03o`000?oonf[ooo]Z04kooo]Z00?o0000oookJ_oonfX0
C_oonfX00ol0003ooo]ZoookJP0GoookJP03olc8K_l007oo001o00Ko001o0OmVI7H1oookJP7ooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZG?oonfX00oo<b6ko<S9jo`00O`05o`00O`7o411m0Ooo
nfX1oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000
oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l000000ooonf[o0000oookJP0BoookJP;o0000
00?ooo]Zo`000?oonfX04_oonfX2o`000003oookJ_l0003ooo]Z01;ooo]Z0_l000000ooonf[o0000
oookJP0BoookJP;o000000?ooo]Zo`000?oonfX04_oonfX2o`000003oookJ_l0003ooo]Z01;ooo]Z
0_l000000ooonf[o0000oookJP0BoookJP;o000000?ooo]Zo`000?oonfX04_oonfX2o`000003oook
J_l0003ooo]Z01;ooo]Z0_l00002oookJP03o`000?oonf[ooo]Z013ooo]Z0_l00002oookJP03o`00
0?oonf[ooo]Z017ooo]Z0_l000000ooonf[o0000oookJP0BoookJP;o000000?ooo]Zo`000?oonfX0
4_oonfX2o`000003oookJ_l0003ooo]Z01;ooo]Z0_l000000ooonf[o0000oookJP0QoookJP007ooo
nfX01?l0003ooo]Zo`000?l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0ol0000DoookJP?o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0002;ooo]Z000OoookJP03o`000?oo
nf[o000000;o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00004ooonfX4o`0001?ooo]Z1?l0
000CoookJPCo00005?oonfX3o`0001Cooo]Z0ol0000QoookJP007ooonfX6o`0001;ooo]Z1Ol0000B
oookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000B
oookJPGo00004_oonfX6o`00017ooo]Z1_l0000AoookJPKo00004OoonfX6o`0001;ooo]Z1Ol0000B
oookJPGo00008?oonfX001oooo]Z0_l000001?oonf[o0000o`000?l0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000DoookJP?o00005?oonfX3
o`00023ooo]Z000OoookJP03o`000?oonf[ooo]Z00;ooo]Z0_l0000EoookJP;o00005OoonfX2o`00
01Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000FoookJP;o00005OoonfX2o`00
01Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`00
01oooo]Z000OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
IooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oo
nf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0
003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z
00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l0003ooookJVSooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOo
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJVOooo]Z000OoookJP?o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o00005Ooo
nfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005Ooo
nfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000SoookJP007ooonfX4
o`0001?ooo]Z1?l0000CoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5
o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000CoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000CoookJPCo00008_oonfX001oooo]Z1_l0000AoookJPKo00004_oonfX5o`00
01;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPKo00004OoonfX6o`00
017ooo]Z1_l0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004OoonfX6o`00
023ooo]Z000OoookJPOo00004?oonfX7o`00013ooo]Z1ol0000@oookJPOo00004?oonfX7o`00013o
oo]Z1ol0000@oookJPOo00004?oonfX8o`00013ooo]Z1ol0000@oookJPOo00004?oonfX7o`00013o
oo]Z1ol0000@oookJPOo00004?oonfX7o`00013ooo]Z1ol0000OoookJP007ooonfX00ol0003ooo]Z
oookJP02oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX4o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000NoookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYW
oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX2o`000?oooo]ZJ?oo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0
oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000Boook
JP?o001o2_oonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000BoookJP?o001o2_oonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000BoookJP?o001o2_oonfX3o`0001Cooo]Z0ol0000DoookJP?o0000
5?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o0000
5?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o0000
8ooonfX001;ooo]Z0ol007l:oookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004Ooo
nfX6o`00017ooo]Z1_l0000BoookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004Ooo
nfX6o`00017ooo]Z1_l0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000PoookJP004_oonfX3
o`00O`[ooo]Z2?l0000?oookJPSo00003ooonfX8o`0000oooo]Z2?l0000?oookJPSo00003ooonfX8
o`0000oooo]Z2?l0000?oookJPWo00003_oonfX9o`0000kooo]Z2Ol0000>oookJPWo00003ooonfX8
o`0000oooo]Z2?l0000?oookJPSo00003ooonfX8o`0001kooo]Z000BoookJP?o001o2_oonfX4o`00
01?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00005?oonfX3o`00
01Cooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`00
01?ooo]Z1?l0000CoookJPCo00008_oonfX001;ooo]Z0ol007l:oookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001;ooo]Z0ol007l:oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001;ooo]Z0ol0
07l:oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX000oooo]Z1_l007l:oookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX000oooo]Z1_l007l:oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX0017o
oo]Z1?l007l:oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001;ooo]Z0ol007l:oookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYW
oookJP007ooonfX2o`000?oooo]ZJ?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0
oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000Ooook
JP04o`000?oonf[ooo]ZoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX5o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000NoookJP007ooonfX6o`00
017ooo]Z1_l0000AoookJPKo00004OoonfX7o`00013ooo]Z1ol0000@oookJPOo00004?oonfX7o`00
013ooo]Z1ol0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004OoonfX6o`00
017ooo]Z1_l0000AoookJPKo00008?oonfX001oooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;o
oo]Z1_l0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004_oonfX5o`0001;o
oo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`00027o
oo]Z000OoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPGo00004_oonfX5o`0001;ooo]Z
1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001?ooo]Z
1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000RoookJP007ooonfX3o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00008ooonfX001oooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000Ooook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JVOooo]Z000OoookJP;o0000oooonfYXoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYW
oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oo
oo]Z00?o0000oookJ_oonfX00ooonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Go
oo]Z0_l0000EoookJP;o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Go
oo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00007_oonfX001oooo]Z
0_l00002oookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z
1?l0000CoookJPCo00004ooonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z
1Ol0000BoookJPGo00004ooonfX4o`0001?ooo]Z1?l0000NoookJP007ooonfX00ol0003ooo]Zo`00
0004o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oo
nfX5o`0001;ooo]Z1_l0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000AoookJPKo00004Ooo
nfX6o`0001;ooo]Z1Ol0000BoookJPGo00007ooonfX001oooo]Z1_l0000BoookJPGo00004_oonfX5
o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPKo00004OoonfX6
o`00017ooo]Z1_l0000AoookJPKo00004OoonfX6o`00017ooo]Z1_l0000BoookJPGo00004_oonfX5
o`00023ooo]Z000OoookJPKo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`00
01;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000CoookJPGo00004_oonfX5o`00
01;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000PoookJP007ooonfX5o`0001?o
oo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?o
oo]Z1?l0000CoookJPCo00004ooonfX00ol0003ooo]Zo`000002o`0001;ooo]Z00?o0000oookJ_l0
00000_l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00008OoonfX001oooo]Z
00Co0000oookJ_oonf[o00004ooonfX01?l0003ooo]ZoookJ_l0000CoookJP04o`000?oonf[ooo]Z
o`0001?ooo]Z00Co0000oookJ_oonf[o00004ooonfX01?l0003ooo]ZoookJ_l0000CoookJP04o`00
0?oonf[ooo]Zo`0001?ooo]Z00Co0000oookJ_oonf[o00004ooonfX01?l0003ooo]ZoookJ_l0000C
oookJP04o`000?oonf[ooo]Zo`0001?ooo]Z00Go0000oookJ_oonf[ooo]Zo`00000BoookJP05o`00
0?oonf[ooo]ZoookJ_l000004ooonfX01?l0003ooo]ZoookJ_l0000CoookJP04o`000?oonf[ooo]Z
o`0001?ooo]Z00Co0000oookJ_oonf[o00004ooonfX01?l0003ooo]ZoookJ_l0000RoookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOo
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nfYWoookJP003_oonfX9o`00O`Sooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP003_oonfX9o`00
O`Sooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP003_oonfX4o`00O`gooo]Z00?o0000oookJ_oo
nfX0oooonfYWoookJP003ooonfX4o`00O`cooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP004?oo
nfX5o`00O`[ooo]Z0ol0003ooookJVOooo]Z000BoookJPCo001o2OoonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000CoookJP?o001o2OoonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000DoookJP?o
001o2?oonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000>oookJP?o001o0ooonfX3o`00O`Sooo]Z
00?o0000oookJ_oonfX0oooonfYWoookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJP03o`000?oo
nf[ooo]Z0?oooo]ZIooonfX000kooo]Z1?l007l2oookJP?o001o2?oonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000?oookJPOo001o2OoonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000@oookJPGo
001o2_oonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
IooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP03oookJP;o00005OoonfX2o`0001Kooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z
00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP;o00005OoonfX2o`0001Gooo]Z
0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001kooo]Z
000OoookJP03o`000?oonf[ooo]Z00;ooo]Z0ol0000DoookJP?o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z000O
oookJP04o`000?oonf[ooo]ZoookJP?o00005?oonfX3o`0001Gooo]Z0_l0000EoookJP;o00005Ooo
nfX2o`0001Gooo]Z0_l0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000OoookJP007ooonfX2
o`000003oookJ_l0003o000000;o00004ooonfX4o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000OoookJP007ooonfX00ol0
003ooo]Zo`000003o`0001?ooo]Z1?l0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000Doook
JP?o00005?oonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00008?oonfX001oooo]Z1_l0000BoookJPGo
00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1Ol0000BoookJPGo
00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo
00004_oonfX5o`00023ooo]Z000OoookJP03o`000?oonf[ooo]Z00?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005OoonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000PoookJP007ooonfX01Ol0003ooo]Zo`000?oonf[o000001Cooo]Z00?o0000oookJ_l00000
5?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l00000
5?oonfX00ol0003ooo]Zo`00000DoookJP04o`000?oonf[ooo]Zo`0001Cooo]Z00?o0000oookJ_l0
00005?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l0
00005?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l0
00005?oonfX00ol0003ooo]Zo`00000QoookJP007ooonfX00ol0003ooo]Zo`00000FoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z0_l0000FoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000
oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooo
nfX2o`000?oooo]ZJ?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0
003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z
00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoook
JP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
IooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oo
nfX01?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX07?oonfX001oooo]Z00?o0000oookJ_oonfX00ooonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
7_oonfX001oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001Gooo]Z0_l0000EoookJP;o00005Ooo
nfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Kooo]Z0_l0000EoookJP;o00005Ooo
nfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00007ooo
nfX001oooo]Z0_l00002oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000OoookJP007ooonfX00ol0
003ooo]ZoookJP04o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001Cooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00007ooonfX001oooo]Z00?o0000oookJ_l0
00000ol0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?o
oo]Z1?l0000DoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?o
oo]Z1?l0000CoookJPCo00004ooonfX4o`00023ooo]Z000OoookJP04o`000?oonf[ooo]ZoookJP;o
00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o
00005OoonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l0
00005?oonfX00ol0003ooo]Zo`00000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o
00008?oonfX001oooo]Z00Co0000oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z023ooo]Z000OoookJP04o`000?oonf[ooo]Zo`0001Kooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0PoookJP007ooonfX00ol0003ooo]Zo`00000FoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z0_l0000FoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z0_l0000FoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP;o0000
oooonfYXoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000Ooook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooo
nfX0013ooo]Z1Ol007l:oookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01cooo]Z000?oookJPOo001o2OoonfX00ol0
003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0LoookJP003_oonfX3o`00O`?ooo]Z0ol007l8oookJP03o`000?oonf[ooo]Z00?o
oo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Go
oo]Z0_l0000FoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Go
oo]Z0_l0000EoookJP;o00005OoonfX2o`0001kooo]Z000>oookJP?o001o0ooonfX3o`00O`Sooo]Z
00?o0000oookJ_oonfX00_oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z
0_l0000EoookJP;o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o00007_oonfX001Cooo]Z0ol0
07l8oookJP?o00000_oonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00007ooonfX001Cooo]Z0ol007l8
oookJP04o`000?oonf[ooo]ZoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooo
nfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000OoookJP004_oonfX4
o`00O`Wooo]Z00?o0000oookJ_oonfX01?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000C
oookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000C
oookJPCo00004ooonfX4o`0001?ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001oooo]Z000Boook
JP?o001o2_oonfX01ol0003ooo]ZoookJ_oonf[o0000oookJ_l000005?oonfX00ol0003ooo]Zo`00
000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l000005?oonfX00ol0003ooo]Zo`00
000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oookJ_l000005OoonfX2o`0001Gooo]Z0_l0
000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0
000OoookJP005?oonfX2o`00O`Wooo]Z00Go0000oookJ_oonf[ooo]Zo`00000FoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX07ooonfX000kooo]Z0ol007l3oookJP?o001o2?oonfX0
1?l0003ooo]ZoookJ_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08?oo
nfX000kooo]Z0ol007l3oookJP?o001o2?oonfX01?l0003ooo]ZoookJ_l0000FoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oo
nf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08?oonfX000oooo]Z1ol007l9oookJP03o`000?oonf[o
000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0QoookJP004?oonfX5o`00
O`[ooo]Z00?o0000oookJ_l000005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
027ooo]Z000OoookJP03o`000?oonf[o000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003o
oo]ZoookJP0QoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0RoookJP007ooonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0RoookJP007ooonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l0
003ooookJVSooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYW
oookJP007ooonfX00ol0003ooo]ZoookJP04oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0LoookJP007ooonfX00ol0003ooo]ZoookJP04oookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z0_l0000EoookJP;o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX07?oonfX001oooo]Z00?o0000oookJ_oonfX0
0ooonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0ol0000DoookJP?o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00007_oonfX001oooo]Z00?o0000oookJ_oonfX00_oo
nfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Cooo]Z1?l0000CoookJPCo00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oo
nfX3o`0001Cooo]Z0ol0000DoookJP?o00007_oonfX001oooo]Z0_l00002oookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJPCo00004ooonfX4
o`0001?ooo]Z1?l0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3
o`0001Cooo]Z0ol0000OoookJP007ooonfX00ol0003ooo]ZoookJP04o`0001?ooo]Z1?l0000Coook
JPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX5o`0001;ooo]Z1Ol0000Boook
JPGo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000Coook
JPCo00007ooonfX001oooo]Z00?o0000oookJ_oonfX00_oonfX2o`0001Gooo]Z0_l0000EoookJP;o
00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o
00007ooonfX001oooo]Z00Oo0000oookJ_oonf[ooo]Zo`000?oonf[o000001Cooo]Z00?o0000oook
J_l000005?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000oook
J_l000005?oonfX00ol0003ooo]Zo`00000DoookJP04o`000?oonf[ooo]Zo`0001Cooo]Z00?o0000
oookJ_l000005?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000
oookJ_l000005?oonfX00ol0003ooo]Zo`00000DoookJP03o`000?oonf[o000001Cooo]Z00?o0000
oookJ_l000005?oonfX00ol0003ooo]Zo`00000OoookJP007ooonfX01Ol0003ooo]ZoookJ_oonf[o
000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[o
oo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0OoookJP007ooonfX01Ol0
003ooo]ZoookJ_oonf[o000001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0O
oookJP007ooonfX01?l0003ooo]ZoookJ_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX08?oonfX001oooo]Z00Co0000oookJ_oonf[o00005_oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0E
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z023ooo]Z000OoookJP04o`000?oonf[ooo]Zo`0001Kooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0PoookJP007ooonfX00ol0003ooo]Zo`00000Foook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z00?o0000oookJ_l0
00005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oo
nfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP;o0000
5_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX0
5?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP;o00005_oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP;o00005_oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX0
0ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z0_l0
003ooookJVSooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oook
J_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003ooo]ZoookJP3ooookJVOooo]Z
000OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Zoook
JP0DoookJP03o`000?oonf[ooo]Z01cooo]Z000OoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000
oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01cooo]Z000Ooook
JP03o`000?oonf[ooo]Z00?ooo]Z0_l0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000Eoook
JP;o00005OoonfX2o`0001Gooo]Z0_l0000FoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000Eoook
JP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001kooo]Z000OoookJP03
o`000?oonf[ooo]Z00;ooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005OoonfX2o`0001Gooo]Z0_l0000EoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o
00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001kooo]Z000OoookJP03o`00
0?oonf[ooo]Z00;ooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o0000
5?oonfX3o`0001Cooo]Z0ol0000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o0000
5OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001oooo]Z000OoookJP04o`000?oo
nf[ooo]ZoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z
0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z0ol0000OoookJP007ooonfX2o`000003oookJ_l0
003o000000?o00004_oonfX5o`0001;ooo]Z1Ol0000BoookJPGo00004_oonfX5o`0001?ooo]Z1?l0
000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0
000CoookJPCo00004ooonfX4o`0001?ooo]Z1?l0000OoookJP007ooonfX00ol0003ooo]ZoookJP02
oookJP?o00005?oonfX3o`0001Cooo]Z0ol0000DoookJP?o00005?oonfX3o`0001Cooo]Z00?o0000
oookJ_l000005?oonfX00ol0003ooo]Zo`00000EoookJP;o00005OoonfX2o`0001Gooo]Z0_l0000E
oookJP;o00005OoonfX2o`0001Gooo]Z0_l0000EoookJP;o00005OoonfX2o`0001oooo]Z000Ooook
JP03o`000?oonf[ooo]Z00;ooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Eoook
JP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01kooo]Z000OoookJP05o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01oooo]Z000OoookJP05o`000?oonf[ooo]Zoook
J_l000005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05OoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01oooo]Z000OoookJP05
o`000?oonf[ooo]ZoookJ_l000005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01oooo]Z000OoookJP04o`000?oonf[ooo]Zo`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0PoookJP007ooonfX01?l0003ooo]ZoookJ_l0000FoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z
01Cooo]Z00?o0000oookJ_oonfX08?oonfX001oooo]Z00Co0000oookJ_oonf[o00005_oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0
003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z023ooo]Z000OoookJP03o`000?oonf[o000001Ko
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Go
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Co
oo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]Z
o`00000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]Z
oookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z00?o
0000oookJ_l000005_oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o
0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z027ooo]Z000C
oookJP?o001o2OoonfX2o`0001Kooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0D
oookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0R
oookJP004ooonfX3o`00O`Wooo]Z0_l0000FoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oook
J_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oook
J_oonfX08_oonfX001?ooo]Z0ol007l9oookJP;o00005_oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03
o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03
o`000?oonf[ooo]Z02;ooo]Z000>oookJPWo001o2?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0EoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oonfX00ol0003ooo]ZoookJP0DoookJP03o`00
0?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX08ooonfX000kooo]Z2Ol007l8oookJP?o00005?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01Cooo]Z00?o0000oookJ_oonfX05?oo
nfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02?ooo]Z000>oookJP;o001o0ooonfX3
o`00O`Wooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP003ooonfX2o`00O`;ooo]Z0ol007l9oook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX000oooo]Z0ol007l01?oonf[o001oo`00Ool007l9oook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX0013ooo]Z0_l007l01?oonf[o001oo`00Ool007l9oook
JP03o`000?oonf[ooo]Z0?oooo]ZIooonfX0017ooo]Z1Ol007l9oookJP03o`000?oonf[ooo]Z0?oo
oo]ZIooonfX0017ooo]Z1Ol007l9oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001;ooo]Z1?l0
07l9oookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001?ooo]Z0ol007l9oookJP03o`000?oonf[o
oo]Z0?oooo]ZIooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYWoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJVOooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZIooonfX001oooo]Z00?o
0000oookJ_oonfX0oooonfYWoookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00
oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00
oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00oooonfZ9oookJP00
oooonfZ9oookJP006ooonfX00onHUW;oA49io`00O`02o`00O`03odA2NOnHUW;ooo]Z0?oooo]ZI_oo
nfX001Wooo]Z00_ok^Y[oc8bN_l007ooEE=gomgIK?oonf[oc<Q^ob4QO?l007oo<S9jonkZJ`3ooook
JVGooo]Z000IoookJP03oc8bN_l007oo411m00Cooo]Z00Cok^Y[oa0@OOl007oo<S9joooonfYUoook
JP006?oonfX01?nHUW;o001oo`00OonHUW85oookJP04ohN5Lol007oo001ooiRFL_oooo]ZI?oonfX0
01Sooo]Z00CoA49io`00Ool007ooc<Q^1OoonfX01?o<b6ko001oo`00Oom4@WWooookJVCooo]Z000H
oookJP?o001o00Oooo]Zo`00OooMfFcooo]ZomgIK?l007oooo]Z00?o001ooooonfYToookJP006?oo
nfX3o`00O`03oookJ_l007oo001o00?o001o00Cooo]Zo`00Ool007oo001ooooonfYToookJP006?oo
nfX3o`00O`03oookJ_l007oo001o00?o001o00Cooo]Zo`00Ool007oo001ooooonfYToookJP006?oo
nfX02_m4@WWo001oo`00OooMfFco001oolc8K_oonf[oc<Q^o`00Ooo<b6h2o`00O`03odA2NOoonf[o
oo]Z0?oooo]ZH_oonfX001Sooo]Z00CoV9Ibo`00Ool007ooV9Ib1OoonfX01?n7QG?o001oo`00Oonj
^6oooookJVCooo]Z000IoookJP04oc8bN_l007oo411monkZJ`Cooo]Z00?o411mo`00Oom4@WT0oooo
nfYUoookJP006OoonfX02oo^jV_o<S9jo`00Oolb<W[oc<Q^oookJ_oMfFcoA49io`00Oolb<W[ok^Y[
0?oooo]ZIOoonfX001_ooo]Z00?oV9IbodA2NOl007l00_l007l00olb<W[oV9IboookJP3ooookJVKo
oo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWo
oo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWo
oo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWo
oo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWooo]Z003ooookJXWo
oo]Z0000\
\>"],
  ImageRangeCache->{{{0, 391.625}, {574.875, 0}} -> {-0.387356, -2.38267, \
0.0123861, 0.0123861}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note in the equations and the plot that",
  Cell[BoxData[
      \(d\[CapitalTheta]\/d\[Tau]\)]],
  "is independent of \[Tau]."
}], "Text"],

Cell[TextData[{
  "Slightly more complicated example: ",
  Cell[BoxData[
      \(TraditionalForm\`dy\/dt\)]],
  "= y sin(",
  Cell[BoxData[
      \(TraditionalForm\`yt\/\(1\  + \ t\  + y\)\)]],
  "),\n(dt,dy) = dt(1,ysin",
  Cell[BoxData[
      \(TraditionalForm\`yt\/\(1\  + \ t\  + y\)\)]],
  "))"
}], "Subsection"],

Cell["\<\
As in the simpler example above we first plot the derivative's \
value as a surface using Plot3D, then we represent the behavior as a vector \
field\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[y\ \ Sin[\ \(y\ t\)\/\(t + y + 1\)], {t, 0, 10}, {y, 0, 10}, 
      AxesLabel \[Rule] {"\<t\>", "\<y\>", \*"\"\<\!\(dy\/dt\)\>\""}, 
      PlotPoints \[Rule] 40]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -14 -19.3395 ]
[.02757 .24618 0 .66054 ]
[.14598 .19958 -13.9113 -20 ]
[.14598 .19958 .0887 0 ]
[.27013 .15073 -13.3275 -20 ]
[.27013 .15073 .67247 0 ]
[.40046 .09948 -12.7438 -20 ]
[.40046 .09948 1.25625 0 ]
[.53743 .04564 -12.16 -20 ]
[.53743 .04564 1.84003 0 ]
[.68156 -0.01098 -19.8449 -20 ]
[.68156 -0.01098 4.1551 0 ]
[.29165 .07573 -9.25297 -20 ]
[.29165 .07573 .68453 0 ]
[.70096 -0.00478 0 -13.9157 ]
[.70096 -0.00478 14 6.08431 ]
[.76745 .09703 0 -13.693 ]
[.76745 .09703 14 6.30695 ]
[.82812 .18993 0 -13.4944 ]
[.82812 .18993 14 6.50564 ]
[.88369 .27502 0 -13.316 ]
[.88369 .27502 14 6.68404 ]
[.93478 .35327 0 -13.1549 ]
[.93478 .35327 14 6.84511 ]
[.98191 .42546 0 -13.0087 ]
[.98191 .42546 24 6.99126 ]
[.91861 .21225 0 -13.4028 ]
[.91861 .21225 14 6.59718 ]
[.02412 .2651 -36.9375 -6.09401 ]
[.02412 .2651 0 13.906 ]
[.01568 .31794 -26.9375 -6.1933 ]
[.01568 .31794 0 13.8067 ]
[.00696 .37263 -14 -6.29641 ]
[.00696 .37263 0 13.7036 ]
[-0.00208 .42927 -14 -6.40357 ]
[-0.00208 .42927 0 13.5964 ]
[-0.01144 .48795 -24 -6.51502 ]
[-0.01144 .48795 0 13.485 ]
[-0.05457 .39542 -33.5625 -14.5605 ]
[-0.05457 .39542 0 31.6895 ]
[ -0.005 -0.005 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.01 w
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -75 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.1552 .20892 m
.15981 .21359 L
s
gsave
.14598 .19958 -74.9113 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.27893 .16047 m
.28333 .16533 L
s
gsave
.27013 .15073 -74.3275 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.40878 .10962 m
.41294 .11469 L
s
gsave
.40046 .09948 -73.7438 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.54521 .0562 m
.54911 .06148 L
s
gsave
.53743 .04564 -73.16 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -80.8449 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.253 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
68.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.68874 0 m
.96935 .42924 L
s
.25 Mabswid
.68874 0 m
.68263 .00239 L
s
gsave
.70096 -0.00478 -61 -17.9157 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.75514 .10158 m
.74899 .10385 L
s
gsave
.76745 .09703 -61 -17.693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.81573 .19425 m
.80953 .19642 L
s
gsave
.82812 .18993 -61 -17.4944 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.87123 .27915 m
.865 .28122 L
s
gsave
.88369 .27502 -61 -17.316 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92227 .35722 m
.91601 .35919 L
s
gsave
.93478 .35327 -61 -17.1549 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.96935 .42924 m
.96306 .43113 L
s
gsave
.98191 .42546 -61 -17.0087 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -17.4028 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(y) show
73.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01 w
.03716 .25514 m
0 .48963 L
s
.25 Mabswid
.03634 .26032 m
.04245 .25793 L
s
gsave
.02412 .2651 -97.9375 -10.094 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.02795 .31327 m
.03408 .31094 L
s
gsave
.01568 .31794 -87.9375 -10.1933 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(-) show
75.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.01926 .36807 m
.02542 .3658 L
s
gsave
.00696 .37263 -75 -10.2964 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.01027 .42482 m
.01644 .4226 L
s
gsave
-0.00208 .42927 -75 -10.4036 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.00095 .48363 m
.00715 .48147 L
s
gsave
-0.01144 .48795 -85 -10.515 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.03468 .27077 m
.03835 .26934 L
s
.03302 .28129 m
.03669 .27987 L
s
.03134 .29188 m
.03501 .29046 L
s
.02965 .30254 m
.03333 .30113 L
s
.02623 .32408 m
.02992 .32269 L
s
.02451 .33497 m
.02819 .33358 L
s
.02277 .34593 m
.02646 .34454 L
s
.02102 .35696 m
.02471 .35559 L
s
.01749 .37926 m
.02118 .3779 L
s
.0157 .39053 m
.0194 .38918 L
s
.01391 .40188 m
.0176 .40054 L
s
.01209 .41331 m
.0158 .41197 L
s
.00843 .43642 m
.01214 .43509 L
s
.00658 .44809 m
.01029 .44678 L
s
.00472 .45985 m
.00843 .45854 L
s
.00284 .4717 m
.00656 .4704 L
s
gsave
-0.05457 .39542 -94.5625 -18.5605 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 54.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 32.500 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
%%BeginResource: font Helvetica-Bold-MISO
%%BeginFont: Helvetica-Bold-MISO
/Helvetica-Bold /Helvetica-Bold-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
67.312 17.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(dy) show
%%IncludeResource: font Mathematica1-Bold
%%IncludeFont: Mathematica1-Bold
/Mathematica1-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 0.500 setrgbcolor
1.750 setlinewidth
65.875 27.062 moveto
23.938 0.000 rlineto
stroke
69.312 48.938 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(dt) show
92.562 32.500 moveto
%%IncludeResource: font Helvetica-Bold-MISO
%%IncludeFont: Helvetica-Bold-MISO
/Helvetica-Bold-MISO findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.787 .299 0 r
.39362 .6948 .40169 .70185 .41448 .72102 .40642 .71334 Metetra
.703 .203 0 r
.40642 .71334 .41448 .72102 .42757 .73838 .41951 .73009 Metetra
.532 .035 0 r
.41951 .73009 .42757 .73838 .44095 .75311 .4329 .74428 Metetra
0 .196 .704 r
.4329 .74428 .44095 .75311 .45461 .76467 .44657 .75539 Metetra
.08 .416 .865 r
.44657 .75539 .45461 .76467 .46851 .77275 .46049 .76313 Metetra
.339 .56 .918 r
.46049 .76313 .46851 .77275 .48262 .77727 .47462 .76744 Metetra
.506 .638 .913 r
.47462 .76744 .48262 .77727 .4969 .77829 .48893 .76839 Metetra
.61 .68 .891 r
.48893 .76839 .4969 .77829 .5113 .77602 .50337 .76618 Metetra
.677 .705 .869 r
.50337 .76618 .5113 .77602 .52579 .77077 .5179 .76112 Metetra
.723 .723 .85 r
.5179 .76112 .52579 .77077 .54034 .76289 .53249 .75353 Metetra
.755 .737 .836 r
.53249 .75353 .54034 .76289 .55491 .75277 .54712 .74379 Metetra
.78 .749 .825 r
.54712 .74379 .55491 .75277 .56949 .7408 .56176 .73227 Metetra
.799 .761 .818 r
.56176 .73227 .56949 .7408 .58405 .72736 .5764 .71933 Metetra
.814 .773 .814 r
.5764 .71933 .58405 .72736 .59858 .71281 .59102 .70531 Metetra
.827 .785 .813 r
.59102 .70531 .59858 .71281 .61309 .69748 .60562 .69052 Metetra
.837 .798 .814 r
.60562 .69052 .61309 .69748 .62757 .68165 .62019 .67524 Metetra
.845 .811 .817 r
.62019 .67524 .62757 .68165 .64201 .66558 .63473 .65969 Metetra
.852 .824 .821 r
.63473 .65969 .64201 .66558 .65644 .64948 .64926 .64409 Metetra
.856 .838 .827 r
.64926 .64409 .65644 .64948 .67084 .63354 .66377 .6286 Metetra
.859 .852 .834 r
.66377 .6286 .67084 .63354 .68524 .6179 .67828 .61337 Metetra
.86 .865 .842 r
.67828 .61337 .68524 .6179 .69963 .60269 .69278 .59851 Metetra
.859 .878 .852 r
.69278 .59851 .69963 .60269 .71404 .58798 .7073 .58411 Metetra
.855 .89 .862 r
.7073 .58411 .71404 .58798 .72847 .57386 .72184 .57024 Metetra
.85 .901 .872 r
.72184 .57024 .72847 .57386 .74293 .56037 .73641 .55693 Metetra
.842 .91 .883 r
.73641 .55693 .74293 .56037 .75744 .54754 .75102 .54424 Metetra
.832 .918 .893 r
.75102 .54424 .75744 .54754 .772 .5354 .76568 .53217 Metetra
.82 .923 .904 r
.76568 .53217 .772 .5354 .78662 .52394 .7804 .52073 Metetra
.806 .926 .915 r
.7804 .52073 .78662 .52394 .80132 .51318 .79519 .50993 Metetra
.792 .927 .924 r
.79519 .50993 .80132 .51318 .8161 .50309 .81006 .49975 Metetra
.776 .925 .934 r
.81006 .49975 .8161 .50309 .83098 .49366 .82502 .49018 Metetra
.761 .92 .942 r
.82502 .49018 .83098 .49366 .84595 .48488 .84007 .48121 Metetra
.745 .914 .95 r
.84007 .48121 .84595 .48488 .86103 .47671 .85522 .47282 Metetra
.73 .906 .956 r
.85522 .47282 .86103 .47671 .87622 .46913 .87047 .46497 Metetra
.716 .895 .961 r
.87047 .46497 .87622 .46913 .89153 .46211 .88584 .45765 Metetra
.702 .883 .965 r
.88584 .45765 .89153 .46211 .90697 .45562 .90133 .45082 Metetra
.69 .87 .967 r
.90133 .45082 .90697 .45562 .92253 .44964 .91694 .44446 Metetra
.678 .855 .967 r
.91694 .44446 .92253 .44964 .93823 .44411 .93267 .43854 Metetra
.668 .84 .966 r
.93267 .43854 .93823 .44411 .95407 .43903 .94854 .43303 Metetra
.659 .824 .963 r
.94854 .43303 .95407 .43903 .97005 .43435 .96454 .42791 Metetra
.771 .277 0 r
.38547 .68769 .39362 .6948 .40642 .71334 .39828 .70559 Metetra
.679 .175 0 r
.39828 .70559 .40642 .71334 .41951 .73009 .41139 .72173 Metetra
0 0 .502 r
.41139 .72173 .41951 .73009 .4329 .74428 .42479 .73537 Metetra
0 .224 .728 r
.42479 .73537 .4329 .74428 .44657 .75539 .43847 .74602 Metetra
.104 .432 .873 r
.43847 .74602 .44657 .75539 .46049 .76313 .45241 .75343 Metetra
.349 .566 .919 r
.45241 .75343 .46049 .76313 .47462 .76744 .46656 .75753 Metetra
.508 .639 .913 r
.46656 .75753 .47462 .76744 .48893 .76839 .48089 .75841 Metetra
.608 .679 .892 r
.48089 .75841 .48893 .76839 .50337 .76618 .49536 .75626 Metetra
.673 .704 .871 r
.49536 .75626 .50337 .76618 .5179 .76112 .50994 .75137 Metetra
.717 .721 .853 r
.50994 .75137 .5179 .76112 .53249 .75353 .52458 .74407 Metetra
.749 .735 .839 r
.52458 .74407 .53249 .75353 .54712 .74379 .53927 .7347 Metetra
.774 .748 .829 r
.53927 .7347 .54712 .74379 .56176 .73227 .55397 .72363 Metetra
.793 .76 .823 r
.55397 .72363 .56176 .73227 .5764 .71933 .56868 .71118 Metetra
.808 .772 .819 r
.56868 .71118 .5764 .71933 .59102 .70531 .58338 .69769 Metetra
.821 .784 .818 r
.58338 .69769 .59102 .70531 .60562 .69052 .59806 .68344 Metetra
.831 .797 .819 r
.59806 .68344 .60562 .69052 .62019 .67524 .61273 .66869 Metetra
.839 .81 .822 r
.61273 .66869 .62019 .67524 .63473 .65969 .62737 .65366 Metetra
.846 .824 .826 r
.62737 .65366 .63473 .65969 .64926 .64409 .642 .63856 Metetra
.851 .837 .832 r
.642 .63856 .64926 .64409 .66377 .6286 .65662 .62353 Metetra
.853 .851 .839 r
.65662 .62353 .66377 .6286 .67828 .61337 .67123 .60872 Metetra
.854 .865 .847 r
.67123 .60872 .67828 .61337 .69278 .59851 .68585 .59423 Metetra
.854 .878 .856 r
.68585 .59423 .69278 .59851 .7073 .58411 .70048 .58015 Metetra
.85 .89 .866 r
.70048 .58015 .7073 .58411 .72184 .57024 .71512 .56653 Metetra
.845 .901 .876 r
.71512 .56653 .72184 .57024 .73641 .55693 .7298 .55344 Metetra
.838 .91 .886 r
.7298 .55344 .73641 .55693 .75102 .54424 .74452 .54089 Metetra
.829 .918 .896 r
.74452 .54089 .75102 .54424 .76568 .53217 .75928 .52891 Metetra
.818 .924 .906 r
.75928 .52891 .76568 .53217 .7804 .52073 .7741 .51752 Metetra
.805 .927 .916 r
.7741 .51752 .7804 .52073 .79519 .50993 .78899 .5067 Metetra
.791 .929 .925 r
.78899 .5067 .79519 .50993 .81006 .49975 .80395 .49646 Metetra
.777 .928 .934 r
.80395 .49646 .81006 .49975 .82502 .49018 .81899 .48678 Metetra
.762 .925 .942 r
.81899 .48678 .82502 .49018 .84007 .48121 .83412 .47766 Metetra
.748 .919 .949 r
.83412 .47766 .84007 .48121 .85522 .47282 .84935 .46906 Metetra
.733 .912 .955 r
.84935 .46906 .85522 .47282 .87047 .46497 .86467 .46098 Metetra
.72 .903 .96 r
.86467 .46098 .87047 .46497 .88584 .45765 .8801 .45338 Metetra
.707 .893 .964 r
.8801 .45338 .88584 .45765 .90133 .45082 .89565 .44624 Metetra
.695 .881 .967 r
.89565 .44624 .90133 .45082 .91694 .44446 .91131 .43954 Metetra
.685 .868 .968 r
.91131 .43954 .91694 .44446 .93267 .43854 .92709 .43325 Metetra
.675 .854 .968 r
.92709 .43325 .93267 .43854 .94854 .43303 .943 .42735 Metetra
.666 .839 .966 r
.943 .42735 .94854 .43303 .96454 .42791 .95903 .42181 Metetra
.753 .254 0 r
.37724 .68051 .38547 .68769 .39828 .70559 .39007 .69777 Metetra
.653 .146 0 r
.39007 .69777 .39828 .70559 .41139 .72173 .40319 .7133 Metetra
0 .03 .537 r
.40319 .7133 .41139 .72173 .42479 .73537 .41661 .72639 Metetra
0 .253 .751 r
.41661 .72639 .42479 .73537 .43847 .74602 .4303 .73658 Metetra
.129 .447 .881 r
.4303 .73658 .43847 .74602 .45241 .75343 .44426 .74365 Metetra
.359 .571 .92 r
.44426 .74365 .45241 .75343 .46656 .75753 .45843 .74754 Metetra
.509 .639 .913 r
.45843 .74754 .46656 .75753 .48089 .75841 .47279 .74834 Metetra
.605 .678 .893 r
.47279 .74834 .48089 .75841 .49536 .75626 .4873 .74624 Metetra
.668 .702 .872 r
.4873 .74624 .49536 .75626 .50994 .75137 .50191 .74152 Metetra
.712 .719 .855 r
.50191 .74152 .50994 .75137 .52458 .74407 .5166 .7345 Metetra
.743 .733 .842 r
.5166 .7345 .52458 .74407 .53927 .7347 .53134 .7255 Metetra
.768 .746 .833 r
.53134 .7255 .53927 .7347 .55397 .72363 .54611 .71486 Metetra
.787 .758 .827 r
.54611 .71486 .55397 .72363 .56868 .71118 .56089 .7029 Metetra
.802 .77 .824 r
.56089 .7029 .56868 .71118 .58338 .69769 .57567 .68993 Metetra
.814 .783 .823 r
.57567 .68993 .58338 .69769 .59806 .68344 .59043 .67621 Metetra
.825 .796 .824 r
.59043 .67621 .59806 .68344 .61273 .66869 .60519 .662 Metetra
.833 .809 .827 r
.60519 .662 .61273 .66869 .62737 .65366 .61993 .6475 Metetra
.84 .823 .832 r
.61993 .6475 .62737 .65366 .642 .63856 .63466 .63289 Metetra
.845 .836 .838 r
.63466 .63289 .642 .63856 .65662 .62353 .64938 .61833 Metetra
.848 .85 .845 r
.64938 .61833 .65662 .62353 .67123 .60872 .6641 .60394 Metetra
.849 .864 .853 r
.6641 .60394 .67123 .60872 .68585 .59423 .67883 .58983 Metetra
.848 .877 .861 r
.67883 .58983 .68585 .59423 .70048 .58015 .69357 .57608 Metetra
.845 .889 .87 r
.69357 .57608 .70048 .58015 .71512 .56653 .70832 .56274 Metetra
.841 .9 .88 r
.70832 .56274 .71512 .56653 .7298 .55344 .72311 .54987 Metetra
.834 .91 .889 r
.72311 .54987 .7298 .55344 .74452 .54089 .73793 .53749 Metetra
.825 .918 .899 r
.73793 .53749 .74452 .54089 .75928 .52891 .7528 .52563 Metetra
.815 .924 .908 r
.7528 .52563 .75928 .52891 .7741 .51752 .76773 .5143 Metetra
.803 .928 .917 r
.76773 .5143 .7741 .51752 .78899 .5067 .78271 .50349 Metetra
.79 .93 .926 r
.78271 .50349 .78899 .5067 .80395 .49646 .79777 .49322 Metetra
.777 .93 .934 r
.79777 .49322 .80395 .49646 .81899 .48678 .8129 .48346 Metetra
.763 .928 .941 r
.8129 .48346 .81899 .48678 .83412 .47766 .82811 .4742 Metetra
.749 .924 .948 r
.82811 .4742 .83412 .47766 .84935 .46906 .84342 .46544 Metetra
.736 .918 .954 r
.84342 .46544 .84935 .46906 .86467 .46098 .85882 .45714 Metetra
.723 .911 .96 r
.85882 .45714 .86467 .46098 .8801 .45338 .87432 .4493 Metetra
.711 .902 .964 r
.87432 .4493 .8801 .45338 .89565 .44624 .88993 .44188 Metetra
.7 .892 .967 r
.88993 .44188 .89565 .44624 .91131 .43954 .90565 .43487 Metetra
.69 .88 .969 r
.90565 .43487 .91131 .43954 .92709 .43325 .92148 .42825 Metetra
.681 .868 .97 r
.92148 .42825 .92709 .43325 .943 .42735 .93743 .42198 Metetra
.673 .855 .969 r
.93743 .42198 .943 .42735 .95903 .42181 .95351 .41606 Metetra
.732 .229 0 r
.36894 .67326 .37724 .68051 .39007 .69777 .38178 .68988 Metetra
.624 .115 0 r
.38178 .68988 .39007 .69777 .40319 .7133 .39492 .70479 Metetra
0 .065 .572 r
.39492 .70479 .40319 .7133 .41661 .72639 .40835 .71733 Metetra
0 .281 .773 r
.40835 .71733 .41661 .72639 .4303 .73658 .42207 .72706 Metetra
.153 .462 .888 r
.42207 .72706 .4303 .73658 .44426 .74365 .43604 .73379 Metetra
.369 .576 .92 r
.43604 .73379 .44426 .74365 .45843 .74754 .45024 .73746 Metetra
.511 .64 .912 r
.45024 .73746 .45843 .74754 .47279 .74834 .46462 .73818 Metetra
.603 .677 .893 r
.46462 .73818 .47279 .74834 .4873 .74624 .47916 .73613 Metetra
.664 .701 .874 r
.47916 .73613 .4873 .74624 .50191 .74152 .49381 .73158 Metetra
.706 .718 .858 r
.49381 .73158 .50191 .74152 .5166 .7345 .50855 .72482 Metetra
.737 .732 .846 r
.50855 .72482 .5166 .7345 .53134 .7255 .52334 .71618 Metetra
.761 .744 .837 r
.52334 .71618 .53134 .7255 .54611 .71486 .53817 .70597 Metetra
.78 .757 .832 r
.53817 .70597 .54611 .71486 .56089 .7029 .55302 .69449 Metetra
.795 .769 .829 r
.55302 .69449 .56089 .7029 .57567 .68993 .56787 .68203 Metetra
.808 .781 .828 r
.56787 .68203 .57567 .68993 .59043 .67621 .58272 .66884 Metetra
.818 .794 .83 r
.58272 .66884 .59043 .67621 .60519 .662 .59757 .65516 Metetra
.827 .808 .833 r
.59757 .65516 .60519 .662 .61993 .6475 .61241 .64118 Metetra
.833 .821 .837 r
.61241 .64118 .61993 .6475 .63466 .63289 .62724 .62707 Metetra
.838 .835 .843 r
.62724 .62707 .63466 .63289 .64938 .61833 .64206 .61298 Metetra
.841 .849 .85 r
.64206 .61298 .64938 .61833 .6641 .60394 .65689 .59903 Metetra
.843 .863 .858 r
.65689 .59903 .6641 .60394 .67883 .58983 .67172 .58531 Metetra
.842 .876 .866 r
.67172 .58531 .67883 .58983 .69357 .57608 .68657 .57189 Metetra
.84 .888 .875 r
.68657 .57189 .69357 .57608 .70832 .56274 .70143 .55885 Metetra
.836 .899 .884 r
.70143 .55885 .70832 .56274 .72311 .54987 .71633 .54622 Metetra
.829 .909 .893 r
.71633 .54622 .72311 .54987 .73793 .53749 .73126 .53403 Metetra
.821 .918 .902 r
.73126 .53403 .73793 .53749 .7528 .52563 .74624 .5223 Metetra
.812 .924 .911 r
.74624 .5223 .7528 .52563 .76773 .5143 .76127 .51106 Metetra
.8 .929 .919 r
.76127 .51106 .76773 .5143 .78271 .50349 .77635 .50029 Metetra
.788 .932 .927 r
.77635 .50029 .78271 .50349 .79777 .49322 .79151 .49 Metetra
.776 .932 .934 r
.79151 .49 .79777 .49322 .8129 .48346 .80673 .48019 Metetra
.763 .931 .941 r
.80673 .48019 .8129 .48346 .82811 .4742 .82204 .47084 Metetra
.75 .928 .948 r
.82204 .47084 .82811 .4742 .84342 .46544 .83743 .46193 Metetra
.737 .924 .954 r
.83743 .46193 .84342 .46544 .85882 .45714 .85291 .45346 Metetra
.725 .918 .959 r
.85291 .45346 .85882 .45714 .87432 .4493 .86849 .4454 Metetra
.714 .91 .963 r
.86849 .4454 .87432 .4493 .88993 .44188 .88417 .43774 Metetra
.703 .901 .967 r
.88417 .43774 .88993 .44188 .90565 .43487 .89995 .43045 Metetra
.694 .891 .969 r
.89995 .43045 .90565 .43487 .92148 .42825 .91584 .42352 Metetra
.686 .881 .971 r
.91584 .42352 .92148 .42825 .93743 .42198 .93185 .41693 Metetra
.678 .869 .971 r
.93185 .41693 .93743 .42198 .95351 .41606 .94797 .41065 Metetra
.71 .201 0 r
.36056 .66595 .36894 .67326 .38178 .68988 .37342 .68192 Metetra
.592 .082 0 r
.37342 .68192 .38178 .68988 .39492 .70479 .38657 .69621 Metetra
0 .1 .607 r
.38657 .69621 .39492 .70479 .40835 .71733 .40002 .70819 Metetra
0 .308 .793 r
.40002 .70819 .40835 .71733 .42207 .72706 .41376 .71747 Metetra
.177 .476 .894 r
.41376 .71747 .42207 .72706 .43604 .73379 .42775 .72385 Metetra
.379 .581 .921 r
.42775 .72385 .43604 .73379 .45024 .73746 .44198 .7273 Metetra
.513 .641 .912 r
.44198 .7273 .45024 .73746 .46462 .73818 .45639 .72793 Metetra
.6 .676 .894 r
.45639 .72793 .46462 .73818 .47916 .73613 .47096 .72592 Metetra
.659 .699 .876 r
.47096 .72592 .47916 .73613 .49381 .73158 .48565 .72153 Metetra
.701 .716 .861 r
.48565 .72153 .49381 .73158 .50855 .72482 .50043 .71503 Metetra
.731 .73 .849 r
.50043 .71503 .50855 .72482 .52334 .71618 .51528 .70674 Metetra
.755 .742 .841 r
.51528 .70674 .52334 .71618 .53817 .70597 .53016 .69695 Metetra
.774 .755 .836 r
.53016 .69695 .53817 .70597 .55302 .69449 .54508 .68594 Metetra
.789 .767 .833 r
.54508 .68594 .55302 .69449 .56787 .68203 .56 .67399 Metetra
.801 .78 .833 r
.56 .67399 .56787 .68203 .58272 .66884 .57494 .66133 Metetra
.811 .793 .835 r
.57494 .66133 .58272 .66884 .59757 .65516 .58987 .64817 Metetra
.82 .806 .838 r
.58987 .64817 .59757 .65516 .61241 .64118 .6048 .63471 Metetra
.826 .82 .843 r
.6048 .63471 .61241 .64118 .62724 .62707 .61972 .6211 Metetra
.831 .833 .849 r
.61972 .6211 .62724 .62707 .64206 .61298 .63465 .60748 Metetra
.835 .847 .855 r
.63465 .60748 .64206 .61298 .65689 .59903 .64958 .59397 Metetra
.836 .861 .863 r
.64958 .59397 .65689 .59903 .67172 .58531 .66452 .58064 Metetra
.836 .874 .871 r
.66452 .58064 .67172 .58531 .68657 .57189 .67948 .56758 Metetra
.834 .887 .879 r
.67948 .56758 .68657 .57189 .70143 .55885 .69445 .55484 Metetra
.83 .898 .888 r
.69445 .55484 .70143 .55885 .71633 .54622 .70946 .54247 Metetra
.824 .908 .897 r
.70946 .54247 .71633 .54622 .73126 .53403 .7245 .53048 Metetra
.817 .917 .905 r
.7245 .53048 .73126 .53403 .74624 .5223 .73959 .51892 Metetra
.808 .924 .913 r
.73959 .51892 .74624 .5223 .76127 .51106 .75472 .50778 Metetra
.797 .929 .921 r
.75472 .50778 .76127 .51106 .77635 .50029 .76991 .49708 Metetra
.786 .932 .928 r
.76991 .49708 .77635 .50029 .79151 .49 .78517 .48681 Metetra
.774 .934 .935 r
.78517 .48681 .79151 .49 .80673 .48019 .80049 .47697 Metetra
.762 .934 .942 r
.80049 .47697 .80673 .48019 .82204 .47084 .81589 .46754 Metetra
.749 .932 .948 r
.81589 .46754 .82204 .47084 .83743 .46193 .83137 .45853 Metetra
.737 .928 .953 r
.83137 .45853 .83743 .46193 .85291 .45346 .84694 .44991 Metetra
.726 .923 .958 r
.84694 .44991 .85291 .45346 .86849 .4454 .8626 .44167 Metetra
.715 .917 .963 r
.8626 .44167 .86849 .4454 .88417 .43774 .87836 .4338 Metetra
.706 .91 .966 r
.87836 .4338 .88417 .43774 .89995 .43045 .89421 .42627 Metetra
.697 .902 .969 r
.89421 .42627 .89995 .43045 .91584 .42352 .91017 .41906 Metetra
.689 .892 .971 r
.91017 .41906 .91584 .42352 .93185 .41693 .92624 .41217 Metetra
.682 .882 .973 r
.92624 .41217 .93185 .41693 .94797 .41065 .94242 .40557 Metetra
.685 .172 0 r
.3521 .65856 .36056 .66595 .37342 .68192 .36498 .67388 Metetra
.556 .046 0 r
.36498 .67388 .37342 .68192 .38657 .69621 .37815 .68755 Metetra
0 .137 .642 r
.37815 .68755 .38657 .69621 .40002 .70819 .39163 .69898 Metetra
0 .335 .813 r
.39163 .69898 .40002 .70819 .41376 .71747 .40538 .70779 Metetra
.2 .49 .9 r
.40538 .70779 .41376 .71747 .42775 .72385 .4194 .71382 Metetra
.389 .587 .921 r
.4194 .71382 .42775 .72385 .44198 .7273 .43365 .71705 Metetra
.515 .642 .912 r
.43365 .71705 .44198 .7273 .45639 .72793 .44809 .71759 Metetra
.598 .675 .894 r
.44809 .71759 .45639 .72793 .47096 .72592 .46269 .71561 Metetra
.655 .697 .877 r
.46269 .71561 .47096 .72592 .48565 .72153 .47742 .71137 Metetra
.695 .714 .863 r
.47742 .71137 .48565 .72153 .50043 .71503 .49224 .70513 Metetra
.725 .728 .852 r
.49224 .70513 .50043 .71503 .51528 .70674 .50714 .69718 Metetra
.748 .74 .845 r
.50714 .69718 .51528 .70674 .53016 .69695 .52208 .6878 Metetra
.767 .753 .84 r
.52208 .6878 .53016 .69695 .54508 .68594 .53706 .67725 Metetra
.782 .765 .838 r
.53706 .67725 .54508 .68594 .56 .67399 .55206 .66579 Metetra
.794 .778 .838 r
.55206 .66579 .56 .67399 .57494 .66133 .56707 .65365 Metetra
.804 .791 .84 r
.56707 .65365 .57494 .66133 .58987 .64817 .58208 .64102 Metetra
.813 .804 .843 r
.58208 .64102 .58987 .64817 .6048 .63471 .5971 .62807 Metetra
.819 .818 .848 r
.5971 .62807 .6048 .63471 .61972 .6211 .61212 .61497 Metetra
.824 .832 .854 r
.61212 .61497 .61972 .6211 .63465 .60748 .62715 .60182 Metetra
.828 .845 .861 r
.62715 .60182 .63465 .60748 .64958 .59397 .64218 .58875 Metetra
.83 .859 .868 r
.64218 .58875 .64958 .59397 .66452 .58064 .65723 .57583 Metetra
.83 .872 .876 r
.65723 .57583 .66452 .58064 .67948 .56758 .6723 .56313 Metetra
.828 .885 .884 r
.6723 .56313 .67948 .56758 .69445 .55484 .68738 .55071 Metetra
.824 .896 .892 r
.68738 .55071 .69445 .55484 .70946 .54247 .7025 .5386 Metetra
.819 .907 .901 r
.7025 .5386 .70946 .54247 .7245 .53048 .71765 .52685 Metetra
.812 .916 .909 r
.71765 .52685 .7245 .53048 .73959 .51892 .73285 .51546 Metetra
.804 .923 .916 r
.73285 .51546 .73959 .51892 .75472 .50778 .74809 .50446 Metetra
.794 .929 .923 r
.74809 .50446 .75472 .50778 .76991 .49708 .76339 .49384 Metetra
.783 .933 .93 r
.76339 .49384 .76991 .49708 .78517 .48681 .77875 .48362 Metetra
.772 .935 .937 r
.77875 .48362 .78517 .48681 .80049 .47697 .79417 .47378 Metetra
.76 .935 .942 r
.79417 .47378 .80049 .47697 .81589 .46754 .80967 .46431 Metetra
.748 .934 .948 r
.80967 .46431 .81589 .46754 .83137 .45853 .82525 .45522 Metetra
.737 .932 .953 r
.82525 .45522 .83137 .45853 .84694 .44991 .84091 .44649 Metetra
.726 .928 .958 r
.84091 .44649 .84694 .44991 .8626 .44167 .85665 .4381 Metetra
.716 .924 .962 r
.85665 .4381 .8626 .44167 .87836 .4338 .87249 .43004 Metetra
.707 .918 .966 r
.87249 .43004 .87836 .4338 .89421 .42627 .88843 .4223 Metetra
.698 .911 .969 r
.88843 .4223 .89421 .42627 .91017 .41906 .90446 .41486 Metetra
.691 .903 .972 r
.90446 .41486 .91017 .41906 .92624 .41217 .9206 .40771 Metetra
.684 .894 .973 r
.9206 .40771 .92624 .41217 .94242 .40557 .93685 .40082 Metetra
.656 .139 0 r
.34355 .65111 .3521 .65856 .36498 .67388 .35646 .66577 Metetra
.518 .009 0 r
.35646 .66577 .36498 .67388 .37815 .68755 .36966 .67882 Metetra
0 .173 .676 r
.36966 .67882 .37815 .68755 .39163 .69898 .38315 .68968 Metetra
0 .361 .83 r
.38315 .68968 .39163 .69898 .40538 .70779 .39693 .69803 Metetra
.223 .504 .905 r
.39693 .69803 .40538 .70779 .4194 .71382 .41097 .70371 Metetra
.399 .592 .921 r
.41097 .70371 .4194 .71382 .43365 .71705 .42525 .70672 Metetra
.517 .643 .912 r
.42525 .70672 .43365 .71705 .44809 .71759 .43971 .70716 Metetra
.596 .674 .895 r
.43971 .70716 .44809 .71759 .46269 .71561 .45435 .70521 Metetra
.651 .696 .879 r
.45435 .70521 .46269 .71561 .47742 .71137 .46911 .70111 Metetra
.69 .712 .865 r
.46911 .70111 .47742 .71137 .49224 .70513 .48398 .69511 Metetra
.719 .725 .855 r
.48398 .69511 .49224 .70513 .50714 .69718 .49892 .68749 Metetra
.742 .738 .848 r
.49892 .68749 .50714 .69718 .52208 .6878 .51392 .67851 Metetra
.76 .75 .844 r
.51392 .67851 .52208 .6878 .53706 .67725 .52896 .66841 Metetra
.774 .763 .842 r
.52896 .66841 .53706 .67725 .55206 .66579 .54403 .65744 Metetra
.787 .775 .843 r
.54403 .65744 .55206 .66579 .56707 .65365 .55912 .64581 Metetra
.797 .788 .845 r
.55912 .64581 .56707 .65365 .58208 .64102 .57421 .6337 Metetra
.805 .802 .848 r
.57421 .6337 .58208 .64102 .5971 .62807 .58932 .62126 Metetra
.812 .815 .853 r
.58932 .62126 .5971 .62807 .61212 .61497 .60444 .60865 Metetra
.817 .829 .859 r
.60444 .60865 .61212 .61497 .62715 .60182 .61956 .59599 Metetra
.82 .843 .866 r
.61956 .59599 .62715 .60182 .64218 .58875 .6347 .58336 Metetra
.822 .857 .873 r
.6347 .58336 .64218 .58875 .65723 .57583 .64985 .57085 Metetra
.823 .87 .881 r
.64985 .57085 .65723 .57583 .6723 .56313 .66502 .55852 Metetra
.821 .883 .889 r
.66502 .55852 .6723 .56313 .68738 .55071 .68022 .54643 Metetra
.818 .894 .897 r
.68022 .54643 .68738 .55071 .7025 .5386 .69545 .53462 Metetra
.813 .905 .905 r
.69545 .53462 .7025 .5386 .71765 .52685 .71071 .52311 Metetra
.807 .914 .912 r
.71071 .52311 .71765 .52685 .73285 .51546 .72601 .51192 Metetra
.799 .922 .919 r
.72601 .51192 .73285 .51546 .74809 .50446 .74137 .50107 Metetra
.79 .928 .926 r
.74137 .50107 .74809 .50446 .76339 .49384 .75678 .49057 Metetra
.78 .932 .932 r
.75678 .49057 .76339 .49384 .77875 .48362 .77224 .48041 Metetra
.769 .935 .938 r
.77224 .48041 .77875 .48362 .79417 .47378 .78777 .4706 Metetra
.758 .937 .943 r
.78777 .4706 .79417 .47378 .80967 .46431 .80337 .46113 Metetra
.746 .937 .948 r
.80337 .46113 .80967 .46431 .82525 .45522 .81905 .45199 Metetra
.735 .935 .953 r
.81905 .45199 .82525 .45522 .84091 .44649 .83481 .44317 Metetra
.725 .932 .957 r
.83481 .44317 .84091 .44649 .85665 .4381 .85065 .43467 Metetra
.715 .929 .961 r
.85065 .43467 .85665 .4381 .87249 .43004 .86657 .42646 Metetra
.706 .924 .965 r
.86657 .42646 .87249 .43004 .88843 .4223 .88259 .41855 Metetra
.698 .918 .968 r
.88259 .41855 .88843 .4223 .90446 .41486 .89871 .4109 Metetra
.691 .912 .971 r
.89871 .4109 .90446 .41486 .9206 .40771 .91493 .40352 Metetra
.685 .905 .973 r
.91493 .40352 .9206 .40771 .93685 .40082 .93125 .39638 Metetra
.625 .105 0 r
.33493 .64358 .34355 .65111 .35646 .66577 .34786 .65759 Metetra
0 .03 .523 r
.34786 .65759 .35646 .66577 .36966 .67882 .36109 .67001 Metetra
0 .21 .708 r
.36109 .67001 .36966 .67882 .38315 .68968 .37461 .68031 Metetra
.016 .387 .847 r
.37461 .68031 .38315 .68968 .39693 .69803 .38841 .6882 Metetra
.245 .517 .91 r
.38841 .6882 .39693 .69803 .41097 .70371 .40248 .69352 Metetra
.409 .597 .922 r
.40248 .69352 .41097 .70371 .42525 .70672 .41677 .6963 Metetra
.52 .644 .911 r
.41677 .6963 .42525 .70672 .43971 .70716 .43127 .69663 Metetra
.594 .673 .895 r
.43127 .69663 .43971 .70716 .45435 .70521 .44594 .6947 Metetra
.647 .694 .88 r
.44594 .6947 .45435 .70521 .46911 .70111 .46074 .69074 Metetra
.684 .71 .867 r
.46074 .69074 .46911 .70111 .48398 .69511 .47565 .68497 Metetra
.713 .723 .858 r
.47565 .68497 .48398 .69511 .49892 .68749 .49064 .67767 Metetra
.735 .736 .852 r
.49064 .67767 .49892 .68749 .51392 .67851 .50569 .66908 Metetra
.753 .748 .848 r
.50569 .66908 .51392 .67851 .52896 .66841 .52079 .65943 Metetra
.767 .76 .847 r
.52079 .65943 .52896 .66841 .54403 .65744 .53593 .64893 Metetra
.779 .773 .847 r
.53593 .64893 .54403 .65744 .55912 .64581 .55108 .6378 Metetra
.789 .786 .85 r
.55108 .6378 .55912 .64581 .57421 .6337 .56626 .6262 Metetra
.797 .799 .853 r
.56626 .6262 .57421 .6337 .58932 .62126 .58145 .61427 Metetra
.804 .813 .858 r
.58145 .61427 .58932 .62126 .60444 .60865 .59666 .60216 Metetra
.809 .827 .864 r
.59666 .60216 .60444 .60865 .61956 .59599 .61188 .58997 Metetra
.813 .84 .871 r
.61188 .58997 .61956 .59599 .6347 .58336 .62712 .57779 Metetra
.815 .854 .878 r
.62712 .57779 .6347 .58336 .64985 .57085 .64237 .56569 Metetra
.815 .867 .886 r
.64237 .56569 .64985 .57085 .66502 .55852 .65765 .55375 Metetra
.814 .88 .893 r
.65765 .55375 .66502 .55852 .68022 .54643 .67296 .542 Metetra
.811 .892 .901 r
.67296 .542 .68022 .54643 .69545 .53462 .68829 .53049 Metetra
.807 .902 .909 r
.68829 .53049 .69545 .53462 .71071 .52311 .70367 .51924 Metetra
.801 .912 .916 r
.70367 .51924 .71071 .52311 .72601 .51192 .71909 .50827 Metetra
.794 .92 .923 r
.71909 .50827 .72601 .51192 .74137 .50107 .73455 .4976 Metetra
.785 .927 .929 r
.73455 .4976 .74137 .50107 .75678 .49057 .75007 .48723 Metetra
.775 .932 .935 r
.75007 .48723 .75678 .49057 .77224 .48041 .76565 .47717 Metetra
.765 .935 .94 r
.76565 .47717 .77224 .48041 .78777 .4706 .78129 .46741 Metetra
.755 .937 .945 r
.78129 .46741 .78777 .4706 .80337 .46113 .79699 .45796 Metetra
.744 .938 .949 r
.79699 .45796 .80337 .46113 .81905 .45199 .81277 .4488 Metetra
.733 .937 .953 r
.81277 .4488 .81905 .45199 .83481 .44317 .82863 .43994 Metetra
.723 .936 .957 r
.82863 .43994 .83481 .44317 .85065 .43467 .84457 .43135 Metetra
.714 .933 .961 r
.84457 .43135 .85065 .43467 .86657 .42646 .86059 .42303 Metetra
.705 .929 .964 r
.86059 .42303 .86657 .42646 .88259 .41855 .87671 .41497 Metetra
.697 .925 .967 r
.87671 .41497 .88259 .41855 .89871 .4109 .89291 .40716 Metetra
.69 .92 .97 r
.89291 .40716 .89871 .4109 .91493 .40352 .90921 .39959 Metetra
.684 .914 .973 r
.90921 .39959 .91493 .40352 .93125 .39638 .92561 .39223 Metetra
.59 .068 0 r
.32622 .63598 .33493 .64358 .34786 .65759 .33919 .64933 Metetra
0 .071 .565 r
.33919 .64933 .34786 .65759 .36109 .67001 .35244 .66112 Metetra
0 .247 .74 r
.35244 .66112 .36109 .67001 .37461 .68031 .36599 .67086 Metetra
.053 .411 .862 r
.36599 .67086 .37461 .68031 .38841 .6882 .37982 .67828 Metetra
.267 .529 .914 r
.37982 .67828 .38841 .6882 .40248 .69352 .39391 .68324 Metetra
.419 .601 .922 r
.39391 .68324 .40248 .69352 .41677 .6963 .40823 .68579 Metetra
.522 .645 .911 r
.40823 .68579 .41677 .6963 .43127 .69663 .42276 .68601 Metetra
.593 .673 .895 r
.42276 .68601 .43127 .69663 .44594 .6947 .43746 .6841 Metetra
.643 .692 .881 r
.43746 .6841 .44594 .6947 .46074 .69074 .45229 .68025 Metetra
.679 .708 .869 r
.45229 .68025 .46074 .69074 .47565 .68497 .46724 .67471 Metetra
.706 .721 .861 r
.46724 .67471 .47565 .68497 .49064 .67767 .48228 .66772 Metetra
.728 .733 .855 r
.48228 .66772 .49064 .67767 .50569 .66908 .49738 .6595 Metetra
.745 .745 .852 r
.49738 .6595 .50569 .66908 .52079 .65943 .51254 .65028 Metetra
.759 .758 .851 r
.51254 .65028 .52079 .65943 .53593 .64893 .52774 .64026 Metetra
.771 .77 .852 r
.52774 .64026 .53593 .64893 .55108 .6378 .54297 .62961 Metetra
.781 .783 .854 r
.54297 .62961 .55108 .6378 .56626 .6262 .55822 .61851 Metetra
.789 .796 .858 r
.55822 .61851 .56626 .6262 .58145 .61427 .5735 .60709 Metetra
.796 .81 .863 r
.5735 .60709 .58145 .61427 .59666 .60216 .58879 .59547 Metetra
.801 .823 .869 r
.58879 .59547 .59666 .60216 .61188 .58997 .60411 .58375 Metetra
.804 .837 .876 r
.60411 .58375 .61188 .58997 .62712 .57779 .61944 .57202 Metetra
.807 .851 .883 r
.61944 .57202 .62712 .57779 .64237 .56569 .6348 .56035 Metetra
.807 .864 .89 r
.6348 .56035 .64237 .56569 .65765 .55375 .65018 .54879 Metetra
.806 .877 .898 r
.65018 .54879 .65765 .55375 .67296 .542 .6656 .5374 Metetra
.804 .889 .905 r
.6656 .5374 .67296 .542 .68829 .53049 .68105 .5262 Metetra
.8 .899 .913 r
.68105 .5262 .68829 .53049 .70367 .51924 .69653 .51522 Metetra
.795 .909 .919 r
.69653 .51522 .70367 .51924 .71909 .50827 .71206 .50449 Metetra
.788 .918 .926 r
.71206 .50449 .71909 .50827 .73455 .4976 .72764 .49402 Metetra
.78 .925 .932 r
.72764 .49402 .73455 .4976 .75007 .48723 .74327 .48381 Metetra
.771 .93 .937 r
.74327 .48381 .75007 .48723 .76565 .47717 .75896 .47386 Metetra
.761 .934 .942 r
.75896 .47386 .76565 .47717 .78129 .46741 .77471 .46419 Metetra
.751 .937 .946 r
.77471 .46419 .78129 .46741 .79699 .45796 .79053 .45479 Metetra
.741 .938 .95 r
.79053 .45479 .79699 .45796 .81277 .4488 .80642 .44565 Metetra
.731 .939 .954 r
.80642 .44565 .81277 .4488 .82863 .43994 .82238 .43676 Metetra
.721 .938 .957 r
.82238 .43676 .82863 .43994 .84457 .43135 .83842 .42812 Metetra
.712 .936 .961 r
.83842 .42812 .84457 .43135 .86059 .42303 .85455 .41973 Metetra
.703 .934 .964 r
.85455 .41973 .86059 .42303 .87671 .41497 .87076 .41156 Metetra
.695 .93 .967 r
.87076 .41156 .87671 .41497 .89291 .40716 .88706 .40362 Metetra
.688 .926 .969 r
.88706 .40362 .89291 .40716 .90921 .39959 .90345 .39588 Metetra
.682 .922 .972 r
.90345 .39588 .90921 .39959 .92561 .39223 .91994 .38835 Metetra
.551 .028 0 r
.31743 .6283 .32622 .63598 .33919 .64933 .33043 .64099 Metetra
0 .113 .607 r
.33043 .64099 .33919 .64933 .35244 .66112 .34371 .65215 Metetra
0 .283 .769 r
.34371 .65215 .35244 .66112 .36599 .67086 .35729 .66133 Metetra
.09 .435 .875 r
.35729 .66133 .36599 .67086 .37982 .67828 .37115 .66827 Metetra
.288 .541 .917 r
.37115 .66827 .37982 .67828 .39391 .68324 .38527 .67288 Metetra
.429 .606 .922 r
.38527 .67288 .39391 .68324 .40823 .68579 .39962 .67519 Metetra
.525 .646 .91 r
.39962 .67519 .40823 .68579 .42276 .68601 .41418 .6753 Metetra
.591 .672 .896 r
.41418 .6753 .42276 .68601 .43746 .6841 .4289 .67339 Metetra
.639 .691 .882 r
.4289 .67339 .43746 .6841 .45229 .68025 .44377 .66966 Metetra
.674 .705 .871 r
.44377 .66966 .45229 .68025 .46724 .67471 .45876 .66433 Metetra
.7 .718 .864 r
.45876 .66433 .46724 .67471 .48228 .66772 .47384 .65763 Metetra
.721 .731 .858 r
.47384 .65763 .48228 .66772 .49738 .6595 .489 .64978 Metetra
.738 .743 .856 r
.489 .64978 .49738 .6595 .51254 .65028 .50421 .64097 Metetra
.752 .755 .855 r
.50421 .64097 .51254 .65028 .52774 .64026 .51947 .6314 Metetra
.763 .767 .856 r
.51947 .6314 .52774 .64026 .54297 .62961 .53477 .62124 Metetra
.773 .78 .859 r
.53477 .62124 .54297 .62961 .55822 .61851 .5501 .61063 Metetra
.781 .793 .863 r
.5501 .61063 .55822 .61851 .5735 .60709 .56546 .5997 Metetra
.787 .806 .868 r
.56546 .5997 .5735 .60709 .58879 .59547 .58084 .58857 Metetra
.792 .82 .874 r
.58084 .58857 .58879 .59547 .60411 .58375 .59624 .57732 Metetra
.796 .833 .88 r
.59624 .57732 .60411 .58375 .61944 .57202 .61167 .56604 Metetra
.798 .847 .887 r
.61167 .56604 .61944 .57202 .6348 .56035 .62713 .55479 Metetra
.799 .86 .895 r
.62713 .55479 .6348 .56035 .65018 .54879 .64262 .54363 Metetra
.798 .873 .902 r
.64262 .54363 .65018 .54879 .6656 .5374 .65814 .5326 Metetra
.796 .885 .909 r
.65814 .5326 .6656 .5374 .68105 .5262 .6737 .52173 Metetra
.793 .896 .917 r
.6737 .52173 .68105 .5262 .69653 .51522 .6893 .51104 Metetra
.788 .906 .923 r
.6893 .51104 .69653 .51522 .71206 .50449 .70494 .50056 Metetra
.782 .915 .929 r
.70494 .50056 .71206 .50449 .72764 .49402 .72063 .49031 Metetra
.774 .922 .935 r
.72063 .49031 .72764 .49402 .74327 .48381 .73638 .48028 Metetra
.766 .928 .94 r
.73638 .48028 .74327 .48381 .75896 .47386 .75218 .47048 Metetra
.757 .933 .944 r
.75218 .47048 .75896 .47386 .77471 .46419 .76804 .46091 Metetra
.747 .936 .948 r
.76804 .46091 .77471 .46419 .79053 .45479 .78397 .45159 Metetra
.737 .938 .952 r
.78397 .45159 .79053 .45479 .80642 .44565 .79997 .44249 Metetra
.727 .939 .955 r
.79997 .44249 .80642 .44565 .82238 .43676 .81605 .43361 Metetra
.718 .939 .958 r
.81605 .43361 .82238 .43676 .83842 .42812 .8322 .42496 Metetra
.709 .938 .96 r
.8322 .42496 .83842 .42812 .85455 .41973 .84843 .41652 Metetra
.7 .937 .963 r
.84843 .41652 .85455 .41973 .87076 .41156 .86474 .40828 Metetra
.692 .934 .966 r
.86474 .40828 .87076 .41156 .88706 .40362 .88115 .40024 Metetra
.685 .931 .968 r
.88115 .40024 .88706 .40362 .90345 .39588 .89764 .39238 Metetra
.679 .928 .97 r
.89764 .39238 .90345 .39588 .91994 .38835 .91422 .3847 Metetra
.508 0 0 r
.30855 .62056 .31743 .6283 .33043 .64099 .32158 .63258 Metetra
0 .157 .649 r
.32158 .63258 .33043 .64099 .34371 .65215 .3349 .6431 Metetra
0 .319 .796 r
.3349 .6431 .34371 .65215 .35729 .66133 .34851 .65172 Metetra
.126 .458 .887 r
.34851 .65172 .35729 .66133 .37115 .66827 .3624 .65818 Metetra
.309 .552 .92 r
.3624 .65818 .37115 .66827 .38527 .67288 .37655 .66243 Metetra
.439 .611 .921 r
.37655 .66243 .38527 .67288 .39962 .67519 .39093 .66449 Metetra
.528 .647 .91 r
.39093 .66449 .39962 .67519 .41418 .6753 .40552 .66448 Metetra
.59 .671 .896 r
.40552 .66448 .41418 .6753 .4289 .67339 .42028 .66257 Metetra
.635 .689 .883 r
.42028 .66257 .4289 .67339 .44377 .66966 .43518 .65894 Metetra
.668 .703 .873 r
.43518 .65894 .44377 .66966 .45876 .66433 .45021 .65382 Metetra
.694 .716 .866 r
.45021 .65382 .45876 .66433 .47384 .65763 .46533 .6474 Metetra
.714 .728 .861 r
.46533 .6474 .47384 .65763 .489 .64978 .48054 .6399 Metetra
.73 .74 .859 r
.48054 .6399 .489 .64978 .50421 .64097 .4958 .6315 Metetra
.744 .752 .859 r
.4958 .6315 .50421 .64097 .51947 .6314 .51112 .62237 Metetra
.755 .764 .86 r
.51112 .62237 .51947 .6314 .53477 .62124 .52649 .61267 Metetra
.764 .776 .863 r
.52649 .61267 .53477 .62124 .5501 .61063 .54189 .60254 Metetra
.772 .789 .867 r
.54189 .60254 .5501 .61063 .56546 .5997 .55733 .5921 Metetra
.778 .802 .872 r
.55733 .5921 .56546 .5997 .58084 .58857 .57279 .58145 Metetra
.783 .816 .878 r
.57279 .58145 .58084 .58857 .59624 .57732 .58829 .57067 Metetra
.787 .829 .885 r
.58829 .57067 .59624 .57732 .61167 .56604 .60381 .55984 Metetra
.789 .843 .892 r
.60381 .55984 .61167 .56604 .62713 .55479 .61937 .54902 Metetra
.79 .856 .899 r
.61937 .54902 .62713 .55479 .64262 .54363 .63496 .53825 Metetra
.79 .868 .906 r
.63496 .53825 .64262 .54363 .65814 .5326 .65058 .52759 Metetra
.788 .88 .913 r
.65058 .52759 .65814 .5326 .6737 .52173 .66625 .51705 Metetra
.785 .891 .92 r
.66625 .51705 .6737 .52173 .6893 .51104 .68196 .50667 Metetra
.781 .902 .927 r
.68196 .50667 .6893 .51104 .70494 .50056 .69771 .49646 Metetra
.775 .911 .933 r
.69771 .49646 .70494 .50056 .72063 .49031 .71352 .48644 Metetra
.768 .918 .938 r
.71352 .48644 .72063 .49031 .73638 .48028 .72938 .47661 Metetra
.76 .925 .943 r
.72938 .47661 .73638 .48028 .75218 .47048 .7453 .46698 Metetra
.752 .93 .947 r
.7453 .46698 .75218 .47048 .76804 .46091 .76128 .45755 Metetra
.743 .934 .95 r
.76128 .45755 .76804 .46091 .78397 .45159 .77732 .44832 Metetra
.733 .937 .953 r
.77732 .44832 .78397 .45159 .79997 .44249 .79344 .43929 Metetra
.724 .939 .956 r
.79344 .43929 .79997 .44249 .81605 .43361 .80962 .43046 Metetra
.714 .939 .959 r
.80962 .43046 .81605 .43361 .8322 .42496 .82589 .42182 Metetra
.705 .939 .961 r
.82589 .42182 .8322 .42496 .84843 .41652 .84223 .41336 Metetra
.697 .938 .963 r
.84223 .41336 .84843 .41652 .86474 .40828 .85866 .40509 Metetra
.689 .937 .965 r
.85866 .40509 .86474 .40828 .88115 .40024 .87517 .39698 Metetra
.682 .935 .967 r
.87517 .39698 .88115 .40024 .89764 .39238 .89176 .38904 Metetra
.675 .932 .969 r
.89176 .38904 .89764 .39238 .91422 .3847 .90845 .38126 Metetra
0 .059 .536 r
.29959 .61273 .30855 .62056 .32158 .63258 .31266 .62408 Metetra
0 .201 .689 r
.31266 .62408 .32158 .63258 .3349 .6431 .32601 .63398 Metetra
0 .354 .821 r
.32601 .63398 .3349 .6431 .34851 .65172 .33966 .64202 Metetra
.16 .479 .897 r
.33966 .64202 .34851 .65172 .3624 .65818 .35358 .64801 Metetra
.329 .563 .923 r
.35358 .64801 .3624 .65818 .37655 .66243 .36776 .65189 Metetra
.448 .616 .921 r
.36776 .65189 .37655 .66243 .39093 .66449 .38218 .65371 Metetra
.531 .649 .909 r
.38218 .65371 .39093 .66449 .40552 .66448 .39679 .65357 Metetra
.589 .671 .896 r
.39679 .65357 .40552 .66448 .42028 .66257 .41158 .65164 Metetra
.632 .687 .884 r
.41158 .65164 .42028 .66257 .43518 .65894 .42652 .64811 Metetra
.663 .701 .875 r
.42652 .64811 .43518 .65894 .45021 .65382 .44158 .64318 Metetra
.688 .713 .868 r
.44158 .64318 .45021 .65382 .46533 .6474 .45675 .63703 Metetra
.707 .725 .864 r
.45675 .63703 .46533 .6474 .48054 .6399 .472 .62986 Metetra
.723 .737 .862 r
.472 .62986 .48054 .6399 .4958 .6315 .48732 .62185 Metetra
.736 .748 .862 r
.48732 .62185 .4958 .6315 .51112 .62237 .5027 .61315 Metetra
.747 .76 .864 r
.5027 .61315 .51112 .62237 .52649 .61267 .51812 .60391 Metetra
.756 .773 .867 r
.51812 .60391 .52649 .61267 .54189 .60254 .53359 .59424 Metetra
.763 .785 .871 r
.53359 .59424 .54189 .60254 .55733 .5921 .5491 .58428 Metetra
.769 .798 .876 r
.5491 .58428 .55733 .5921 .57279 .58145 .56465 .57409 Metetra
.774 .811 .882 r
.56465 .57409 .57279 .58145 .58829 .57067 .58023 .56378 Metetra
.778 .825 .889 r
.58023 .56378 .58829 .57067 .60381 .55984 .59585 .55339 Metetra
.78 .838 .896 r
.59585 .55339 .60381 .55984 .61937 .54902 .6115 .54299 Metetra
.782 .851 .903 r
.6115 .54299 .61937 .54902 .63496 .53825 .62719 .53263 Metetra
.781 .863 .91 r
.62719 .53263 .63496 .53825 .65058 .52759 .64292 .52234 Metetra
.78 .875 .917 r
.64292 .52234 .65058 .52759 .66625 .51705 .6587 .51215 Metetra
.777 .886 .924 r
.6587 .51215 .66625 .51705 .68196 .50667 .67451 .50208 Metetra
.773 .897 .93 r
.67451 .50208 .68196 .50667 .69771 .49646 .69038 .49216 Metetra
.768 .906 .936 r
.69038 .49216 .69771 .49646 .71352 .48644 .7063 .48238 Metetra
.762 .914 .941 r
.7063 .48238 .71352 .48644 .72938 .47661 .72228 .47277 Metetra
.754 .921 .946 r
.72228 .47277 .72938 .47661 .7453 .46698 .73831 .46333 Metetra
.746 .927 .949 r
.73831 .46333 .7453 .46698 .76128 .45755 .75441 .45406 Metetra
.738 .931 .953 r
.75441 .45406 .76128 .45755 .77732 .44832 .77057 .44496 Metetra
.729 .935 .956 r
.77057 .44496 .77732 .44832 .79344 .43929 .78681 .43603 Metetra
.72 .937 .958 r
.78681 .43603 .79344 .43929 .80962 .43046 .80311 .42727 Metetra
.71 .939 .96 r
.80311 .42727 .80962 .43046 .82589 .42182 .81949 .41867 Metetra
.701 .939 .962 r
.81949 .41867 .82589 .42182 .84223 .41336 .83595 .41023 Metetra
.693 .939 .963 r
.83595 .41023 .84223 .41336 .85866 .40509 .85249 .40195 Metetra
.685 .938 .965 r
.85249 .40195 .85866 .40509 .87517 .39698 .86911 .39382 Metetra
.678 .937 .966 r
.86911 .39382 .87517 .39698 .89176 .38904 .88582 .38582 Metetra
.671 .935 .968 r
.88582 .38582 .89176 .38904 .90845 .38126 .90262 .37797 Metetra
0 .105 .584 r
.29053 .60483 .29959 .61273 .31266 .62408 .30365 .61551 Metetra
0 .245 .728 r
.30365 .61551 .31266 .62408 .32601 .63398 .31704 .62477 Metetra
0 .387 .844 r
.31704 .62477 .32601 .63398 .33966 .64202 .33072 .63224 Metetra
.194 .499 .906 r
.33072 .63224 .33966 .64202 .35358 .64801 .34468 .63775 Metetra
.348 .574 .925 r
.34468 .63775 .35358 .64801 .36776 .65189 .3589 .64127 Metetra
.458 .62 .921 r
.3589 .64127 .36776 .65189 .38218 .65371 .37334 .64283 Metetra
.534 .65 .909 r
.37334 .64283 .38218 .65371 .39679 .65357 .38799 .64256 Metetra
.589 .67 .896 r
.38799 .64256 .39679 .65357 .41158 .65164 .40281 .64061 Metetra
.628 .686 .885 r
.40281 .64061 .41158 .65164 .42652 .64811 .41778 .63716 Metetra
.658 .699 .876 r
.41778 .63716 .42652 .64811 .44158 .64318 .43288 .6324 Metetra
.682 .711 .87 r
.43288 .6324 .44158 .64318 .45675 .63703 .44809 .62651 Metetra
.7 .722 .867 r
.44809 .62651 .45675 .63703 .472 .62986 .46338 .61966 Metetra
.715 .733 .865 r
.46338 .61966 .472 .62986 .48732 .62185 .47875 .61202 Metetra
.728 .745 .865 r
.47875 .61202 .48732 .62185 .5027 .61315 .49418 .60373 Metetra
.738 .757 .867 r
.49418 .60373 .5027 .61315 .51812 .60391 .50967 .59493 Metetra
.747 .769 .87 r
.50967 .59493 .51812 .60391 .53359 .59424 .52521 .58572 Metetra
.754 .781 .875 r
.52521 .58572 .53359 .59424 .5491 .58428 .54079 .57621 Metetra
.76 .794 .88 r
.54079 .57621 .5491 .58428 .56465 .57409 .55642 .56649 Metetra
.765 .806 .886 r
.55642 .56649 .56465 .57409 .58023 .56378 .57208 .55663 Metetra
.769 .819 .892 r
.57208 .55663 .58023 .56378 .59585 .55339 .58779 .54669 Metetra
.771 .832 .899 r
.58779 .54669 .59585 .55339 .6115 .54299 .60354 .53671 Metetra
.772 .845 .906 r
.60354 .53671 .6115 .54299 .62719 .53263 .61933 .52675 Metetra
.772 .857 .913 r
.61933 .52675 .62719 .53263 .64292 .52234 .63516 .51684 Metetra
.771 .869 .92 r
.63516 .51684 .64292 .52234 .6587 .51215 .65104 .507 Metetra
.769 .88 .927 r
.65104 .507 .6587 .51215 .67451 .50208 .66697 .49725 Metetra
.765 .891 .933 r
.66697 .49725 .67451 .50208 .69038 .49216 .68294 .48762 Metetra
.761 .9 .939 r
.68294 .48762 .69038 .49216 .7063 .48238 .69898 .47811 Metetra
.755 .909 .944 r
.69898 .47811 .7063 .48238 .72228 .47277 .71507 .46874 Metetra
.748 .916 .948 r
.71507 .46874 .72228 .47277 .73831 .46333 .73122 .4595 Metetra
.741 .922 .952 r
.73122 .4595 .73831 .46333 .75441 .45406 .74744 .45041 Metetra
.733 .928 .955 r
.74744 .45041 .75441 .45406 .77057 .44496 .76372 .44146 Metetra
.724 .932 .958 r
.76372 .44146 .77057 .44496 .78681 .43603 .78007 .43265 Metetra
.715 .935 .96 r
.78007 .43265 .78681 .43603 .80311 .42727 .7965 .42399 Metetra
.706 .937 .962 r
.7965 .42399 .80311 .42727 .81949 .41867 .813 .41546 Metetra
.698 .938 .963 r
.813 .41546 .81949 .41867 .83595 .41023 .82958 .40707 Metetra
.689 .938 .964 r
.82958 .40707 .83595 .41023 .85249 .40195 .84623 .39882 Metetra
.681 .938 .965 r
.84623 .39882 .85249 .40195 .86911 .39382 .86298 .39069 Metetra
.673 .938 .966 r
.86298 .39069 .86911 .39382 .88582 .38582 .87981 .38268 Metetra
.666 .937 .967 r
.87981 .38268 .88582 .38582 .90262 .37797 .89672 .37478 Metetra
0 .153 .631 r
.28139 .59685 .29053 .60483 .30365 .61551 .29455 .60686 Metetra
0 .288 .765 r
.29455 .60686 .30365 .61551 .31704 .62477 .30799 .61547 Metetra
.042 .419 .864 r
.30799 .61547 .31704 .62477 .33072 .63224 .32171 .62237 Metetra
.227 .518 .914 r
.32171 .62237 .33072 .63224 .34468 .63775 .33571 .62741 Metetra
.367 .584 .926 r
.33571 .62741 .34468 .63775 .3589 .64127 .34995 .63055 Metetra
.467 .625 .92 r
.34995 .63055 .3589 .64127 .37334 .64283 .36443 .63186 Metetra
.538 .651 .908 r
.36443 .63186 .37334 .64283 .38799 .64256 .37911 .63145 Metetra
.588 .67 .896 r
.37911 .63145 .38799 .64256 .40281 .64061 .39396 .62947 Metetra
.625 .685 .886 r
.39396 .62947 .40281 .64061 .41778 .63716 .40897 .62609 Metetra
.654 .697 .878 r
.40897 .62609 .41778 .63716 .43288 .6324 .4241 .62149 Metetra
.676 .708 .872 r
.4241 .62149 .43288 .6324 .44809 .62651 .43935 .61584 Metetra
.693 .719 .869 r
.43935 .61584 .44809 .62651 .46338 .61966 .45468 .60929 Metetra
.708 .73 .868 r
.45468 .60929 .46338 .61966 .47875 .61202 .4701 .60201 Metetra
.72 .741 .868 r
.4701 .60201 .47875 .61202 .49418 .60373 .48559 .59411 Metetra
.73 .752 .87 r
.48559 .59411 .49418 .60373 .50967 .59493 .50114 .58573 Metetra
.738 .764 .874 r
.50114 .58573 .50967 .59493 .52521 .58572 .51674 .57696 Metetra
.745 .776 .878 r
.51674 .57696 .52521 .58572 .54079 .57621 .53239 .5679 Metetra
.751 .788 .883 r
.53239 .5679 .54079 .57621 .55642 .56649 .54809 .55863 Metetra
.756 .801 .889 r
.54809 .55863 .55642 .56649 .57208 .55663 .56384 .54921 Metetra
.759 .813 .896 r
.56384 .54921 .57208 .55663 .58779 .54669 .57963 .5397 Metetra
.761 .826 .903 r
.57963 .5397 .58779 .54669 .60354 .53671 .59547 .53015 Metetra
.763 .839 .909 r
.59547 .53015 .60354 .53671 .61933 .52675 .61136 .52059 Metetra
.763 .851 .916 r
.61136 .52059 .61933 .52675 .63516 .51684 .62729 .51105 Metetra
.762 .862 .923 r
.62729 .51105 .63516 .51684 .65104 .507 .64327 .50156 Metetra
.76 .874 .93 r
.64327 .50156 .65104 .507 .66697 .49725 .65931 .49215 Metetra
.757 .884 .936 r
.65931 .49215 .66697 .49725 .68294 .48762 .6754 .48282 Metetra
.753 .894 .942 r
.6754 .48282 .68294 .48762 .69898 .47811 .69154 .47359 Metetra
.748 .903 .947 r
.69154 .47359 .69898 .47811 .71507 .46874 .70775 .46446 Metetra
.742 .91 .951 r
.70775 .46446 .71507 .46874 .73122 .4595 .72402 .45545 Metetra
.735 .917 .955 r
.72402 .45545 .73122 .4595 .74744 .45041 .74036 .44656 Metetra
.727 .923 .958 r
.74036 .44656 .74744 .45041 .76372 .44146 .75676 .43778 Metetra
.719 .927 .96 r
.75676 .43778 .76372 .44146 .78007 .43265 .77323 .42912 Metetra
.711 .931 .962 r
.77323 .42912 .78007 .43265 .7965 .42399 .78978 .42058 Metetra
.702 .934 .964 r
.78978 .42058 .7965 .42399 .813 .41546 .8064 .41215 Metetra
.694 .935 .965 r
.8064 .41215 .813 .41546 .82958 .40707 .8231 .40384 Metetra
.685 .937 .966 r
.8231 .40384 .82958 .40707 .84623 .39882 .83989 .39564 Metetra
.677 .937 .966 r
.83989 .39564 .84623 .39882 .86298 .39069 .85675 .38754 Metetra
.67 .937 .967 r
.85675 .38754 .86298 .39069 .87981 .38268 .87371 .37954 Metetra
.662 .937 .967 r
.87371 .37954 .87981 .38268 .89672 .37478 .89075 .37165 Metetra
0 .202 .678 r
.27216 .58879 .28139 .59685 .29455 .60686 .28536 .59812 Metetra
0 .331 .798 r
.28536 .59812 .29455 .60686 .30799 .61547 .29885 .60609 Metetra
.089 .449 .882 r
.29885 .60609 .30799 .61547 .32171 .62237 .31261 .61242 Metetra
.258 .536 .92 r
.31261 .61242 .32171 .62237 .33571 .62741 .32665 .61698 Metetra
.386 .593 .927 r
.32665 .61698 .33571 .62741 .34995 .63055 .34093 .61975 Metetra
.477 .629 .919 r
.34093 .61975 .34995 .63055 .36443 .63186 .35545 .62079 Metetra
.541 .653 .908 r
.35545 .62079 .36443 .63186 .37911 .63145 .37016 .62023 Metetra
.588 .67 .896 r
.37016 .62023 .37911 .63145 .39396 .62947 .38504 .61821 Metetra
.623 .683 .886 r
.38504 .61821 .39396 .62947 .40897 .62609 .40008 .61489 Metetra
.649 .695 .879 r
.40008 .61489 .40897 .62609 .4241 .62149 .41525 .61044 Metetra
.67 .706 .874 r
.41525 .61044 .4241 .62149 .43935 .61584 .43053 .60501 Metetra
.687 .716 .871 r
.43053 .60501 .43935 .61584 .45468 .60929 .44591 .59875 Metetra
.7 .726 .87 r
.44591 .59875 .45468 .60929 .4701 .60201 .46137 .5918 Metetra
.712 .737 .871 r
.46137 .5918 .4701 .60201 .48559 .59411 .47691 .58428 Metetra
.721 .748 .873 r
.47691 .58428 .48559 .59411 .50114 .58573 .49252 .5763 Metetra
.729 .759 .877 r
.49252 .5763 .50114 .58573 .51674 .57696 .50818 .56796 Metetra
.736 .771 .881 r
.50818 .56796 .51674 .57696 .53239 .5679 .5239 .55933 Metetra
.741 .783 .886 r
.5239 .55933 .53239 .5679 .54809 .55863 .53968 .5505 Metetra
.746 .795 .892 r
.53968 .5505 .54809 .55863 .56384 .54921 .5555 .54151 Metetra
.749 .807 .898 r
.5555 .54151 .56384 .54921 .57963 .5397 .57138 .53242 Metetra
.752 .819 .905 r
.57138 .53242 .57963 .5397 .59547 .53015 .58731 .52328 Metetra
.753 .831 .912 r
.58731 .52328 .59547 .53015 .61136 .52059 .60328 .51411 Metetra
.754 .843 .919 r
.60328 .51411 .61136 .52059 .62729 .51105 .61931 .50495 Metetra
.753 .855 .926 r
.61931 .50495 .62729 .51105 .64327 .50156 .6354 .49582 Metetra
.751 .866 .932 r
.6354 .49582 .64327 .50156 .65931 .49215 .65154 .48674 Metetra
.749 .877 .938 r
.65154 .48674 .65931 .49215 .6754 .48282 .66774 .47772 Metetra
.745 .886 .944 r
.66774 .47772 .6754 .48282 .69154 .47359 .684 .46877 Metetra
.74 .895 .949 r
.684 .46877 .69154 .47359 .70775 .46446 .70032 .45991 Metetra
.735 .903 .953 r
.70032 .45991 .70775 .46446 .72402 .45545 .71671 .45114 Metetra
.729 .91 .957 r
.71671 .45114 .72402 .45545 .74036 .44656 .73316 .44246 Metetra
.722 .916 .96 r
.73316 .44246 .74036 .44656 .75676 .43778 .74968 .43387 Metetra
.715 .922 .963 r
.74968 .43387 .75676 .43778 .77323 .42912 .76628 .42538 Metetra
.707 .926 .965 r
.76628 .42538 .77323 .42912 .78978 .42058 .78295 .41698 Metetra
.699 .929 .966 r
.78295 .41698 .78978 .42058 .8064 .41215 .7997 .40868 Metetra
.69 .932 .967 r
.7997 .40868 .8064 .41215 .8231 .40384 .81653 .40047 Metetra
.682 .934 .968 r
.81653 .40047 .8231 .40384 .83989 .39564 .83344 .39235 Metetra
.674 .935 .968 r
.83344 .39235 .83989 .39564 .85675 .38754 .85043 .38431 Metetra
.666 .935 .968 r
.85043 .38431 .85675 .38754 .87371 .37954 .86751 .37636 Metetra
.659 .935 .968 r
.86751 .37636 .87371 .37954 .89075 .37165 .88468 .36849 Metetra
0 .252 .722 r
.26283 .58065 .27216 .58879 .28536 .59812 .27609 .5893 Metetra
0 .372 .829 r
.27609 .5893 .28536 .59812 .29885 .60609 .28962 .59663 Metetra
.134 .478 .897 r
.28962 .59663 .29885 .60609 .31261 .61242 .30344 .60239 Metetra
.289 .553 .925 r
.30344 .60239 .31261 .61242 .32665 .61698 .31751 .60646 Metetra
.404 .602 .927 r
.31751 .60646 .32665 .61698 .34093 .61975 .33184 .60885 Metetra
.486 .633 .919 r
.33184 .60885 .34093 .61975 .35545 .62079 .34638 .60963 Metetra
.545 .654 .907 r
.34638 .60963 .35545 .62079 .37016 .62023 .36113 .60891 Metetra
.588 .67 .896 r
.36113 .60891 .37016 .62023 .38504 .61821 .37604 .60684 Metetra
.62 .682 .887 r
.37604 .60684 .38504 .61821 .40008 .61489 .39112 .60357 Metetra
.645 .693 .88 r
.39112 .60357 .40008 .61489 .41525 .61044 .40632 .59925 Metetra
.665 .703 .876 r
.40632 .59925 .41525 .61044 .43053 .60501 .42164 .59402 Metetra
.68 .713 .873 r
.42164 .59402 .43053 .60501 .44591 .59875 .43706 .58803 Metetra
.693 .723 .873 r
.43706 .58803 .44591 .59875 .46137 .5918 .45256 .5814 Metetra
.704 .733 .873 r
.45256 .5814 .46137 .5918 .47691 .58428 .46815 .57423 Metetra
.713 .744 .876 r
.46815 .57423 .47691 .58428 .49252 .5763 .48381 .56664 Metetra
.72 .754 .879 r
.48381 .56664 .49252 .5763 .50818 .56796 .49954 .5587 Metetra
.727 .765 .884 r
.49954 .5587 .50818 .56796 .5239 .55933 .51532 .55048 Metetra
.732 .777 .889 r
.51532 .55048 .5239 .55933 .53968 .5505 .53117 .54207 Metetra
.736 .788 .894 r
.53117 .54207 .53968 .5505 .5555 .54151 .54707 .5335 Metetra
.74 .8 .901 r
.54707 .5335 .5555 .54151 .57138 .53242 .56302 .52482 Metetra
.742 .812 .907 r
.56302 .52482 .57138 .53242 .58731 .52328 .57904 .51608 Metetra
.743 .824 .914 r
.57904 .51608 .58731 .52328 .60328 .51411 .59511 .5073 Metetra
.744 .835 .921 r
.59511 .5073 .60328 .51411 .61931 .50495 .61123 .49852 Metetra
.744 .847 .927 r
.61123 .49852 .61931 .50495 .6354 .49582 .62742 .48974 Metetra
.742 .858 .934 r
.62742 .48974 .6354 .49582 .65154 .48674 .64366 .48099 Metetra
.74 .868 .94 r
.64366 .48099 .65154 .48674 .66774 .47772 .65997 .47229 Metetra
.737 .878 .945 r
.65997 .47229 .66774 .47772 .684 .46877 .67634 .46363 Metetra
.733 .887 .951 r
.67634 .46363 .684 .46877 .70032 .45991 .69277 .45504 Metetra
.728 .895 .955 r
.69277 .45504 .70032 .45991 .71671 .45114 .70928 .44651 Metetra
.723 .902 .959 r
.70928 .44651 .71671 .45114 .73316 .44246 .72585 .43806 Metetra
.717 .909 .962 r
.72585 .43806 .73316 .44246 .74968 .43387 .74249 .42968 Metetra
.71 .915 .965 r
.74249 .42968 .74968 .43387 .76628 .42538 .75921 .42137 Metetra
.703 .92 .967 r
.75921 .42137 .76628 .42538 .78295 .41698 .77601 .41314 Metetra
.695 .924 .968 r
.77601 .41314 .78295 .41698 .7997 .40868 .79288 .40498 Metetra
.687 .927 .969 r
.79288 .40498 .7997 .40868 .81653 .40047 .80984 .39689 Metetra
.679 .929 .97 r
.80984 .39689 .81653 .40047 .83344 .39235 .82688 .38888 Metetra
.671 .931 .97 r
.82688 .38888 .83344 .39235 .85043 .38431 .844 .38094 Metetra
.664 .932 .97 r
.844 .38094 .85043 .38431 .86751 .37636 .86121 .37306 Metetra
.656 .933 .97 r
.86121 .37306 .86751 .37636 .88468 .36849 .87851 .36524 Metetra
0 .301 .764 r
.25341 .57243 .26283 .58065 .27609 .5893 .26673 .5804 Metetra
.005 .412 .856 r
.26673 .5804 .27609 .5893 .28962 .59663 .28031 .58709 Metetra
.178 .504 .91 r
.28031 .58709 .28962 .59663 .30344 .60239 .29417 .59226 Metetra
.318 .569 .929 r
.29417 .59226 .30344 .60239 .31751 .60646 .30829 .59585 Metetra
.421 .611 .928 r
.30829 .59585 .31751 .60646 .33184 .60885 .32266 .59786 Metetra
.495 .638 .918 r
.32266 .59786 .33184 .60885 .34638 .60963 .33724 .59837 Metetra
.549 .656 .906 r
.33724 .59837 .34638 .60963 .36113 .60891 .35202 .59749 Metetra
.588 .67 .896 r
.35202 .59749 .36113 .60891 .37604 .60684 .36697 .59536 Metetra
.618 .681 .887 r
.36697 .59536 .37604 .60684 .39112 .60357 .38207 .59212 Metetra
.641 .691 .881 r
.38207 .59212 .39112 .60357 .40632 .59925 .39731 .58791 Metetra
.659 .7 .877 r
.39731 .58791 .40632 .59925 .42164 .59402 .41266 .58287 Metetra
.674 .71 .875 r
.41266 .58287 .42164 .59402 .43706 .58803 .42812 .57712 Metetra
.686 .719 .874 r
.42812 .57712 .43706 .58803 .45256 .5814 .44367 .57078 Metetra
.696 .729 .875 r
.44367 .57078 .45256 .5814 .46815 .57423 .45931 .56395 Metetra
.705 .739 .878 r
.45931 .56395 .46815 .57423 .48381 .56664 .47502 .55672 Metetra
.712 .749 .881 r
.47502 .55672 .48381 .56664 .49954 .5587 .4908 .54916 Metetra
.718 .76 .886 r
.4908 .54916 .49954 .5587 .51532 .55048 .50665 .54135 Metetra
.723 .771 .891 r
.50665 .54135 .51532 .55048 .53117 .54207 .52256 .53333 Metetra
.727 .782 .896 r
.52256 .53333 .53117 .54207 .54707 .5335 .53854 .52517 Metetra
.73 .793 .902 r
.53854 .52517 .54707 .5335 .56302 .52482 .55457 .51689 Metetra
.732 .804 .909 r
.55457 .51689 .56302 .52482 .57904 .51608 .57067 .50854 Metetra
.734 .815 .915 r
.57067 .50854 .57904 .51608 .59511 .5073 .58682 .50014 Metetra
.734 .827 .922 r
.58682 .50014 .59511 .5073 .61123 .49852 .60304 .49171 Metetra
.734 .838 .928 r
.60304 .49171 .61123 .49852 .62742 .48974 .61932 .48328 Metetra
.733 .848 .935 r
.61932 .48328 .62742 .48974 .64366 .48099 .63567 .47487 Metetra
.731 .858 .941 r
.63567 .47487 .64366 .48099 .65997 .47229 .65208 .46648 Metetra
.729 .868 .946 r
.65208 .46648 .65997 .47229 .67634 .46363 .66856 .45812 Metetra
.725 .877 .952 r
.66856 .45812 .67634 .46363 .69277 .45504 .68511 .4498 Metetra
.721 .886 .956 r
.68511 .4498 .69277 .45504 .70928 .44651 .70172 .44153 Metetra
.717 .893 .96 r
.70172 .44153 .70928 .44651 .72585 .43806 .71842 .43332 Metetra
.711 .9 .964 r
.71842 .43332 .72585 .43806 .74249 .42968 .73518 .42515 Metetra
.705 .906 .967 r
.73518 .42515 .74249 .42968 .75921 .42137 .75202 .41704 Metetra
.699 .912 .969 r
.75202 .41704 .75921 .42137 .77601 .41314 .76895 .40899 Metetra
.692 .916 .971 r
.76895 .40899 .77601 .41314 .79288 .40498 .78595 .401 Metetra
.685 .92 .972 r
.78595 .401 .79288 .40498 .80984 .39689 .80303 .39305 Metetra
.677 .923 .972 r
.80303 .39305 .80984 .39689 .82688 .38888 .8202 .38517 Metetra
.67 .926 .973 r
.8202 .38517 .82688 .38888 .844 .38094 .83746 .37733 Metetra
.662 .928 .973 r
.83746 .37733 .844 .38094 .86121 .37306 .8548 .36955 Metetra
.655 .929 .972 r
.8548 .36955 .86121 .37306 .87851 .36524 .87224 .36182 Metetra
0 .349 .803 r
.24389 .56413 .25341 .57243 .26673 .5804 .25727 .57141 Metetra
.061 .449 .879 r
.25727 .57141 .26673 .5804 .28031 .58709 .27091 .57745 Metetra
.22 .529 .921 r
.27091 .57745 .28031 .58709 .29417 .59226 .28482 .58205 Metetra
.345 .584 .932 r
.28482 .58205 .29417 .59226 .30829 .59585 .29899 .58516 Metetra
.438 .619 .927 r
.29899 .58516 .30829 .59585 .32266 .59786 .3134 .58678 Metetra
.505 .642 .917 r
.3134 .58678 .32266 .59786 .33724 .59837 .32802 .58701 Metetra
.553 .658 .905 r
.32802 .58701 .33724 .59837 .35202 .59749 .34283 .58596 Metetra
.589 .67 .895 r
.34283 .58596 .35202 .59749 .36697 .59536 .35782 .58375 Metetra
.616 .68 .887 r
.35782 .58375 .36697 .59536 .38207 .59212 .37295 .58053 Metetra
.638 .689 .882 r
.37295 .58053 .38207 .59212 .39731 .58791 .38822 .57642 Metetra
.654 .698 .878 r
.38822 .57642 .39731 .58791 .41266 .58287 .40361 .57155 Metetra
.668 .707 .876 r
.40361 .57155 .41266 .58287 .42812 .57712 .41911 .56603 Metetra
.679 .715 .876 r
.41911 .56603 .42812 .57712 .44367 .57078 .4347 .55996 Metetra
.689 .724 .877 r
.4347 .55996 .44367 .57078 .45931 .56395 .45038 .55344 Metetra
.697 .734 .88 r
.45038 .55344 .45931 .56395 .47502 .55672 .46614 .54655 Metetra
.703 .744 .883 r
.46614 .54655 .47502 .55672 .4908 .54916 .48198 .53935 Metetra
.709 .754 .887 r
.48198 .53935 .4908 .54916 .50665 .54135 .49789 .53191 Metetra
.713 .764 .892 r
.49789 .53191 .50665 .54135 .52256 .53333 .51386 .52427 Metetra
.717 .774 .897 r
.51386 .52427 .52256 .53333 .53854 .52517 .52991 .51649 Metetra
.72 .785 .903 r
.52991 .51649 .53854 .52517 .55457 .51689 .54602 .50859 Metetra
.722 .796 .91 r
.54602 .50859 .55457 .51689 .57067 .50854 .56219 .50061 Metetra
.724 .806 .916 r
.56219 .50061 .57067 .50854 .58682 .50014 .57844 .49258 Metetra
.725 .817 .922 r
.57844 .49258 .58682 .50014 .60304 .49171 .59474 .48451 Metetra
.725 .828 .929 r
.59474 .48451 .60304 .49171 .61932 .48328 .61112 .47642 Metetra
.724 .838 .935 r
.61112 .47642 .61932 .48328 .63567 .47487 .62756 .46834 Metetra
.723 .848 .941 r
.62756 .46834 .63567 .47487 .65208 .46648 .64408 .46025 Metetra
.721 .857 .946 r
.64408 .46025 .65208 .46648 .66856 .45812 .66066 .45219 Metetra
.718 .866 .952 r
.66066 .45219 .66856 .45812 .68511 .4498 .67732 .44415 Metetra
.714 .875 .956 r
.67732 .44415 .68511 .4498 .70172 .44153 .69405 .43614 Metetra
.71 .883 .961 r
.69405 .43614 .70172 .44153 .71842 .43332 .71086 .42817 Metetra
.706 .89 .964 r
.71086 .42817 .71842 .43332 .73518 .42515 .72774 .42023 Metetra
.7 .896 .968 r
.72774 .42023 .73518 .42515 .75202 .41704 .74471 .41233 Metetra
.695 .902 .97 r
.74471 .41233 .75202 .41704 .76895 .40899 .76175 .40447 Metetra
.689 .907 .972 r
.76175 .40447 .76895 .40899 .78595 .401 .77888 .39665 Metetra
.682 .912 .974 r
.77888 .39665 .78595 .401 .80303 .39305 .7961 .38887 Metetra
.675 .916 .975 r
.7961 .38887 .80303 .39305 .8202 .38517 .8134 .38113 Metetra
.669 .919 .975 r
.8134 .38113 .8202 .38517 .83746 .37733 .83079 .37343 Metetra
.662 .921 .975 r
.83079 .37343 .83746 .37733 .8548 .36955 .84827 .36576 Metetra
.654 .923 .975 r
.84827 .36576 .8548 .36955 .87224 .36182 .86584 .35812 Metetra
0 .395 .838 r
.23428 .55574 .24389 .56413 .25727 .57141 .24772 .56234 Metetra
.116 .484 .899 r
.24772 .56234 .25727 .57141 .27091 .57745 .26142 .56773 Metetra
.26 .552 .929 r
.26142 .56773 .27091 .57745 .28482 .58205 .27539 .57176 Metetra
.372 .597 .934 r
.27539 .57176 .28482 .58205 .29899 .58516 .28961 .57437 Metetra
.454 .627 .927 r
.28961 .57437 .29899 .58516 .3134 .58678 .30405 .57561 Metetra
.514 .646 .916 r
.30405 .57561 .3134 .58678 .32802 .58701 .31871 .57555 Metetra
.558 .66 .905 r
.31871 .57555 .32802 .58701 .34283 .58596 .33356 .57432 Metetra
.59 .67 .895 r
.33356 .57432 .34283 .58596 .35782 .58375 .34858 .57203 Metetra
.615 .679 .888 r
.34858 .57203 .35782 .58375 .37295 .58053 .36375 .56881 Metetra
.634 .687 .882 r
.36375 .56881 .37295 .58053 .38822 .57642 .37906 .56478 Metetra
.65 .695 .879 r
.37906 .56478 .38822 .57642 .40361 .57155 .39448 .56005 Metetra
.663 .703 .877 r
.39448 .56005 .40361 .57155 .41911 .56603 .41002 .55474 Metetra
.673 .712 .877 r
.41002 .55474 .41911 .56603 .4347 .55996 .42565 .54892 Metetra
.682 .72 .878 r
.42565 .54892 .4347 .55996 .45038 .55344 .44137 .54269 Metetra
.689 .729 .881 r
.44137 .54269 .45038 .55344 .46614 .54655 .45718 .53611 Metetra
.695 .738 .884 r
.45718 .53611 .46614 .54655 .48198 .53935 .47307 .52924 Metetra
.7 .747 .888 r
.47307 .52924 .48198 .53935 .49789 .53191 .48903 .52215 Metetra
.704 .757 .893 r
.48903 .52215 .49789 .53191 .51386 .52427 .50507 .51487 Metetra
.708 .767 .898 r
.50507 .51487 .51386 .52427 .52991 .51649 .52118 .50745 Metetra
.711 .777 .904 r
.52118 .50745 .52991 .51649 .54602 .50859 .53737 .49991 Metetra
.713 .787 .91 r
.53737 .49991 .54602 .50859 .56219 .50061 .55362 .49229 Metetra
.715 .797 .916 r
.55362 .49229 .56219 .50061 .57844 .49258 .56994 .48461 Metetra
.715 .807 .922 r
.56994 .48461 .57844 .49258 .59474 .48451 .58634 .47688 Metetra
.716 .817 .928 r
.58634 .47688 .59474 .48451 .61112 .47642 .6028 .46912 Metetra
.715 .827 .934 r
.6028 .46912 .61112 .47642 .62756 .46834 .61934 .46135 Metetra
.714 .836 .94 r
.61934 .46135 .62756 .46834 .64408 .46025 .63596 .45358 Metetra
.713 .846 .946 r
.63596 .45358 .64408 .46025 .66066 .45219 .65264 .4458 Metetra
.71 .854 .951 r
.65264 .4458 .66066 .45219 .67732 .44415 .66941 .43804 Metetra
.708 .863 .956 r
.66941 .43804 .67732 .44415 .69405 .43614 .68625 .43029 Metetra
.704 .871 .96 r
.68625 .43029 .69405 .43614 .71086 .42817 .70317 .42256 Metetra
.7 .878 .964 r
.70317 .42256 .71086 .42817 .72774 .42023 .72018 .41485 Metetra
.696 .885 .968 r
.72018 .41485 .72774 .42023 .74471 .41233 .73726 .40717 Metetra
.691 .891 .971 r
.73726 .40717 .74471 .41233 .76175 .40447 .75443 .39951 Metetra
.686 .897 .973 r
.75443 .39951 .76175 .40447 .77888 .39665 .77169 .39188 Metetra
.68 .902 .975 r
.77169 .39188 .77888 .39665 .7961 .38887 .78903 .38427 Metetra
.674 .906 .976 r
.78903 .38427 .7961 .38887 .8134 .38113 .80646 .37668 Metetra
.668 .91 .977 r
.80646 .37668 .8134 .38113 .83079 .37343 .82399 .36912 Metetra
.662 .913 .978 r
.82399 .36912 .83079 .37343 .84827 .36576 .8416 .36159 Metetra
.655 .916 .978 r
.8416 .36159 .84827 .36576 .86584 .35812 .85931 .35407 Metetra
.019 .439 .868 r
.22457 .54726 .23428 .55574 .24772 .56234 .23808 .55317 Metetra
.169 .516 .916 r
.23808 .55317 .24772 .56234 .26142 .56773 .25184 .55792 Metetra
.298 .573 .935 r
.25184 .55792 .26142 .56773 .27539 .57176 .26587 .56137 Metetra
.397 .61 .935 r
.26587 .56137 .27539 .57176 .28961 .57437 .28013 .5635 Metetra
.47 .634 .926 r
.28013 .5635 .28961 .57437 .30405 .57561 .29463 .56434 Metetra
.523 .65 .915 r
.29463 .56434 .30405 .57561 .31871 .57555 .30933 .564 Metetra
.562 .662 .904 r
.30933 .564 .31871 .57555 .33356 .57432 .32422 .56258 Metetra
.591 .671 .895 r
.32422 .56258 .33356 .57432 .34858 .57203 .33927 .56019 Metetra
.614 .678 .888 r
.33927 .56019 .34858 .57203 .36375 .56881 .35447 .55695 Metetra
.632 .686 .883 r
.35447 .55695 .36375 .56881 .37906 .56478 .36981 .55298 Metetra
.646 .693 .88 r
.36981 .55298 .37906 .56478 .39448 .56005 .38527 .54838 Metetra
.657 .7 .878 r
.38527 .54838 .39448 .56005 .41002 .55474 .40084 .54325 Metetra
.667 .708 .878 r
.40084 .54325 .41002 .55474 .42565 .54892 .41651 .53765 Metetra
.675 .716 .879 r
.41651 .53765 .42565 .54892 .44137 .54269 .43228 .53168 Metetra
.682 .724 .882 r
.43228 .53168 .44137 .54269 .45718 .53611 .44813 .52539 Metetra
.687 .732 .885 r
.44813 .52539 .45718 .53611 .47307 .52924 .46407 .51883 Metetra
.692 .741 .889 r
.46407 .51883 .47307 .52924 .48903 .52215 .48009 .51206 Metetra
.696 .75 .893 r
.48009 .51206 .48903 .52215 .50507 .51487 .49619 .50512 Metetra
.699 .759 .898 r
.49619 .50512 .50507 .51487 .52118 .50745 .51237 .49803 Metetra
.702 .768 .903 r
.51237 .49803 .52118 .50745 .53737 .49991 .52862 .49083 Metetra
.704 .778 .909 r
.52862 .49083 .53737 .49991 .55362 .49229 .54494 .48355 Metetra
.705 .787 .915 r
.54494 .48355 .55362 .49229 .56994 .48461 .56135 .47619 Metetra
.706 .797 .921 r
.56135 .47619 .56994 .48461 .58634 .47688 .57782 .46879 Metetra
.707 .806 .927 r
.57782 .46879 .58634 .47688 .6028 .46912 .59438 .46135 Metetra
.707 .815 .933 r
.59438 .46135 .6028 .46912 .61934 .46135 .61101 .45388 Metetra
.706 .824 .938 r
.61101 .45388 .61934 .46135 .63596 .45358 .62772 .4464 Metetra
.705 .833 .944 r
.62772 .4464 .63596 .45358 .65264 .4458 .64451 .43891 Metetra
.703 .841 .949 r
.64451 .43891 .65264 .4458 .66941 .43804 .66138 .43141 Metetra
.701 .85 .954 r
.66138 .43141 .66941 .43804 .68625 .43029 .67833 .42392 Metetra
.698 .857 .958 r
.67833 .42392 .68625 .43029 .70317 .42256 .69536 .41643 Metetra
.695 .865 .963 r
.69536 .41643 .70317 .42256 .72018 .41485 .71248 .40896 Metetra
.691 .872 .966 r
.71248 .40896 .72018 .41485 .73726 .40717 .72968 .40149 Metetra
.687 .878 .97 r
.72968 .40149 .73726 .40717 .75443 .39951 .74697 .39403 Metetra
.683 .884 .972 r
.74697 .39403 .75443 .39951 .77169 .39188 .76435 .38659 Metetra
.678 .89 .975 r
.76435 .38659 .77169 .39188 .78903 .38427 .78182 .37916 Metetra
.673 .894 .977 r
.78182 .37916 .78903 .38427 .80646 .37668 .79938 .37174 Metetra
.668 .899 .978 r
.79938 .37174 .80646 .37668 .82399 .36912 .81704 .36433 Metetra
.663 .903 .98 r
.81704 .36433 .82399 .36912 .8416 .36159 .83479 .35694 Metetra
.657 .906 .98 r
.83479 .35694 .8416 .36159 .85931 .35407 .85264 .34955 Metetra
.082 .48 .894 r
.21476 .5387 .22457 .54726 .23808 .55317 .22834 .54392 Metetra
.218 .545 .929 r
.22834 .54392 .23808 .55317 .25184 .55792 .24217 .54802 Metetra
.333 .592 .94 r
.24217 .54802 .25184 .55792 .26587 .56137 .25625 .5509 Metetra
.421 .622 .935 r
.25625 .5509 .26587 .56137 .28013 .5635 .27058 .55253 Metetra
.485 .641 .925 r
.27058 .55253 .28013 .5635 .29463 .56434 .28512 .55299 Metetra
.532 .654 .913 r
.28512 .55299 .29463 .56434 .30933 .564 .29986 .55235 Metetra
.567 .664 .903 r
.29986 .55235 .30933 .564 .32422 .56258 .31479 .55073 Metetra
.593 .671 .894 r
.31479 .55073 .32422 .56258 .33927 .56019 .32988 .54823 Metetra
.613 .678 .887 r
.32988 .54823 .33927 .56019 .35447 .55695 .34512 .54496 Metetra
.629 .684 .883 r
.34512 .54496 .35447 .55695 .36981 .55298 .36049 .54103 Metetra
.642 .691 .88 r
.36049 .54103 .36981 .55298 .38527 .54838 .37598 .53653 Metetra
.653 .697 .879 r
.37598 .53653 .38527 .54838 .40084 .54325 .39159 .53155 Metetra
.661 .704 .879 r
.39159 .53155 .40084 .54325 .41651 .53765 .4073 .52615 Metetra
.669 .711 .88 r
.4073 .52615 .41651 .53765 .43228 .53168 .4231 .52041 Metetra
.675 .719 .882 r
.4231 .52041 .43228 .53168 .44813 .52539 .439 .51438 Metetra
.68 .726 .885 r
.439 .51438 .44813 .52539 .46407 .51883 .45499 .5081 Metetra
.684 .734 .889 r
.45499 .5081 .46407 .51883 .48009 .51206 .47106 .50163 Metetra
.688 .743 .893 r
.47106 .50163 .48009 .51206 .49619 .50512 .48722 .49499 Metetra
.691 .751 .898 r
.48722 .49499 .49619 .50512 .51237 .49803 .50345 .48821 Metetra
.693 .759 .903 r
.50345 .48821 .51237 .49803 .52862 .49083 .51977 .48133 Metetra
.695 .768 .908 r
.51977 .48133 .52862 .49083 .54494 .48355 .53617 .47435 Metetra
.697 .777 .913 r
.53617 .47435 .54494 .48355 .56135 .47619 .55265 .46731 Metetra
.698 .786 .919 r
.55265 .46731 .56135 .47619 .57782 .46879 .5692 .4602 Metetra
.698 .794 .924 r
.5692 .4602 .57782 .46879 .59438 .46135 .58584 .45306 Metetra
.698 .803 .93 r
.58584 .45306 .59438 .46135 .61101 .45388 .60256 .44588 Metetra
.698 .811 .935 r
.60256 .44588 .61101 .45388 .62772 .4464 .61936 .43868 Metetra
.697 .82 .941 r
.61936 .43868 .62772 .4464 .64451 .43891 .63625 .43146 Metetra
.696 .828 .946 r
.63625 .43146 .64451 .43891 .66138 .43141 .65322 .42422 Metetra
.694 .835 .951 r
.65322 .42422 .66138 .43141 .67833 .42392 .67027 .41698 Metetra
.692 .843 .955 r
.67027 .41698 .67833 .42392 .69536 .41643 .68741 .40973 Metetra
.69 .85 .96 r
.68741 .40973 .69536 .41643 .71248 .40896 .70464 .40247 Metetra
.687 .857 .964 r
.70464 .40247 .71248 .40896 .72968 .40149 .72196 .39522 Metetra
.684 .864 .967 r
.72196 .39522 .72968 .40149 .74697 .39403 .73937 .38796 Metetra
.68 .87 .97 r
.73937 .38796 .74697 .39403 .76435 .38659 .75687 .38071 Metetra
.677 .875 .973 r
.75687 .38071 .76435 .38659 .78182 .37916 .77447 .37346 Metetra
.673 .881 .976 r
.77447 .37346 .78182 .37916 .79938 .37174 .79216 .36621 Metetra
.668 .886 .978 r
.79216 .36621 .79938 .37174 .81704 .36433 .80994 .35896 Metetra
.664 .89 .98 r
.80994 .35896 .81704 .36433 .83479 .35694 .82783 .35171 Metetra
.659 .894 .981 r
.82783 .35171 .83479 .35694 .85264 .34955 .84581 .34447 Metetra
.142 .518 .915 r
.20485 .53005 .21476 .5387 .22834 .54392 .2185 .53458 Metetra
.266 .572 .939 r
.2185 .53458 .22834 .54392 .24217 .54802 .2324 .53804 Metetra
.367 .609 .943 r
.2324 .53804 .24217 .54802 .25625 .5509 .24655 .54033 Metetra
.443 .633 .935 r
.24655 .54033 .25625 .5509 .27058 .55253 .26093 .54148 Metetra
.5 .648 .924 r
.26093 .54148 .27058 .55253 .28512 .55299 .27552 .54154 Metetra
.541 .658 .912 r
.27552 .54154 .28512 .55299 .29986 .55235 .29031 .5406 Metetra
.572 .666 .902 r
.29031 .5406 .29986 .55235 .31479 .55073 .30528 .53877 Metetra
.595 .672 .893 r
.30528 .53877 .31479 .55073 .32988 .54823 .3204 .53614 Metetra
.613 .678 .887 r
.3204 .53614 .32988 .54823 .34512 .54496 .33568 .53283 Metetra
.628 .683 .883 r
.33568 .53283 .34512 .54496 .36049 .54103 .35108 .52892 Metetra
.639 .689 .88 r
.35108 .52892 .36049 .54103 .37598 .53653 .36661 .5245 Metetra
.648 .695 .879 r
.36661 .5245 .37598 .53653 .39159 .53155 .38225 .51965 Metetra
.656 .701 .879 r
.38225 .51965 .39159 .53155 .4073 .52615 .398 .51442 Metetra
.663 .707 .88 r
.398 .51442 .4073 .52615 .4231 .52041 .41384 .50888 Metetra
.668 .714 .882 r
.41384 .50888 .4231 .52041 .439 .51438 .42979 .50307 Metetra
.673 .721 .885 r
.42979 .50307 .439 .51438 .45499 .5081 .44582 .49705 Metetra
.677 .728 .888 r
.44582 .49705 .45499 .5081 .47106 .50163 .46194 .49084 Metetra
.68 .735 .892 r
.46194 .49084 .47106 .50163 .48722 .49499 .47815 .48447 Metetra
.683 .743 .896 r
.47815 .48447 .48722 .49499 .50345 .48821 .49445 .47797 Metetra
.685 .751 .901 r
.49445 .47797 .50345 .48821 .51977 .48133 .51083 .47137 Metetra
.687 .758 .906 r
.51083 .47137 .51977 .48133 .53617 .47435 .52729 .46468 Metetra
.688 .766 .911 r
.52729 .46468 .53617 .47435 .55265 .46731 .54384 .45792 Metetra
.689 .774 .916 r
.54384 .45792 .55265 .46731 .5692 .4602 .56048 .4511 Metetra
.69 .782 .921 r
.56048 .4511 .5692 .4602 .58584 .45306 .57719 .44423 Metetra
.69 .79 .926 r
.57719 .44423 .58584 .45306 .60256 .44588 .594 .43732 Metetra
.69 .798 .932 r
.594 .43732 .60256 .44588 .61936 .43868 .61089 .43037 Metetra
.69 .806 .937 r
.61089 .43037 .61936 .43868 .63625 .43146 .62787 .4234 Metetra
.689 .813 .942 r
.62787 .4234 .63625 .43146 .65322 .42422 .64493 .41641 Metetra
.688 .82 .946 r
.64493 .41641 .65322 .42422 .67027 .41698 .66209 .4094 Metetra
.686 .828 .951 r
.66209 .4094 .67027 .41698 .68741 .40973 .67933 .40238 Metetra
.685 .834 .955 r
.67933 .40238 .68741 .40973 .70464 .40247 .69667 .39534 Metetra
.683 .841 .959 r
.69667 .39534 .70464 .40247 .72196 .39522 .7141 .38829 Metetra
.68 .847 .963 r
.7141 .38829 .72196 .39522 .73937 .38796 .73162 .38123 Metetra
.678 .853 .967 r
.73162 .38123 .73937 .38796 .75687 .38071 .74924 .37416 Metetra
.675 .859 .97 r
.74924 .37416 .75687 .38071 .77447 .37346 .76696 .36709 Metetra
.672 .865 .973 r
.76696 .36709 .77447 .37346 .79216 .36621 .78478 .36001 Metetra
.668 .87 .975 r
.78478 .36001 .79216 .36621 .80994 .35896 .80269 .35292 Metetra
.665 .875 .977 r
.80269 .35292 .80994 .35896 .82783 .35171 .82071 .34582 Metetra
.661 .879 .979 r
.82071 .34582 .82783 .35171 .84581 .34447 .83882 .33871 Metetra
.199 .552 .932 r
.19484 .52131 .20485 .53005 .2185 .53458 .20857 .52515 Metetra
.31 .595 .946 r
.20857 .52515 .2185 .53458 .2324 .53804 .22254 .52796 Metetra
.398 .625 .944 r
.22254 .52796 .2324 .53804 .24655 .54033 .23675 .52968 Metetra
.465 .643 .934 r
.23675 .52968 .24655 .54033 .26093 .54148 .25119 .53034 Metetra
.514 .654 .922 r
.25119 .53034 .26093 .54148 .27552 .54154 .26584 .53 Metetra
.55 .662 .911 r
.26584 .53 .27552 .54154 .29031 .5406 .28067 .52875 Metetra
.577 .668 .901 r
.28067 .52875 .29031 .5406 .30528 .53877 .29568 .5267 Metetra
.597 .673 .893 r
.29568 .5267 .30528 .53877 .3204 .53614 .31085 .52394 Metetra
.613 .677 .887 r
.31085 .52394 .3204 .53614 .33568 .53283 .32615 .52056 Metetra
.626 .682 .883 r
.32615 .52056 .33568 .53283 .35108 .52892 .34159 .51665 Metetra
.636 .687 .88 r
.34159 .51665 .35108 .52892 .36661 .5245 .35716 .51229 Metetra
.645 .692 .879 r
.35716 .51229 .36661 .5245 .38225 .51965 .37283 .50753 Metetra
.652 .697 .879 r
.37283 .50753 .38225 .51965 .398 .51442 .38862 .50244 Metetra
.658 .703 .88 r
.38862 .50244 .398 .51442 .41384 .50888 .4045 .49707 Metetra
.662 .709 .882 r
.4045 .49707 .41384 .50888 .42979 .50307 .42049 .49147 Metetra
.667 .715 .884 r
.42049 .49147 .42979 .50307 .44582 .49705 .43657 .48566 Metetra
.67 .721 .887 r
.43657 .48566 .44582 .49705 .46194 .49084 .45274 .47968 Metetra
.673 .728 .891 r
.45274 .47968 .46194 .49084 .47815 .48447 .469 .47355 Metetra
.676 .735 .895 r
.469 .47355 .47815 .48447 .49445 .47797 .48535 .46731 Metetra
.678 .742 .899 r
.48535 .46731 .49445 .47797 .51083 .47137 .50179 .46096 Metetra
.679 .749 .903 r
.50179 .46096 .51083 .47137 .52729 .46468 .51832 .45452 Metetra
.681 .756 .908 r
.51832 .45452 .52729 .46468 .54384 .45792 .53494 .44801 Metetra
.682 .763 .913 r
.53494 .44801 .54384 .45792 .56048 .4511 .55164 .44144 Metetra
.682 .77 .917 r
.55164 .44144 .56048 .4511 .57719 .44423 .56844 .43482 Metetra
.683 .777 .922 r
.56844 .43482 .57719 .44423 .594 .43732 .58532 .42815 Metetra
.683 .784 .927 r
.58532 .42815 .594 .43732 .61089 .43037 .6023 .42145 Metetra
.683 .791 .932 r
.6023 .42145 .61089 .43037 .62787 .4234 .61936 .41471 Metetra
.682 .798 .936 r
.61936 .41471 .62787 .4234 .64493 .41641 .63652 .40794 Metetra
.682 .805 .941 r
.63652 .40794 .64493 .41641 .66209 .4094 .65377 .40115 Metetra
.681 .811 .945 r
.65377 .40115 .66209 .4094 .67933 .40238 .67112 .39433 Metetra
.68 .818 .949 r
.67112 .39433 .67933 .40238 .69667 .39534 .68856 .38749 Metetra
.678 .824 .953 r
.68856 .38749 .69667 .39534 .7141 .38829 .7061 .38064 Metetra
.677 .83 .957 r
.7061 .38064 .7141 .38829 .73162 .38123 .72373 .37376 Metetra
.675 .836 .961 r
.72373 .37376 .73162 .38123 .74924 .37416 .74147 .36687 Metetra
.673 .841 .964 r
.74147 .36687 .74924 .37416 .76696 .36709 .7593 .35996 Metetra
.67 .847 .967 r
.7593 .35996 .76696 .36709 .78478 .36001 .77724 .35304 Metetra
.668 .852 .97 r
.77724 .35304 .78478 .36001 .80269 .35292 .79527 .3461 Metetra
.665 .857 .973 r
.79527 .3461 .80269 .35292 .82071 .34582 .81342 .33914 Metetra
.663 .861 .975 r
.81342 .33914 .82071 .34582 .83882 .33871 .83166 .33217 Metetra
.254 .583 .945 r
.18472 .51248 .19484 .52131 .20857 .52515 .19853 .51563 Metetra
.351 .617 .951 r
.19853 .51563 .20857 .52515 .22254 .52796 .21258 .51779 Metetra
.428 .639 .944 r
.21258 .51779 .22254 .52796 .23675 .52968 .22686 .51894 Metetra
.485 .652 .933 r
.22686 .51894 .23675 .52968 .25119 .53034 .24136 .5191 Metetra
.527 .66 .92 r
.24136 .5191 .25119 .53034 .26584 .53 .25606 .51836 Metetra
.559 .666 .909 r
.25606 .51836 .26584 .53 .28067 .52875 .27095 .51681 Metetra
.582 .67 .9 r
.27095 .51681 .28067 .52875 .29568 .5267 .286 .51453 Metetra
.6 .674 .892 r
.286 .51453 .29568 .5267 .31085 .52394 .3012 .51162 Metetra
.614 .677 .887 r
.3012 .51162 .31085 .52394 .32615 .52056 .31655 .50816 Metetra
.625 .681 .883 r
.31655 .50816 .32615 .52056 .34159 .51665 .33203 .50422 Metetra
.634 .685 .88 r
.33203 .50422 .34159 .51665 .35716 .51229 .34762 .49989 Metetra
.642 .689 .879 r
.34762 .49989 .35716 .51229 .37283 .50753 .36333 .4952 Metetra
.648 .694 .879 r
.36333 .4952 .37283 .50753 .38862 .50244 .37915 .49023 Metetra
.653 .699 .88 r
.37915 .49023 .38862 .50244 .4045 .49707 .39508 .48499 Metetra
.657 .704 .881 r
.39508 .48499 .4045 .49707 .42049 .49147 .4111 .47955 Metetra
.661 .709 .883 r
.4111 .47955 .42049 .49147 .43657 .48566 .42723 .47392 Metetra
.664 .715 .886 r
.42723 .47392 .43657 .48566 .45274 .47968 .44344 .46814 Metetra
.667 .721 .889 r
.44344 .46814 .45274 .47968 .469 .47355 .45976 .46222 Metetra
.669 .727 .893 r
.45976 .46222 .469 .47355 .48535 .46731 .47616 .45619 Metetra
.671 .733 .896 r
.47616 .45619 .48535 .46731 .50179 .46096 .49266 .45006 Metetra
.673 .739 .9 r
.49266 .45006 .50179 .46096 .51832 .45452 .50925 .44385 Metetra
.674 .745 .904 r
.50925 .44385 .51832 .45452 .53494 .44801 .52593 .43756 Metetra
.675 .751 .908 r
.52593 .43756 .53494 .44801 .55164 .44144 .54271 .43122 Metetra
.676 .758 .913 r
.54271 .43122 .55164 .44144 .56844 .43482 .55957 .42481 Metetra
.676 .764 .917 r
.55957 .42481 .56844 .43482 .58532 .42815 .57654 .41836 Metetra
.676 .77 .921 r
.57654 .41836 .58532 .42815 .6023 .42145 .59359 .41187 Metetra
.676 .776 .926 r
.59359 .41187 .6023 .42145 .61936 .41471 .61074 .40533 Metetra
.676 .782 .93 r
.61074 .40533 .61936 .41471 .63652 .40794 .62799 .39876 Metetra
.676 .789 .934 r
.62799 .39876 .63652 .40794 .65377 .40115 .64533 .39216 Metetra
.675 .794 .938 r
.64533 .39216 .65377 .40115 .67112 .39433 .66277 .38553 Metetra
.675 .8 .942 r
.66277 .38553 .67112 .39433 .68856 .38749 .68031 .37888 Metetra
.674 .806 .946 r
.68031 .37888 .68856 .38749 .7061 .38064 .69795 .3722 Metetra
.673 .812 .95 r
.69795 .3722 .7061 .38064 .72373 .37376 .71569 .36549 Metetra
.672 .817 .953 r
.71569 .36549 .72373 .37376 .74147 .36687 .73353 .35876 Metetra
.67 .822 .956 r
.73353 .35876 .74147 .36687 .7593 .35996 .75148 .352 Metetra
.669 .827 .96 r
.75148 .352 .7593 .35996 .77724 .35304 .76953 .34523 Metetra
.667 .832 .963 r
.76953 .34523 .77724 .35304 .79527 .3461 .78769 .33843 Metetra
.665 .837 .966 r
.78769 .33843 .79527 .3461 .81342 .33914 .80595 .33161 Metetra
.663 .842 .968 r
.80595 .33161 .81342 .33914 .83166 .33217 .82432 .32476 Metetra
.304 .61 .954 r
.1745 .50356 .18472 .51248 .19853 .51563 .1884 .50602 Metetra
.389 .636 .953 r
.1884 .50602 .19853 .51563 .21258 .51779 .20253 .50754 Metetra
.455 .651 .944 r
.20253 .50754 .21258 .51779 .22686 .51894 .21688 .50811 Metetra
.504 .661 .931 r
.21688 .50811 .22686 .51894 .24136 .5191 .23144 .50779 Metetra
.54 .666 .919 r
.23144 .50779 .24136 .5191 .25606 .51836 .2462 .50664 Metetra
.567 .67 .907 r
.2462 .50664 .25606 .51836 .27095 .51681 .26114 .50477 Metetra
.587 .672 .898 r
.26114 .50477 .27095 .51681 .286 .51453 .27623 .50225 Metetra
.603 .675 .891 r
.27623 .50225 .286 .51453 .3012 .51162 .29148 .49917 Metetra
.615 .678 .886 r
.29148 .49917 .3012 .51162 .31655 .50816 .30686 .49561 Metetra
.625 .681 .882 r
.30686 .49561 .31655 .50816 .33203 .50422 .32237 .49163 Metetra
.633 .684 .88 r
.32237 .49163 .33203 .50422 .34762 .49989 .33801 .4873 Metetra
.639 .687 .879 r
.33801 .4873 .34762 .49989 .36333 .4952 .35375 .48266 Metetra
.645 .691 .879 r
.35375 .48266 .36333 .4952 .37915 .49023 .36961 .47776 Metetra
.649 .695 .879 r
.36961 .47776 .37915 .49023 .39508 .48499 .38557 .47264 Metetra
.653 .699 .88 r
.38557 .47264 .39508 .48499 .4111 .47955 .40164 .46732 Metetra
.656 .704 .882 r
.40164 .46732 .4111 .47955 .42723 .47392 .4178 .46184 Metetra
.659 .709 .884 r
.4178 .46184 .42723 .47392 .44344 .46814 .43407 .45622 Metetra
.661 .714 .887 r
.43407 .45622 .44344 .46814 .45976 .46222 .45043 .45047 Metetra
.663 .719 .89 r
.45043 .45047 .45976 .46222 .47616 .45619 .46688 .44462 Metetra
.665 .724 .893 r
.46688 .44462 .47616 .45619 .49266 .45006 .48344 .43868 Metetra
.666 .729 .897 r
.48344 .43868 .49266 .45006 .50925 .44385 .50009 .43265 Metetra
.668 .735 .9 r
.50009 .43265 .50925 .44385 .52593 .43756 .51683 .42655 Metetra
.669 .74 .904 r
.51683 .42655 .52593 .43756 .54271 .43122 .53367 .42039 Metetra
.669 .745 .907 r
.53367 .42039 .54271 .43122 .55957 .42481 .55061 .41418 Metetra
.67 .751 .911 r
.55061 .41418 .55957 .42481 .57654 .41836 .56764 .40791 Metetra
.67 .756 .915 r
.56764 .40791 .57654 .41836 .59359 .41187 .58477 .4016 Metetra
.671 .762 .919 r
.58477 .4016 .59359 .41187 .61074 .40533 .602 .39524 Metetra
.671 .767 .923 r
.602 .39524 .61074 .40533 .62799 .39876 .61933 .38884 Metetra
.671 .772 .926 r
.61933 .38884 .62799 .39876 .64533 .39216 .63676 .38241 Metetra
.67 .778 .93 r
.63676 .38241 .64533 .39216 .66277 .38553 .65429 .37595 Metetra
.67 .783 .934 r
.65429 .37595 .66277 .38553 .68031 .37888 .67192 .36945 Metetra
.67 .788 .937 r
.67192 .36945 .68031 .37888 .69795 .3722 .68966 .36292 Metetra
.669 .793 .941 r
.68966 .36292 .69795 .3722 .71569 .36549 .7075 .35636 Metetra
.668 .798 .944 r
.7075 .35636 .71569 .36549 .73353 .35876 .72545 .34977 Metetra
.668 .802 .947 r
.72545 .34977 .73353 .35876 .75148 .352 .7435 .34315 Metetra
.667 .807 .95 r
.7435 .34315 .75148 .352 .76953 .34523 .76166 .3365 Metetra
.666 .811 .953 r
.76166 .3365 .76953 .34523 .78769 .33843 .77993 .32983 Metetra
.665 .816 .956 r
.77993 .32983 .78769 .33843 .80595 .33161 .79831 .32312 Metetra
.663 .82 .959 r
.79831 .32312 .80595 .33161 .82432 .32476 .8168 .31639 Metetra
.351 .634 .96 r
.16417 .49455 .1745 .50356 .1884 .50602 .17816 .49631 Metetra
.424 .652 .954 r
.17816 .49631 .1884 .50602 .20253 .50754 .19237 .49719 Metetra
.48 .663 .942 r
.19237 .49719 .20253 .50754 .21688 .50811 .2068 .49719 Metetra
.522 .668 .929 r
.2068 .49719 .21688 .50811 .23144 .50779 .22143 .49638 Metetra
.553 .672 .917 r
.22143 .49638 .23144 .50779 .2462 .50664 .23624 .49484 Metetra
.576 .673 .906 r
.23624 .49484 .2462 .50664 .26114 .50477 .25123 .49264 Metetra
.593 .675 .897 r
.25123 .49264 .26114 .50477 .27623 .50225 .26638 .48987 Metetra
.606 .676 .891 r
.26638 .48987 .27623 .50225 .29148 .49917 .28166 .48661 Metetra
.617 .678 .886 r
.28166 .48661 .29148 .49917 .30686 .49561 .29709 .48293 Metetra
.625 .68 .882 r
.29709 .48293 .30686 .49561 .32237 .49163 .31264 .47889 Metetra
.632 .683 .88 r
.31264 .47889 .32237 .49163 .33801 .4873 .32831 .47453 Metetra
.638 .685 .878 r
.32831 .47453 .33801 .4873 .35375 .48266 .34409 .46991 Metetra
.642 .688 .878 r
.34409 .46991 .35375 .48266 .36961 .47776 .35999 .46505 Metetra
.646 .692 .878 r
.35999 .46505 .36961 .47776 .38557 .47264 .37599 .46 Metetra
.649 .695 .879 r
.37599 .46 .38557 .47264 .40164 .46732 .39209 .45478 Metetra
.652 .699 .881 r
.39209 .45478 .40164 .46732 .4178 .46184 .4083 .44941 Metetra
.654 .703 .882 r
.4083 .44941 .4178 .46184 .43407 .45622 .42461 .44391 Metetra
.657 .707 .885 r
.42461 .44391 .43407 .45622 .45043 .45047 .44101 .4383 Metetra
.658 .711 .887 r
.44101 .4383 .45043 .45047 .46688 .44462 .45752 .43259 Metetra
.66 .716 .89 r
.45752 .43259 .46688 .44462 .48344 .43868 .47413 .42679 Metetra
.661 .72 .893 r
.47413 .42679 .48344 .43868 .50009 .43265 .49083 .42091 Metetra
.662 .725 .895 r
.49083 .42091 .50009 .43265 .51683 .42655 .50763 .41497 Metetra
.663 .729 .899 r
.50763 .41497 .51683 .42655 .53367 .42039 .52453 .40896 Metetra
.664 .734 .902 r
.52453 .40896 .53367 .42039 .55061 .41418 .54154 .4029 Metetra
.664 .738 .905 r
.54154 .4029 .55061 .41418 .56764 .40791 .55864 .39678 Metetra
.665 .743 .908 r
.55864 .39678 .56764 .40791 .58477 .4016 .57584 .39062 Metetra
.665 .747 .911 r
.57584 .39062 .58477 .4016 .602 .39524 .59314 .38441 Metetra
.666 .752 .915 r
.59314 .38441 .602 .39524 .61933 .38884 .61055 .37815 Metetra
.666 .756 .918 r
.61055 .37815 .61933 .38884 .63676 .38241 .62806 .37186 Metetra
.666 .761 .921 r
.62806 .37186 .63676 .38241 .65429 .37595 .64568 .36553 Metetra
.666 .765 .924 r
.64568 .36553 .65429 .37595 .67192 .36945 .6634 .35916 Metetra
.666 .77 .927 r
.6634 .35916 .67192 .36945 .68966 .36292 .68123 .35276 Metetra
.665 .774 .93 r
.68123 .35276 .68966 .36292 .7075 .35636 .69916 .34632 Metetra
.665 .778 .933 r
.69916 .34632 .7075 .35636 .72545 .34977 .7172 .33985 Metetra
.665 .782 .936 r
.7172 .33985 .72545 .34977 .7435 .34315 .73536 .33334 Metetra
.664 .786 .939 r
.73536 .33334 .7435 .34315 .76166 .3365 .75362 .3268 Metetra
.664 .79 .942 r
.75362 .3268 .76166 .3365 .77993 .32983 .772 .32023 Metetra
.663 .794 .945 r
.772 .32023 .77993 .32983 .79831 .32312 .79049 .31362 Metetra
.662 .798 .947 r
.79049 .31362 .79831 .32312 .8168 .31639 .80909 .30698 Metetra
.394 .655 .963 r
.15373 .48543 .16417 .49455 .17816 .49631 .16781 .48651 Metetra
.457 .667 .953 r
.16781 .48651 .17816 .49631 .19237 .49719 .18211 .48675 Metetra
.504 .673 .94 r
.18211 .48675 .19237 .49719 .2068 .49719 .19662 .48619 Metetra
.539 .676 .927 r
.19662 .48619 .2068 .49719 .22143 .49638 .21132 .4849 Metetra
.565 .677 .914 r
.21132 .4849 .22143 .49638 .23624 .49484 .22619 .48295 Metetra
.584 .677 .904 r
.22619 .48295 .23624 .49484 .25123 .49264 .24124 .48042 Metetra
.599 .677 .896 r
.24124 .48042 .25123 .49264 .26638 .48987 .25643 .4774 Metetra
.61 .678 .89 r
.25643 .4774 .26638 .48987 .28166 .48661 .27176 .47394 Metetra
.619 .679 .885 r
.27176 .47394 .28166 .48661 .29709 .48293 .28723 .47012 Metetra
.626 .68 .882 r
.28723 .47012 .29709 .48293 .31264 .47889 .30282 .46599 Metetra
.632 .682 .879 r
.30282 .46599 .31264 .47889 .32831 .47453 .31852 .46158 Metetra
.636 .684 .878 r
.31852 .46158 .32831 .47453 .34409 .46991 .33435 .45694 Metetra
.64 .686 .877 r
.33435 .45694 .34409 .46991 .35999 .46505 .35028 .4521 Metetra
.644 .689 .877 r
.35028 .4521 .35999 .46505 .37599 .46 .36632 .44709 Metetra
.646 .691 .878 r
.36632 .44709 .37599 .46 .39209 .45478 .38246 .44193 Metetra
.649 .694 .879 r
.38246 .44193 .39209 .45478 .4083 .44941 .39871 .43663 Metetra
.651 .698 .88 r
.39871 .43663 .4083 .44941 .42461 .44391 .41506 .43122 Metetra
.653 .701 .882 r
.41506 .43122 .42461 .44391 .44101 .4383 .43151 .4257 Metetra
.654 .704 .884 r
.43151 .4257 .44101 .4383 .45752 .43259 .44807 .42009 Metetra
.655 .708 .886 r
.44807 .42009 .45752 .43259 .47413 .42679 .46472 .41441 Metetra
.657 .711 .888 r
.46472 .41441 .47413 .42679 .49083 .42091 .48148 .40864 Metetra
.658 .715 .891 r
.48148 .40864 .49083 .42091 .50763 .41497 .49834 .40281 Metetra
.658 .719 .893 r
.49834 .40281 .50763 .41497 .52453 .40896 .5153 .39692 Metetra
.659 .723 .896 r
.5153 .39692 .52453 .40896 .54154 .4029 .53236 .39097 Metetra
.66 .726 .898 r
.53236 .39097 .54154 .4029 .55864 .39678 .54953 .38497 Metetra
.66 .73 .901 r
.54953 .38497 .55864 .39678 .57584 .39062 .5668 .37892 Metetra
.661 .734 .904 r
.5668 .37892 .57584 .39062 .59314 .38441 .58418 .37282 Metetra
.661 .737 .906 r
.58418 .37282 .59314 .38441 .61055 .37815 .60166 .36668 Metetra
.661 .741 .909 r
.60166 .36668 .61055 .37815 .62806 .37186 .61924 .3605 Metetra
.662 .745 .912 r
.61924 .3605 .62806 .37186 .64568 .36553 .63694 .35427 Metetra
.662 .748 .914 r
.63694 .35427 .64568 .36553 .6634 .35916 .65474 .348 Metetra
.662 .752 .917 r
.65474 .348 .6634 .35916 .68123 .35276 .67265 .34169 Metetra
.662 .755 .92 r
.67265 .34169 .68123 .35276 .69916 .34632 .69068 .33535 Metetra
.662 .759 .922 r
.69068 .33535 .69916 .34632 .7172 .33985 .70881 .32897 Metetra
.662 .762 .925 r
.70881 .32897 .7172 .33985 .73536 .33334 .72706 .32255 Metetra
.661 .766 .927 r
.72706 .32255 .73536 .33334 .75362 .3268 .74542 .31609 Metetra
.661 .769 .929 r
.74542 .31609 .75362 .3268 .772 .32023 .76389 .30959 Metetra
.661 .772 .932 r
.76389 .30959 .772 .32023 .79049 .31362 .78248 .30306 Metetra
.661 .775 .934 r
.78248 .30306 .79049 .31362 .80909 .30698 .80119 .29649 Metetra
.433 .673 .963 r
.14318 .47623 .15373 .48543 .16781 .48651 .15736 .47662 Metetra
.486 .68 .951 r
.15736 .47662 .16781 .48651 .18211 .48675 .17175 .47623 Metetra
.526 .682 .937 r
.17175 .47623 .18211 .48675 .19662 .48619 .18633 .47511 Metetra
.555 .682 .924 r
.18633 .47511 .19662 .48619 .21132 .4849 .20111 .47333 Metetra
.576 .682 .912 r
.20111 .47333 .21132 .4849 .22619 .48295 .21605 .47097 Metetra
.592 .681 .903 r
.21605 .47097 .22619 .48295 .24124 .48042 .23115 .46812 Metetra
.604 .68 .895 r
.23115 .46812 .24124 .48042 .25643 .4774 .24639 .46483 Metetra
.614 .68 .889 r
.24639 .46483 .25643 .4774 .27176 .47394 .26177 .46117 Metetra
.621 .68 .884 r
.26177 .46117 .27176 .47394 .28723 .47012 .27728 .45719 Metetra
.627 .681 .881 r
.27728 .45719 .28723 .47012 .30282 .46599 .29291 .45294 Metetra
.632 .681 .879 r
.29291 .45294 .30282 .46599 .31852 .46158 .30866 .44846 Metetra
.636 .683 .877 r
.30866 .44846 .31852 .46158 .33435 .45694 .32452 .44378 Metetra
.639 .684 .876 r
.32452 .44378 .33435 .45694 .35028 .4521 .34049 .43893 Metetra
.642 .686 .876 r
.34049 .43893 .35028 .4521 .36632 .44709 .35657 .43392 Metetra
.644 .688 .876 r
.35657 .43392 .36632 .44709 .38246 .44193 .37275 .42878 Metetra
.646 .69 .877 r
.37275 .42878 .38246 .44193 .39871 .43663 .38904 .42352 Metetra
.648 .693 .878 r
.38904 .42352 .39871 .43663 .41506 .43122 .40543 .41815 Metetra
.649 .695 .879 r
.40543 .41815 .41506 .43122 .43151 .4257 .42193 .41269 Metetra
.651 .698 .881 r
.42193 .41269 .43151 .4257 .44807 .42009 .43853 .40715 Metetra
.652 .701 .882 r
.43853 .40715 .44807 .42009 .46472 .41441 .45524 .40153 Metetra
.653 .704 .884 r
.45524 .40153 .46472 .41441 .48148 .40864 .47205 .39585 Metetra
.654 .706 .886 r
.47205 .39585 .48148 .40864 .49834 .40281 .48896 .39009 Metetra
.655 .709 .888 r
.48896 .39009 .49834 .40281 .5153 .39692 .50598 .38428 Metetra
.655 .712 .89 r
.50598 .38428 .5153 .39692 .53236 .39097 .5231 .37841 Metetra
.656 .715 .892 r
.5231 .37841 .53236 .39097 .54953 .38497 .54032 .37249 Metetra
.656 .718 .894 r
.54032 .37249 .54953 .38497 .5668 .37892 .55766 .36651 Metetra
.657 .721 .896 r
.55766 .36651 .5668 .37892 .58418 .37282 .5751 .36049 Metetra
.657 .724 .898 r
.5751 .36049 .58418 .37282 .60166 .36668 .59265 .35443 Metetra
.657 .727 .9 r
.59265 .35443 .60166 .36668 .61924 .3605 .61031 .34831 Metetra
.658 .73 .902 r
.61031 .34831 .61924 .3605 .63694 .35427 .62808 .34216 Metetra
.658 .732 .905 r
.62808 .34216 .63694 .35427 .65474 .348 .64595 .33596 Metetra
.658 .735 .907 r
.64595 .33596 .65474 .348 .67265 .34169 .66395 .32972 Metetra
.658 .738 .909 r
.66395 .32972 .67265 .34169 .69068 .33535 .68205 .32344 Metetra
.658 .741 .911 r
.68205 .32344 .69068 .33535 .70881 .32897 .70027 .31711 Metetra
.659 .744 .913 r
.70027 .31711 .70881 .32897 .72706 .32255 .7186 .31075 Metetra
.659 .746 .915 r
.7186 .31075 .72706 .32255 .74542 .31609 .73705 .30435 Metetra
.659 .749 .917 r
.73705 .30435 .74542 .31609 .76389 .30959 .75562 .29791 Metetra
.659 .751 .919 r
.75562 .29791 .76389 .30959 .78248 .30306 .77431 .29142 Metetra
.659 .754 .921 r
.77431 .29142 .78248 .30306 .80119 .29649 .79311 .2849 Metetra
.469 .688 .962 r
.13252 .46692 .14318 .47623 .15736 .47662 .14679 .46663 Metetra
.513 .691 .948 r
.14679 .46663 .15736 .47662 .17175 .47623 .16128 .46562 Metetra
.546 .69 .934 r
.16128 .46562 .17175 .47623 .18633 .47511 .17595 .46395 Metetra
.57 .689 .921 r
.17595 .46395 .18633 .47511 .20111 .47333 .19079 .46169 Metetra
.587 .687 .91 r
.19079 .46169 .20111 .47333 .21605 .47097 .2058 .45893 Metetra
.6 .685 .901 r
.2058 .45893 .21605 .47097 .23115 .46812 .22096 .45574 Metetra
.61 .683 .894 r
.22096 .45574 .23115 .46812 .24639 .46483 .23626 .45218 Metetra
.618 .682 .888 r
.23626 .45218 .24639 .46483 .26177 .46117 .25169 .4483 Metetra
.624 .681 .884 r
.25169 .4483 .26177 .46117 .27728 .45719 .26724 .44415 Metetra
.629 .681 .881 r
.26724 .44415 .27728 .45719 .29291 .45294 .28291 .43977 Metetra
.633 .681 .878 r
.28291 .43977 .29291 .45294 .30866 .44846 .2987 .43519 Metetra
.636 .682 .877 r
.2987 .43519 .30866 .44846 .32452 .44378 .3146 .43043 Metetra
.639 .683 .876 r
.3146 .43043 .32452 .44378 .34049 .43893 .33061 .42553 Metetra
.641 .684 .875 r
.33061 .42553 .34049 .43893 .35657 .43392 .34673 .42049 Metetra
.643 .685 .875 r
.34673 .42049 .35657 .43392 .37275 .42878 .36296 .41534 Metetra
.645 .687 .875 r
.36296 .41534 .37275 .42878 .38904 .42352 .37929 .41008 Metetra
.646 .689 .876 r
.37929 .41008 .38904 .42352 .40543 .41815 .39573 .40473 Metetra
.647 .691 .876 r
.39573 .40473 .40543 .41815 .42193 .41269 .41227 .39929 Metetra
.648 .692 .877 r
.41227 .39929 .42193 .41269 .43853 .40715 .42891 .39378 Metetra
.649 .694 .879 r
.42891 .39378 .43853 .40715 .45524 .40153 .44567 .38819 Metetra
.65 .696 .88 r
.44567 .38819 .45524 .40153 .47205 .39585 .46252 .38254 Metetra
.651 .699 .881 r
.46252 .38254 .47205 .39585 .48896 .39009 .47949 .37683 Metetra
.651 .701 .882 r
.47949 .37683 .48896 .39009 .50598 .38428 .49656 .37105 Metetra
.652 .703 .884 r
.49656 .37105 .50598 .38428 .5231 .37841 .51374 .36523 Metetra
.653 .705 .885 r
.51374 .36523 .5231 .37841 .54032 .37249 .53102 .35935 Metetra
.653 .707 .887 r
.53102 .35935 .54032 .37249 .55766 .36651 .54841 .35342 Metetra
.654 .709 .889 r
.54841 .35342 .55766 .36651 .5751 .36049 .56592 .34744 Metetra
.654 .712 .89 r
.56592 .34744 .5751 .36049 .59265 .35443 .58353 .34141 Metetra
.654 .714 .892 r
.58353 .34141 .59265 .35443 .61031 .34831 .60126 .33534 Metetra
.655 .716 .893 r
.60126 .33534 .61031 .34831 .62808 .34216 .61909 .32922 Metetra
.655 .718 .895 r
.61909 .32922 .62808 .34216 .64595 .33596 .63704 .32306 Metetra
.655 .72 .897 r
.63704 .32306 .64595 .33596 .66395 .32972 .65511 .31685 Metetra
.655 .722 .898 r
.65511 .31685 .66395 .32972 .68205 .32344 .67329 .3106 Metetra
.655 .724 .9 r
.67329 .3106 .68205 .32344 .70027 .31711 .69158 .30431 Metetra
.656 .726 .901 r
.69158 .30431 .70027 .31711 .7186 .31075 .71 .29797 Metetra
.656 .728 .903 r
.71 .29797 .7186 .31075 .73705 .30435 .72853 .2916 Metetra
.656 .73 .904 r
.72853 .2916 .73705 .30435 .75562 .29791 .74718 .28518 Metetra
.656 .732 .906 r
.74718 .28518 .75562 .29791 .77431 .29142 .76596 .27871 Metetra
.656 .734 .907 r
.76596 .27871 .77431 .29142 .79311 .2849 .78485 .27221 Metetra
.501 .701 .959 r
.12174 .45751 .13252 .46692 .14679 .46663 .13612 .45655 Metetra
.537 .7 .945 r
.13612 .45655 .14679 .46663 .16128 .46562 .1507 .45492 Metetra
.564 .698 .931 r
.1507 .45492 .16128 .46562 .17595 .46395 .16546 .45271 Metetra
.583 .694 .918 r
.16546 .45271 .17595 .46395 .19079 .46169 .18038 .44998 Metetra
.598 .691 .908 r
.18038 .44998 .19079 .46169 .2058 .45893 .19546 .44682 Metetra
.608 .688 .9 r
.19546 .44682 .2058 .45893 .22096 .45574 .21068 .44329 Metetra
.616 .686 .893 r
.21068 .44329 .22096 .45574 .23626 .45218 .22603 .43945 Metetra
.622 .684 .887 r
.22603 .43945 .23626 .45218 .25169 .4483 .24151 .43534 Metetra
.627 .683 .883 r
.24151 .43534 .25169 .4483 .26724 .44415 .25711 .43101 Metetra
.631 .682 .88 r
.25711 .43101 .26724 .44415 .28291 .43977 .27283 .42647 Metetra
.634 .682 .878 r
.27283 .42647 .28291 .43977 .2987 .43519 .28866 .42177 Metetra
.637 .682 .876 r
.28866 .42177 .2987 .43519 .3146 .43043 .3046 .41692 Metetra
.639 .682 .875 r
.3046 .41692 .3146 .43043 .33061 .42553 .32065 .41194 Metetra
.641 .683 .874 r
.32065 .41194 .33061 .42553 .34673 .42049 .33681 .40684 Metetra
.642 .683 .874 r
.33681 .40684 .34673 .42049 .36296 .41534 .35308 .40165 Metetra
.644 .684 .874 r
.35308 .40165 .36296 .41534 .37929 .41008 .36945 .39636 Metetra
.645 .685 .874 r
.36945 .39636 .37929 .41008 .39573 .40473 .38593 .39098 Metetra
.646 .687 .874 r
.38593 .39098 .39573 .40473 .41227 .39929 .40252 .38553 Metetra
.647 .688 .875 r
.40252 .38553 .41227 .39929 .42891 .39378 .41921 .38001 Metetra
.647 .689 .875 r
.41921 .38001 .42891 .39378 .44567 .38819 .43601 .37442 Metetra
.648 .69 .876 r
.43601 .37442 .44567 .38819 .46252 .38254 .45292 .36877 Metetra
.649 .692 .877 r
.45292 .36877 .46252 .38254 .47949 .37683 .46993 .36306 Metetra
.649 .693 .878 r
.46993 .36306 .47949 .37683 .49656 .37105 .48705 .35729 Metetra
.65 .695 .879 r
.48705 .35729 .49656 .37105 .51374 .36523 .50428 .35147 Metetra
.65 .696 .88 r
.50428 .35147 .51374 .36523 .53102 .35935 .52162 .34559 Metetra
.651 .698 .881 r
.52162 .34559 .53102 .35935 .54841 .35342 .53907 .33967 Metetra
.651 .699 .882 r
.53907 .33967 .54841 .35342 .56592 .34744 .55664 .3337 Metetra
.651 .701 .883 r
.55664 .3337 .56592 .34744 .58353 .34141 .57431 .32768 Metetra
.652 .702 .884 r
.57431 .32768 .58353 .34141 .60126 .33534 .5921 .32161 Metetra
.652 .704 .885 r
.5921 .32161 .60126 .33534 .61909 .32922 .61 .3155 Metetra
.652 .705 .886 r
.61 .3155 .61909 .32922 .63704 .32306 .62801 .30934 Metetra
.652 .707 .887 r
.62801 .30934 .63704 .32306 .65511 .31685 .64615 .30314 Metetra
.653 .708 .888 r
.64615 .30314 .65511 .31685 .67329 .3106 .6644 .29689 Metetra
.653 .71 .889 r
.6644 .29689 .67329 .3106 .69158 .30431 .68277 .2906 Metetra
.653 .711 .891 r
.68277 .2906 .69158 .30431 .71 .29797 .70125 .28426 Metetra
.653 .713 .892 r
.70125 .28426 .71 .29797 .72853 .2916 .71986 .27788 Metetra
.653 .714 .893 r
.71986 .27788 .72853 .2916 .74718 .28518 .73859 .27146 Metetra
.654 .716 .894 r
.73859 .27146 .74718 .28518 .76596 .27871 .75744 .26499 Metetra
.654 .717 .895 r
.75744 .26499 .76596 .27871 .78485 .27221 .77642 .25847 Metetra
.53 .712 .955 r
.11085 .448 .12174 .45751 .13612 .45655 .12534 .44637 Metetra
.56 .709 .941 r
.12534 .44637 .13612 .45655 .1507 .45492 .14001 .44414 Metetra
.581 .704 .927 r
.14001 .44414 .1507 .45492 .16546 .45271 .15486 .4414 Metetra
.596 .7 .916 r
.15486 .4414 .16546 .45271 .18038 .44998 .16986 .43822 Metetra
.607 .696 .906 r
.16986 .43822 .18038 .44998 .19546 .44682 .18501 .43466 Metetra
.616 .692 .898 r
.18501 .43466 .19546 .44682 .21068 .44329 .20029 .4308 Metetra
.622 .689 .892 r
.20029 .4308 .21068 .44329 .22603 .43945 .2157 .42667 Metetra
.627 .687 .887 r
.2157 .42667 .22603 .43945 .24151 .43534 .23123 .42232 Metetra
.63 .685 .883 r
.23123 .42232 .24151 .43534 .25711 .43101 .24688 .41779 Metetra
.633 .684 .88 r
.24688 .41779 .25711 .43101 .27283 .42647 .26265 .41308 Metetra
.636 .683 .878 r
.26265 .41308 .27283 .42647 .28866 .42177 .27852 .40824 Metetra
.638 .683 .876 r
.27852 .40824 .28866 .42177 .3046 .41692 .29451 .40327 Metetra
.64 .682 .874 r
.29451 .40327 .3046 .41692 .32065 .41194 .3106 .39818 Metetra
.641 .682 .873 r
.3106 .39818 .32065 .41194 .33681 .40684 .32681 .393 Metetra
.642 .682 .873 r
.32681 .393 .33681 .40684 .35308 .40165 .34312 .38773 Metetra
.643 .683 .872 r
.34312 .38773 .35308 .40165 .36945 .39636 .35953 .38238 Metetra
.644 .683 .872 r
.35953 .38238 .36945 .39636 .38593 .39098 .37606 .37695 Metetra
.645 .684 .872 r
.37606 .37695 .38593 .39098 .40252 .38553 .39269 .37145 Metetra
.646 .684 .872 r
.39269 .37145 .40252 .38553 .41921 .38001 .40943 .36589 Metetra
.646 .685 .872 r
.40943 .36589 .41921 .38001 .43601 .37442 .42627 .36026 Metetra
.647 .686 .873 r
.42627 .36026 .43601 .37442 .45292 .36877 .44322 .35458 Metetra
.647 .687 .873 r
.44322 .35458 .45292 .36877 .46993 .36306 .46029 .34884 Metetra
.648 .688 .874 r
.46029 .34884 .46993 .36306 .48705 .35729 .47746 .34304 Metetra
.648 .688 .874 r
.47746 .34304 .48705 .35729 .50428 .35147 .49474 .33719 Metetra
.648 .689 .875 r
.49474 .33719 .50428 .35147 .52162 .34559 .51213 .3313 Metetra
.649 .69 .875 r
.51213 .3313 .52162 .34559 .53907 .33967 .52964 .32535 Metetra
.649 .691 .876 r
.52964 .32535 .53907 .33967 .55664 .3337 .54726 .31935 Metetra
.649 .692 .876 r
.54726 .31935 .55664 .3337 .57431 .32768 .56499 .31331 Metetra
.65 .693 .877 r
.56499 .31331 .57431 .32768 .5921 .32161 .58283 .30722 Metetra
.65 .694 .878 r
.58283 .30722 .5921 .32161 .61 .3155 .6008 .30108 Metetra
.65 .695 .879 r
.6008 .30108 .61 .3155 .62801 .30934 .61887 .2949 Metetra
.65 .696 .879 r
.61887 .2949 .62801 .30934 .64615 .30314 .63707 .28867 Metetra
.651 .697 .88 r
.63707 .28867 .64615 .30314 .6644 .29689 .65538 .28239 Metetra
.651 .698 .881 r
.65538 .28239 .6644 .29689 .68277 .2906 .67382 .27607 Metetra
.651 .699 .881 r
.67382 .27607 .68277 .2906 .70125 .28426 .69238 .26971 Metetra
.651 .7 .882 r
.69238 .26971 .70125 .28426 .71986 .27788 .71105 .2633 Metetra
.651 .701 .883 r
.71105 .2633 .71986 .27788 .73859 .27146 .72986 .25684 Metetra
.651 .702 .883 r
.72986 .25684 .73859 .27146 .75744 .26499 .74878 .25034 Metetra
.651 .702 .884 r
.74878 .25034 .75744 .26499 .77642 .25847 .76783 .24379 Metetra
.556 .722 .951 r
.09983 .43839 .11085 .448 .12534 .44637 .11443 .43611 Metetra
.58 .716 .936 r
.11443 .43611 .12534 .44637 .14001 .44414 .12921 .43329 Metetra
.596 .71 .924 r
.12921 .43329 .14001 .44414 .15486 .4414 .14414 .43003 Metetra
.608 .705 .913 r
.14414 .43003 .15486 .4414 .16986 .43822 .15923 .4264 Metetra
.616 .7 .904 r
.15923 .4264 .16986 .43822 .18501 .43466 .17445 .42246 Metetra
.623 .696 .897 r
.17445 .42246 .18501 .43466 .20029 .4308 .18979 .41827 Metetra
.628 .693 .891 r
.18979 .41827 .20029 .4308 .2157 .42667 .20526 .41386 Metetra
.631 .69 .887 r
.20526 .41386 .2157 .42667 .23123 .42232 .22085 .40926 Metetra
.634 .688 .883 r
.22085 .40926 .23123 .42232 .24688 .41779 .23655 .40451 Metetra
.636 .686 .88 r
.23655 .40451 .24688 .41779 .26265 .41308 .25237 .39963 Metetra
.638 .685 .878 r
.25237 .39963 .26265 .41308 .27852 .40824 .26829 .39462 Metetra
.64 .684 .876 r
.26829 .39462 .27852 .40824 .29451 .40327 .28432 .38951 Metetra
.641 .683 .874 r
.28432 .38951 .29451 .40327 .3106 .39818 .30046 .38431 Metetra
.642 .683 .873 r
.30046 .38431 .3106 .39818 .32681 .393 .31671 .37902 Metetra
.643 .682 .872 r
.31671 .37902 .32681 .393 .34312 .38773 .33307 .37365 Metetra
.644 .682 .872 r
.33307 .37365 .34312 .38773 .35953 .38238 .34953 .36821 Metetra
.644 .682 .871 r
.34953 .36821 .35953 .38238 .37606 .37695 .3661 .3627 Metetra
.645 .682 .871 r
.3661 .3627 .37606 .37695 .39269 .37145 .38277 .35712 Metetra
.645 .682 .87 r
.38277 .35712 .39269 .37145 .40943 .36589 .39955 .35149 Metetra
.646 .682 .87 r
.39955 .35149 .40943 .36589 .42627 .36026 .41645 .3458 Metetra
.646 .683 .87 r
.41645 .3458 .42627 .36026 .44322 .35458 .43345 .34005 Metetra
.646 .683 .87 r
.43345 .34005 .44322 .35458 .46029 .34884 .45056 .33425 Metetra
.647 .683 .87 r
.45056 .33425 .46029 .34884 .47746 .34304 .46778 .3284 Metetra
.647 .684 .871 r
.46778 .3284 .47746 .34304 .49474 .33719 .48511 .3225 Metetra
.647 .684 .871 r
.48511 .3225 .49474 .33719 .51213 .3313 .50255 .31655 Metetra
.648 .685 .871 r
.50255 .31655 .51213 .3313 .52964 .32535 .52011 .31055 Metetra
.648 .685 .871 r
.52011 .31055 .52964 .32535 .54726 .31935 .53778 .3045 Metetra
.648 .686 .872 r
.53778 .3045 .54726 .31935 .56499 .31331 .55557 .2984 Metetra
.648 .686 .872 r
.55557 .2984 .56499 .31331 .58283 .30722 .57347 .29226 Metetra
.648 .687 .872 r
.57347 .29226 .58283 .30722 .6008 .30108 .59149 .28607 Metetra
.649 .687 .873 r
.59149 .28607 .6008 .30108 .61887 .2949 .60963 .27984 Metetra
.649 .688 .873 r
.60963 .27984 .61887 .2949 .63707 .28867 .62788 .27356 Metetra
.649 .688 .873 r
.62788 .27356 .63707 .28867 .65538 .28239 .64626 .26723 Metetra
.649 .689 .874 r
.64626 .26723 .65538 .28239 .67382 .27607 .66476 .26085 Metetra
.649 .689 .874 r
.66476 .26085 .67382 .27607 .69238 .26971 .68338 .25444 Metetra
.649 .69 .874 r
.68338 .25444 .69238 .26971 .71105 .2633 .70212 .24797 Metetra
.649 .69 .875 r
.70212 .24797 .71105 .2633 .72986 .25684 .72099 .24146 Metetra
.65 .691 .875 r
.72099 .24146 .72986 .25684 .74878 .25034 .73998 .2349 Metetra
.65 .691 .875 r
.73998 .2349 .74878 .25034 .76783 .24379 .75911 .22829 Metetra
.579 .729 .946 r
.0887 .42868 .09983 .43839 .11443 .43611 .10341 .42575 Metetra
.597 .723 .932 r
.10341 .42575 .11443 .43611 .12921 .43329 .11829 .42237 Metetra
.61 .716 .92 r
.11829 .42237 .12921 .43329 .14414 .43003 .13332 .41862 Metetra
.619 .71 .911 r
.13332 .41862 .14414 .43003 .15923 .4264 .14848 .41456 Metetra
.625 .705 .903 r
.14848 .41456 .15923 .4264 .17445 .42246 .16377 .41024 Metetra
.63 .7 .896 r
.16377 .41024 .17445 .42246 .18979 .41827 .17919 .40573 Metetra
.633 .697 .891 r
.17919 .40573 .18979 .41827 .20526 .41386 .19472 .40104 Metetra
.636 .694 .887 r
.19472 .40104 .20526 .41386 .22085 .40926 .21036 .3962 Metetra
.638 .691 .883 r
.21036 .3962 .22085 .40926 .23655 .40451 .22612 .39123 Metetra
.639 .689 .881 r
.22612 .39123 .23655 .40451 .25237 .39963 .24199 .38616 Metetra
.641 .688 .878 r
.24199 .38616 .25237 .39963 .26829 .39462 .25796 .38098 Metetra
.642 .686 .876 r
.25796 .38098 .26829 .39462 .28432 .38951 .27404 .37571 Metetra
.643 .685 .875 r
.27404 .37571 .28432 .38951 .30046 .38431 .29023 .37037 Metetra
.643 .684 .874 r
.29023 .37037 .30046 .38431 .31671 .37902 .30652 .36495 Metetra
.644 .684 .872 r
.30652 .36495 .31671 .37902 .33307 .37365 .32292 .35946 Metetra
.644 .683 .872 r
.32292 .35946 .33307 .37365 .34953 .36821 .33943 .35391 Metetra
.645 .682 .871 r
.33943 .35391 .34953 .36821 .3661 .3627 .35604 .3483 Metetra
.645 .682 .87 r
.35604 .3483 .3661 .3627 .38277 .35712 .37276 .34263 Metetra
.646 .682 .87 r
.37276 .34263 .38277 .35712 .39955 .35149 .38959 .3369 Metetra
.646 .682 .869 r
.38959 .3369 .39955 .35149 .41645 .3458 .40653 .33112 Metetra
.646 .682 .869 r
.40653 .33112 .41645 .3458 .43345 .34005 .42358 .32529 Metetra
.646 .681 .869 r
.42358 .32529 .43345 .34005 .45056 .33425 .44074 .31941 Metetra
.647 .681 .869 r
.44074 .31941 .45056 .33425 .46778 .3284 .45801 .31348 Metetra
.647 .681 .869 r
.45801 .31348 .46778 .3284 .48511 .3225 .47539 .3075 Metetra
.647 .681 .869 r
.47539 .3075 .48511 .3225 .50255 .31655 .49289 .30147 Metetra
.647 .682 .868 r
.49289 .30147 .50255 .31655 .52011 .31055 .5105 .29539 Metetra
.647 .682 .868 r
.5105 .29539 .52011 .31055 .53778 .3045 .52822 .28927 Metetra
.647 .682 .868 r
.52822 .28927 .53778 .3045 .55557 .2984 .54606 .2831 Metetra
.648 .682 .869 r
.54606 .2831 .55557 .2984 .57347 .29226 .56402 .27689 Metetra
.648 .682 .869 r
.56402 .27689 .57347 .29226 .59149 .28607 .58209 .27062 Metetra
.648 .682 .869 r
.58209 .27062 .59149 .28607 .60963 .27984 .60028 .26432 Metetra
.648 .682 .869 r
.60028 .26432 .60963 .27984 .62788 .27356 .6186 .25796 Metetra
.648 .683 .869 r
.6186 .25796 .62788 .27356 .64626 .26723 .63703 .25156 Metetra
.648 .683 .869 r
.63703 .25156 .64626 .26723 .66476 .26085 .65559 .24511 Metetra
.648 .683 .869 r
.65559 .24511 .66476 .26085 .68338 .25444 .67427 .23862 Metetra
.648 .683 .869 r
.67427 .23862 .68338 .25444 .70212 .24797 .69308 .23208 Metetra
.648 .683 .869 r
.69308 .23208 .70212 .24797 .72099 .24146 .71201 .22549 Metetra
.648 .684 .869 r
.71201 .22549 .72099 .24146 .73998 .2349 .73107 .21886 Metetra
.649 .684 .87 r
.73107 .21886 .73998 .2349 .75911 .22829 .75026 .21218 Metetra
.599 .736 .94 r
.07745 .41885 .0887 .42868 .10341 .42575 .09227 .41532 Metetra
.613 .728 .928 r
.09227 .41532 .10341 .42575 .11829 .42237 .10725 .41139 Metetra
.622 .721 .917 r
.10725 .41139 .11829 .42237 .13332 .41862 .12237 .40717 Metetra
.628 .715 .909 r
.12237 .40717 .13332 .41862 .14848 .41456 .13761 .4027 Metetra
.633 .709 .902 r
.13761 .4027 .14848 .41456 .16377 .41024 .15298 .39804 Metetra
.636 .705 .896 r
.15298 .39804 .16377 .41024 .17919 .40573 .16846 .39321 Metetra
.638 .701 .892 r
.16846 .39321 .17919 .40573 .19472 .40104 .18406 .38825 Metetra
.64 .698 .888 r
.18406 .38825 .19472 .40104 .21036 .3962 .19976 .38317 Metetra
.641 .695 .885 r
.19976 .38317 .21036 .3962 .22612 .39123 .21557 .37799 Metetra
.643 .693 .882 r
.21557 .37799 .22612 .39123 .24199 .38616 .23149 .37272 Metetra
.643 .691 .88 r
.23149 .37272 .24199 .38616 .25796 .38098 .24752 .36737 Metetra
.644 .69 .878 r
.24752 .36737 .25796 .38098 .27404 .37571 .26365 .36194 Metetra
.645 .688 .876 r
.26365 .36194 .27404 .37571 .29023 .37037 .27988 .35644 Metetra
.645 .687 .875 r
.27988 .35644 .29023 .37037 .30652 .36495 .29622 .35089 Metetra
.645 .686 .874 r
.29622 .35089 .30652 .36495 .32292 .35946 .31267 .34527 Metetra
.646 .685 .873 r
.31267 .34527 .32292 .35946 .33943 .35391 .32923 .33959 Metetra
.646 .685 .872 r
.32923 .33959 .33943 .35391 .35604 .3483 .34589 .33386 Metetra
.646 .684 .871 r
.34589 .33386 .35604 .3483 .37276 .34263 .36266 .32808 Metetra
.647 .683 .871 r
.36266 .32808 .37276 .34263 .38959 .3369 .37954 .32224 Metetra
.647 .683 .87 r
.37954 .32224 .38959 .3369 .40653 .33112 .39652 .31636 Metetra
.647 .683 .87 r
.39652 .31636 .40653 .33112 .42358 .32529 .41362 .31043 Metetra
.647 .682 .869 r
.41362 .31043 .42358 .32529 .44074 .31941 .43083 .30445 Metetra
.647 .682 .869 r
.43083 .30445 .44074 .31941 .45801 .31348 .44815 .29842 Metetra
.647 .682 .869 r
.44815 .29842 .45801 .31348 .47539 .3075 .46558 .29234 Metetra
.647 .681 .868 r
.46558 .29234 .47539 .3075 .49289 .30147 .48313 .28622 Metetra
.647 .681 .868 r
.48313 .28622 .49289 .30147 .5105 .29539 .50079 .28006 Metetra
.647 .681 .868 r
.50079 .28006 .5105 .29539 .52822 .28927 .51856 .27384 Metetra
.648 .681 .868 r
.51856 .27384 .52822 .28927 .54606 .2831 .53646 .26758 Metetra
.648 .681 .867 r
.53646 .26758 .54606 .2831 .56402 .27689 .55447 .26128 Metetra
.648 .681 .867 r
.55447 .26128 .56402 .27689 .58209 .27062 .5726 .25493 Metetra
.648 .681 .867 r
.5726 .25493 .58209 .27062 .60028 .26432 .59085 .24853 Metetra
.648 .681 .867 r
.59085 .24853 .60028 .26432 .6186 .25796 .60922 .24209 Metetra
.648 .68 .867 r
.60922 .24209 .6186 .25796 .63703 .25156 .62771 .2356 Metetra
.648 .68 .867 r
.62771 .2356 .63703 .25156 .65559 .24511 .64632 .22906 Metetra
.648 .68 .867 r
.64632 .22906 .65559 .24511 .67427 .23862 .66507 .22248 Metetra
.648 .68 .867 r
.66507 .22248 .67427 .23862 .69308 .23208 .68393 .21585 Metetra
.648 .68 .867 r
.68393 .21585 .69308 .23208 .71201 .22549 .70293 .20918 Metetra
.648 .68 .867 r
.70293 .20918 .71201 .22549 .73107 .21886 .72205 .20245 Metetra
.648 .68 .867 r
.72205 .20245 .73107 .21886 .75026 .21218 .7413 .19568 Metetra
.617 .741 .935 r
.06607 .40892 .07745 .41885 .09227 .41532 .08101 .4048 Metetra
.627 .733 .924 r
.08101 .4048 .09227 .41532 .10725 .41139 .09609 .40038 Metetra
.633 .726 .915 r
.09609 .40038 .10725 .41139 .12237 .40717 .11129 .39572 Metetra
.637 .719 .907 r
.11129 .39572 .12237 .40717 .13761 .4027 .12662 .39088 Metetra
.64 .714 .901 r
.12662 .39088 .13761 .4027 .15298 .39804 .14206 .38589 Metetra
.642 .71 .897 r
.14206 .38589 .15298 .39804 .16846 .39321 .15761 .38077 Metetra
.643 .706 .893 r
.15761 .38077 .16846 .39321 .18406 .38825 .17327 .37555 Metetra
.644 .703 .889 r
.17327 .37555 .18406 .38825 .19976 .38317 .18903 .37024 Metetra
.645 .701 .887 r
.18903 .37024 .19976 .38317 .21557 .37799 .2049 .36486 Metetra
.646 .698 .884 r
.2049 .36486 .21557 .37799 .23149 .37272 .22087 .35939 Metetra
.646 .697 .882 r
.22087 .35939 .23149 .37272 .24752 .36737 .23695 .35387 Metetra
.647 .695 .881 r
.23695 .35387 .24752 .36737 .26365 .36194 .25313 .34828 Metetra
.647 .693 .879 r
.25313 .34828 .26365 .36194 .27988 .35644 .26942 .34263 Metetra
.647 .692 .878 r
.26942 .34263 .27988 .35644 .29622 .35089 .28581 .33693 Metetra
.647 .691 .877 r
.28581 .33693 .29622 .35089 .31267 .34527 .30231 .33118 Metetra
.648 .69 .876 r
.30231 .33118 .31267 .34527 .32923 .33959 .31892 .32537 Metetra
.648 .689 .875 r
.31892 .32537 .32923 .33959 .34589 .33386 .33563 .31952 Metetra
.648 .688 .874 r
.33563 .31952 .34589 .33386 .36266 .32808 .35245 .31361 Metetra
.648 .688 .873 r
.35245 .31361 .36266 .32808 .37954 .32224 .36937 .30766 Metetra
.648 .687 .873 r
.36937 .30766 .37954 .32224 .39652 .31636 .38641 .30167 Metetra
.648 .686 .872 r
.38641 .30167 .39652 .31636 .41362 .31043 .40356 .29562 Metetra
.648 .686 .872 r
.40356 .29562 .41362 .31043 .43083 .30445 .42082 .28954 Metetra
.648 .685 .871 r
.42082 .28954 .43083 .30445 .44815 .29842 .43819 .2834 Metetra
.648 .685 .871 r
.43819 .2834 .44815 .29842 .46558 .29234 .45567 .27722 Metetra
.648 .685 .87 r
.45567 .27722 .46558 .29234 .48313 .28622 .47327 .271 Metetra
.648 .684 .87 r
.47327 .271 .48313 .28622 .50079 .28006 .49098 .26473 Metetra
.648 .684 .87 r
.49098 .26473 .50079 .28006 .51856 .27384 .50881 .25842 Metetra
.648 .684 .87 r
.50881 .25842 .51856 .27384 .53646 .26758 .52676 .25206 Metetra
.648 .683 .869 r
.52676 .25206 .53646 .26758 .55447 .26128 .54483 .24565 Metetra
.648 .683 .869 r
.54483 .24565 .55447 .26128 .5726 .25493 .56301 .2392 Metetra
.648 .683 .869 r
.56301 .2392 .5726 .25493 .59085 .24853 .58132 .23271 Metetra
.648 .683 .869 r
.58132 .23271 .59085 .24853 .60922 .24209 .59975 .22617 Metetra
.648 .682 .868 r
.59975 .22617 .60922 .24209 .62771 .2356 .6183 .21958 Metetra
.648 .682 .868 r
.6183 .21958 .62771 .2356 .64632 .22906 .63697 .21295 Metetra
.648 .682 .868 r
.63697 .21295 .64632 .22906 .66507 .22248 .65577 .20627 Metetra
.648 .682 .868 r
.65577 .20627 .66507 .22248 .68393 .21585 .6747 .19954 Metetra
.648 .682 .868 r
.6747 .19954 .68393 .21585 .70293 .20918 .69376 .19277 Metetra
.648 .681 .868 r
.69376 .19277 .70293 .20918 .72205 .20245 .71294 .18594 Metetra
.648 .681 .867 r
.71294 .18594 .72205 .20245 .7413 .19568 .73226 .17908 Metetra
.632 .745 .93 r
.05456 .39888 .06607 .40892 .08101 .4048 .06961 .39422 Metetra
.638 .737 .92 r
.06961 .39422 .08101 .4048 .09609 .40038 .08479 .38934 Metetra
.642 .73 .913 r
.08479 .38934 .09609 .40038 .11129 .39572 .10009 .3843 Metetra
.644 .724 .907 r
.10009 .3843 .11129 .39572 .12662 .39088 .11549 .37912 Metetra
.646 .72 .902 r
.11549 .37912 .12662 .39088 .14206 .38589 .131 .37384 Metetra
.647 .716 .898 r
.131 .37384 .14206 .38589 .15761 .38077 .14662 .36847 Metetra
.648 .713 .895 r
.14662 .36847 .15761 .38077 .17327 .37555 .16234 .36302 Metetra
.648 .71 .892 r
.16234 .36302 .17327 .37555 .18903 .37024 .17816 .3575 Metetra
.649 .707 .89 r
.17816 .3575 .18903 .37024 .2049 .36486 .19409 .35192 Metetra
.649 .705 .888 r
.19409 .35192 .2049 .36486 .22087 .35939 .21012 .34629 Metetra
.649 .703 .886 r
.21012 .34629 .22087 .35939 .23695 .35387 .22625 .34059 Metetra
.649 .702 .885 r
.22625 .34059 .23695 .35387 .25313 .34828 .24249 .33485 Metetra
.649 .7 .884 r
.24249 .33485 .25313 .34828 .26942 .34263 .25883 .32906 Metetra
.649 .699 .883 r
.25883 .32906 .26942 .34263 .28581 .33693 .27527 .32322 Metetra
.649 .698 .882 r
.27527 .32322 .28581 .33693 .30231 .33118 .29182 .31733 Metetra
.65 .697 .881 r
.29182 .31733 .30231 .33118 .31892 .32537 .30848 .3114 Metetra
.65 .696 .88 r
.30848 .3114 .31892 .32537 .33563 .31952 .32524 .30542 Metetra
.65 .695 .879 r
.32524 .30542 .33563 .31952 .35245 .31361 .34211 .2994 Metetra
.65 .695 .878 r
.34211 .2994 .35245 .31361 .36937 .30766 .35909 .29333 Metetra
.65 .694 .878 r
.35909 .29333 .36937 .30766 .38641 .30167 .37618 .28722 Metetra
.65 .693 .877 r
.37618 .28722 .38641 .30167 .40356 .29562 .39338 .28107 Metetra
.65 .693 .877 r
.39338 .28107 .40356 .29562 .42082 .28954 .4107 .27487 Metetra
.65 .692 .876 r
.4107 .27487 .42082 .28954 .43819 .2834 .42812 .26863 Metetra
.65 .692 .876 r
.42812 .26863 .43819 .2834 .45567 .27722 .44566 .26234 Metetra
.65 .691 .876 r
.44566 .26234 .45567 .27722 .47327 .271 .46331 .25601 Metetra
.65 .691 .875 r
.46331 .25601 .47327 .271 .49098 .26473 .48108 .24964 Metetra
.65 .691 .875 r
.48108 .24964 .49098 .26473 .50881 .25842 .49897 .24322 Metetra
.65 .69 .875 r
.49897 .24322 .50881 .25842 .52676 .25206 .51697 .23676 Metetra
.65 .69 .874 r
.51697 .23676 .52676 .25206 .54483 .24565 .5351 .23026 Metetra
.65 .69 .874 r
.5351 .23026 .54483 .24565 .56301 .2392 .55334 .2237 Metetra
.65 .689 .874 r
.55334 .2237 .56301 .2392 .58132 .23271 .57171 .21711 Metetra
.65 .689 .874 r
.57171 .21711 .58132 .23271 .59975 .22617 .59019 .21046 Metetra
.65 .689 .873 r
.59019 .21046 .59975 .22617 .6183 .21958 .60881 .20378 Metetra
.65 .688 .873 r
.60881 .20378 .6183 .21958 .63697 .21295 .62754 .19704 Metetra
.65 .688 .873 r
.62754 .19704 .63697 .21295 .65577 .20627 .64641 .19026 Metetra
.65 .688 .873 r
.64641 .19026 .65577 .20627 .6747 .19954 .6654 .18343 Metetra
.649 .688 .872 r
.6654 .18343 .6747 .19954 .69376 .19277 .68452 .17656 Metetra
.649 .688 .872 r
.68452 .17656 .69376 .19277 .71294 .18594 .70377 .16963 Metetra
.649 .687 .872 r
.70377 .16963 .71294 .18594 .73226 .17908 .72315 .16266 Metetra
.644 .748 .925 r
.04293 .38873 .05456 .39888 .06961 .39422 .05808 .3836 Metetra
.647 .741 .918 r
.05808 .3836 .06961 .39422 .08479 .38934 .07335 .37834 Metetra
.649 .735 .912 r
.07335 .37834 .08479 .38934 .10009 .3843 .08873 .37296 Metetra
.65 .73 .908 r
.08873 .37296 .10009 .3843 .11549 .37912 .10421 .36751 Metetra
.651 .726 .904 r
.10421 .36751 .11549 .37912 .131 .37384 .11979 .36198 Metetra
.651 .723 .901 r
.11979 .36198 .131 .37384 .14662 .36847 .13547 .3564 Metetra
.651 .72 .899 r
.13547 .3564 .14662 .36847 .16234 .36302 .15125 .35075 Metetra
.651 .718 .897 r
.15125 .35075 .16234 .36302 .17816 .3575 .16714 .34506 Metetra
.652 .716 .895 r
.16714 .34506 .17816 .3575 .19409 .35192 .18312 .33931 Metetra
.652 .714 .894 r
.18312 .33931 .19409 .35192 .21012 .34629 .19921 .33352 Metetra
.652 .713 .893 r
.19921 .33352 .21012 .34629 .22625 .34059 .2154 .32769 Metetra
.652 .711 .891 r
.2154 .32769 .22625 .34059 .24249 .33485 .23169 .32181 Metetra
.652 .71 .89 r
.23169 .32181 .24249 .33485 .25883 .32906 .24808 .31588 Metetra
.652 .709 .89 r
.24808 .31588 .25883 .32906 .27527 .32322 .26458 .30992 Metetra
.652 .708 .889 r
.26458 .30992 .27527 .32322 .29182 .31733 .28119 .30391 Metetra
.652 .707 .888 r
.28119 .30391 .29182 .31733 .30848 .3114 .2979 .29786 Metetra
.652 .707 .887 r
.2979 .29786 .30848 .3114 .32524 .30542 .31471 .29177 Metetra
.652 .706 .887 r
.31471 .29177 .32524 .30542 .34211 .2994 .33164 .28563 Metetra
.652 .705 .886 r
.33164 .28563 .34211 .2994 .35909 .29333 .34868 .27946 Metetra
.652 .705 .886 r
.34868 .27946 .35909 .29333 .37618 .28722 .36582 .27324 Metetra
.652 .704 .885 r
.36582 .27324 .37618 .28722 .39338 .28107 .38308 .26698 Metetra
.652 .704 .885 r
.38308 .26698 .39338 .28107 .4107 .27487 .40045 .26068 Metetra
.652 .703 .885 r
.40045 .26068 .4107 .27487 .42812 .26863 .41793 .25433 Metetra
.651 .703 .884 r
.41793 .25433 .42812 .26863 .44566 .26234 .43553 .24795 Metetra
.651 .702 .884 r
.43553 .24795 .44566 .26234 .46331 .25601 .45324 .24152 Metetra
.651 .702 .884 r
.45324 .24152 .46331 .25601 .48108 .24964 .47107 .23504 Metetra
.651 .702 .883 r
.47107 .23504 .48108 .24964 .49897 .24322 .48902 .22852 Metetra
.651 .701 .883 r
.48902 .22852 .49897 .24322 .51697 .23676 .50708 .22196 Metetra
.651 .701 .883 r
.50708 .22196 .51697 .23676 .5351 .23026 .52527 .21535 Metetra
.651 .701 .883 r
.52527 .21535 .5351 .23026 .55334 .2237 .54357 .2087 Metetra
.651 .701 .882 r
.54357 .2087 .55334 .2237 .57171 .21711 .562 .20201 Metetra
.651 .7 .882 r
.562 .20201 .57171 .21711 .59019 .21046 .58056 .19526 Metetra
.651 .7 .882 r
.58056 .19526 .59019 .21046 .60881 .20378 .59923 .18847 Metetra
.651 .7 .882 r
.59923 .18847 .60881 .20378 .62754 .19704 .61804 .18164 Metetra
.651 .7 .882 r
.61804 .18164 .62754 .19704 .64641 .19026 .63697 .17476 Metetra
.651 .699 .882 r
.63697 .17476 .64641 .19026 .6654 .18343 .65603 .16783 Metetra
.651 .699 .881 r
.65603 .16783 .6654 .18343 .68452 .17656 .67522 .16085 Metetra
.651 .699 .881 r
.67522 .16085 .68452 .17656 .70377 .16963 .69454 .15383 Metetra
.651 .699 .881 r
.69454 .15383 .70377 .16963 .72315 .16266 .71399 .14675 Metetra
.652 .751 .922 r
.03116 .37846 .04293 .38873 .05808 .3836 .04641 .37297 Metetra
.653 .745 .917 r
.04641 .37297 .05808 .3836 .07335 .37834 .06176 .36742 Metetra
.654 .74 .913 r
.06176 .36742 .07335 .37834 .08873 .37296 .07721 .3618 Metetra
.654 .737 .911 r
.07721 .3618 .08873 .37296 .10421 .36751 .09276 .35614 Metetra
.654 .734 .908 r
.09276 .35614 .10421 .36751 .11979 .36198 .1084 .35043 Metetra
.654 .732 .907 r
.1084 .35043 .11979 .36198 .13547 .3564 .12415 .34468 Metetra
.654 .73 .905 r
.12415 .34468 .13547 .3564 .15125 .35075 .13999 .33889 Metetra
.654 .729 .904 r
.13999 .33889 .15125 .35075 .16714 .34506 .15593 .33305 Metetra
.654 .727 .903 r
.15593 .33305 .16714 .34506 .18312 .33931 .17197 .32718 Metetra
.654 .726 .902 r
.17197 .32718 .18312 .33931 .19921 .33352 .18812 .32127 Metetra
.654 .725 .901 r
.18812 .32127 .19921 .33352 .2154 .32769 .20436 .31532 Metetra
.654 .724 .901 r
.20436 .31532 .2154 .32769 .23169 .32181 .22071 .30932 Metetra
.654 .723 .9 r
.22071 .30932 .23169 .32181 .24808 .31588 .23716 .30329 Metetra
.654 .723 .899 r
.23716 .30329 .24808 .31588 .26458 .30992 .25372 .29722 Metetra
.654 .722 .899 r
.25372 .29722 .26458 .30992 .28119 .30391 .27038 .29111 Metetra
.654 .722 .899 r
.27038 .29111 .28119 .30391 .2979 .29786 .28715 .28496 Metetra
.654 .721 .898 r
.28715 .28496 .2979 .29786 .31471 .29177 .30402 .27877 Metetra
.654 .721 .898 r
.30402 .27877 .31471 .29177 .33164 .28563 .32101 .27254 Metetra
.654 .72 .898 r
.32101 .27254 .33164 .28563 .34868 .27946 .3381 .26626 Metetra
.654 .72 .897 r
.3381 .26626 .34868 .27946 .36582 .27324 .35531 .25995 Metetra
.654 .72 .897 r
.35531 .25995 .36582 .27324 .38308 .26698 .37263 .25359 Metetra
.654 .719 .897 r
.37263 .25359 .38308 .26698 .40045 .26068 .39006 .2472 Metetra
.654 .719 .896 r
.39006 .2472 .40045 .26068 .41793 .25433 .4076 .24076 Metetra
.654 .719 .896 r
.4076 .24076 .41793 .25433 .43553 .24795 .42526 .23428 Metetra
.653 .718 .896 r
.42526 .23428 .43553 .24795 .45324 .24152 .44304 .22775 Metetra
.653 .718 .896 r
.44304 .22775 .45324 .24152 .47107 .23504 .46093 .22118 Metetra
.653 .718 .896 r
.46093 .22118 .47107 .23504 .48902 .22852 .47895 .21457 Metetra
.653 .718 .896 r
.47895 .21457 .48902 .22852 .50708 .22196 .49708 .20791 Metetra
.653 .717 .895 r
.49708 .20791 .50708 .22196 .52527 .21535 .51533 .20121 Metetra
.653 .717 .895 r
.51533 .20121 .52527 .21535 .54357 .2087 .53371 .19447 Metetra
.653 .717 .895 r
.53371 .19447 .54357 .2087 .562 .20201 .55221 .18768 Metetra
.653 .717 .895 r
.55221 .18768 .562 .20201 .58056 .19526 .57083 .18084 Metetra
.653 .717 .895 r
.57083 .18084 .58056 .19526 .59923 .18847 .58958 .17395 Metetra
.653 .717 .895 r
.58958 .17395 .59923 .18847 .61804 .18164 .60846 .16702 Metetra
.653 .716 .895 r
.60846 .16702 .61804 .18164 .63697 .17476 .62746 .16005 Metetra
.653 .716 .894 r
.62746 .16005 .63697 .17476 .65603 .16783 .6466 .15302 Metetra
.653 .716 .894 r
.6466 .15302 .65603 .16783 .67522 .16085 .66586 .14595 Metetra
.653 .716 .894 r
.66586 .14595 .67522 .16085 .69454 .15383 .68526 .13882 Metetra
.653 .716 .894 r
.68526 .13882 .69454 .15383 .71399 .14675 .7048 .13165 Metetra
.656 .751 .92 r
.01926 .36807 .03116 .37846 .04641 .37297 .03458 .3624 Metetra
.656 .749 .918 r
.03458 .3624 .04641 .37297 .06176 .36742 .05 .35669 Metetra
.656 .747 .917 r
.05 .35669 .06176 .36742 .07721 .3618 .06551 .35095 Metetra
.656 .746 .916 r
.06551 .35095 .07721 .3618 .09276 .35614 .08111 .34517 Metetra
.656 .745 .916 r
.08111 .34517 .09276 .35614 .1084 .35043 .09681 .33935 Metetra
.655 .744 .915 r
.09681 .33935 .1084 .35043 .12415 .34468 .11261 .3335 Metetra
.655 .743 .914 r
.11261 .3335 .12415 .34468 .13999 .33889 .12851 .32761 Metetra
.655 .743 .914 r
.12851 .32761 .13999 .33889 .15593 .33305 .14451 .32169 Metetra
.655 .742 .914 r
.14451 .32169 .15593 .33305 .17197 .32718 .16061 .31573 Metetra
.655 .742 .913 r
.16061 .31573 .17197 .32718 .18812 .32127 .17681 .30973 Metetra
.655 .742 .913 r
.17681 .30973 .18812 .32127 .20436 .31532 .19311 .30369 Metetra
.655 .741 .913 r
.19311 .30369 .20436 .31532 .22071 .30932 .20952 .29761 Metetra
.655 .741 .913 r
.20952 .29761 .22071 .30932 .23716 .30329 .22603 .2915 Metetra
.655 .741 .913 r
.22603 .2915 .23716 .30329 .25372 .29722 .24265 .28534 Metetra
.655 .741 .912 r
.24265 .28534 .25372 .29722 .27038 .29111 .25937 .27915 Metetra
.655 .74 .912 r
.25937 .27915 .27038 .29111 .28715 .28496 .2762 .27291 Metetra
.655 .74 .912 r
.2762 .27291 .28715 .28496 .30402 .27877 .29314 .26664 Metetra
.655 .74 .912 r
.29314 .26664 .30402 .27877 .32101 .27254 .31019 .26033 Metetra
.655 .74 .912 r
.31019 .26033 .32101 .27254 .3381 .26626 .32735 .25397 Metetra
.655 .74 .912 r
.32735 .25397 .3381 .26626 .35531 .25995 .34462 .24758 Metetra
.655 .74 .912 r
.34462 .24758 .35531 .25995 .37263 .25359 .362 .24114 Metetra
.655 .74 .912 r
.362 .24114 .37263 .25359 .39006 .2472 .3795 .23466 Metetra
.655 .739 .912 r
.3795 .23466 .39006 .2472 .4076 .24076 .39712 .22813 Metetra
.655 .739 .912 r
.39712 .22813 .4076 .24076 .42526 .23428 .41484 .22157 Metetra
.655 .739 .912 r
.41484 .22157 .42526 .23428 .44304 .22775 .43269 .21496 Metetra
.655 .739 .911 r
.43269 .21496 .44304 .22775 .46093 .22118 .45066 .2083 Metetra
.655 .739 .911 r
.45066 .2083 .46093 .22118 .47895 .21457 .46874 .20161 Metetra
.655 .739 .911 r
.46874 .20161 .47895 .21457 .49708 .20791 .48695 .19486 Metetra
.655 .739 .911 r
.48695 .19486 .49708 .20791 .51533 .20121 .50528 .18807 Metetra
.655 .739 .911 r
.50528 .18807 .51533 .20121 .53371 .19447 .52373 .18124 Metetra
.655 .739 .911 r
.52373 .18124 .53371 .19447 .55221 .18768 .54231 .17436 Metetra
.655 .739 .911 r
.54231 .17436 .55221 .18768 .57083 .18084 .56101 .16743 Metetra
.655 .739 .911 r
.56101 .16743 .57083 .18084 .58958 .17395 .57984 .16046 Metetra
.655 .739 .911 r
.57984 .16046 .58958 .17395 .60846 .16702 .5988 .15344 Metetra
.655 .739 .911 r
.5988 .15344 .60846 .16702 .62746 .16005 .61789 .14637 Metetra
.655 .739 .911 r
.61789 .14637 .62746 .16005 .6466 .15302 .6371 .13925 Metetra
.655 .739 .911 r
.6371 .13925 .6466 .15302 .66586 .14595 .65646 .13208 Metetra
.655 .739 .911 r
.65646 .13208 .66586 .14595 .68526 .13882 .67594 .12487 Metetra
.655 .739 .911 r
.67594 .12487 .68526 .13882 .7048 .13165 .69556 .1176 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.01 w
.03716 .25514 m
.68874 0 L
s
.25 Mabswid
.03716 .25514 m
.04196 .25962 L
s
gsave
.02757 .24618 -75 -23.3395 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.1552 .20892 m
.15981 .21359 L
s
gsave
.14598 .19958 -74.9113 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.27893 .16047 m
.28333 .16533 L
s
gsave
.27013 .15073 -74.3275 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.40878 .10962 m
.41294 .11469 L
s
gsave
.40046 .09948 -73.7438 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.54521 .0562 m
.54911 .06148 L
s
gsave
.53743 .04564 -73.16 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.68874 0 m
.69233 .00549 L
s
gsave
.68156 -0.01098 -80.8449 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.253 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
68.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 467.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001db000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonfZ4oookJP?o001o1Ooo
nfX5o`00Ok3ooo]Z003ooookJXCooo]Z0ol007l4oookJPOo001o[ooonfX00?oooo]ZQ?oonfX3o`00
O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007n_oookJP00oooonfZ4oookJP?o001o0ooonfX3o`00
O`?ooo]Z0ol007n^oookJP00oooonfZ4oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007n^oookJP00
oooonfZ4oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007n^oookJP00oooonfZ4oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007n^oookJP00oooonfZ4oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007n^
oookJP00oooonfZ4oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007n^oookJP00oooonfZ1oookJPKo
001o0ooonfX3o`00O`?ooo]Z0ol007l<oookJPGo001oWOoonfX00?oooo]ZPOoonfX6o`00O`Cooo]Z
0ol007l01?oonf[o001oo`00Ool007l<oookJPOo001oW?oonfX00?oooo]ZPooonfX4o`00O`Cooo]Z
1ol007l<oookJP?o001o00Cooo]Zo`00Ool007oo001oW?oonfX00?oooo]ZQ?oonfX3o`00O`Gooo]Z
1Ol007l<oookJP?o001o0ooonfX3o`00Oi_ooo]Z003ooookJYgooo]Z0ol007l3oookJP?o001oVooo
nfX00?oooo]ZWOoonfX3o`00O`?ooo]Z0ol007nKoookJP00oooonfZMoookJP?o001o0ooonfX3o`00
Oi_ooo]Z003ooookJYgooo]Z0ol007l3oookJP?o001oVooonfX00?oooo]ZWOoonfX3o`00O`?ooo]Z
0ol007nKoookJP00oooonfZMoookJP?o001o0ooonfX3o`00Oi_ooo]Z003ooookJY;ooo]Z1Ol00007
oookJP?o001o00Cooo]Zo`00Ool007oo001oW?oonfX00?oooo]ZSooonfX8o`0000Oooo]Z1ol007nL
oookJP00oooonfZ=oookJP_o00001ooonfX5o`00Oigooo]Z003ooookJX[ooo]Z3ol0002XoookJP00
oooonfZ7oookJQ;o0000Z?oonfX00?oooo]ZQOoonfX=o`0000;ooo]Z1_l0002WoookJP00oooonfZ2
oookJPko00001OoonfX6o`000:Kooo]Z003ooookJX3ooo]Z3Ol00008oookJPKo0000Y_oonfX00?oo
oo]ZOOoonfX=o`0000_ooo]Z1ol0002UoookJP00oooonfY1oookJPGo001o=OoonfX=o`0000gooo]Z
00?o0000oookJ_l000001Ol0002ToookJP00oooonfY0oookJPOo001o<OoonfX=o`00013ooo]Z00?o
0000oookJ_l000001Ol0002ToookJP00oooonfXooookJP?o001o0ooonfX3o`00Obkooo]Z3Ol0000C
oookJP03o`000?oonf[o000000Go0000XooonfX00?oooo]Z?ooonfX3o`00O`?ooo]Z0ol007l[oook
JPgo00005_oonfX00ol0003ooo]ZoookJP06o`000:;ooo]Z003ooookJSoooo]Z0ol007l3oookJP?o
001o:?oonfX>o`0001Sooo]Z00?o0000oookJ_oonfX01_l0002RoookJP00oooonfXooookJP?o001o
0ooonfX3o`00ObKooo]Z3Ol0000KoookJP04o`000?oonf[ooo]ZoookJPKo0000XOoonfX00?oooo]Z
@?oonfX7o`00ObCooo]Z3_l0000MoookJP03o`000?oonf[ooo]Z00;ooo]Z1Ol0002QoookJP00oooo
nfY0oookJPOo001o8_oonfX=o`00023ooo]Z00?o0000oookJ_oonfX00_oonfX6o`000:3ooo]Z003o
oookJSoooo]Z0ol007l3oookJP?o001o7_oonfX=o`0002?ooo]Z00?o0000oookJ_oonfX00ooonfX6
o`0009oooo]Z003ooookJSoooo]Z0ol007l3oookJP?o001o7?oonfX=o`0002Gooo]Z00?o0000oook
J_oonfX00ooonfX6o`0009oooo]Z003ooookJSoooo]Z0ol007l3oookJP?o001o6OoonfX=o`0002So
oo]Z00?o0000oookJ_oonfX01?oonfX6o`0009kooo]Z003ooookJT3ooo]Z1ol007lHoookJPgo0000
:_oonfX00ol0003ooo]ZoookJP05oookJPKo0000WOoonfX00?oooo]Z@OoonfX5o`00OaKooo]Z3Ol0
000]oookJP03o`000?oonf[ooo]Z00Gooo]Z1_l0002MoookJP00oooonfYIoookJPko0000;ooonfX0
0ol0003ooo]ZoookJP06oookJPKo0000W?oonfX00?oooo]ZEooonfX=o`0003;ooo]Z00?o0000oook
J_oonfX01ooonfX6o`0009_ooo]Z003:oookJPCo001oQOoonfX>o`0003Cooo]Z00?o0000oookJ_oo
nfX01ooonfX6o`0009_ooo]Z0039oookJPGo001oPooonfX=o`0003Oooo]Z00?o0000oookJ_oonfX0
2?oonfX6o`0009[ooo]Z0039oookJP?o001oP_oonfX=o`0003[ooo]Z00?o0000oookJ_oonfX02Ooo
nfX6o`0009Wooo]Z0039oookJP?o001oP?oonfX=o`0003cooo]Z00?o0000oookJ_oonfX02OoonfX6
o`0009Wooo]Z0039oookJP?o001oOOoonfX=o`00043ooo]Z00?o0000oookJ_oonfX02OoonfX6o`00
09Sooo]Z0039oookJP?o001oNooonfX=o`0004;ooo]Z00?o0000oookJ_oonfX02_oonfX6o`0009Oo
oo]Z0039oookJP?o001oN?oonfX=o`0004Gooo]Z00?o0000oookJ_oonfX02_oonfX6o`0009Oooo]Z
0039oookJP?o001oMOoonfX>o`0004Oooo]Z00?o0000oookJ_oonfX02ooonfX6o`0009Kooo]Z0038
oookJPKo001oLOoonfX=o`0004[ooo]Z00?o0000oookJ_oonfX03?oonfX6o`0009Gooo]Z0038oook
JPKo001oK_oonfX>o`0004cooo]Z00?o0000oookJ_oonfX03?oonfX6o`0009Gooo]Z0039oookJP?o
001oK_oonfX=o`0004oooo]Z00?o0000oookJ_oonfX03OoonfX6o`0009Cooo]Z0039oookJP?o001o
JooonfX=o`0005;ooo]Z00?o0000oookJ_oonfX03_oonfX6o`0009?ooo]Z003koookJPGo001o=Ooo
nfX=o`0005Cooo]Z00?o0000oookJ_oonfX03_oonfX6o`0009?ooo]Z003joookJPOo001o<OoonfX=
o`0005Oooo]Z00?o0000oookJ_oonfX03ooonfX6o`0009;ooo]Z003joookJP?o001o0_oonfX3o`00
Obgooo]Z3_l0001IoookJP03o`000?oonf[ooo]Z013ooo]Z1_l0002AoookJP00nOoonfX3o`00O`?o
oo]Z0ol007l[oookJPgo0000G?oonfX00ol0003ooo]ZoookJP0@oookJPKo0000TOoonfX00?Wooo]Z
0ol007l3oookJP?o001o:?oonfX>o`0005kooo]Z00?o0000oookJ_oonfX04OoonfX6o`00093ooo]Z
003ioookJPCo001o0_oonfX3o`00ObKooo]Z3Ol0001QoookJP03o`000?oonf[ooo]Z01;ooo]Z1Ol0
000=oookJPWo001oN_oonfX00?Wooo]Z2?l007lToookJPgo0000I?oonfX00ol0003ooo]ZoookJP0B
oookJPKo00003?oonfX9o`00Og[ooo]Z003ioookJP?o001o00Cooo]Zo`00Ool007oo001o8ooonfX=
o`0006Kooo]Z00?o0000oookJ_oonfX04ooonfX6o`0000_ooo]Z1?l007mooookJP00nOoonfX3o`00
ObCooo]Z3Ol0001YoookJP03o`000?oonf[ooo]Z01?ooo]Z1_l0000<oookJPCo001oO_oonfX00?Wo
oo]Z0ol007lRoookJPgo0000JooonfX00ol0003ooo]ZoookJP0DoookJPKo00003?oonfX5o`00Ogco
oo]Z003joookJP?o001o0_oonfX3o`00OaWooo]Z3Ol0001_oookJP03o`000?oonf[ooo]Z01Cooo]Z
1_l0000=oookJPCo001oNooonfX00?[ooo]Z1ol007lGoookJPko0000LOoonfX00ol0003ooo]Zoook
JP0DoookJPKo00003_oonfX3o`00Og_ooo]Z003loookJPCo001o5_oonfX=o`0007Cooo]Z00?o0000
oookJ_oonfX05OoonfX6o`0000kooo]Z0ol007mjoookJP00oooonfXDoookJPko0000M_oonfX00ol0
003ooo]ZoookJP0FoookJPKo00001ooonfX3o`00O`?ooo]Z0ol007mjoookJP00oooonfXBoookJPgo
0000NOoonfX00ol0003ooo]ZoookJP0FoookJPKo00001ooonfX3o`00O`?ooo]Z0ol007mjoookJP00
oooonfX?oookJPgo0000O?oonfX00ol0003ooo]ZoookJP0GoookJPKo00001_oonfX4o`00O`;ooo]Z
0ol007mjoookJP00oooonfX=oookJPgo0000O_oonfX00ol0003ooo]ZoookJP0HoookJPKo00001_oo
nfX7o`00Og_ooo]Z003ooookJP[ooo]Z3Ol00021oookJP03o`000?oonf[ooo]Z01Sooo]Z1_l00007
oookJPGo001oO?oonfX00?oooo]Z2?oonfX=o`0008?ooo]Z00?o0000oookJ_oonfX06OoonfX6o`00
08Oooo]Z003ooookJPGooo]Z3Ol00026oookJP03o`000?oonf[ooo]Z01[ooo]Z1_l00026oookJP00
oooonfX2oookJPko0000R?oonfX00ol0003ooo]ZoookJP0JoookJPKo0000Q_oonfX00?oooo]Z3Ol0
002;oookJP03o`000?oonf[ooo]Z01_ooo]Z1_l00025oookJP00o?oonfX?o`0008cooo]Z00?o0000
oookJ_oonfX07?oonfX6o`0008Cooo]Z003joookJPgo0000T?oonfX2o`0001gooo]Z1_l00024oook
JP00mooonfX=o`00093ooo]Z1Ol0000NoookJPKo0000PooonfX00?Gooo]Z3Ol0002@oookJP;o0000
0onW_NT00ol0003oYkgYo`00000NoookJPKo0000P_oonfX00;gooo]Z0ol007lboookJPgo0000T?oo
nfX3o`0000GoYkgY00?o0000ojNmjOl000007_oonfX6o`0008;ooo]Z002moookJP?o001o;ooonfX>
o`00093ooo]Z0_l00009ojNmj@03o`000?nW_NWo000001kooo]Z1_l00021oookJP00_OoonfX3o`00
Obgooo]Z3Ol0002@oookJP?o000000?oYkgYo`000?nW_NT02?nW_NT01?l0003oYkgYojNmjOl0000N
oookJPKo0000P?oonfX00;Sooo]Z2Ol007lYoookJPko0000T?oonfX2o`0000GoYkgY00?o0000ojNm
jOnW_NT01_nW_NT01?l0003oYkgYojNmjOl0000NoookJPKo0000P?oonfX00;Sooo]Z2Ol007lWoook
JPgo0000T?oonfX3o`0000OoYkgY00?o0000ojNmjOnW_NT01_nW_NT00ol0003oYkgYojNmj@02o`00
01kooo]Z1_l0001ooookJP00^?oonfX2o`00O`?ooo]Z0ol007lUoookJPgo0000T?oonfX3o`0000_o
YkgY00?o0000ojNmjOnW_NT01OnW_NT3o`000003ojNgi?l0003ooo]Z01kooo]Z1_l0001noookJP00
^OoonfX2o`00O`;ooo]Z0ol007lSoookJPgo0000SooonfX3o`0000;oYkgY00?o0000ojNmjOnW_NT0
2_nW_NT00ol0003oYkgYojNmj@02ojNmj@?o00001?nW]n@00ol0003ooo]ZoookJP0LoookJPKo0000
O_oonfX00;Wooo]Z0ol007l01?oonf[o001oo`00Ool007lPoookJPgo0000SooonfX3o`0000KoYkgY
00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYo`000002o`0000;oYkOT00?o0000ojNgi?nW]n@0
0onW]n@00ol0003ooo]ZoookJP0LoookJPKo0000OOoonfX00;[ooo]Z0_l007l01?oonf[o001oo`00
Ool007lNoookJPgo0000S_oonfX3o`0000[oYkgY00?o0000ojNmjOnW_NT02?nW_NT2o`0000GoYkOT
00?o0000ojNgi?nW]n@00onW]n@00ol0003ooo]ZoookJP0MoookJPGo0000OOoonfX00;_ooo]Z1Ol0
07lKoookJPgo0000SooonfX2o`000003ojNmjOl0003oYkgY00_oYkgY00?o0000ojNmjOnW_NT01OnW
_NT2o`000003ojNgi?l0003oYkOT00CoYkOT00?o0000ojNgi?nW]n@01?nW]n@00ol0003ooo]Zoook
JP0LoookJPKo0000O?oonfX00;_ooo]Z1Ol007lHoookJPko0000S_oonfX3o`0000CoYkgY00?o0000
ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNmj@02ojNmj@?o00001?nW]n@00ol0003oYkOTojNgi002
ojNgi003o`000?nW]nCoYkOT00CoYkOT00?o0000oookJ_oonfX07OoonfX6o`0007_ooo]Z002loook
JPCo001o5_oonfX=o`0008oooo]Z0_l00008ojNmj@03o`000?nW_NWoYkgY00WoYkgY00Co0000ojNm
jOl0003o00002?nW]n@01Ol0003oYkOTojNgi?nW]nCo000000OoYkOT00?o0000oookJ_oonfX07?oo
nfX6o`0007_ooo]Z002moookJP?o001o4ooonfX>o`0008kooo]Z0ol0000;ojNmj@03o`000?nW_NWo
YkgY00OoYkgY0ol0000;ojNgi004o`000?nW]nCoYkOTo`0000KoYkOT0ol0000NoookJPKo0000N_oo
nfX00=7ooo]Z3Ol0002>oookJP?o00000_nW_NT00ol0003oYkgYojNmj@09ojNmj@03o`000?nW_NWo
YkgY00CoYkgY0ol00002ojNgi003o`000?nW]nCoYkOT00WoYkOT00Co0000ojNgi?nW]nCo00000onW
]n@3o`0000;oY[;Q00?o0000oookJ_oonfX07OoonfX6o`0007Wooo]Z003>oookJPgo0000S_oonfX3
o`0000KoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNmj@03o`0000KoYkOT00?o0000
ojNgi?nW]n@02OnW]n@00ol0003oYkOTo`000003o`0000KoY[;Q00?o0000oookJ_oonfX07?oonfX6
o`0007Wooo]Z003<oookJPgo0000SOoonfX3o`0000[oYkgY00?o0000ojNmjOnW_NT02?nW_NT3o`00
00WoYkOT00?o0000ojNgi?nW]n@02OnW]n@3o`0000WoY[;Q00?o0000oookJ_oonfX07OoonfX6o`00
07Sooo]Z0039oookJPgo0000S_oonfX2o`000003ojNmjOl0003oYkgY00_oYkgY00?o0000ojNmjOnW
_NT01OnW_NT2o`000003ojNgi?l0003oYkOT00[oYkOT00?o0000ojNgi?nW]n@01OnW]n@3o`000003
ojJbhOl0003o000000[oY[;Q00?o0000oookJ_oonfX07OoonfX6o`0007Oooo]Z0037oookJPgo0000
SOoonfX3o`0000CoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNmj@02ojNmj@?o0000
1?nW]n@00ol0003oYkOTojNgi009ojNgi003o`000?nW]nCoYkOT00;oYkOT0_l00005ojJbh@03o`00
0?nV/^7oY[;Q00SoY[;Q00?o0000oookJ_oonfX07OoonfX6o`0007Oooo]Z0034oookJPgo0000S_oo
nfX2o`0000SoYkgY00?o0000ojNmjOnW_NT02OnW_NT01?l0003oYkgYo`000?l00008ojNgi003o`00
0?nW]nCoYkOT00SoYkOT00?o0000ojNgi?l000000_l00008ojJbh@03o`000?nV/^7oY[;Q00SoY[;Q
00?o0000oookJ_oonfX07OoonfX6o`0007Kooo]Z0031oookJPko0000SOoonfX3o`0000_oYkgY00?o
0000ojNmjOnW_NT01onW_NT3o`0000_oYkOT00?o0000ojNgi?nW]n@01onW]n@2o`0000_oY[;Q00?o
0000ojJbhOnV/^402?nV/^400ol0003ooo]ZoookJP0NoookJPKo0000MOoonfX00;oooo]Z3Ol0002=
oookJP?o00000_nW_NT00ol0003oYkgYojNmj@09ojNmj@03o`000?nW_NWoYkgY00CoYkgY0ol00002
ojNgi@03o`000?nW]nCoYkOT00WoYkOT00?o0000ojNgi?nW]n@01?nW]n@3o`000003ojJbhOl0003o
Y[;Q00[oY[;Q0_l00009ojJbh@;o00007ooonfX6o`0007Gooo]Z002loookJPoo0000RooonfX3o`00
00KoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNmj@03o`0000KoYkOU00?o0000ojNg
i?nW]n@02OnW]n@00ol0003oYkOTojNgi003o`0000GoY[;Q00?o0000ojJbhOnV/^402?nV/^42o`00
00KoY[;Q0ol000000onV[moo0000oookJP0OoookJPKo0000M?oonfX00;[ooo]Z3Ol0002<oookJP?o
00002_nW_NT00ol0003oYkgYojNmj@08ojNmj@?o00002OnW]nD00ol0003oYkOTojNgi009ojNgi0?o
00002OnV/^400ol0003oY[;QojJbh@07ojJbh@03o`000?nV/^7o000000;oY[;Q0ol00005ojJ_g`03
o`000?oonf[ooo]Z01kooo]Z1_l0001coookJP00]ooonfX=o`0008gooo]Z0_l000000onW_NWo0000
ojNmj@0;ojNmj@03o`000?nW_NWoYkgY00GoYkgY0_l000000onW]nGo0000ojNgi@0:ojNgi@03o`00
0?nW]nCoYkOT00GoYkOT0ol000000onV/^7o0000ojJbh@09ojJbh@03o`000?nV/^7oY[;Q00OoY[;Q
00?o0000ojJbhOl000000_l00009ojJ_g`03o`000?oonf[ooo]Z01gooo]Z1_l0001coookJP00NOoo
nfX9o`00Oc?ooo]Z3Ol0002<oookJP?o00001?nW_NT00ol0003oYkgYojNmj@09ojNmj@03o`000?nW
_NWoYkgY00;oYkgY0ol00004ojNgi@03o`000?nW]nGoYkOU00WoYkOU00?o0000ojNgi?nW]n@00_nW
]n@2o`0000GoY[;Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[;QojJbh@05ojJbh@?o000000?o
Y[3Oo`000?nV[ml02OnV[ml00ol0003ooo]ZoookJP0NoookJPKo0000L_oonfX007Wooo]Z2Ol007l`
oookJPgo0000SOoonfX2o`0000SoYkgY00?o0000ojNmjOnW_NT02OnW_NT01?l0003oYkgYo`000?l0
0008ojNgi@03o`000?nW]nGoYkOU00SoYkOU00?o0000ojNgi?l000000_l00007ojJbh@03o`000?nV
/^7oY[;Q00SoY[;Q00?o0000ojJbhOnV/^400onV/^42o`000003ojJ`gol0003oY[3O00;oY[3O00?o
0000ojJ_gonV[ml02?nV[ml00ol0003ooo]ZoookJP0NoookJPKo0000LOoonfX007Wooo]Z1?l007lc
oookJPgo0000SOoonfX2o`0000_oYkgY00?o0000ojNmjOnW_NT01onW_NT3o`0000_oYkOU00?o0000
ojNgiOnW]nD01onW]nD2o`0000_oY[;Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[;Qo`000002
o`0000?oY[3O00Go0000ojJ`gonV/=ooY[3Oo`00000:ojJ_g`03o`000?oonf[ooo]Z01kooo]Z1_l0
000BoookJP?o001oG?oonfX007[ooo]Z1?l007l_oookJPgo0000SOoonfX3o`000003ojNmjOl0003o
YkgY00[oYkgY00?o0000ojNmjOnW_NT01?nW_NT3o`0000;oYkOU00?o0000ojNgiOnW]nD02OnW]nD0
0ol0003oYkOUojNgi@04ojNgi@?o000000?oY[?Qo`000?nV/^402_nV/^400ol0003oY[;QojJbh@07
ojJbh@?o00001_nV/=l00ol0003oY[3OojJ`g`02ojJ`g`03o`000?nV[mooYZoO00SoYZoO00?o0000
oookJ_oonfX07_oonfX6o`00017ooo]Z0ol007mLoookJP00NooonfX5o`00Ob[ooo]Z3_l0002<oook
JP?o00001OnW_NT00ol0003oYkgYojNmj@09ojNmj@03o`000?nW_NWoYkgY00?o00001_nW]nD00ol0
003oYkOUojNgi@09ojNgi@03o`000?nW]nGoYkOU00?o00001OnV/n400ol0003oY[;QojJbh@09ojJb
h@03o`000?nV/^7oY[;Q00?oY[;Q0ol00002ojJ`g`03o`000?nV/=ooY[3O00CoY[3O00?o0000ojJ`
gonV/=l00_nV/=l00ol0003oYZoOojJ_g`08ojJ_g`;o00008?oonfX6o`00013ooo]Z0ol007mLoook
JP00OOoonfX4o`00ObOooo]Z3Ol0002<oookJP?o00002OnW_NT00ol0003oYkgYojNmj@08ojNmj@?o
00002OnW]nD00ol0003oYkOUojNgi@09ojNgi@?o00002OnV/n400ol0003oY[;QojJbh@08ojJbh@03
o`000?nV/^7oY[;Q00?o00001_nV/=l00ol0003oY[3OojJ`g`03ojJ`g`03o`000?nV/=ooY[3O00;o
Y[3O00?o0000ojJ_gonV[ml01OnV[ml3o`000003ojF^gOl0003ooo]Z01oooo]Z1_l0000;oookJPWo
001oFooonfX007kooo]Z0ol007lToookJPko0000S?oonfX2o`000003ojNmjOl0003oYkgY00[oYkgY
00?o0000ojNmjOnW_NT01?nW_NT3o`000003ojNgiOl0003oYkOU00[oYkOU00?o0000ojNgiOnW]nD0
1OnW]nD3o`000003ojJchOl0003oY[?Q00WoY[?Q00?o0000ojJbhOnV/^402?nV/^43o`0000[oY[3O
00?o0000ojJ`gonV/=l00_nV/=l00ol0003oY[3OojJ`g`03ojJ`g`03o`000?nV[mooYZoO00;oYZoO
0_l00005ojF^g@03o`000?oonf[ooo]Z01kooo]Z1_l0000:oookJPWo001oFooonfX007oooo]Z0ol0
07lQoookJPgo0000S?oonfX3o`0000CoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNm
j@03o`0000GoYkOU00?o0000ojNgiOnW]nD02OnW]nD00ol0003oYkOUojNgi@02ojNgi@;o00001OnV
/n400ol0003oY[?QojJch@08ojJch@03o`000?nV/^7oY[;Q00GoY[;Q0_l000000onV/=oo0000ojJ`
g`0:ojJ`g`03o`000?nV/=ooY[3O00;oY[3O00?o0000ojJ`gonV/=l00onV/=l00ol0003oYZoOo`00
0002o`0000OoYJkM00?o0000oookJ_oonfX07ooonfX6o`0000Wooo]Z0_l007l3oookJP?o001oG?oo
nfX007Wooo]Z0ol007l3oookJP?o001o7_oonfX=o`0008gooo]Z0_l00008ojNmj@03o`000?nW_NWo
YkgY00SoYkgY0ol00009ojNgi@03o`000?nW]nGoYkOU00SoYkOU00?o0000ojNgiOl000000_l00008
ojJch@03o`000?nV/n7oY[?Q00OoY[?Q00?o0000ojJbhOnV/^400_nV/^43o`0000CoY[3O00?o0000
ojJ`gonV/=l02OnV/=l01Ol0003oY[3OojJ`gonV/=oo000000GoY[3O0_l0000;ojF^g@03o`000?oo
nf[ooo]Z01kooo]Z1_l0000:oookJP;o001o0_oonfX3o`00Oecooo]Z001ioookJP?o001o0ooonfX3
o`00Oacooo]Z3Ol0002<oookJP?o00002onW_NT00ol0003oYkgYojNmj@05ojNmj@;o000000?oYkOU
o`000?nW]nD02_nW]nD00ol0003oYkOUojNgi@07ojNgi@;o00002onV/n400ol0003oY[?QojJch@08
ojJch@04o`000?nV/^7o0000o`0000SoY[3O00?o0000ojJ`gonV/=l02?nV/=l01Ol0003oY[3OojJ`
gonV/=oo000000;oY[3O0ol000000onU[]ko0000ojF^g@0:ojF^g@03o`000?oonf[ooo]Z01oooo]Z
1_l00009oookJP?o001o00Cooo]Zo`00Ool007oo001o9_oonfX4o`00Oc;ooo]Z001ioookJPCo001o
0_oonfX3o`00OaWooo]Z3Ol0002<oookJP?o00000_nW_NT00ol0003oYkgYojNmj@09ojNmj@03o`00
0?nW_NWoYkgY00;oYkgY0ol00004ojNgi@03o`000?nW]nGoYkOU00SoYkOU00?o0000ojNgiOnW]nD0
1?nW]nD3o`000003ojJchOl0003oY[?Q00_oY[?Q00?o0000ojJchOnV/n401onV/n42o`0000[oY[3O
00?o0000ojJ`gonV/=l02OnV/=l00ol0003oY[3OojJ`g`03o`0000GoYJkN00?o0000ojF^gOnU[]d0
2OnU[]d00ol0003ooo]ZoookJP0OoookJPGo00002_oonfX2o`00O`04oookJ_l007oo001oo`00ObKo
oo]Z1Ol007laoookJP00N_oonfX7o`00OaOooo]Z3_l0002;oookJP?o00001_nW_NT00ol0003oYkgY
ojNmj@09ojNmj@04o`000?nW_NWo0000o`0000SoYkOU00?o0000ojNgiOnW]nD02?nW]nD00ol0003o
YkOUojNgi@03o`0000GoY[?Q00?o0000ojJchOnV/n402OnV/n400ol0003oY[?QojJch@04ojJch@?o
000000?oY[3Oo`000?nV/=l02_nV/=l00ol0003oY[3OojJ`g`07ojJ`g`Go00002?nU[]h00ol0003o
YJkMojF^g@08ojF^g@03o`000?oonf[ooo]Z01oooo]Z1_l0000:oookJPGo001o:OoonfX3o`00Oc3o
oo]Z001koookJPGo001o5_oonfX=o`0008_ooo]Z0ol0000:ojNmj@03o`000?nW_NWoYkgY00SoYkgY
0_l0000:ojNgi@03o`000?nW]nGoYkOU00SoYkOU0ol00009ojJch@03o`000?nV/n7oY[?Q00WoY[?Q
00?o0000ojJchOnV/n400ol00005ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV/=l0
1?nV/=l3o`0000;oYJkN00Co0000ojF^g_nU[]ko00001onU[]h00ol0003oYJkMojF^g@08ojF^g@;o
00008OoonfX6o`0000Wooo]Z1Ol007lYoookJP?o001o<?oonfX009?ooo]Z3_l0002:oookJP?o0000
00?oYkgYo`000?nW_NT02onW_NT00ol0003oYkgYojNmj@04ojNmj@?o000000?oYkOUo`000?nW]nD0
2_nW]nD00ol0003oYkOUojNgi@05ojNgi@;o000000?oY[?Qo`000?nV/n402_nV/n400ol0003oY[?Q
ojJch@07ojJch@Co00002OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00?o0000
1_nU[]h00ol0003oYJkNo`000008ojF^gP03o`000?nU[]goYJkM00GoYJkM0_l000000onU[]go0000
oookJP0PoookJPKo00002_oonfX4o`00ObSooo]Z1Ol007l_oookJP00TOoonfX=o`0008[ooo]Z0ol0
0005ojNmj@03o`000?nW_NWoYkgY00[oYkgY00?o0000ojNmjOnW_NT00ol00005ojNgi@03o`000?nW
]nGoYkOU00SoYkOU00?o0000ojNgiOnW]nD00_nW]nD3o`0000CoY[?Q00?o0000ojJchOnV/n402?nV
/n400ol0003oY[?QojJch@04ojJch@?o00000_nV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV
/=ooY[3O00SoY[3O0ol00009ojF^gP03o`000?nU[]ko000000SoYJkN00?o0000ojF^gOnU[]d00_nU
[]d3o`0000CoYJkM00?o0000oookJ_oonfX07ooonfX6o`0000[ooo]Z0ol007lXoookJPGo001o;ooo
nfX008kooo]Z3Ol0002:oookJP?o00002OnW_NT00ol0003oYkgYojNmj@08ojNmj@Co00002OnW]nD0
0ol0003oYkOUojNgi@08ojNgi@04o`000?nW]nGo0000o`0000SoY[?Q00?o0000ojJchOnV/n402?nV
/n400ol0003oY[?QojJch@03o`0000KoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3OojJ`
g`05ojJ`g`;o000000?oYJkNo`000?nU[]h02_nU[]h2o`0000WoYJkN00Co0000ojF^gOl0003o0000
1onU[]d00ol0003ooo]ZoookJP0PoookJPKo0000<ooonfX3o`00O`04oookJ_l007oo001oo`00Obko
oo]Z002<oookJPgo0000R_oonfX2o`000003ojNmjOl0003oYkgY00[oYkgY00?o0000ojNmjOnW_NT0
1?nW_NT3o`0000;oYkOU00?o0000ojNgiOnW]nD02OnW]nD00ol0003oYkOUojNgi@07ojNgi@;o0000
2_nV/n400ol0003oY[?QojJch@08ojJch@?o00002OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`00
0?nV/=ooY[3O00;oY[3O0ol00004ojF^gP03o`000?nU[]koYJkN00SoYJkN0_l00008ojF^gP?o0000
2_nU[]d00ol0003ooo]ZoookJP0OoookJPKo0000<ooonfX3o`00O`04oookJ_l007oo001oo`00Obko
oo]Z0029oookJPgo0000R_oonfX3o`0000CoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgY
ojNmj@03o`0000KoYkOU00?o0000ojNgiOnW]nD02?nW]nD00ol0003oYkOUojNgi@04ojNgi@?o0000
00?oY[?Qo`000?nV/n402_nV/n400ol0003oY[?QojJch@05ojJch@;o000000?oY[3Oo`000?nV/=l0
2_nV/=l00ol0003oY[3OojJ`g`08ojJ`g`04o`000?nV/=oo0000o`0000SoYJkN00?o0000ojF^g_nU
[]h02?nU[]h00ol0003oYJkNojF^gP03ojF^gP?o00000_nU[]d00ol0003oYJkMojF^g@09ojF^g@03
o`000?oonf[ooo]Z01oooo]Z1_l0000boookJP?o001o00Cooo]Zo`00Ool007oo001o;_oonfX008Oo
oo]Z3Ol0002:oookJP;o00002?nW_NT00ol0003oYkgYojNmj@08ojNmj@?o00002_nW]nD00ol0003o
YkOUojNgi@08ojNgi@03o`000?nW]nGoYkOU00?o00001OnV/n400ol0003oY[?QojJch@08ojJch@03
o`000?nV/n7oY[?Q00;oY[?Q0ol00004ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV
/=l01onV/=l3o`0000[oYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP03o`0000Ko
YJkM00?o0000ojF^gOnU[]d02?nU[]d00ol0003ooo]ZoookJP0PoookJPKo0000<OoonfX3o`00O`04
oookJ_l007oo001oo`00Obkooo]Z0024oookJPgo0000RooonfX2o`0000_oYkgY00?o0000ojNmjOnW
_NT01OnW_NT2o`000003ojNgiOl0003oYkOU00_oYkOU00?o0000ojNgiOnW]nD01onW]nD3o`0000Wo
Y[?Q00?o0000ojJchOnV/n402?nV/n401?l0003oY[?Qo`000?l00008ojJ`g`03o`000?nV/=ooY[3O
00SoY[3O00?o0000ojJ`gonV/=l00onV/=l3o`0000;oYJkN00?o0000ojF^g_nU[]h02OnU[]h00ol0
003oYJkNojF^gP07ojF^gP?o00002OnU[]d00ol0003oYJkMojF^g@09ojF^g@03o`000?oonf[ooo]Z
01oooo]Z1_l0000`oookJP?o001o0ooonfX3o`00Obgooo]Z0021oookJPko0000R_oonfX3o`000003
ojNmjOl0003oYkgY00[oYkgY00?o0000ojNmjOnW_NT00_nW_NT3o`0000CoYkOU00?o0000ojNgiOnW
]nD02OnW]nD00ol0003oYkOUojNgi@04ojNgi@?o000000?oY[?Ro`000?nV/n402_nV/n400ol0003o
Y[?QojJch@07ojJch@;o00002_nV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00?o
00001_nU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]koYJkN00CoYJkN1Ol0000;ojF^g@03
o`000?nU[]goYJkM00SoYJkM00?o0000oookJ_oonfX08?oonfX6o`0002oooo]Z0ol007l3oookJP?o
001o;OoonfX007oooo]Z3_l00029oookJP?o00001OnW_NT00ol0003oYkgYojNmj@09ojNmj@04o`00
0?nW_NWo0000o`0000SoYkOU00?o0000ojNgiOnW]nD02OnW]nD00ol0003oYkOUojNgi@03o`0000Go
Y[?R00?o0000ojJchOnV/n402?nV/n400ol0003oY[?QojJch@04ojJch@?o000000?oY[3Oo`000?nV
/=l02_nV/=l00ol0003oY[3OojJ`g`07ojJ`g`?o00002OnU[]h00ol0003oYJkNojF^gP09ojF^gP03
o`000?nU[]koYJkN00?o00000onU[]d00ol0003oYJkMo`00000:ojF^g@03o`000?nU[]goYJkM00Oo
YJkM0ol0000RoookJPKo0000;_oonfX3o`00O`?ooo]Z0ol007l]oookJP00O?oonfX>o`0008Wooo]Z
0ol00009ojNmj@03o`000?nW_NWoYkgY00SoYkgY0_l0000;ojNgi@03o`000?nW]nGoYkOU00OoYkOU
1?l00009ojJchP03o`000?nV/n7oY[?Q00SoY[?Q00?o0000ojJchOnV/n400ol00005ojJ`g`03o`00
0?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV/=l01?nV/=l3o`000003ojF^g_l0003oYJkN00[oYJkN
00?o0000ojF^g_nU[]h02?nU[]h3o`0000KoYJkM00Co0000ojF^gOnU[]go00002_nU[]d00ol0003o
YJkMojF^g@03ojF^g@?o00000_nV[mh00ol0003ooo]ZoookJP0PoookJPKo0000;OoonfX3o`00O`Go
oo]Z0ol007l/oookJP00N_oonfX=o`0008Wooo]Z0ol000000onW_NWo0000ojNmj@0:ojNmj@03o`00
0?nW_NWoYkgY00CoYkgY0ol000000onW]nGo0000ojNgi@0:ojNgi@03o`000?nW]nGoYkOU00CoYkOU
0ol00002ojJchP03o`000?nV/n;oY[?R00WoY[?R00?o0000ojJchOnV/n401onV/n43o`0000WoY[3O
00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3OojJ`g`03o`0000GoYJkN00?o0000ojF^g_nU[]h0
2?nU[]h00ol0003oYJkNojF^gP05ojF^gP?o000000?oYJkMo`000?nU[]d01_nU[]d01?l0003oYJkM
ojF^gOl0000:ojF^g@03o`000?nU[]goYJkM00?o00001_nV[mh00ol0003ooo]ZoookJP0PoookJPKo
0000HooonfX0043ooo]Z1Ol007lboookJPgo0000ROoonfX3o`0000GoYkgY00?o0000ojNmjOnW_NT0
2OnW_NT00ol0003oYkgYojNmj@03o`0000GoYkOU00?o0000ojNgiOnW]nD02OnW]nD00ol0003oYkOU
ojNgi@03o`0000KoY[?R00?o0000ojJch_nV/n802?nV/n800ol0003oY[?QojJch@04ojJch@?o0000
00?oY[3Oo`000?nV/=l02OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`?o00002OnU[]h00ol0003oYJkN
ojF^gP08ojF^gP03o`000?nU[]koYJkN00;oYJkN0_l00005ojF^g@03o`000?nU[]goYJkM00CoYJkM
00Go0000ojF^gOnU[]goYJkMo`000009ojF^g@?o00002OnV[mh00ol0003ooo]ZoookJP0QoookJPKo
0000H_oonfX003oooo]Z1ol007l_oookJPgo0000R?oonfX3o`0000WoYkgY00?o0000ojNmjOnW_NT0
2?nW_NT3o`0000WoYkOU00?o0000ojNgiOnW]nD02?nW]nD3o`0000WoY[?R00?o0000ojJch_nV/n80
2OnV/n800ol0003oY[?QojJch@03o`0000GoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3O
ojJ`g`05ojJ`g`;o000000?oYJkNo`000?nU[]h02OnU[]h00ol0003oYJkNojF^gP08ojF^gP03o`00
0?nU[]ko000000;o00001onU[]d00ol0003oYJkMojF^g@04ojF^g@05o`000?nU[]goYJkMojF^gOl0
00001_nU[]d3o`000003ojF_g_l0003oYZoN00[oYZoN00?o0000oookJ_oonfX08?oonfX6o`0006;o
oo]Z000ooookJP?o001o00Cooo]Zo`00Ool007oo001o;?oonfX=o`0008Wooo]Z0_l000000onW_NWo
0000ojNmj@0:ojNmj@03o`000?nW_NWoYkgY00CoYkgY0ol000000onW]nGo0000ojNgi@0:ojNgi@03
o`000?nW]nGoYkOU00GoYkOU0_l000000onV/n;o0000ojJchP0:ojJchP03o`000?nV/n;oY[?R00So
Y[?R0ol00009ojJ`g`03o`000?nV/=ooY[3O00OoY[3O00?o0000ojJ`gonV/=l00_nV/=l3o`0000Co
YJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP07ojF^gP;o00002onU[]d00ol0003o
YJkMojF^g@03ojF^g@03o`000?nU[]goYJkM00;oYJkM00?o0000ojF^gOnU[]d00ol00005ojF_gP03
o`000?nV[mkoYZoN00SoYZoN00?o0000oookJ_oonfX08OoonfX6o`00067ooo]Z000noookJP?o001o
0ooonfX3o`00ObWooo]Z3Ol00029oookJP;o00001?nW_NT00ol0003oYkgYojNmj@09ojNmj@03o`00
0?nW_NWoYkgY00?o00001OnW]nD00ol0003oYkOUojNgi@08ojNgi@03o`000?nW]nGoYkOU00;oYkOU
0ol00004ojJchP03o`000?nV/n;oY[?R00SoY[?R00?o0000ojJch_nV/n801OnV/n83o`000003ojJ`
gol0003oY[3O00WoY[3O00?o0000ojJ`gonV/=l02?nV/=l01?l0003oY[3Oo`000?l00008ojF^gP03
o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^gOl0003oYJkM00[o
YJkM00?o0000ojF^gOnU[]d00onU[]d00ol0003oYJkMojF^g@02ojF^g@?o00002OnU[mh00ol0003o
YZoNojJ_gP08ojJ_gP03o`000?oonf[ooo]Z027ooo]Z1_l0001PoookJP00?_oonfX3o`00O`?ooo]Z
0ol007lVoookJPgo0000R_oonfX2o`0000OoYkgY00?o0000ojNmjOnW_NT02?nW_NT3o`0000WoYkOU
00?o0000ojNgiOnW]nD02?nW]nD01?l0003oYkOUo`000?l00008ojJchP03o`000?nV/n;oY[?R00So
Y[?R00?o0000ojJch_nV/n800_nV/n82o`0000GoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003o
Y[3OojJ`g`07ojJ`g`;o00002_nU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]koYJkN00?o
00001OnU[]d00ol0003oYJkMojF^g@08ojF^g@03o`000?nU[]goYJkM00?oYJkM00?o0000ojF^gOl0
00000_l000000onU[]ko0000ojF_gP09ojF_gP03o`000?nV[mkoYZoN00SoYZoN00?o0000oookJ_oo
nfX08OoonfX6o`00063ooo]Z000noookJP?o001o0ooonfX3o`00Ob?ooo]Z3_l0002:oookJP;o0000
2_nW_NT00ol0003oYkgYojNmj@05ojNmj@;o000000?oYkOUo`000?nW]nD02_nW]nD00ol0003oYkOU
ojNgi@07ojNgi@;o00002_nV/n800ol0003oY[?RojJchP08ojJchP03o`000?nV/n;o000000;o0000
1onV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00CoY[3O0ol000000onU[]ko0000
ojF^gP0:ojF^gP03o`000?nU[]koYJkN00OoYJkN0ol00009ojF^g@03o`000?nU[]goYJkM00SoYJkM
00?o0000ojF^gOnU[]d00_nU[]d2o`0000GoYJkN00?o0000ojF_g_nU[mh02?nU[mh00ol0003oYZoN
ojJ_gP07ojJ_gP;o00008ooonfX6o`0005oooo]Z000noookJP?o001o0ooonfX3o`00Ob7ooo]Z3Ol0
002:oookJP?o000000?oYkgYo`000?nW_NT02_nW_NT00ol0003oYkgYojNmj@02ojNmj@;o00001?nW
]nD00ol0003oYkOUojNgi@08ojNgi@03o`000?nW]nGoYkOU00CoYkOU0ol000000onV/n;o0000ojJc
hP0:ojJchP03o`000?nV/n;oY[?R00OoY[?R0_l0000;ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o
0000ojJ`gonV/=l00ol00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h01?nU
[]h3o`000003ojF^gOl0003oYJkM00WoYJkM00?o0000ojF^gOnU[]d02?nU[]d00ol0003oYJkMo`00
0002o`000003ojF^g_l0003oYJkN00CoYJkN00?o0000ojF_g_nU[mh02?nU[mh00ol0003oYZoNojJ_
gP04ojJ_gP?o000000?oY[3Oo`000?oonfX08ooonfX6o`0005kooo]Z000noookJP?o001o0ooonfX3
o`00Oakooo]Z3_l00029oookJP?o00001OnW_NT00ol0003oYkgYojNmj@09ojNmj@04o`000?nW_NWo
0000o`0000OoYkOU00?o0000ojNgiOnW]nD02?nW]nD00ol0003oYkOUojNgi@03o`0000GoY[?R00?o
0000ojJch_nV/n802?nV/n800ol0003oY[?RojJchP04ojJchP?o000000?oY[3Oo`000?nV/=l02_nV
/=l00ol0003oY[3OojJ`g`07ojJ`g`Co00002?nU[]h00ol0003oYJkNojF^gP09ojF^gP03o`000?nU
[]koYJkN00?o00001OnU[]d00ol0003oYJkMojF^g@08ojF^g@03o`000?nU[]goYJkM00OoYJkM0_l0
0004ojF^gP03o`000?nU[]koYJkN00CoYJkN00?o0000ojF_g_nU[mh02?nU[mh00ol0003oYZoNojJ_
gP03o`0000GoY[3O00?o0000oookJ_oonfX08OoonfX6o`0005kooo]Z000noookJP?o001o0ooonfX3
o`00Oacooo]Z3Ol00029oookJP?o00002OnW_NT00ol0003oYkgYojNmj@08ojNmj@;o00002_nW]nD0
0ol0003oYkOUojNgi@07ojNgi@?o00002OnV/n800ol0003oY[?RojJchP08ojJchP03o`000?nV/n;o
Y[?R00?o00001OnV/=l00ol0003oY[3OojJ`g`09ojJ`g`03o`000?nV/=ooY[3O00?oY[3O0ol00002
ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h02?nU[]h3o`0000WoYJkM00?o0000
ojF^gOnU[]d01onU[]d00ol0003oYJkMojF^g@04ojF^g@?o000000?oYJkNo`000?nU[]h00onU[]h0
0ol0003oYJkNojF^gP04ojF^gP03o`000?nU[mkoYJoN00OoYJoN1?l00009ojJ`g`03o`000?oonf[o
oo]Z027ooo]Z1_l0001MoookJP00?_oonfX3o`00O`?ooo]Z0ol007lIoookJPgo0000ROoonfX3o`00
0003ojNmjOl0003oYkgY00[oYkgY00?o0000ojNmjOnW_NT01?nW_NT3o`000003ojNhiOl0003oYkOU
00[oYkOU00?o0000ojNgiOnW]nD00onW]nD3o`000003ojJch_l0003oY[?R00[oY[?R00?o0000ojJc
h_nV/n801onV/n83o`0000WoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3OojJ`g`03o`00
00KoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP05ojF^gP?o000000?oYJkMo`00
0?nU[]d02OnU[]d00ol0003oYJkMojF^g@08ojF^g@03o`000?nU[]goYJkM00?o00001OnU[]h01Ol0
003oYJkNojF^g_nU[]ko000000OoYJkN00?o0000ojF_g_nU[mh00onU[mh3o`0000;oY[3O00?o0000
ojJ`gonV/=l02OnV/=l00ol0003ooo]ZoookJP0QoookJPKo0000G?oonfX003oooo]Z0ol007l01?oo
nf[o001oo`00Ool007lHoookJPgo0000R?oonfX3o`0000GoYkgY00?o0000ojNmjOnW_NT02OnW_NT0
0ol0003oYkgYojNmj@03o`0000GoYkSU00?o0000ojNgiOnW]nD02OnW]nD00ol0003oYkOUo`000002
o`0000GoY[?R00?o0000ojJch_nV/n802?nV/n800ol0003oY[?RojJchP04ojJchP?o000000?oY[3O
o`000?nV/=l02_nV/=l00ol0003oY[3OojJ`g`07ojJ`g`?o00002OnU[]h00ol0003oYJkNojF^gP08
ojF^gP03o`000?nU[]koYJkN00;oYJkN0_l00005ojF^g@03o`000?nU[]goYJkM00SoYJkM00?o0000
ojF^gOnU[]d01onU[]d3o`0000WoYJkN00Co0000ojF^g_nU[]ko00001onU[]h00ol0003oYJoNojF_
gP03o`0000KoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003ooo]ZoookJP0QoookJPKo0000G?oo
nfX003oooo]Z1ol007lEoookJPgo0000R?oonfX3o`0000WoYkgY00?o0000ojNmjOnW_NT02?nW_NT3
o`0000WoYkSU00?o0000ojNgiOnW]nD02?nW]nD2o`0000WoY[?R00?o0000ojJch_nV/n802?nV/n80
0ol0003oY[?RojJchP03o`0000GoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3OojJ`g`04
ojJ`g`?o000000?oYJkNo`000?nU[]h02_nU[]h00ol0003oYJkNojF^gP07ojF^gP03o`000?nU[]ko
000000;o00001onU[]d00ol0003oYJkMojF^g@08ojF^g@03o`000?nU[]goYJkM00CoYJkM0ol00000
0onU[]ko0000ojF^gP0:ojF^gP03o`000?nU[]ko000000OoYJkN0ol00009ojJ`g`03o`000?nV/=oo
Y[3O00WoY[3O00?o0000oookJ_oonfX08OoonfX6o`0005_ooo]Z0010oookJPGo001o5?oonfX=o`00
08Oooo]Z0ol000000onW_NWo0000ojNmj@0:ojNmj@03o`000?nW_NWoYkgY00CoYkgY0ol000000onW
^>Go0000ojNhi@0:ojNhi@03o`000?nW]nGoYkOU00CoYkOU0ol000000onV/n;o0000ojJchP09ojJc
hP03o`000?nV/n;oY[?R00OoY[?R0ol00009ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`
gonV/=l00ol00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h01onU[]h2o`00
00_oYJkM00?o0000ojF^gOnU[]d02?nU[]d00ol0003oYJkMojF^g@03o`0000GoYJkN00?o0000ojF^
g_nU[]h02?nU[]h00ol0003oYJkNo`000004ojF^gP?o000000?oY[3Oo`000?nV/=l02_nV/=l00ol0
003oY[3OojJ`g`08ojJ`g`;o00008ooonfX5o`0005_ooo]Z001FoookJPgo0000QooonfX3o`0000Go
YkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYojNmj@03o`0000GoYkSU00?o0000ojNhiOnW
^>D02OnW^>D00ol0003oYkOUojNgi@03o`0000GoY[?R00?o0000ojJch_nV/n801onV/n800ol0003o
Y[?RojJchP04ojJchP?o000000?oY[3Oo`000?nV/=l02OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`?o
00002OnU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]koYJkN00?oYJkN0ol000000onU[]go
0000ojF^g@0:ojF^g@03o`000?nU[]goYJkM00OoYJkM1?l00008ojF^gP03o`000?nU[]koYJkN00Wo
YJkN0_l000001?nU[]ko0000o`000?l00005ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`
gonV/=l01OnV/=l3o`000003ojJch_l0003ooo]Z02;ooo]Z1_l0001JoookJP00DooonfX>o`0008Ko
oo]Z0ol00009ojNmj@03o`000?nW_NWoYkgY00SoYkgY0ol00009ojNhi@03o`000?nW^>GoYkSU00So
YkSU0ol00009ojJchP03o`000?nV/n;oY[?R00OoY[?R00?o0000ojJch_nV/n800ol00005ojJ`g`03
o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV/=l01OnV/=l2o`000003ojF^g_l0003oYJkN00Wo
YJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP03o`0000GoYJkM00?o0000ojF^gOnU
[]d02OnU[]d00ol0003oYJkMojF^g@03ojF^g@?o00000_nU[]h00ol0003oYJkNojF^gP08ojF^gP03
o`000?nU[]koYJkN00GoYJkN1_l00009ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV
/=l00_nV/=l2o`0000GoY[?R00?o0000oookJ_oonfX08OoonfX6o`0005Wooo]Z001AoookJPgo0000
Q_oonfX3o`0000;oYkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0003oYkgYojNmj@04ojNmj@?o0000
00?oYkSUo`000?nW^>D02_nW^>D00ol0003oYkSUojNhi@05ojNhi@;o000000?oY[?Ro`000?nV/n80
2_nV/n800ol0003oY[?RojJchP06ojJchP?o00002OnV/=l00ol0003oY[3OojJ`g`07ojJ`g`03o`00
0?nV/=ooY[3O00;oY[3O0ol00004ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h0
1onU[]h3o`0000WoYJkM00?o0000ojF^gOnU[]d02?nU[]d00ol0003oYJkMojF^g@03o`0000KoYJkN
00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP02ojF^gPKo000000?oY[3Oo`000?l00000
2OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV/=oo000000;o00001onV/n800ol0003ooo]Z
oookJP0QoookJPKo0000FOoonfX004kooo]Z3_l00025oookJP?o00001_nW_NT00ol0003oYkgYojNm
j@08ojNmj@03o`000?nW_NWoYkgY00?o00001OnW^>D00ol0003oYkSUojNhi@08ojNhi@03o`000?nW
^>GoYkSU00;oYkSU0ol00004ojJchP03o`000?nV/n;oY[?R00SoY[?R00?o0000ojJch_nV/n800onV
/n83o`000003ojJ`gol0003oY[3O00WoY[3O00?o0000ojJ`gonV/=l02?nV/=l01?l0003oY[3Oo`00
0?l00008ojF^gP03o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^
gOl0003oYJkM00[oYJkM00?o0000ojF^gOnU[]d01onU[]d3o`0000WoYJkN00?o0000ojF^g_nU[]h0
2?nU[]h4o`000003ojF^g_l0003o000000GoY[3O0_l00009ojJ`g`03o`000?nV/=ooY[3O00OoY[3O
0_l0000;ojJchP03o`000?oonf[ooo]Z027ooo]Z1_l0001HoookJP00COoonfX<o`0008Kooo]Z0_l0
000:ojNmj@03o`000?nW_NWoYkgY00OoYkgY0ol00009ojNhi@03o`000?nW^>GoYkSU00SoYkSU00Co
0000ojNhiOl0003o00002?nV/n800ol0003oY[?RojJchP08ojJchP03o`000?nV/n;o000000;o0000
1OnV/=l00ol0003oY[3OojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00OoY[3O0_l0000:ojF^gP03o`00
0?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00ol00005ojF^g@03o`000?nU[]goYJkM00SoYJkM
00?o0000ojF^gOnU[]d01?nU[]d3o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h0
1OnU[]h3o`000004ojF^g_l0003o0000o`0000OoY[3O00?o0000ojJ`gol000002?nV/=l00ol0003o
Y[3OojJ`g`04ojJ`g`?o000000?oY[?Ro`000?nV/n802_nV/n800ol0003ooo]ZoookJP0RoookJPKo
0000EooonfX004gooo]Z2Ol00027oookJP;o000000?oYkgYo`000?nW_NT02_nW_NT00ol0003oYkgY
ojNmj@03ojNmj@?o000000?oYkSUo`000?nW^>D02_nW^>D00ol0003oYkSUojNhi@07ojNhi@;o0000
2_nV/n800ol0003oY[?RojJchP08ojJchP;o00002OnV/=l00ol0003oY[3OojJ`g`07ojJ`g`03o`00
0?nV/=ooY[3O00CoY[3O0ol000000onU[mko0000ojF^gP0:ojF^gP03o`000?nU[]koYJkN00OoYJkN
0ol00009ojF^g@03o`000?nU[]goYJkM00SoYJkM00?o0000ojF^gOnU[]d00ol00005ojF^gP03o`00
0?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00_nU[]h3o`0000;oYJkN0_l0000;ojJ`g`;o0000
2OnV/=l00ol0003oY[3OojJ`g`03o`0000GoY[?R00?o0000ojJch_nV/n802OnV/n800ol0003ooo]Z
oookJP0QoookJPKo0000EooonfX004gooo]Z1ol00026oookJP?o00001?nW_NT00ol0003oYkgYojNm
j@09ojNmj@03o`000?nW_NWo000000;o00001OnW^>D00ol0003oYkSUojNhi@08ojNhi@03o`000?nW
^>GoYkSU00CoYkSU0ol000000onV/n;o0000ojJchP0:ojJchP03o`000?nV/n;oY[?R00GoY[?R0_l0
00000onV/>3o0000ojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV/=l00ol0
0005ojF_gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^gOl0
003oYJkM00WoYJkM00?o0000ojF^gOnU[]d02?nU[]d3o`0000WoYJkN00?o0000ojF^g_nU[]h02?nU
[]h4o`0000;oYJkN0ol000000onV/=oo0000ojJ`g`0:ojJ`g`03o`000?nV/=oo000000OoY[3O1?l0
0008ojJchP03o`000?nV/n;oY[?R00WoY[?R00?o0000oookJ_oonfX08_oonfX6o`0005Kooo]Z001=
oookJPKo0000QOoonfX2o`0000SoYkgY00?o0000ojNmjOnW_NT02?nW_NT2o`0000WoYkSU00?o0000
ojNhiOnW^>D02?nW^>D00ol0003oYkSUojNhi@03o`0000GoY[?R00?o0000ojJch_nV/n802?nV/n80
0ol0003oY[?RojJchP02ojJchP?o00001?nV/>000ol0003oY[3OojJ`g`07ojJ`g`03o`000?nV/=oo
Y[3O00OoY[3O0ol00009ojF_gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00ol00005
ojF^g@03o`000?nU[]goYJkM00SoYJkM00?o0000ojF^gOnU[]d01OnU[]d2o`000003ojF^g_l0003o
YJkN00WoYJkN00?o0000ojF^g_nU[]h01_nU[]h3o`0000;oYJkN0ol00005ojJ`g`03o`000?nV/=oo
Y[3O00WoY[3O00?o0000ojJ`gol000000onV/=l3o`0000;oY[?R00?o0000ojJch_nV/n802?nV/n80
0ol0003oY[?RojJchP07ojJchP?o00009?oonfX6o`0005Gooo]Z001<oookJPGo00000_oonfX00ol0
003ooo]ZoookJP20oookJP;o00002onW_NT00ol0003oYkgYojNmj@05ojNmj@;o000000?oYkSUo`00
0?nW^>D02OnW^>D00ol0003oYkSUojNhi@07ojNhi@?o00002OnV/n800ol0003oY[?RojJchP08ojJc
hP04o`000?nV/n;o0000o`0000SoY[3P00?o0000ojJ`gonV/=l01_nV/=l00ol0003oY[3OojJ`g`04
ojJ`g`?o000000?oYJoNo`000?nU[mh02_nU[mh00ol0003oYJkNojF^gP07ojF^gP?o00002OnU[]d0
0ol0003oYJkMojF^g@07ojF^g@03o`000?nU[]goYJkM00;oYJkM0ol00004ojF^gP03o`000?nU[]ko
YJkN00SoYJkN00?o0000ojF^g_nU[]h00onU[]h2o`0000;oYJkN0ol00009ojJ`g`03o`000?nV/=oo
Y[3O00SoY[3O00?o0000ojJ`gol000000ol00006ojJchP03o`000?nV/n;oY[?R00SoY[?R00?o0000
ojJch_nV/n800onV/n83o`0000;oYkOU00?o0000oookJ_oonfX08_oonfX6o`0000kooo]Z1Ol007m2
oookJP00C?oonfX5o`0000?ooo]Z00?o0000oookJ_oonfX0O?oonfX3o`0000;oYkgY00?o0000ojNm
jOnW_NT02?nW_NT00ol0003oYkgYojNmj@02ojNmj@?o00001?nW^>D00ol0003oYkSUojNhi@08ojNh
i@03o`000?nW^>GoYkSU00?oYkSU0ol000000onV]>;o0000ojJchP0:ojJchP03o`000?nV/n;oY[?R
00OoY[?R0_l0000:ojJ`h003o`000?nV/=ooY[3O00OoY[3O00?o0000ojJ`gonV/=l00ol00005ojF_
gP03o`000?nU[mkoYJoN00SoYJoN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^gOl0003oYJkM
00WoYJkM00?o0000ojF^gOnU[]d02?nU[]d01?l0003oYJkMo`000?l00008ojF^gP03o`000?nU[]ko
YJkN00OoYJkN00?o0000ojF^g_nU[]h00ol000001_nU[]ko0000o`000?l0003oY[3Oo`0000_oY[3O
00?o0000ojJ`gonV/=l01onV/=l4o`0000SoY[?R00?o0000ojJch_nV/n802?nV/n800ol0003oY[?R
ojJchP03o`0000KoYkOU00?o0000oookJ_oonfX08_oonfX6o`0000cooo]Z1ol007m1oookJP00=_oo
nfX3o`00O`Gooo]Z1Ol007l9oookJPGo00001?oonfX00ol0003ooo]ZoookJP1hoookJP?o00001_nW
_NT00ol0003oYkgYojNmj@08ojNmj@04o`000?nW_NWo0000o`0000SoYkSU00?o0000ojNhiOnW^>D0
2?nW^>D00ol0003oYkSUo`000002o`0000GoY[CR00?o0000ojJch_nV/n802?nV/n800ol0003oY[?R
ojJchP04ojJchP?o000000?oY[7Po`000?nV/>002_nV/>000ol0003oY[3OojJ`g`06ojJ`g`?o0000
2OnU[mh00ol0003oYJoNojF_gP08ojF_gP03o`000?nU[]koYJkN00?o00001OnU[]d00ol0003oYJkM
ojF^g@08ojF^g@03o`000?nU[]goYJkM00OoYJkM0_l0000:ojF^gP03o`000?nU[]koYJkN00OoYJkN
0ol000001?nU[]ko0000o`000?l00005ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV
/=l01?nV/=l3o`000005ojJchOl0003oY[?RojJch_l000002?nV/n800ol0003oY[?RojJchP07ojJc
hP?o00002OnW]nD00ol0003ooo]ZoookJP0SoookJPKo00002ooonfX3o`00O`;ooo]Z0ol007m0oook
JP00=_oonfX3o`00O`Cooo]Z1ol007l8oookJPCo00001_oonfX00ol0003ooo]ZoookJP1eoookJP;o
00002_nW_NT00ol0003oYkgYojNmj@07ojNmj@;o00002onW^>D00ol0003oYkSUojNhi@07ojNhi@;o
00002OnV]>800ol0003oY[?RojJchP08ojJchP03o`000?nV/n;oY[?R00?o00001OnV/N000ol0003o
Y[3PojJ`h008ojJ`h003o`000?nV/=ooY[3O00?oY[3O0ol000000onU[mko0000ojF_gP0:ojF_gP03
o`000?nU[mkoYJoN00OoYJoN0ol00009ojF^g@03o`000?nU[]goYJkM00OoYJkM00?o0000ojF^gOnU
[]d01?nU[]d3o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h00onU[]h3o`000004
ojF^g_l0003o0000o`0000WoY[3O00?o0000ojJ`gonV/=l02?nV/=l00ol0003oY[3OojJ`g`03o`00
00GoY[?Q00Co0000ojJch_nV/n;o00002?nV/n800ol0003oY[?RojJchP03ojJchP?o000000?oYkOT
o`000?nW]nD02_nW]nD00ol0003ooo]ZoookJP0RoookJPKo00002_oonfX3o`00O`?ooo]Z0ol007m0
oookJP00=_oonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJPCo00001ooonfX0
0ol0003ooo]ZoookJP1aoookJP?o000000?oYkgYo`000?nW_NT02_nW_NT00ol0003oYkgYojNmj@03
ojNmj@?o000000?oYkSUo`000?nW^>D02_nW^>D00ol0003oYkSUojNhi@04ojNhi@?o000000?oY[CR
o`000?nV]>802OnV]>800ol0003oY[?RojJchP07ojJchP?o00002OnV/N000ol0003oY[3PojJ`h008
ojJ`h003o`000?nV/=oo000000;o00001OnU[mh00ol0003oYJoNojF_gP08ojF_gP03o`000?nU[mko
YJoN00CoYJoN0ol000000onU[]ko0000ojF^g@09ojF^g@03o`000?nU[]goYJkM00SoYJkM00?o0000
ojF^gOnU[]d00ol00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00ol00000
1_nU[]ko0000o`000?l0003oY[3Oo`0000_oY[3O00?o0000ojJ`gonV/=l01onV/=l3o`0000WoY[?Q
00?o0000ojJch_l000002?nV/n800ol0003oY[?RojJchP03o`0000GoYkOT00?o0000ojNgiOnW]nD0
2OnW]nD00ol0003ooo]ZoookJP0RoookJPKo00002OoonfX3o`00O`?ooo]Z0ol007m0oookJP009_oo
nfX:o`00O`Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l00008oookJP03o`000?oo
nf[ooo]Z06gooo]Z0ol00005ojNmj@03o`000?nW_NWoYkgY00WoYkgY00?o0000ojNmjOl000000_l0
0005ojNhi@03o`000?nW^>GoYkSU00WoYkSU00?o0000ojNhiOnW^>D00ol00005ojJdhP03o`000?nV
]>;oY[CR00OoY[CR00?o0000ojJch_nV/n801?nV/n83o`000003ojJah?l0003oY[7P00[oY[7P00?o
0000ojJ`h?nV/>001onV/>02o`0000WoYJoN00?o0000ojF_g_nU[mh02?nU[mh00ol0003oYJoNojF_
gP03o`0000GoYJkN00?o0000ojF^gOnU[]d02?nU[]d00ol0003oYJkMojF^g@07ojF^g@?o00002OnU
[]h00ol0003oYJkNojF^gP07ojF^gP?o000000CoYJkNo`000?l0003o00001OnV/=l00ol0003oY[3O
ojJ`g`08ojJ`g`03o`000?nV/=ooY[3O00CoY[3O0ol000000onV/^7o0000ojJch@0:ojJch@03o`00
0?nV/n;o000000OoY[?R0ol00009ojNgi003o`000?nW]nGoYkOU00SoYkOU00?o0000oookJ_oonfX0
8ooonfX6o`0000Sooo]Z1?l007l2oookJP?o001o@?oonfX002Kooo]Z2_l007l6oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l6oookJPGo00002OoonfX00ol0003ooo]ZoookJP1YoookJP?o00002OnW
_NT00ol0003oYkgYojNmj@08ojNmj@;o00002OnW^>D00ol0003oYkSUojNhi@08ojNhi@?o00002OnV
]>800ol0003oY[CRojJdhP07ojJdhP03o`000?nV/n;oY[?R00?o00001OnV/N000ol0003oY[7PojJa
h008ojJah003o`000?nV/>3oY[3P00CoY[3P0ol000000onU[mko0000ojF_gP09ojF_gP03o`000?nU
[mkoYJoN00OoYJoN0ol00009ojF^gP03o`000?nU[]goYJkM00OoYJkM00?o0000ojF^gOnU[]d01?nU
[]d3o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h00onU[]h3o`000004ojF^g_l0
003o0000o`0000SoY[3O00?o0000ojJ`gonV/=l02OnV/=l00ol0003oY[3OojJ`g`03o`0000GoY[;Q
00?o0000ojJchOnV/n402?nV/n401?l0003oY[?RojJch_l00003ojJchP?o000000?oYkKTo`000?nW
]n@02_nW]n@00ol0003oYkOUojNgi@07ojNgi@;o00009?oonfX6o`0000Sooo]Z2?l007m1oookJP00
=_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX5o`0000[ooo]Z00?o0000oookJ_oonfX0
IOoonfX3o`0000;oYkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0003oYkgYojNmj@04ojNmj@?o0000
00?oYkSUo`000?nW^>D02OnW^>D00ol0003oYkSUojNhi@04ojNhi@?o000000?oY[CRo`000?nV]>80
2_nV]>800ol0003oY[CRojJdhP06ojJdhP?o00002OnV/N000ol0003oY[7PojJah008ojJah003o`00
0?nV/>3oY[3P00?o00001OnU[mh00ol0003oYJoNojF_gP07ojF_gP03o`000?nU[mkoYJoN00CoYJoN
0ol000000onU[]ko0000ojF^gP09ojF^gP03o`000?nU[]goYJkM00SoYJkM00?o0000ojF^gOnU[]d0
0ol00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00ol000001_nU[]ko0000
o`000?l0003oY[3Oo`0000[oY[3O00?o0000ojJ`gonV/=l02?nV/=l3o`0000SoY[;Q00?o0000ojJc
hOnV/n402OnV/n400ol0003oY[?RojJchP03o`0000GoYkKT00?o0000ojNgi?nW]n@02?nW]n@00ol0
003oYkOUojNgi@04ojNgi@?o000000?oYk_Xo`000?oonfX09?oonfX6o`0000Oooo]Z0ol007l01?oo
nf[o001oo`00Ool007m2oookJP00=_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX5o`00
00_ooo]Z00?o0000oookJ_oonfX0HOoonfX3o`0000KoYkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0
003oYkgYojNmj@03o`0000GoYkSU00?o0000ojNhiOnW^>D02?nW^>D00ol0003oYkSUojNhi@03o`00
00GoY[CR00?o0000ojJdh_nV]>802?nV]>800ol0003oY[CRojJdhP03ojJdhP?o000000?oY[7Po`00
0?nV/N002_nV/N000ol0003oY[7PojJah007ojJah0?o00002?nU[mh00ol0003oYJoNojF_gP08ojF_
gP03o`000?nU[mkoYJoN00?o00001OnU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]goYJkM
00OoYJkM0ol00009ojF^gP03o`000?nU[]koYJkN00SoYJkN0_l000001?nU[]ko0000o`000?l00005
ojJ`g`03o`000?nV/=ooY[3O00OoY[3O00?o0000ojJ`gonV/=l01OnV/=l3o`000003ojJbhOl0003o
Y[;Q00WoY[;Q00?o0000ojJchOnV/n402?nV/n44o`0000OoYkKT00?o0000ojNgi?nW]n@02OnW]n@0
0ol0003oYkOUojNgi@03o`0000GoYk_X00?o0000oookJ_oonfX08ooonfX6o`0000Kooo]Z0ol007m6
oookJP00=_oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX5o`0000cooo]Z00?o0000oook
J_oonfX0G_oonfX2o`0000[oYkgY00?o0000ojNmjOnW_NT01onW_NT3o`0000WoYkSU00?o0000ojNh
iOnW^>D01onW^>D3o`0000WoY[CR00?o0000ojJdh_nV]>802?nV]>800ol0003oY[CRo`000002o`00
00GoY[7P00?o0000ojJah?nV/N002?nV/N000ol0003oY[7PojJah004ojJah0?o000000?oYJoNo`00
0?nU[mh02OnU[mh00ol0003oYJoNojF_gP07ojF_gP?o00002OnU[]h00ol0003oYJkNojF^gP07ojF^
gP03o`000?nU[]goYJkM00CoYJkM0ol000000onU[]ko0000ojF^gP0:ojF^gP03o`000?nU[]koYJkN
00CoYJkN1_l00008ojJ`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`gonV/=l00_nV/=l2o`00
00GoY[;Q00?o0000ojJbhOnV/^401onV/^400ol0003oY[?QojJch@05ojJch@?o000000GoYkKTo`00
0?nW]^CoYkKTo`000007ojNfi003o`000?nW]nCoYkOT00OoYkOT1?l00009ojNkj003o`000?oonf[o
oo]Z02;ooo]Z1_l00006oookJP?o001oA_oonfX003Kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`Kooo]Z1?l0000>oookJP03o`000?oonf[ooo]Z05[ooo]Z0ol000000onW_NWo0000ojNmj@0:ojNm
j@03o`000?nW_NWoYkgY00?oYkgY0ol000000onW^>Go0000ojNhi@0:ojNhi@03o`000?nW^>GoYkSU
00?oYkSU0ol000000onV]>;o0000ojJdhP0:ojJdhP03o`000?nV]>;oY[CR00OoY[CR0_l00009ojJa
h003o`000?nV/N3oY[7P00SoY[7P00?o0000ojJah?nV/N000ol00005ojF_gP03o`000?nU[mkoYJoN
00OoYJoN00?o0000ojF_g_nU[mh01OnU[mh2o`000003ojF^g_l0003oYJkN00WoYJkN00?o0000ojF^
g_nU[]h02?nU[]h00ol0003oYJkMojF^g@03o`0000GoYJkN00?o0000ojF^g_nU[]h02?nU[]h01?l0
003oYJkNojF^g_nU[]h6o`000003ojJ_gol0003oY[3O00WoY[3O00?o0000ojJ`gonV/=l01onV/=l0
0ol0003oY[3Oo`000002o`0000OoY[;Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[?QojJch@02
ojJch@;o00001OnW]^@01?l0003oYkKTojNfi?l00007ojNfi003o`000?nW]nCoYkOT00?oYkOT0ol0
0002ojNki`03o`000?nW^nSoYk_X00SoYk_X00?o0000oookJ_oonfX08ooonfX6o`0000Kooo]Z0ol0
07l2oookJP?o001o@?oonfX003?ooo]Z1_l007l3oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000?
oookJP;o0000EooonfX3o`0000GoYkgY00?o0000ojNmjOnW_NT02OnW_NT00ol0003oYkgYo`000002
o`0000GoYkSU00?o0000ojNhiOnW^>D02OnW^>D00ol0003oYkSUo`000002o`0000GoY[CR00?o0000
ojJdh_nV]>802?nV]>800ol0003oY[CRojJdhP04ojJdhP?o000000?oY[7Po`000?nV/N002OnV/N00
0ol0003oY[7PojJah007ojJah0?o00002OnU[mh00ol0003oYJoNojF_gP07ojF_gP04o`000?nU[mko
YJoNojF_gP?o00001?nU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]koYJkN00OoYJkN0ol0
0009ojF^gP03o`000?nU[]koYJkN00SoYJkN1_l00005ojJ_g`03o`000?nV/=ooY[3O00OoY[3O00?o
0000ojJ`gonV/=l01onV/=l2o`0000_oY[;Q00?o0000ojJbhOnV/^401onV/^400ol0003oY[?Qo`00
0002o`0000OoYkKT00Go0000ojNfi?nW]^CoYkKTo`000006ojNfi003o`000?nW]nCoYkOT00?o0000
1_nW^nL00ol0003oYk_XojNkj008ojNkj003o`000?oonf[ooo]Z02?ooo]Z1_l00005oookJPOo001o
@OoonfX003?ooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o1_oonfX5o`00017ooo]Z
00?o0000oookJ_oonfX0DOoonfX3o`0000WoYkgY00?o0000ojNmjOnW_NT02?nW_NT2o`0000WoYkSU
00?o0000ojNhiOnW^>D02?nW^>D2o`0000WoY[CR00?o0000ojJdh_nV]>802?nV]>800ol0003oY[CR
ojJdhP03o`0000GoY[7P00?o0000ojJah?nV/N001onV/N000ol0003oY[7PojJah004ojJah0?o0000
00?oYJoNo`000?nU[mh02OnU[mh00ol0003oYJoNojF_gP07ojF_gP04o`000?nU[mko0000o`0000So
YJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP04ojF^gP?o000000?oYJkNo`000?nU
[]h02OnU[]h00ol0003oYJkNojF^gP05ojF^gPKo00002?nV[ml00ol0003oY[3OojJ`g`08ojJ`g`03
o`000?nV/=ooY[3O00?oY[3O0ol000000onV/^7o0000ojJbh@0:ojJbh@03o`000?nV/^7oY[;Q00Oo
Y[;Q0_l0000;ojNfi004o`000?nW]^CoYkKTo`0000KoYkKT0ol0000:ojNki`03o`000?nW^nSoYk_X
00OoYk_X0_l0000ToookJPKo00001ooonfX4o`00Od;ooo]Z000eoookJPCo001o1?oonfX7o`00O`Ko
oo]Z1Ol0000BoookJP03o`000?oonf[ooo]Z04gooo]Z0ol00002ojNmj@03o`000?nW_NWoYkgY00So
YkgY00?o0000ojNmjOnW_NT01?nW_NT3o`000003ojNhi_l0003oYkSU00WoYkSU00?o0000ojNhiOnW
^>D01?nW^>D3o`000003ojJdhol0003oY[CR00WoY[CR00?o0000ojJdh_nV]>801onV]>83o`0000Wo
Y[7P00?o0000ojJah?nV/N001onV/N000ol0003oY[7PojJah003o`0000GoYJoN00?o0000ojF_g_nU
[mh02?nU[mh00ol0003oYJoNojF_gP06ojF_gP;o00002_nU[]h00ol0003oYJkNojF^gP08ojF^gP03
o`000?nU[]koYJkN00?o00001OnU[]h00ol0003oYJkNojF^gP08ojF^gP04o`000?nU[]koYJkNojF^
gP?o000000GoYJkNo`000?l0003oYJoOo`00000:ojJ_g`03o`000?nV/=ooY[3O00OoY[3O00?o0000
ojJ`gonV/=l00ol00005ojJbh@03o`000?nV/^7oY[;Q00WoY[;Q00?o0000ojJbhOnV/^400onV/^43
o`000003ojNfi?l0003oYkKT00_oYkKT00Co0000ojNfi?nW]^Co00000_nW]^@3o`000003ojNjiol0
003oYk_W00[oYk_W00?o0000ojNkj?nW^nP01?nW^nP3o`000003ojS1jol0003ooo]Z02Cooo]Z1_l0
001<oookJP00=_oonfX3o`00O`Gooo]Z1Ol007l7oookJPGo00004ooonfX00ol0003ooo]ZoookJP19
oookJP?o00001_nW_NT00ol0003oYkgYojNmj@08ojNmj@03o`000?nW_NWoYkgY00?o00001OnW^>H0
0ol0003oYkSUojNhi@08ojNhi@03o`000?nW^>GoYkSU00?o00001OnV]><00ol0003oY[CRojJdhP08
ojJdhP03o`000?nV]>;oY[CR00?oY[CR0ol000000onV/N3o0000ojJah00:ojJah003o`000?nV/N3o
Y[7P00KoY[7P0ol00009ojF_gP03o`000?nU[mkoYJoN00OoYJoN00?o0000ojF_g_nU[mh00onU[mh3
o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h01onU[]h3o`0000WoYJkN00?o0000
ojF^g_nU[]h01onU[]h4o`000004ojF^g_l0003o0000o`0000CoYJoO00?o0000ojJ_gonV[ml01onV
[ml00ol0003oY[3OojJ`g`07ojJ`g`?o00002OnV/^400ol0003oY[;QojJbh@08ojJbh@03o`000?nV
/^7oY[;Q00?o00001OnW]^@00ol0003oYkKTojNfi009ojNfi003o`000?nW]^CoYkKT00?o00001OnW
^^L00ol0003oYk_WojNki`09ojNki`03o`000?nW^nSoYk_X00?o00001OnX`N/00ol0003ooo]Zoook
JP0SoookJPKo0000BooonfX004[ooo]Z1Ol0000DoookJP03o`000?oonf[ooo]Z04Kooo]Z0_l0000:
ojNmj@03o`000?nW_NWoYkgY00OoYkgY0ol00009ojNhiP03o`000?nW^>GoYkSU00OoYkSU0ol00009
ojJdh`03o`000?nV]>;oY[CR00SoY[CR00?o0000ojJdh_l000000_l00005ojJah003o`000?nV/N3o
Y[7P00SoY[7P00?o0000ojJah?nV/N000onV/N03o`000003ojF_gol0003oYJoN00WoYJoN00?o0000
ojF_g_nU[mh02?nU[mh00ol0003oYJoNo`000002o`0000GoYJkN00?o0000ojF^g_nU[]h02?nU[]h0
0ol0003oYJkNojF^gP04ojF^gP?o000000?oYJkNo`000?nU[]h02OnU[]h00ol0003oYJkNojF^gP05
ojF^gPCo000000?oYJkNo`000?l000001onU[ml00ol0003oYZoOojJ_g`08ojJ_g`03o`000?nV/=oo
Y[3O00?oY[3O0ol000000onV/^7o0000ojJbh@0:ojJbh@03o`000?nV/^7oY[;Q00OoY[;Q0ol00009
ojNfi003o`000?nW]^CoYkKT00SoYkKT0ol000000onW^^Oo0000ojNji`06ojNji`03o`000?nW^nOo
Yk_W00SoYk_W0ol00009ojS1j`03o`000?oonf[ooo]Z02;ooo]Z1_l0001;oookJP00B_oonfX4o`00
01Kooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000;oYkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0
003oYkgYojNmj@03ojNmj@?o00000_nW^>H00ol0003oYkSVojNhiP08ojNhiP03o`000?nW^>GoYkSU
00?oYkSU0ol000000onV]>?o0000ojJdh`0:ojJdh`03o`000?nV]>;oY[CR00OoY[CR0_l00009ojJa
h003o`000?nV/N3oY[7P00SoY[7P00?o0000ojJah?l000000_l00005ojF_g`03o`000?nU[mkoYJoN
00SoYJoN00?o0000ojF_g_nU[mh01onU[mh2o`0000WoYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0
003oYJkNojF^gP03o`0000GoYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP02ojF^
gP;o00000onU[]h2o`0000[oYJoO00?o0000ojJ_gonV[ml01onV[ml00ol0003oY[3OojJ`g`03o`00
00GoY[;Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[;QojJbh@04ojJbh@?o000000?oYkGSo`00
0?nW]^@02_nW]^@00ol0003oYkKTojNfi004ojNfi0?o000000?oYk[Wo`000?nW^^L00_nW^^L00ol0
003oYk[WojNji`05ojNji`03o`000?nW^nOoYk_W00CoYk_W0ol000000onX`>_o0000ojS1j`09ojS1
j`03o`000?oonf[ooo]Z02?ooo]Z1_l0001:oookJP00B_oonfX4o`0001Oooo]Z00?o0000oookJ_oo
nfX0?_oonfX3o`0000KoYkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0003oYkgYo`000002o`0000Ko
YkSV00?o0000ojNhi_nW^>H02?nW^>H00ol0003oYkSUo`000002o`0000GoY[CS00?o0000ojJdhonV
]><02?nV]><00ol0003oY[CRojJdhP04ojJdhP?o000000?oY[7Po`000?nV/N002OnV/N000ol0003o
Y[7PojJah007ojJah0;o00002OnU[ml00ol0003oYJoNojF_gP07ojF_gP03o`000?nU[mkoYJoN00Co
YJoN0ol000000onU[]ko0000ojF^gP09ojF^gP03o`000?nU[]koYJkN00OoYJkN0ol00009ojF^gP03
o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_l000000_l00002ojF^gP?o000000?oYJoOo`000?nU
[ml02OnU[ml00ol0003oYZoOojJ_g`07ojJ_g`?o00002OnV/^400ol0003oY[;QojJbh@08ojJbh@03
o`000?nV/^7oY[;Q00?o00001OnW]N<00ol0003oYkKTojNfi009ojNfi003o`000?nW]^CoYkKT00?o
00001OnW^^L01Ol0003oYk[WojNjionW^^Oo000000OoYk[W00?o0000ojNkionW^nL00ol00005ojS0
j`03o`000?nX`N_oZ<7[00SoZ<7[00?o0000oookJ_oonfX08ooonfX5o`0004[ooo]Z001:oookJPCo
00006?oonfX00ol0003ooo]ZoookJP0koookJP;o00002_nW_NT00ol0003oYkgYojNmj@07ojNmj@;o
00002_nW^>H00ol0003oYkSVojNhiP07ojNhiP;o00002OnV]><00ol0003oY[CSojJdh`08ojJdh`03
o`000?nV]>;oY[CR00?o00001OnV/N000ol0003oY[7PojJah007ojJah003o`000?nV/N3oY[7P00Co
Y[7P0ol000000onU[moo0000ojF_g`08ojF_g`03o`000?nU[mkoYJoN00SoYJoN00?o0000ojF_g_nU
[mh00ol00005ojF^gP03o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_nU[]h01?nU[]h3o`000003
ojF^g_l0003oYJkN00WoYJkN00?o0000ojF^g_nU[]h01_nU[]h3o`0000;oYJkN0ol00005ojF_g`03
o`000?nU[mooYJoO00SoYJoO00?o0000ojJ_gonV[ml00onV[ml3o`000003ojJahOl0003oY[;Q00[o
Y[;Q00?o0000ojJbhOnV/^401onV/^43o`0000WoYkGS00?o0000ojNfi?nW]^@02?nW]^@3o`0000So
Yk[W00?o0000ojNjionW^^L00_nW^^L00ol0003oYk[WojNji`04ojNji`?o00002OnX`>/00ol0003o
Z<7[ojS1j`07ojS1j`;o00009?oonfX6o`0004Wooo]Z0019oookJPGo00006OoonfX00ol0003ooo]Z
oookJP0goookJP?o000000?oYkgYo`000?nW_NT02_nW_NT00ol0003oYkgYojNmj@03ojNmj@?o0000
00?oYkWVo`000?nW^>H02_nW^>H00ol0003oYkSVojNhiP03ojNhiP?o000000?oY[CSo`000?nV]><0
2OnV]><00ol0003oY[CSojJdh`07ojJdh`?o00002OnV/N000ol0003oY[7PojJah007ojJah003o`00
0?nV/N3oY[7P00?o00001OnU[ml00ol0003oYJoOojF_g`07ojF_g`03o`000?nU[mkoYJoN00OoYJoN
0ol00009ojF^gP03o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_nU[]h00ol00005ojF^gP03o`00
0?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00_nU[]h3o`0000;oYJkN0ol00008ojF_g`03o`00
0?nU[mooYJoO00SoYJoO00?o0000ojJ_gonV[ml00ol00005ojJah@03o`000?nV/^7oY[;Q00SoY[;Q
00?o0000ojJbhOnV/^401?nV/^43o`000003ojNehol0003oYkGS00[oYkGS00?o0000ojNfi?nW]^@0
1OnW]^@2o`000003ojNii_l0003oYk[W00WoYk[W00Go0000ojNjionW^^OoYk[Wo`000003ojNji`?o
000000?oZ;oZo`000?nX`>/02OnX`>/00ol0003oZ<7[ojS1j`04ojS1j`?o000000?oZLK_o`000?oo
nfX09?oonfX6o`0004Sooo]Z0019oookJPGo00006_oonfX00ol0003ooo]ZoookJP0coookJP?o0000
1OnW_NT00ol0003oYkgYojNmj@09ojNmj@03o`000?nW_NWo000000;o00001OnW^NH00ol0003oYkSV
ojNhiP09ojNhiP03o`000?nW^>Ko000000;o00001OnV]><00ol0003oY[CSojJdh`08ojJdh`03o`00
0?nV]>?oY[CS00?oY[CS0ol000000onV/N7o0000ojJah00:ojJah003o`000?nV/N3oY[7P00KoY[7P
0ol00009ojF_g`03o`000?nU[mooYJoO00KoYJoO00?o0000ojF_g_nU[mh01?nU[mh3o`000003ojF^
g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h01_nU[]h3o`0000WoYJkN00?o0000ojF^g_nU[]h0
1onU[]h00ol0003oYJkNo`000002o`0000;oYJkN0ol000000onU[moo0000ojF_g`09ojF_g`03o`00
0?nU[mooYJoO00OoYJoO0ol00009ojJah@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojJbhOnV/^40
0ol00005ojNeh`03o`000?nW]N?oYkGS00SoYkGS00?o0000ojNfi?nW]^@00_nW]^@3o`0000CoYkWV
00?o0000ojNjionW^^L02?nW^^L01?l0003oYk[WojNjionW^^L3o`0000GoZ;oZ00?o0000ojS0jonX
`>/02?nX`>/00ol0003oZ<7[ojS1j`03o`0000GoZLK_00?o0000oookJ_oonfX08_oonfX6o`0004So
oo]Z0019oookJPGo00006ooonfX00ol0003ooo]ZoookJP0`oookJP;o00002OnW_NT00ol0003oYkgY
ojNmj@08ojNmj@;o00002OnW^NH00ol0003oYkSVojNhiP08ojNhiP;o00002OnV]><00ol0003oY[CS
ojJdh`08ojJdh`03o`000?nV]>?o000000;o00001OnV/N400ol0003oY[7PojJah008ojJah003o`00
0?nV/N3oY[7P00?oY[7P0ol000000onU[moo0000ojF_g`09ojF_g`03o`000?nU[mooYJoO00OoYJoO
00?o0000ojF_g_nU[mh00ol00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h0
0onU[]h3o`000003ojF^g_l0003oYJkN00WoYJkN00?o0000ojF^g_nU[]h01_nU[]h3o`0000;oYJkN
0ol00005ojF_g`03o`000?nU[mooYJoO00SoYJoO00?o0000ojF_gonU[ml00onU[ml3o`000003ojJa
h?l0003oY[7Q00[oY[7Q00?o0000ojJbhOnV/^401onV/^43o`0000SoYkGS00?o0000ojNehonW]N<0
2OnW]N<01?l0003oYkKTo`000?l00007ojNiiP03o`000?nW^^OoYk[W00SoYk[W00?o0000ojNjiol0
00000ol00007ojRojP03o`000?nX`>_oZ<3[00OoZ<3[0ol00009ojW6k`03o`000?oonf[ooo]Z02;o
oo]Z1_l00017oookJP00BOoonfX4o`0001gooo]Z00?o0000oookJ_oonfX0;?oonfX3o`000003ojNm
jOl0003oYkgY00WoYkgY00?o0000ojNmjOnW_NT01?nW_NT3o`000003ojNii_l0003oYkWV00WoYkWV
00?o0000ojNhi_nW^>H01?nW^>H3o`000003ojJehol0003oY[CS00WoY[CS00?o0000ojJdhonV]><0
1onV]><2o`0000WoY[7Q00?o0000ojJah?nV/N002?nV/N000ol0003oY[7Po`000002o`0000GoYJoO
00?o0000ojF_gonU[ml02?nU[ml00ol0003oYJoOojF_g`06ojF_g`?o00002OnU[]h00ol0003oYJkN
ojF^gP08ojF^gP03o`000?nU[]ko000000;o00001OnU[]h00ol0003oYJkNojF^gP08ojF^gP03o`00
0?nU[]koYJkN00;oYJkN0ol00002ojF^gP?o00002?nU[ml00ol0003oYJoOojF_g`08ojF_g`03o`00
0?nU[mooYJoO00?o00001OnV/N000ol0003oY[7QojJah@08ojJah@03o`000?nV/^7oY[;Q00CoY[;Q
0ol000000onV]>?o0000ojNeh`09ojNeh`03o`000?nW]N?oYkGS00OoYkGS0ol0000:ojNiiP03o`00
0?nW^^OoYk[W00OoYk[W0_l00004ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o0000ojS0jonX`>/0
1?nX`>/3o`000003ojW5k_l0003oZLK_00[oZLK_00?o0000oookJ_oonfX08_oonfX6o`0004Kooo]Z
0019oookJPCo00007_oonfX00ol0003ooo]ZoookJP0XoookJP?o00001OnW_NT00ol0003oYkgYojNm
j@08ojNmj@03o`000?nW_NWoYkgY00?o00001OnW^NH00ol0003oYkWVojNiiP08ojNiiP03o`000?nW
^>KoYkSV00?o00001OnV]N<00ol0003oY[CSojJdh`07ojJdh`03o`000?nV]>?oY[CS00CoY[CS0ol0
00000onV/^7o0000ojJah@09ojJah@03o`000?nV/N3oY[7P00OoY[7P0_l00009ojF_g`03o`000?nU
[mooYJoO00OoYJoO00?o0000ojF_gonU[ml00onU[ml3o`000003ojF^g_l0003oYJkN00[oYJkN00?o
0000ojF^g_nU[]h01onU[]h2o`0000WoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNo`00
0002o`0000;oYJkN0ol000000onU[mko0000ojF_g`09ojF_g`03o`000?nU[mooYJoO00OoYJoO0ol0
0009ojJah003o`000?nV/N7oY[7Q00SoY[7Q00?o0000ojJbhOnV/^400ol00005ojJdh`03o`000?nW
]N?oYkGS00SoYkGS00?o0000ojNehonW]N<00onW]N<3o`0000;oYkWV00?o0000ojNii_nW^NH02OnW
^NH00ol0003oYk[WojNji`03ojNji`?o000000?oZ;kZo`000?nX_nX00onX_nX00ol0003oZ;oZojRo
jP05ojRojP03o`000?nX`>_oZ<3[00?o00001OnYaNh00ol0003oZLK_ojW6k`08ojW6k`;o00008ooo
nfX6o`0004Kooo]Z0019oookJPCo00007ooonfX00ol0003ooo]ZoookJP0UoookJP;o00002OnW_NT0
0ol0003oYkgYojNmj@07ojNmj@?o00002OnW^NH00ol0003oYkWVojNiiP07ojNiiP?o00002OnV]N<0
0ol0003oY[CSojJdh`07ojJdh`03o`000?nV]>?oY[CS00?o00001OnV/^400ol0003oY[7QojJah@07
ojJah@03o`000?nV/N3oY[7P00CoY[7P0ol000000onU/=oo0000ojF_g`08ojF_g`03o`000?nU[moo
YJoO00SoYJoO00?o0000ojF_gol000000_l00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000
ojF^g_nU[]h01?nU[]h3o`000003ojF^g_l0003oYJkN00SoYJkN00?o0000ojF^g_nU[]h01_nU[]h3
o`0000;oYJkN0ol00005ojF_gP03o`000?nU[mooYJoO00SoYJoO00?o0000ojF_gonU[ml00onU[ml3
o`000003ojJah?l0003oY[7P00[oY[7P00?o0000ojJahOnV/N401onV/N43o`0000SoY[CS00?o0000
ojNehonW]N<02?nW]N<00ol0003oYkGSojNeh`03o`0000KoYkWV00?o0000ojNii_nW^NH02?nW^NH0
0ol0003oYk[WojNji`03o`0000GoZ;kZ00?o0000ojRoj_nX_nX00_nX_nX00ol0003oZ;oZojRojP03
ojRojPCo00002OnYaNh00ol0003oZLK_ojW6k`04ojW6k`?o000000?oZLcbo`000?oonfX08ooonfX6
o`0004Gooo]Z0018oookJPKo00007ooonfX00ol0003ooo]ZoookJP0QoookJP?o000000?oYkgYo`00
0?nW_NT02OnW_NT00ol0003oYkgYojNmj@03ojNmj@?o00000_nW^NH00ol0003oYkWVojNiiP08ojNi
iP03o`000?nW^NKoYkWV00?oYkWV0ol000000onV]N?o0000ojJeh`0:ojJeh`03o`000?nV]>?oY[CS
00KoY[CS0ol00009ojJbh@03o`000?nV/N7oY[7Q00OoY[7Q00?o0000ojJah?nV/N000ol00005ojF`
g`03o`000?nU[mooYJoO00OoYJoO00?o0000ojF_gonU[ml01onU[ml2o`0000WoYJkN00?o0000ojF^
g_nU[]h02?nU[]h00ol0003oYJkNojF^gP03o`0000GoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0
003oYJkNojF^gP03ojF^gP;o00000_nU[]h3o`0000WoYJoN00?o0000ojF_gonU[ml01onU[ml00ol0
003oYJoOojF_g`03o`0000GoY[7P00?o0000ojJah?nV/N002?nV/N000ol0003oY[7QojJah@04ojJa
h@?o000000?oY[CRo`000?nV]><02OnV]><00ol0003oYkGSojNeh`07ojNeh`?o00002_nW^NH00ol0
003oYkWVojNiiP07ojNiiP?o00002OnX_^X00ol0003oZ;oZojRojP02ojRojP03o`000?nX_n[o0000
00;o00000_nYa>d00ol0003oZLG^ojW5kP09ojW5kP03o`000?nYa^ooZLK_00?o00001OnYc?800ol0
003ooo]ZoookJP0RoookJPKo0000A?oonfX004Sooo]Z1Ol0000QoookJP;o00007_oonfX3o`0000Go
YkgY00?o0000ojNmjOnW_NT02?nW_NT00ol0003oYkgYo`000002o`0000KoYkWV00?o0000ojNii_nW
^NH02?nW^NH00ol0003oYkWVo`000002o`0000GoY[GS00?o0000ojJehonV]N<02?nV]N<00ol0003o
Y[CSojJdh`03ojJdh`?o000000?oY[;Qo`000?nV/^402_nV/^400ol0003oY[7QojJah@06ojJah@?o
00002OnU/=l00ol0003oYJoOojF_g`06ojF_g`03o`000?nU[mooYJoO00CoYJoO0ol000000onU[]ko
0000ojF^gP09ojF^gP03o`000?nU[]koYJkN00OoYJkN0ol00008ojF^gP03o`000?nU[]koYJkN00Oo
YJkN00?o0000ojF^g_nU[]h00ol000001_nU[]ko0000o`000?l0003oYJoNo`0000_oYJoN00?o0000
ojF_gonU[ml01_nU[ml3o`0000WoY[7P00?o0000ojJah?nV/N002?nV/N000ol0003oY[7QojJah@03
o`0000GoY[CR00?o0000ojJdhonV]><02?nV]><00ol0003oYkGSojNeh`03ojNeh`?o000000?oYkSU
o`000?nW^NH02_nW^NH00ol0003oYkWVojNiiP04ojNiiP?o000000?oZ;kYo`000?nX_^X02_nX_^X0
0ol0003oZ;oZojRojP03o`0000KoZLC]00?o0000ojW5k_nYaNh02?nYaNh3o`0000WoZLcb00?o0000
oookJ_oonfX08OoonfX6o`0004Cooo]Z0018oookJPGo00008ooonfX00ol0003ooo]ZoookJP0Hoook
JP?o00002OnW_NT00ol0003oYkgYojNmj@07ojNmj@;o00002_nW^NH00ol0003oYkWVojNiiP07ojNi
iP;o00002OnV]N<00ol0003oY[GSojJeh`08ojJeh`03o`000?nV]>?o000000;o00001OnV/^400ol0
003oY[;QojJbh@08ojJbh@03o`000?nV/N7oY[7Q00?oY[7Q0ol000000onU/=oo0000ojF`g`09ojF`
g`03o`000?nU[mooYJoO00OoYJoO00?o0000ojF_gonU[ml00ol00005ojF^gP03o`000?nU[]koYJkN
00OoYJkN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^g_l0003oYJkN00WoYJkN00?o0000ojF^
g_nU[]h01_nU[]h3o`000004ojF^g_l0003o0000o`0000GoYJoN00?o0000ojF_g_nU[mh02?nU[mh0
0ol0003oYJoOojF_g`03ojF_g`?o000000?oY[7Po`000?nV/N002_nV/N000ol0003oY[7PojJah007
ojJah0?o00002?nV]>800ol0003oY[CSojJdh`08ojJdh`03o`000?nW]N?oYkGS00?o00001OnW^>D0
0ol0003oYkWVojNiiP09ojNiiP03o`000?nW^NKoYkWV00?o00001OnX_^T00ol0003oZ;kZojRnjP08
ojRnjP?o00000_nYa>d00ol0003oZLC]ojW4k@05ojW4k@03o`000?nYaNkoZLG^00GoZLG^0_l00000
0onYbo7o0000ojW<lP0:ojW<lP03o`000?oonf[ooo]Z027ooo]Z1_l00013oookJP00>_oonfX5o`00
O`Wooo]Z1?l0000UoookJP03o`000?oonf[ooo]Z01Cooo]Z0ol00002ojNmj@03o`000?nW_NWoYkgY
00SoYkgY00?o0000ojNmjOnW_NT00onW_NT3o`0000;oYkWV00?o0000ojNii_nW^NH02?nW^NH00ol0
003oYkWVojNiiP03ojNiiP?o000000?oY[GSo`000?nV]N<02OnV]N<00ol0003oY[GSojJeh`07ojJe
h`;o00002OnV/^400ol0003oY[;QojJbh@08ojJbh@03o`000?nV/N7o000000;o00001OnU/=l00ol0
003oYK3OojF`g`08ojF`g`03o`000?nU[mooYJoO00KoYJoO0ol00009ojF^gP03o`000?nU[]koYJkN
00OoYJkN00?o0000ojF^g_nU[]h00ol00005ojF^gP03o`000?nU[]koYJkN00OoYJkN00?o0000ojF^
g_nU[]h00onU[]h3o`000004ojF^g_l0003o0000o`0000WoYJoN00?o0000ojF_g_nU[mh02?nU[mh0
0ol0003oYJoOo`000002o`0000GoY[7P00?o0000ojJah?nV/N002?nV/N000ol0003oY[7PojJah004
ojJah0?o000000?oY[CRo`000?nV]>802OnV]>800ol0003oY[CSojJdh`07ojJdh`?o00002OnW^>D0
0ol0003oYkWVojNiiP08ojNiiP?o00002OnX_^T00ol0003oZ;kZojRnjP05ojRnjP;o000000?oZLC]
o`000?nYa>d00onYa>d00ol0003oZLC]ojW4k@04ojW4k@03o`000?nYaNkoZLG^00;oZLG^0ol00004
ojW;l@03o`000?nYc?;oZLcb00SoZLcb0_l0000SoookJPKo0000@_oonfX003Wooo]Z1ol007l8oook
JPCo00009_oonfX00ol0003ooo]ZoookJP0@oookJP?o00001_nW_NT00ol0003oYkgYojNmj@08ojNm
j@03o`000?nW_NWo000000;o00001_nW^NH00ol0003oYkWVojNiiP08ojNiiP03o`000?nW^NKo0000
00;o00001OnV]N<00ol0003oY[GSojJeh`08ojJeh`03o`000?nV]N?oY[GS00?oY[GS0ol000000onV
/^7o0000ojJbh@09ojJbh@03o`000?nV/^7oY[;Q00OoY[;Q0_l00009ojF`g`03o`000?nU/=ooYK3O
00OoYK3O00?o0000ojF_gonU[ml00onU[ml3o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^
g_nU[]h01_nU[]h3o`0000WoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNo`000002o`00
0006ojF^g_l0003o0000o`000?nU[mko00002onU[mh00ol0003oYJoNojF_gP07ojF_gP;o00002OnV
/N000ol0003oY[7PojJah008ojJah003o`000?nV/N3oY[7P00?o00001OnV]>800ol0003oY[CRojJd
hP08ojJdhP03o`000?nV]>?oY[CS00?oY[CS0ol000000onW^>Go0000ojNhi@0:ojNhi@03o`000?nW
^NKoYkWV00CoYkWV0ol000000onX_NWo0000ojRnj@09ojRnj@03o`000?nX_^[oZ;kZ00;oZ;kZ0ol0
0004ojW4k@03o`000?nYa>goZLC]00;oZLC]00?o0000ojW4kOnYa>d01?nYa>d01?l0003oZLG^o`00
0?l00008ojW;l@03o`000?nYc?;oZLcb00CoZLcb0ol00002ojWAm@03o`000?oonf[ooo]Z023ooo]Z
1_l00012oookJP00>?oonfX4o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1?l0000WoookJP03o`00
0?oonf[ooo]Z00gooo]Z0_l0000:ojNmj@03o`000?nW_NWoYkgY00OoYkgY0_l0000:ojNiiP03o`00
0?nW^NKoYkWV00OoYkWV0_l00009ojJeh`03o`000?nV]N?oY[GS00SoY[GS00?o0000ojJehol00000
0_l00005ojJbh@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojJbhOnV/^400onV/^43o`000003ojF`
gol0003oYK3O00WoYK3O00?o0000ojF`gonU/=l01onU/=l00ol0003oYJoOo`000002o`0000GoYJkN
00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP03ojF^gP?o000000?oYJkNo`000?nU[]h0
2OnU[]h00ol0003oYJkNojF^gP06ojF^gP?o000000CoYJkNo`000?l0003o00001OnU[mh00ol0003o
YJoNojF_gP08ojF_gP03o`000?nU[mkoYJoN00CoYJoN0ol000000onV/>3o0000ojJah009ojJah003
o`000?nV/N3oY[7P00OoY[7P0ol00008ojJdhP03o`000?nV]>;oY[CR00SoY[CR00?o0000ojJdhonV
]><00ol00005ojNhi@03o`000?nW^>GoYkSU00WoYkSU00?o0000ojNii_nW^NH00ol00005ojRmj@03
o`000?nX_^WoZ;kY00SoZ;kY00Co0000ojRnj_l0003o00002?nYa>d01Ol0003oZLC]ojW4kOnYa>go
000000KoZLC]0_l0000;ojW;l@03o`000?nYc?;oZLcb00?o00001_nYdOD00ol0003ooo]ZoookJP0P
oookJPKo0000@OoonfX002cooo]Z2_l007l2oookJP?o001o0ooonfX3o`00O`Kooo]Z1Ol0000Xoook
JP03o`000?oonf[ooo]Z00Wooo]Z0ol00002ojNnj@03o`000?nW_NWoYkgY00SoYkgY00?o0000ojNm
jOnW_NT00onW_NT3o`0000;oYkWV00?o0000ojNii_nW^NH02?nW^NH00ol0003oYkWVojNiiP03ojNi
iP?o000000?oY[KTo`000?nV]N<02OnV]N<00ol0003oY[GSojJeh`07ojJeh`;o00002OnV/^400ol0
003oY[;QojJbh@08ojJbh@03o`000?nV/^7o000000;o00001OnU/=l00ol0003oYK3OojF`g`07ojF`
g`03o`000?nU/=ooYK3O00KoYK3O0ol00009ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^
g_l000000_l00005ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h00_nU[]h3o`00
0004ojF^g_l0003o0000o`0000WoYJoN00?o0000ojF_g_nU[mh02?nU[mh00ol0003oYJoNojF_gP03
o`0000GoY[3P00?o0000ojJah?nV/N001onV/N000ol0003oY[7PojJah004ojJah0?o000000?oY[?R
o`000?nV]>802OnV]>800ol0003oY[CRojJdhP07ojJdhP?o00002OnW^>D00ol0003oYkSUojNhi@08
ojNhi@?o00002OnX_NT00ol0003oZ;kYojRnj@07ojRnj@;o00002onYa>d01Ol0003oZLC]ojW4kOnY
a>go000000;oZLC]0ol00002ojW:l@03o`000?nYbo7oZL_a00SoZL_a0ol0000:ojWAm@03o`000?oo
nf[ooo]Z023ooo]Z1_l00010oookJP00;?oonfX:o`00O`Sooo]Z0ol007l6oookJPGo0000:OoonfX0
0ol0003ooo]ZoookJP05oookJP?o00001_nW_^T00ol0003oYkgYojNmj@08ojNmj@03o`000?nW_NWo
000000;o00001_nW^NH00ol0003oYkWVojNiiP08ojNiiP03o`000?nW^NKo000000;o00001OnV]^@0
0ol0003oY[GSojJeh`08ojJeh`03o`000?nV]N?oY[GS00?oY[GS0ol000000onV/^;o0000ojJbh@09
ojJbh@03o`000?nV/^7oY[;Q00OoY[;Q0_l00009ojF`g`03o`000?nU/=ooYK3O00OoYK3O00?o0000
ojF`gonU/=l01Ol00002ojF^gP03o`000?nU[]koYJkN00SoYJkN00?o0000ojF^g_nU[]h01onU[]h2
o`0000WoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNo`000002o`000006ojF^g_l0003o
0000o`000?nU[mko00002onU[mh00ol0003oYJoNojF_gP07ojF_gP?o00002?nV/>000ol0003oY[7P
ojJah008ojJah003o`000?nV/N3oY[7P00?o00001OnV/n800ol0003oY[CRojJdhP08ojJdhP03o`00
0?nV]>;oY[CR00?oY[CR0ol000000onW]nGo0000ojNhi@0:ojNhi@03o`000?nW^>GoYkSU00CoYkSU
0ol000000onX_>So0000ojRmj@09ojRmj@03o`000?nX_^WoZ;kY00CoZ;kY0ol000000onY`nco0000
ojW4k@0;ojW4k@03o`000?nYa>goZLC]00?o00001_nYb_400ol0003oZL_aojW;l@04ojW;l@?o0000
0_nZd?@00ol0003oZM7eojWAm@08ojWAm@;o00008OoonfX6o`00043ooo]Z000noookJP?o001o1_oo
nfX5o`0002[ooo]Z00?o0000oookJ_oonfX00_oonfX2o`0000[oYkkY00?o0000ojNmjOnW_NT01onW
_NT2o`0000[oYkWV00?o0000ojNii_nW^NH01onW^NH2o`0000WoY[KT00?o0000ojJehonV]N<02?nV
]N<00ol0003oY[GSo`000002o`0000GoY[;R00?o0000ojJbhOnV/^401onV/^400ol0003oY[;QojJb
h@04ojJbh@?o000000?oYK3Po`000?nU/=l02OnU/=l00ol0003oYK3OojF`g`06ojF`g`?o00002?nU
[]h00ol0003oYJkNojF^gP07ojF^gP03o`000?nU[]koYJkN00CoYJkN0ol000000onU[]ko0000ojF^
gP08ojF^gP03o`000?nU[]koYJkN00OoYJkN0_l000001?nU[]ko0000o`000?l00005ojF_gP03o`00
0?nU[mkoYJoN00SoYJoN00?o0000ojF_g_nU[mh01?nU[mh3o`000003ojJ`gol0003oY[3P00WoY[3P
00?o0000ojJah?nV/N001onV/N03o`0000SoY[?R00?o0000ojJdh_nV]>802?nV]>800ol0003oY[CR
ojJdhP03o`0000GoYkOU00?o0000ojNhiOnW^>D02OnW^>D00ol0003oYkSUojNhi@03o`0000GoZ;cX
00?o0000ojRmjOnX_NT02?nX_NT00ol0003oZ;kYojRnj@03o`0000GoZL?/00?o0000ojW4kOnYa>d0
2?nYa>d4o`0000;oZL[a00?o0000ojW:lOnYb_401OnYb_400ol0003oZL_aojW;l@03o`0000KoZ]3d
00?o0000ojWAmOnYdOD01?nYdOD3o`000003ojWGmol0003ooo]Z027ooo]Z1_l0000ooookJP00>Ooo
nfX2o`00O`;ooo]Z1?l007l6oookJPCo0000;?oonfX4o`0000;oYkkY00?o0000ojNnjOnW_^T02?nW
_^T00ol0003oYkgYojNmj@03ojNmj@?o00000_nW^^L00ol0003oYkWVojNiiP08ojNiiP03o`000?nW
^NKoYkWV00?oYkWV0ol000000onV]^Co0000ojJfi009ojJfi003o`000?nV]N?oY[GS00OoY[GS0_l0
0009ojJbhP03o`000?nV/^7oY[;Q00OoY[;Q00?o0000ojJbhOnV/^400ol00005ojF`h003o`000?nU
/=ooYK3O00OoYK3O00?o0000ojF`gonU/=l00onU/=l3o`000003ojF_g_l0003oYJkN00WoYJkN00?o
0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP03o`0000GoYJkN00?o0000ojF^g_nU[]h01onU
[]h00ol0003oYJkNojF^gP03ojF^gP?o000000?oYJkNo`000?l000002OnU[mh00ol0003oYJoNojF_
gP08ojF_gP03o`000?nU[mkoYJoN00?o00001OnV/=l00ol0003oY[3PojJ`h008ojJ`h003o`000?nV
/N3oY[7P00?oY[7P0ol000000onV/n;o0000ojJchP09ojJchP03o`000?nV]>;oY[CR00OoY[CR0ol0
0009ojNgi@03o`000?nW^>GoYkSU00SoYkSU0ol00009ojRlj003o`000?nX_NWoZ;gY00OoZ;gY0ol0
0009ojW3k003o`000?nYa>goZLC]00CoZLC]0ol00002ojW9l005o`000?nYb_7oZL[aojW:lOl00000
1onYb_43o`0000[oZ]3d00?o0000ojWAmOnYdOD00ol00005ojWGm`03o`000?oonf[ooo]Z023ooo]Z
1_l0000noookJP00>OoonfX7o`00O`Oooo]Z1?l0000[oookJP;o00001_nW_^T00ol0003oYkkYojNn
j@08ojNnj@03o`000?nW_NWo000000;o00001_nW^^L00ol0003oYkWVojNiiP08ojNiiP03o`000?nW
^NKo000000;o00001OnV]^@00ol0003oY[KTojJfi007ojJfi003o`000?nV]N?oY[GS00CoY[GS0ol0
00000onV/n;o0000ojJbhP09ojJbhP03o`000?nV/^7oY[;Q00KoY[;Q0ol00009ojF`h003o`000?nU
/=ooYK3O00OoYK3O00?o0000ojF`gol000000_l00005ojF_gP03o`000?nU[]koYJkN00SoYJkN00?o
0000ojF^g_nU[]h01_nU[]h3o`0000WoYJkN00?o0000ojF^g_nU[]h01_nU[]h00ol0003oYJkNojF^
gP03o`000006ojF^g_l0003o0000o`000?nU[]ko00002_nU[mh00ol0003oYJoNojF_gP07ojF_gP?o
00002?nV/=l00ol0003oY[3PojJ`h008ojJ`h003o`000?nV/N3oY[7P00?o00001OnV/n800ol0003o
Y[?RojJchP08ojJchP03o`000?nV]>;oY[CR00?oY[CR0ol000000onW]nCo0000ojNgi@0:ojNgi@03
o`000?nW^>GoYkSU00CoYkSU0ol000000onX_>So0000ojRlj009ojRlj003o`000?nX_NWoZ;gY00Co
Z;gY0ol000000onY`^co0000ojW3k00:ojW3k003o`000?nYa>goZLC]00?o00001_nYbO001Ol0003o
ZL[aojW:lOnYb_7o000000CoZL[a0_l000000onZco?o0000oj[@m00:oj[@m0?o00002OnYeoL00ol0
003ooo]ZoookJP0OoookJPKo0000?_oonfX003Wooo]Z1_l007l8oookJPCo0000:OoonfX2o`0000Wo
YkkY00?o0000ojNnjOnW_^T01onW_^T2o`0000[oYk[W00?o0000ojNii_nW^NH01onW^NH2o`0000Wo
Y[KT00?o0000ojJfi?nV]^@01onV]^@00ol0003oY[GSojJeh`03o`0000GoY[?R00?o0000ojJbh_nV
/^801onV/^800ol0003oY[;QojJbh@03ojJbh@?o000000?oYK3Po`000?nU/>002_nU/>000ol0003o
YK3OojF`g`06ojF`g`;o00002OnU[mh00ol0003oYJkNojF^gP07ojF^gP03o`000?nU[]koYJkN00?o
YJkN0ol000000onU[]ko0000ojF^gP0:ojF^gP03o`000?nU[]koYJkN00GoYJkN0ol000001?nU[]ko
0000o`000?l00005ojF^gP03o`000?nU[mkoYJoN00OoYJoN00?o0000ojF_g_nU[mh01?nU[mh3o`00
0003ojF`gol0003oY[3O00WoY[3O00?o0000ojJ`h?nV/>001onV/>03o`0000WoY[?R00?o0000ojJc
h_nV/n801onV/n800ol0003oY[CRojJdhP03o`0000GoYkOT00?o0000ojNgiOnW]nD02OnW]nD00ol0
003oYkSUojNhi@03o`0000GoZ;cX00?o0000ojRlj?nX_>P02?nX_>P00ol0003oZ;gYojRmj@03o`00
00GoZL;/00?o0000ojW3k?nY`n`02?nY`n`3o`0000[oZLW`00Co0000ojW:lOnYb_7oZL[a1?l00004
oj[?l`03o`000?nZd?CoZ]3d00KoZ]3d0_l000000onZe_Oo0000ojWGm`09ojWGm`?o00008?oonfX6
o`0003gooo]Z000ioookJP;o001o2ooonfX5o`0002Kooo]Z0ol000000onW_^[o0000ojNnj@09ojNn
j@03o`000?nW_^WoYkkY00?oYkkY0ol00002ojNji`03o`000?nW^^OoYk[W00SoYk[W00?o0000ojNi
i_nW^NH00onW^NH3o`000003ojJfi?l0003oY[KT00WoY[KT00?o0000ojJfi?nV]^@01_nV]^@3o`00
00WoY[?R00?o0000ojJbh_nV/^801onV/^800ol0003oY[;Qo`000002o`0000GoYK3P00?o0000ojF`
h?nU/>002?nU/>000ol0003oYK3OojF`g`03ojF`g`?o000000?oYJoOo`000?nU[mh02?nU[mh00ol0
003oYJkNojF^gP08ojF^gP03o`000?nU[]ko000000;o00001OnU[]h00ol0003oYJkNojF^gP08ojF^
gP03o`000?nU[]koYJkN00;oYJkN1ol00009ojF^gP03o`000?nU[mkoYJoN00OoYJoN00?o0000ojF_
g_nU[mh00ol00005ojF`g`03o`000?nV/=ooY[3O00SoY[3O00?o0000ojJ`h?nV/>000onV/>03o`00
0003ojJbhOl0003oY[?R00[oY[?R00?o0000ojJch_nV/n801_nV/n83o`0000WoYkOT00?o0000ojNg
iOnW]nD02?nW]nD3o`0000WoZ;cX00?o0000ojRlj?nX_>P01onX_>P3o`0000WoZL;/00?o0000ojW3
k?nY`n`01?nY`n`3o`000003oj[8kol0003oZLW`00_oZLW`00?o0000ojW:lOl000000_l00007oj[?
l`03o`000?nZd?CoZ]3d00;oZ]3d0ol00004oj[Fm`03o`000?nYeoOoZMOg00CoZMOg0ol00003ojWL
n@03o`000?oonf[ooo]Z01kooo]Z1_l0000loookJP00>OoonfX2o`00O`_ooo]Z1Ol0000SoookJP?o
00001OnW_^X00ol0003oYkkYojNnj@08ojNnj@03o`000?nW_^Wo000000;o00001_nW^^L00ol0003o
Yk[WojNji`08ojNji`03o`000?nW^NKo000000;o00001OnV]^@00ol0003oY[KTojJfi007ojJfi003
o`000?nV]^CoY[KT00?oY[KT0ol000000onV/n;o0000ojJchP0:ojJchP03o`000?nV/^;oY[;R00Ko
Y[;R0_l00009ojF`h003o`000?nU/>3oYK3P00SoYK3P00?o0000ojF`gol000000_l00005ojF_g`03
o`000?nU[mkoYJoN00OoYJoN00?o0000ojF^g_nU[]h01onU[]h2o`0000WoYJkN00?o0000ojF^g_nU
[]h02?nU[]h7o`0000;oYJkN00?o0000ojF^g_nU[]h02OnU[]h00ol0003oYJoNojF_gP06ojF_gP?o
00002OnU/=l00ol0003oY[3OojJ`g`07ojJ`g`03o`000?nV/>3oY[3P00?o00001OnV/^400ol0003o
Y[?RojJchP08ojJchP03o`000?nV/n;oY[?R00?oY[?R0ol000000onW]^Co0000ojNgi00:ojNgi003
o`000?nW]nGoYkOU00CoYkOU0ol000000onX^nOo0000ojRlj009ojRlj003o`000?nX_>SoZ;cX00Co
Z;cX0ol000000onY`N_o0000ojW2k00:ojW2k003o`000?nY`ncoZL?/00?o00001OnZb>l00ol0003o
ZLW`ojW9l008ojW9l0?o00000_nZco<00ol0003oZ/ocoj[?l`06oj[?l`04o`000?nZd?Co0000o`00
00SoZ]Kg00?o0000ojWGmonYeoL00ol00007ojWLn@03o`000?oonf[ooo]Z01gooo]Z1_l0000loook
JP00>_oonfX7o`00O`Gooo]Z1Ol0000QoookJP;o00002OnW_^X00ol0003oYkkYojNnj@07ojNnj@;o
00002_nW^^L00ol0003oYk[WojNji`07ojNji`;o00002OnV]^@00ol0003oY[KTojJfi007ojJfi003
o`000?nV]^Co000000;o00001OnV/n800ol0003oY[?RojJchP08ojJchP03o`000?nV/^;oY[;R00?o
Y[;R0ol000000onU/N3o0000ojF`h009ojF`h003o`000?nU/>3oYK3P00OoYK3P0_l00009ojF_g`03
o`000?nU[mkoYJoN00KoYJoN00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF^g_l0003oYJkN00Wo
YJkN00?o0000ojF^g_nU[]h01OnU[]h5o`0000OoYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003o
YJoNojF_gP03ojF_gP?o000000?oYK3Oo`000?nU/=l02_nU/=l00ol0003oY[3OojJ`g`06ojJ`g`?o
00002OnV/^400ol0003oY[?RojJchP08ojJchP03o`000?nV/n;o000000;o00001OnW]^@00ol0003o
YkOTojNgi009ojNgi003o`000?nW]nGoYkOU00?o00001OnX^nL00ol0003oZ;cXojRlj008ojRlj003
o`000?nX_>SoZ;cX00?o00001OnY`N/00ol0003oZL;/ojW2k008ojW2k0?o00002OnZb>l00ol0003o
ZLW`ojW9l004ojW9l0?o00000_nZc_<01Ol0003oZ/ocoj[?lonZco?o000000KoZ/oc0ol0000:oj[F
m`?o00002_nYg?T3o`0001kooo]Z1_l0000>oookJPGo001o:?oonfX003[ooo]Z1ol007l5oookJPCo
00007ooonfX3o`000003ojNnj_l0003oYkkZ00WoYkkZ00?o0000ojNnjOnW_^T00onW_^T3o`0000;o
Yk[W00?o0000ojNjionW^^L02?nW^^L00ol0003oYk[WojNji`03ojNji`?o000000?oY[OUo`000?nV
]^@02OnV]^@00ol0003oY[KTojJfi006ojJfi0;o00002OnV/n800ol0003oY[?RojJchP08ojJchP03
o`000?nV/^;o000000;o00001OnU/N000ol0003oYK3PojF`h007ojF`h003o`000?nU/>3oYK3P00Co
YK3P0ol000000onU[moo0000ojF_g`08ojF_g`03o`000?nU[mkoYJoN00OoYJoN00?o0000ojF^g_nU
[]h00ol00005ojF^gP03o`000?nU[]koYJkN00OoYJkN00?o0000ojF^g_nU[]h00_nU[]h5o`000003
ojF^g_l0003oYJkN00SoYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJoNo`000002o`0000Go
YK3O00?o0000ojF`gonU/=l02?nU/=l00ol0003oY[3OojJ`g`03ojJ`g`?o000000?oY[;Qo`000?nV
/^402_nV/^400ol0003oY[?RojJchP07ojJchP;o00002OnW]^@00ol0003oYkOTojNgi008ojNgi0?o
00002OnX^nL00ol0003oZ;cXojRlj007ojRlj0?o00002OnY`N/00ol0003oZL;/ojW2k005ojW2k0;o
000000?oZ/O^o`000?nZb>l02_nZb>l00ol0003oZLW`ojW9l003o`0000KoZ/kc00Go0000oj[?lonZ
co?oZ/oco`000002oj[?l`?o00000onZe?H00ol0003oZ]Kgoj[Fm`04oj[Fm`?o00000onZfoT00ol0
003oZMciojWLn@04ojWLn@?o00000onYhOX00ol0003ooo]ZoookJP0LoookJPKo00003?oonfX7o`00
ObOooo]Z0016oookJPCo00007?oonfX3o`0000GoYkkZ00?o0000ojNnj_nW_^X02?nW_^X00ol0003o
YkkYo`000002o`0000KoYk[W00?o0000ojNjionW^^L02?nW^^L00ol0003oYk[Wo`000002o`0000Go
Y[OU00?o0000ojJfi?nV]^@01onV]^@00ol0003oY[KTojJfi003ojJfi0?o00000_nV/n800ol0003o
Y[?RojJchP07ojJchP03o`000?nV/n;oY[?R00OoY[?R0_l00009ojFah003o`000?nU/>3oYK3P00Oo
YK3P00?o0000ojF`h?nU/>000ol00005ojF_g`03o`000?nU[mooYJoO00OoYJoO00?o0000ojF_g_nU
[mh01_nU[mh3o`0000WoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNo`000003o`0000Go
YJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP07ojF^gP;o00002OnU/=l00ol0003o
YK3OojF`g`08ojF`g`03o`000?nV/=oo000000;o00001OnV/^400ol0003oY[;QojJbh@08ojJbh@03
o`000?nV/n;oY[?R00CoY[?R0ol000000onW]^?o0000ojNfi009ojNfi003o`000?nW]nCoYkOT00Go
YkOT0_l000000onX^^Ko0000ojRki`09ojRki`03o`000?nX_>SoZ;cX00CoZ;cX0ol000000onY`>[o
0000ojW1j`09ojW1j`03o`000?nY`^coZL;/00;oZL;/0ol00004oj[7kP03o`000?nZb>ooZ/S_00So
Z/S_0ol0000:oj[>l`03o`000?nZco?oZ/oc00?o00001onZe?H00ol0003oZ]Kgoj[Fm`03o`0000Oo
Z]_i00?o0000ojWLnOnYg?T00ol00007ojWQnP03o`000?oonf[ooo]Z01_ooo]Z1_l0000;oookJP?o
001o0ooonfX3o`00ObKooo]Z0016oookJPGo00006OoonfX3o`0000SoYkkZ00?o0000ojNnj_nW_^X0
1onW_^X2o`0000[oYk[W00?o0000ojNjionW^^L01onW^^L2o`0000WoY[OU00?o0000ojJfi?nV]^@0
1onV]^@00ol0003oY[KTo`000002o`0000KoY[?R00?o0000ojJch_nV/n801onV/n800ol0003oY[?R
ojJchP03ojJchP?o000000?oYK7Qo`000?nU/N002OnU/N000ol0003oYK3PojF`h006ojF`h0?o0000
2OnU[ml00ol0003oYJoOojF_g`06ojF_g`03o`000?nU[mkoYJoN00?oYJoN0ol000000onU[]ko0000
ojF^gP0:ojF^gP03o`000?nU[]koYJkN00GoYJkN1?l00009ojF^gP03o`000?nU[]koYJkN00KoYJkN
00?o0000ojF^g_nU[]h01?nU[]h3o`000003ojF`gol0003oYK3O00WoYK3O00?o0000ojF`gonU/=l0
1onU/=l2o`0000WoY[;Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[?RojJchP03o`0000GoYkKS
00?o0000ojNfi?nW]^@01onW]^@00ol0003oYkOTojNgi002ojNgi0?o00001?nX^^H00ol0003oZ;_W
ojRki`08ojRki`03o`000?nX_>SoZ;cX00?o00001OnY`>X00ol0003oZL7[ojW1j`08ojW1j`04o`00
0?nY`^co0000o`0000SoZ/O^00?o0000oj[8konZb>l01?nZb>l3o`0000;oZlgb00?o0000oj[>lonZ
c_<02?nZc_<3o`000003oj[Dm_l0003oZ]Cf00OoZ]Cf0ol0000:oj[Kn@?o00002_nYhOX3o`0001co
oo]Z1_l0000:oookJP?o001o0ooonfX3o`00ObKooo]Z0015oookJPGo00005ooonfX3o`0000?oYkkZ
00?o0000ojNnj_nW_^X01_nW_^X00ol0003oYkkZojNnjP03ojNnjP?o00000_nW^nP00ol0003oYk[W
ojNji`08ojNji`03o`000?nW^^OoYk[W00?oYk[W0ol000000onV]nGo0000ojJgi@09ojJgi@03o`00
0?nV]^CoY[KT00GoY[KT0ol0000:ojJchP03o`000?nV/n;oY[?R00OoY[?R00?o0000ojJch_l00000
0_l00005ojFah@03o`000?nU/N3oYK7P00OoYK7P00?o0000ojF`h?nU/>000onU/>03o`000003ojF_
gol0003oYJoO00[oYJoO00?o0000ojF_gonU[ml01_nU[ml00ol0003oYJoNo`000002o`0000GoYJkN
00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP02ojF^gPCo000000?oYJkNo`000?nU[]h0
2OnU[]h00ol0003oYJkNojF^gP07ojF^gP03o`000?nU[]koYJkN00?o00001OnU/=l00ol0003oYK3O
ojF`g`07ojF`g`03o`000?nU/=ooYK3O00CoYK3O0ol000000onV/^7o0000ojJbh@09ojJbh@03o`00
0?nV/^7oY[;Q00OoY[;Q0ol00008ojNfh`03o`000?nW]^CoYkKT00SoYkKT00Co0000ojNgi?l0003o
00001onX^^H00ol0003oZ;_WojRki`08ojRki`?o00002OnY`>X00ol0003oZL7[ojW1j`07ojW1j`;o
00002onZanh00ol0003oZ/S_oj[8k`03o`0000KoZlgb00?o0000oj[>lonZc_<01?nZc_<3o`0000;o
Zm?e00Co0000oj[Dm_nZe?Ko00001OnZe?H2o`0000;oZm[h00?o0000oj[KnOnZfoT01_nZfoT2o`00
00?oZ]oj00?o0000ojWQn_nYhOX01?nYhOX3o`0000?oZ>Ck00?o0000oookJ_oonfX06_oonfX6o`00
00Wooo]Z0ol007l3oookJP?o001o9_oonfX004Gooo]Z1Ol0000DoookJP?o00001onW_^X00ol0003o
YkkZojNnjP06ojNnjP03o`000?nW_^[o000000;o00001_nW^nP00ol0003oYk[WojNji`08ojNji`03
o`000?nW^^Oo000000;o00001OnV]nD00ol0003oY[OUojJgi@08ojJgi@03o`000?nV]^CoY[KT00Co
00000onV]><00ol0003oY[?RojJchP08ojJchP03o`000?nV/n;oY[?R00GoY[?R0ol00009ojFah@03
o`000?nU/N3oYK7P00OoYK7P00?o0000ojF`h?l000000_l00005ojF_g`03o`000?nU[mooYJoO00So
YJoO00?o0000ojF_gonU[ml01OnU[ml3o`0000WoYJkN00?o0000ojF^g_nU[]h02?nU[]h5o`0000Go
YJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP06ojF^gP?o00002?nU/=l00ol0003o
YK3OojF`g`08ojF`g`03o`000?nU/=ooYK3O00?o00001OnV/^400ol0003oY[;QojJbh@07ojJbh@03
o`000?nV/^7oY[;Q00CoY[;Q0ol000000onW]N?o0000ojNfh`09ojNfh`03o`000?nW]^CoYkKT00Oo
YkKT0_l0000:ojRjiP03o`000?nX^nOoZ;_W00GoZ;_W0_l000000onY_nWo0000ojW0jP09ojW0jP03
o`000?nY`N_oZL7[00CoZL7[0ol00002oj[6kP03o`000?nZankoZ/O^00SoZ/O^0ol0000:oj_=lP03
o`000?nZc_?oZ/kc00?o00001_n[doD01Ol0003oZ]Cfoj[Dm_l0003oZ]Cf00?o00001On[f_P00ol0
003oZ]_ioj[Kn@02oj[Kn@?o00001_nZgoX00ol0003oZN7jojWQnP03o`0000KoZ>Ck0ol0000Joook
JPKo00002OoonfX3o`00O`?ooo]Z0ol007lVoookJP00AOoonfX5o`0001;ooo]Z0ol0000:ojNnjP03
o`000?nW_^[oYkkZ00CoYkkZ1?l00009ojNkj003o`000?nW^^OoYk[W00OoYk[W0_l00009ojJgi@03
o`000?nV]nGoY[OU00OoY[OU0ol00008ojJdh`03o`000?nV/n;oY[?R00SoY[?R00?o0000ojJch_nV
/n801?l00002ojFah@03o`000?nU/N7oYK7Q00SoYK7Q00?o0000ojFah?nU/N001_nU/N02o`0000Wo
YJoO00?o0000ojF_gonU[ml02?nU[ml00ol0003oYJoOojF_g`04o`0000;oYJkN00?o0000ojF^g_nU
[]h02?nU[]h00ol0003oYJkNojF^gP05ojF^gPCo00002OnU[]h00ol0003oYJkNojF^gP07ojF^gP03
o`000?nU[]koYJkN00?oYJkN0ol000000onU[moo0000ojF`g`09ojF`g`03o`000?nU/=ooYK3O00Oo
YK3O0ol00008ojJbh@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojJbhOnV/^400ol00005ojNeh`03
o`000?nW]^?oYkKS00SoYkKS00?o0000ojNfi?nW]^@00onW]^@3o`000003ojRji_l0003oZ;[V00[o
Z;[V00Co0000ojRkionX^nOoZ;_W0ol00004ojVoj@03o`000?nY`>[oZL3Z00SoZL3Z00?o0000ojW1
jonY`N/00ol00006oj[6kP03o`000?nZankoZ/O^00GoZ/O^0_l00002oj_<l@03o`000?n[cO;oZlgb
00SoZlgb0ol0000:oj_Cm@04o`000?nZe?Ko0000o`0000WoZm[h00Co0000oj[KnOl0003o00002OnZ
goX3o`0000OoZ>Ck0_l00003ojSWnP03o`000?oonf[ooo]Z01Sooo]Z1_l00009oookJPOo001o9ooo
nfX004Gooo]Z1?l0000@oookJP?o00000onW_nX00ol0003oYkkZojNnjP08ojNnjP03o`000?nW_^[o
YkkZ00?o00001?nW^nP00ol0003oYk_XojNkj007ojNkj003o`000?nW^^OoYk[W00?oYk[W0ol00000
0onV^>Ko0000ojJgi@09ojJgi@03o`000?nV]nGoY[OU00?oY[OU0ol000000onV]>?o0000ojJdh`09
ojJdh`03o`000?nV/n;oY[?R00OoY[?R0ol00007ojFah@03o`000?nU/N7oYK7Q00OoYK7Q00?o0000
ojFah?nU/N000onU/N03o`000003ojF_gol0003oYJoO00WoYJoO00?o0000ojF_gonU[ml01onU[ml3
o`0000OoYJkN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP02ojF^gPGo000000?oYJkN
o`000?nU[]h02?nU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]ko000000;o00001OnU[ml0
0ol0003oYK3OojF`g`08ojF`g`03o`000?nU/=ooYK3O00?oYK3O0ol000000onV/N7o0000ojJbh@09
ojJbh@03o`000?nV/^7oY[;Q00OoY[;Q0ol00008ojNeh`03o`000?nW]^?oYkKS00SoYkKS00?o0000
ojNfi?nW]^@00ol00005ojRjiP03o`000?nX^^KoZ;[V00SoZ;[V00Co0000ojRkiol0003o00002?nY
_nT00ol0003oZL3ZojW0jP07ojW0jP?o00002_nZa^h00ol0003oZ/O^oj[7kP02oj[7kP;o00001On[
c?400ol0003oZlgboj_=lP05oj_=lP;o00000_n[d_@00ol0003oZm?eoj_Cm@08oj_Cm@Co00002On[
f_P3o`0000SoZ]oj0_l00002ojWSnP03o`000?nXi?_oZ>Ck00;oZ>Ck0ol00005ojSWnP?o00006Ooo
nfX5o`0000Wooo]Z1ol007lWoookJP00AOoonfX5o`0000cooo]Z0ol00007ojNojP03o`000?nW_^[o
YkkZ00OoYkkZ0ol00008ojNkj003o`000?nW^nSoYk_X00OoYk_X00?o0000ojNjiol000000_l00005
ojJhiP03o`000?nV]nGoY[OU00SoY[OU00?o0000ojJgiOl000000_l00005ojJdh`03o`000?nV]>?o
Y[CS00SoY[CS00?o0000ojJch_nV/n800onV/n83o`000003ojFbhOl0003oYK7Q00SoYK7Q00?o0000
ojFahOnU/N401onU/N400ol0003oYK7Po`000002o`0000GoYJoO00?o0000ojF_gonU[ml02?nU[ml0
0ol0003oYJoOojF_g`03ojF_g`?o000000?oY:kOo`000?nU[]h02?nU[]h00ol0003oYJkNojF^gP07
ojF^gPKo00001OnU[]h00ol0003oYJkNojF^gP07ojF^gP03o`000?nU[]koYJkN00OoYJkN0_l00009
ojF_g`03o`000?nU/=ooYK3O00OoYK3O00?o0000ojF`gonU/=l00ol00005ojJah@03o`000?nV/^7o
Y[;Q00SoY[;Q00?o0000ojJbhOnV/^400onV/^43o`000003ojNdhol0003oYkGS00WoYkGS00?o0000
ojNfhonW]^<01onW]^<3o`0000WoZ;[V00?o0000ojRji_nX^^H01onX^^H2o`0000[oZKoY00?o0000
ojW0j_nY`>X01?nY`>X3o`0000;oZ/G]00?o0000oj[6k_nZa^h02OnZa^h01?l0003oZ/O^o`000?l0
0008oj_<l@03o`000?n[cO;oZlgb00;oZlgb0_l00005oj_Bm003o`000?n[doGoZm?e00CoZm?e0ol0
0003oj_Hm`;o00001On[f_P3o`0000?oZmki00?o0000oj[On_nZgoX00_nZgoX3o`0000GoZN?j00Co
0000ojSTnol0003o00001_nXioX2o`0000?oYn[j0_l0000GoookJPKo00001ooonfX3o`00O`?ooo]Z
0ol007lVoookJP00AOoonfX4o`0000_ooo]Z0ol0000:ojNojP03o`000?nW_^[oYkkZ00?oYkkZ0ol0
00000onW_>Wo0000ojNkj009ojNkj003o`000?nW^nSoYk_X00GoYk_X0ol00009ojJhiP03o`000?nV
]nGoY[OU00OoY[OU0_l00009ojJdh`03o`000?nV]>?oY[CS00SoY[CS00?o0000ojJch_l000000_l0
0005ojFbh@03o`000?nU/N7oYK7Q00OoYK7Q00?o0000ojFahOnU/N401OnU/N43o`0000WoYJoO00?o
0000ojF_gonU[ml02?nU[ml00ol0003oYJoOo`000002o`0000GoY:kO00?o0000ojF^g_nU[]h01onU
[]h00ol0003oYJkNojF^gP04ojF^gPGo00002OnU[]h00ol0003oYJkNojF^gP06ojF^gP03o`000?nU
[]koYJkN00CoYJkN0ol000000onU[moo0000ojF_g`09ojF_g`03o`000?nU/=ooYK3O00KoYK3O0ol0
0009ojJah@03o`000?nV/^7oY[;Q00OoY[;Q00?o0000ojJbhOnV/^400ol00005ojNdh`03o`000?nW
]N?oYkGS00SoYkGS00?o0000ojNfhonW]^<00onW]^<3o`000003ojRiiOl0003oZ;[V00WoZ;[V00?o
0000ojRji_nX^^H01?nX^^H3o`0000;oZKkY00?o0000ojVojOnY_nT02?nY_nT00ol0003oZL3ZojW0
jP03o`0000KoZ/G]00?o0000oj[6k_nZa^h02?nZa^h2o`0000_oZlca00Co0000oj_=l_l0003o0000
2?n[d_@00ol0003oZm?eoj_Cm@03o`0000OoZmSg0_l000001?n[f_So0000o`000?l00007oj_Nn@04
o`000?nZgo[o0000o`0000SoZN?j0ol00004ojSWnP?o00001_nWj_X3o`0001Kooo]Z1_l00006oook
JP?o001o0ooonfX3o`00ObKooo]Z0014oookJPGo00002?oonfX3o`0000?oYko[00?o0000ojNoj_nW
_nX02?nW_nX00ol0003oYkkZo`000002o`0000GoYkcY00?o0000ojNkj?nW^nP02?nW^nP00ol0003o
Yk_XojNkj004o`0000?oY[WV00?o0000ojJhi_nV^>H01onV^>H00ol0003oY[OUojJgi@03ojJgi@?o
000000?oYKGTo`000?nV]><02OnV]><00ol0003oY[CSojJdh`07ojJdh`;o00002OnU/^400ol0003o
YK7QojFah@07ojFah@03o`000?nU/N7oYK7Q00Co00000_nU/>000ol0003oYJoOojF_g`08ojF_g`03
o`000?nU[mooYJoO00OoYJoO0_l00009ojB^g`03o`000?nU[]koYJkN00KoYJkN00?o0000ojF^g_nU
[]h00_nU[]h4o`000003ojF^g_l0003oYJkN00[oYJkN00?o0000ojF^g_nU[]h01_nU[]h00ol0003o
YJkNojF^gP03o`0000GoYJoO00?o0000ojF_gonU[ml01onU[ml00ol0003oYK3OojF`g`03ojF`g`?o
000000?oY[7Po`000?nV/N402_nV/N400ol0003oY[;QojJbh@06ojJbh@?o00002OnW]><00ol0003o
YkGSojNeh`07ojNeh`03o`000?nW]^?oYkKS00?o00001OnX^ND00ol0003oZ;[VojRjiP08ojRjiP03
o`000?nX^^KoZ;[V00?o00001_nY_^T00ol0003oZKoYojVoj@07ojVoj@?o00002_nZaNd00ol0003o
Z/K^oj[6kP04oj[6kP?o00000_n[bo000ol0003oZlcaoj_<l@08oj_<l@;o00002_n[d_@3o`0000[o
ZmSg0ol0000:oj_Nn@;o00002?nYhoX2o`0000?oZNOj00Co0000ojSWn_l0003o00001onWj_X2o`00
00?oYnci00?o0000oookJ_oonfX04ooonfX6o`0000Kooo]Z0ol007l3oookJP?o001o9_oonfX004Co
oo]Z1Ol00006oookJP;o00001onW_n/00ol0003oYkoZojNojP07ojNojP;o00002OnW_>T00ol0003o
Yk_XojNkj007ojNkj0?o00002?nV^NH00ol0003oY[SVojJhiP07ojJhiP03o`000?nV]nGo000000;o
00001OnU]N@00ol0003oY[CSojJdh`08ojJdh`03o`000?nV]>?oY[CS00?oY[CS0ol000000onU/^;o
0000ojFbh@09ojFbh@03o`000?nU/N7oYK7Q00KoYK7Q0ol00007ojF`h003o`000?nU[mooYJoO00Oo
YJoO00?o0000ojF_gonU[ml01?nU[ml3o`000003ojB_gol0003oY:kO00WoY:kO00?o0000ojF^g_nU
[]h01_nU[]h5o`0000GoYJkN00?o0000ojF^g_nU[]h02?nU[]h00ol0003oYJkNojF^gP05ojF^gPCo
00002?nU[ml00ol0003oYJoOojF_g`08ojF_g`03o`000?nU/=oo000000;o00001OnV/N000ol0003o
Y[7QojJah@08ojJah@03o`000?nV/^7oY[;Q00?oY[;Q0ol000000onW]>;o0000ojNdh`0:ojNdh`03
o`000?nW]N?oYkGS00KoYkGS0ol00009ojRii@03o`000?nX^^KoZ;[V00OoZ;[V0ol0000:ojVnj@03
o`000?nY_nWoZKoY00?oZKoY0ol00002oj[3k003o`000?nZaNgoZ/G]00WoZ/G]00?o0000oj[6k_nZ
a^h00ol00006oj_;l003o`000?n[c?7oZlca00CoZlca0ol000000on/dO?o0000oj_Bm007oj_Bm0;o
00000_n/eoH00ol0003oZmSgoj_Hm`06oj_Hm`;o00000_n/gOT2o`0000KoZmki0ol00002oj_RnP03
o`000?nYho[oZN?j00;oZN?j0ol00005ojWWnP?o00001OnWj_X3o`0000GoYnci0ol0000DoookJPKo
00001_oonfX7o`00ObOooo]Z0014oookJPGo00000ooonfX3o`0000[oYko[00?o0000ojNoj_nW_nX0
0onW_nX3o`0000;oYkgY00?o0000ojNljOnW_>T01onW_>T00ol0003oYk_XojNkj003ojNkj0?o0000
0_nV^NL00ol0003oY[WVojJiiP07ojJiiP03o`000?nV^>KoY[SV00KoY[SV0_l00009ojFei003o`00
0?nV]>?oY[CS00SoY[CS00?o0000ojJdhol000000_l00005ojFbhP03o`000?nU/^7oYK;Q00OoYK;Q
00?o0000ojFahOnU/N400onU/N43o`000003ojB`h?l0003oYK3P00SoYK3P00?o0000ojF_gonU[ml0
1onU[ml00ol0003oYJoOojF_g`03o`0000GoY:oO00?o0000ojB^gonT[]l01onT[]l00ol0003oYJkN
ojF^gP04ojF^gPCo00002OnU[]h00ol0003oYJkNojF^gP08ojF^gP03o`000?nU[]koYJkN00Co0000
0_nU[ml00ol0003oYJoOojF_g`08ojF_g`03o`000?nU[mooYJoO00OoYJoO0_l00009ojJah003o`00
0?nV/N7oY[7Q00SoY[7Q00?o0000ojJbhOl000000_l00005ojNdhP03o`000?nW]>?oYkCS00SoYkCS
00?o0000ojNehonW]N<00onW]N<3o`000003ojRhiOl0003oZ;WU00[oZ;WU00?o0000ojRji_nX^^H0
0onX^^H3o`0000;oZKgX00?o0000ojVnjOnY_^T02OnY_^T00ol0003oZKoYo`000002o`0000KoZ/?/
00?o0000oj[5kOnZaNd02?nZaNd3o`0000[oZl_`00?o0000oj_<lOn[c?400ol00005ojcAl`03o`00
0?n[d_CoZm;d00;oZm;d0ol00005ojcGmP03o`000?n[f?OoZmSg00;oZmSg0ol00005ojcMn@;o0000
0_n[g_T3o`0000KoZn;j00Co0000ojWSn_l0003o00001_nYioX2o`0000?oZNWj0_l000000onWj_[o
0000o`000006ojO/n@;o00000onWkOP00ol0003ooo]ZoookJP0BoookJPKo00001_oonfX5o`00ObSo
oo]Z0014oookJPSo00000onW`>/00ol0003oYko[ojNoj`08ojNoj`03o`000?nW_n[o000000;o0000
1_nW_NT00ol0003oYkcYojNlj@07ojNlj@03o`000?nW^nSo000000;o00001_nV^NL00ol0003oY[WV
ojJiiP07ojJiiP03o`000?nV^>KoY[SV00;oY[SV0ol00002ojFfi@03o`000?nU]NCoYKGT00OoYKGT
00?o0000ojJdhonV]><01onV]><2o`0000WoYK;R00?o0000ojFbhOnU/^401onU/^400ol0003oYK7Q
o`000002o`0000GoY;3P00?o0000ojF`h?nU/>001onU/>000ol0003oYJoOojF_g`06ojF_g`?o0000
2OnT[ml00ol0003oY:kOojB^g`07ojB^g`03o`000?nU[]koYJkN00Co00000_nT[]h00ol0003oYJkN
ojF^gP08ojF^gP03o`000?nU[]koYJkN00OoYJkN0ol00007ojF_g`03o`000?nU[mooYJoO00SoYJoO
00?o0000ojF_gonU[ml00onU[ml3o`000003ojJah?l0003oY[7P00WoY[7P00?o0000ojJahOnV/N40
1onV/N42o`0000WoYkCR00?o0000ojNdhonW]><02?nW]><00ol0003oYkGSo`000002o`0000GoZ;SU
00?o0000ojRiiOnX^ND02OnX^ND00ol0003oZ;[Vo`000002o`0000KoZKgX00?o0000ojVnjOnY_^T0
2?nY_^T2o`0000[oZ/?/00?o0000oj[5kOnZaNd01?nZaNd3o`0000;oZlW_00?o0000oj_;l?n[bo00
2?n[bo03o`0000Wo[=7c00Co0000oj_Bm?l0003o00002On/eoH01?l0003oZmSgo`000?l00008ojcM
n@Co00002On[h_X3o`0000GoZNOj0_l00006ojWYnP?o00001?nWk?T3o`0000GoYngh0ol0000Boook
JPKo0000<ooonfX004Cooo]Z1?l00008ojO0j`03o`000?nW_n_oYko[00OoYko[0_l0000:ojNmj@03
o`000?nW_>WoYkcY00KoYkcY0_l0000:ojJii`03o`000?nV^NKoY[WV00OoY[WV00Co0000ojJhi_l0
003o00001_nU]^D00ol0003oYKGTojFei007ojFei003o`000?nV]>?oY[CS00?oY[CS0ol000000onU
/n?o0000ojFbhP09ojFbhP03o`000?nU/^7oYK;Q00KoYK;Q0_l00009ojB`h003o`000?nU/>3oYK3P
00KoYK3P00?o0000ojF_gonU[ml00onU[ml3o`000003ojB_gol0003oY:oO00[oY:oO00?o0000ojB^
gonT[]l01_nT[]l3o`0000OoY:kN00?o0000ojF^g_nU[]h01onU[]h00ol0003oYJkNojF^gP04ojF^
gP?o000000?oYJoOo`000?nU[ml02?nU[ml00ol0003oYJoOojF_g`07ojF_g`03o`000?nU[mooYJoO
00?o00001OnV/N000ol0003oY[7PojJah007ojJah003o`000?nV/N7oY[7Q00CoY[7Q0ol000000onV
/n;o0000ojNdhP09ojNdhP03o`000?nW]>?oYkCS00OoYkCS0_l00009ojRhi@03o`000?nX^NGoZ;WU
00SoZ;WU0_l0000:ojVmj003o`000?nY_^WoZKkY00CoZKkY0ol000000onZ`^_o0000oj[3k00:oj[3
k003o`000?nZaNgoZ/G]00?o00001_n[bNl00ol0003oZl_`oj_;l004oj_;l0?o00000_n/co<00ol0
003o[=7cojcAl`07ojcAl`?o00002_n/eoH3o`0000So[=gi0ol000000on/hOWo0000oj_RnP05oj_R
nP?o00000on[i_X2o`000003ojWWn_l0003o000000KoZNWj0_l00003ojW[n@04o`000?nWk?Wo0000
o`0000KoYngh0_l00003ojO^n003o`000?oonf[ooo]Z013ooo]Z1_l0000boookJP00A?oonfX4o`00
00WoYl3[00?o0000ojNojonW_n/00onW_n/3o`0000;oYkkZ00?o0000ojNmjOnW_NT02?nW_NT00ol0
003oYkcYojNlj@02ojNlj@?o00000_nV^^P00ol0003oY[WWojJii`08ojJii`03o`000?nV^NKoY[WV
00GoY[WV0ol00009ojFfi@03o`000?nU]NCoYKGT00OoYKGT00?o0000ojJdhol000000_l00005ojFc
h`03o`000?nU/^;oYK;R00OoYK;R00?o0000ojFbhOnU/^400onU/^43o`000003ojB`hOl0003oY;3P
00WoY;3P00?o0000ojF`h?nU/>001_nU/>000ol0003oYJoOo`000002o`0000GoY:oO00?o0000ojB_
gonT[ml02?nT[ml00ol0003oY:kOojB^g`03ojB^g`?o000000?oY:kOo`000?nT[]h02?nT[]h00ol0
003oYJkNojF^gP07ojF^gP03o`000?nU[]koYJkN00?o00001OnU[ml00ol0003oYJoOojF_g`07ojF_
g`03o`000?nU[mooYJoO00KoYJoO0ol00009ojJah003o`000?nV/N3oY[7P00OoY[7P00?o0000ojJa
hOnV/N400ol00005ojJchP03o`000?nW]>;oYkCR00OoYkCR00?o0000ojNdhonW]><01?nW]><3o`00
0003ojNgi?l0003oZ;SU00WoZ;SU00?o0000ojRiiOnX^ND01?nX^ND3o`000003ojVliol0003oZKgX
00[oZKgX00?o0000ojVnjOnY_^T00ol00005oj[2j`03o`000?nZ`ncoZ/?/00SoZ/?/0ol0000:oj_9
k`03o`000?n[bo3oZl_`00?o00001_n/co<00ol0003o[=7cojcAl`03ojcAl`?o00000on/e_H00ol0
003o[=OfojcGmP04ojcGmP?o00000on/foP00ol0003o[=giojcMn@02ojcMn@?o00000on/hOT00ol0
003o[>7io`000002oj_RnP?o00001on[i_X3o`0000CoZNWj0ol00005ojW[n@?o00001?nWkOP3o`00
00GoYnkh1?l0000@oookJPKo0000<OoonfX000_ooo]Z0ol007l01?oonf[o001oo`00Ool007l4oook
JPCo001o7?oonfX5o`00O`Sooo]Z1_l00009ojO0j`03o`000?nW_n_o000000;o00001_nW_^X00ol0
003oYkgYojNmj@08ojNmj@04o`000?nW_>Wo0000o`0000KoY[[X00?o0000ojJiionV^NL02?nV^NL0
0ol0003oY[WVojJiiP04o`0000;oYKOU00?o0000ojFfiOnU]^D02?nU]^D00ol0003oYKGTojFei005
ojFei0?o00002OnU/n<00ol0003oYK;RojFbhP07ojFbhP03o`000?nU/^7o000000;o00001OnT/>40
0ol0003oY;3PojB`h007ojB`h003o`000?nU/>3oYK3P00GoYK3P0ol00009ojB_g`03o`000?nT[moo
Y:oO00SoY:oO00?o0000ojB^gol000000_l00005ojB^g`03o`000?nT[]koY:kN00OoY:kN00?o0000
ojF^g_nU[]h01_nU[]h3o`0000WoYJoO00?o0000ojF_gonU[ml01_nU[ml00ol0003oYJoOojF_g`03
ojF_g`?o000000?oYK3Po`000?nV/N002_nV/N000ol0003oY[7PojJah006ojJah0?o00002?nV/n80
0ol0003oYkCRojNdhP08ojNdhP03o`000?nW]>?oYkCS00?o00001OnW]n@00ol0003oZ;SUojRhi@08
ojRhi@03o`000?nX^NGoZ;WU00?o00001OnY_>L00ol0003oZKgXojVmj008ojVmj0?o00002OnZ`^/0
0ol0003oZ/?/oj[3k004oj[3k0?o000000?oZlS_o`000?n[bNl02_n[bNl3o`0000[o[<oc00?o0000
ojcAlol000000_l00007ojcFmP03o`000?n/eoKo[=Of00?o00001on/foP01?l0003o[=gio`000?l0
0007ojcQn@Co00002?n[i_X2o`0000?oZnSj00Co0000ojWYn_l0003o00001_nYjoT2o`0000?oZNgi
00Co0000ojO]n?l0003o00001_nWk_P2o`0000?oZ>og0ol0000>oookJPKo0000<OoonfX000[ooo]Z
2?l007l3oookJPGo001o6ooonfX7o`00O`Oooo]Z1Ol000000ooonf[o0000ojO0j`07ojO0j`?o0000
2OnW_^X00ol0003oYkgYojNmj@07ojNmj@;o00002OnV^^P00ol0003oY[WWojJii`07ojJii`?o0000
1onU]nD00ol0003oYKKUojFfi@08ojFfi@03o`000?nU]NCoYKGT00Co00000_nT/n<00ol0003oYK?S
ojFch`08ojFch`03o`000?nU/^;oYK;R00GoYK;R0ol00009ojB`h@03o`000?nT/>3oY;3P00OoY;3P
00?o0000ojF`h?nU/>001?l00002ojB_g`03o`000?nT[mooY:oO00SoY:oO00?o0000ojB_gonT[ml0
1_nT[ml3o`0000WoY:kO00?o0000ojB^g_nT[]h01_nT[]h00ol0003oYJkNojF^gP03ojF^gP?o0000
00?oYJoOo`000?nU[ml02_nU[ml00ol0003oYJoOojF_g`06ojF_g`03o`000?nU[moo000000;o0000
1OnU/>000ol0003oY[7PojJah008ojJah003o`000?nV/N3oY[7P00?oY[7P0ol000000onV/n7o0000
ojJchP09ojJchP03o`000?nW]>;oYkCR00OoYkCR0ol00009ojNgi003o`000?nX^>GoZ;SU00OoZ;SU
0ol00009ojVli`03o`000?nY_NSoZKgX00CoZKgX0ol000000onZ`N_o0000oj[2j`0:oj[2j`03o`00
0?nZ`ncoZ/?/00?o00001On[b>l00ol0003oZlW_oj_9k`06oj_9k`;o000000?o[<kbo`000?n/co<0
2_n/co<2o`0000[o[=Kf0ol0000:ojcKn0?o00001on/hOT2o`0000?o[>Cj00?o0000oj_Vn_n[i_X0
0_n[i_X3o`0000GoZnSj0ol00004ojW[n@?o00001OnYkOT3o`0000CoYnkh0ol00003ojS_m`;o0000
0onYkoL00ol0003ooo]ZoookJP0<oookJPKo0000<?oonfX000Wooo]Z1?l007l00ooonf[o001oo`00
O`02o`00O`?ooo]Z0ol007lMoookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX5o`0000;ooo]Z
00?o0000ojO0jonW`>/00_nW`>/3o`0000?oY/3/00?o0000ojNnj_nW_^X01onW_^X00ol0003oYkgY
ojNmj@03ojNmj@?o000000?oY[cYo`000?nV^^P02OnV^^P00ol0003oY[WWojJii`03ojJii`?o0000
00?oYKSVo`000?nU]nD02?nU]nD00ol0003oYKKUojFfi@07ojFfi@?o00001onT/n<00ol0003oYK?S
ojFch`08ojFch`03o`000?nU/^;oYK;R00Co00000_nT/N400ol0003oY;3QojB`h@08ojB`h@03o`00
0?nT/>3oY;3P00KoY;3P0ol00007ojB_g`03o`000?nT[mooY:oO00OoY:oO00?o0000ojB_gonT[ml0
1?nT[ml3o`000003ojB^gol0003oY:kO00SoY:kO00?o0000ojB^g_nT[]h01onT[]h00ol0003oYJkN
o`000002o`0000GoYJoO00?o0000ojF_gonU[ml02?nU[ml00ol0003oYJoOojF_g`05ojF_g`?o0000
2OnU/>000ol0003oY[7PojJah008ojJah003o`000?nV/N3o000000;o00001OnV/n400ol0003oY[?R
ojJchP08ojJchP03o`000?nW]>;oYkCR00?oYkCR0ol000000onW]nCo0000ojNgi009ojNgi003o`00
0?nX^>GoZ;SU00CoZ;SU0ol000000onY^nOo0000ojVli`0:ojVli`03o`000?nY_NSoZKgX00?o0000
1OnZ`N/00ol0003oZ/;[oj[2j`08oj[2j`?o00002On[b>l00ol0003oZlW_oj_9k`02oj_9k`?o0000
1?n/c_800ol0003o[<ocojc?l`06ojc?l`;o00000_n]e?@00ol0003o[=KfojcFmP05ojcFmP;o0000
0_n]f_L00ol0003o[=_hojcKn006ojcKn0;o00000on]goT00ol0003o[>7iojcQn@02ojcQn@;o0000
0_n/i?X01_l0003o[>CjojcTn_n/i?[o0000oj_VnP;o00001_n[j?X2o`0000?oZn_i00Co0000ojW[
nOl0003o00001_nYkOT2o`0000?oZNkh00Co0000ojO^n?l0003o00000onXkoL3o`0000GoZNog1?l0
000<oookJPKo0000;ooonfX000Wooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Oacooo]Z0ol007l3
oookJP?o001o1_oonfX5o`0000?ooo]Z00Co0000ojO0jol0003o00001onV`>`00ol0003oYkkZojNn
jP07ojNnjP03o`000?nW_NWo000000;o00001OnV_>T00ol0003oY[[XojJjj008ojJjj003o`000?nV
^NOo000000;o00001OnU^>H00ol0003oYKOUojFgi@07ojFgi@03o`000?nU]^GoYKKU00?oYKKU0ol0
00000onT]>Co0000ojBch`08ojBch`03o`000?nU/n?oYK?S00OoYK?S0ol00007ojBah@03o`000?nT
/>7oY;3Q00OoY;3Q00?o0000ojB`h?nT/>000onT/>03o`000003ojB_h?l0003oY:oO00SoY:oO00?o
0000ojB_gonT[ml01onT[ml00ol0003oY:oOojB_g`03o`0000GoY:kO00?o0000ojB^gonT[]l01onT
[]l00ol0003oY:kNojB^gP06ojB^gP;o00002OnU[ml00ol0003oYJoOojF_g`08ojF_g`03o`000?nU
[mooYJoO00Co00000_nU/=l00ol0003oYK3PojF`h008ojF`h003o`000?nV/N3oY[7P00OoY[7P0_l0
0009ojJch@03o`000?nV/n;oY[?R00OoY[?R00?o0000ojNdh_nW]>800ol00005ojNgi003o`000?nW
]nCoYkOT00SoYkOT00?o0000ojRhiOnX^>D00ol00005ojVki`03o`000?nY_>OoZKcW00SoZKcW0ol0
0009oj[1j`03o`000?nZ`^_oZ/;[00GoZ/;[0_l000000on[anko0000oj_8k`0:oj_8k`04o`000?n[
bNoo0000o`0000So[<kb00?o0000ojc?lon/co<00_n/co<3o`0000Go[MCd00?o0000ojcFm_n/e_H0
0_n/e_H2o`0000Go[M[g00?o0000ojcKn?n/foP00_n/foP3o`0000Ko[Moi00Co0000ojcQnOl0003o
00001On/i?X00ol0003o[>CjojcTnP03o`0000CoZnSj0ol00005oj_[n@?o00001OnYkOT2o`0000Go
ZNkh1?l000000onXkoOo0000o`000006ojW_m`;o00000onZkoL3o`0000[ooo]Z1_l0000_oookJP00
2OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o7?oonfX3o`00O`?ooo]Z0ol007l6oookJPCo0000
1OoonfX2o`0000WoY/3/00?o0000ojNnj_nW_^X01OnW_^X4o`0000SoY[cY00?o0000ojJjj?nV^^P0
1onV^^P2o`0000WoYKSV00?o0000ojFgiOnU]nD01onU]nD00ol0003oYKKUo`000002o`0000GoY;CT
00?o0000ojBchonT/n<01onT/n<00ol0003oYK?SojFch`03ojFch`?o000000?oY;7Ro`000?nT/N40
2?nT/N400ol0003oY;3QojB`h@07ojB`h@03o`000?nT/>3o000000;o00001OnT[n000ol0003oY:oO
ojB_g`07ojB_g`03o`000?nT[mooY:oO00KoY:oO0ol00009ojB^g`03o`000?nT[]ooY:kO00KoY:kO
00?o0000ojB^g_nT[]h00onT[]h3o`000003ojB^gol0003oYJoO00WoYJoO00?o0000ojF_gonU[ml0
1onU[ml3o`0000OoYK3O00?o0000ojF`h?nU/>001onU/>000ol0003oY[7PojJah004ojJah0?o0000
00?oY[;Qo`000?nV/n402OnV/n400ol0003oY[?RojJchP06ojJchP?o00002OnW]n@00ol0003oYkOT
ojNgi007ojNgi0?o00002OnY^nL00ol0003oZKcWojVli`05ojVli`;o000000?oZ/3Zo`000?nZ`N/0
2OnZ`N/00ol0003oZ/;[oj[2j`02oj[2j`?o00001?n[anh00ol0003oZlS_oj_8k`08oj_8k`;o0000
2on/c_801?l0003o[<oco`000?l00009ojgDm004o`000?n/e_Ko0000o`0000So[M[g00Co0000ojcK
n?l0003o00002On]goT2o`0000So[>Cj0_l00003ojcWn@04o`000?n[j?[o0000o`0000KoZn_i0_l0
0003oj_]n@;o000000?oZNgio`000?l000001OnYk_P2o`0000?oZ^og0ol00005ojW_m`;o00000onZ
koL2o`0000?oZnog00?o0000oookJ_oonfX02?oonfX6o`0002kooo]Z0009oookJP?o001o0ooonfX3
o`00O`?ooo]Z0ol007lLoookJP?o001o0ooonfX3o`00O`Kooo]Z1?l00007oookJP03o`000?nV`>co
Y/3/00OoY/3/00?o0000ojNnj_nW_^X01?l00004ojFmj`03o`000?nV_>WoY[cY00KoY[cY00?o0000
ojJjj?nV^^P00onV^^P3o`0000;oY;WX00?o0000ojFhi_nU^>H01onU^>H00ol0003oYKOUojFgi@05
ojFgi@?o00002OnT]>@00ol0003oY;?SojBch`07ojBch`03o`000?nU/n?o000000;o00001OnT/N80
0ol0003oY;7QojBah@07ojBah@03o`000?nT/>7oY;3Q00GoY;3Q0ol00009ojB_h003o`000?nT[moo
Y:oO00KoY:oO00?o0000ojB_gonT[ml00onT[ml3o`000003ojB^gol0003oY:kO00[oY:kO00?o0000
ojB^gonT[]l01_nT[]l00ol0003oY:kNo`000002o`0000GoY:kO00?o0000ojF_gonU[ml01onU[ml0
0ol0003oYJoOojF_g`04ojF_g`?o000000?oYK3Oo`000?nU/=l02?nU/=l00ol0003oYK3PojF`h007
ojF`h003o`000?nV/N3oY[7P00?o00001OnV/^400ol0003oY[?QojJch@07ojJch@03o`000?nV/n;o
Y[?R00?oY[?R0ol000000onW]^?o0000ojNgi00:ojNgi003o`000?nW]nCoYkOT00?oYkOT0ol00000
0onX^^Ko0000ojVki`09ojVki`03o`000?nY_>OoZKcW00;oZKcW0ol00004oj[0jP03o`000?nZ`N_o
Z/7[00SoZ/7[00Co0000oj[2jol0003o00002?n[anh00ol0003oZlS_oj_8k`04oj_8k`?o00000_n/
c?400ol0003o[<kbojc>lP08ojc>lP;o00002on]e?@2o`0000[o[M[g0ol00008ojgOn@;o00000_n]
hoT00ol0003o[>CjojcTnP02ojcTnPCo00001?n/ioT3o`0000GoZn_i0_l00006oj_]n@?o00001?nY
k_P2o`0000?oZ^og0_l00003oj__m`;o000000?oZNogo`000?l000000onZkoL2o`0000GoZnog0ol0
0009oookJPKo0000;OoonfX000Wooo]Z0ol007l3oookJP?o001o0ooonfX3o`00Oacooo]Z0ol007l3
oookJP?o001o1_oonfX4o`0000Sooo]Z00?o0000ojK0k?nV`>`01_nV`>`3o`0000WoYKg[00?o0000
ojJljOnV_>T01_nV_>T00ol0003oY[[Xo`000002o`0000KoY;WX00?o0000ojFhi_nU^>H01onU^>H0
0ol0003oYKOUojFgi@04o`0000;oY;GU00?o0000ojBdi?nT]>@02?nT]>@00ol0003oY;?SojBch`05
ojBch`?o00002OnT/N800ol0003oY;7QojBah@07ojBah@03o`000?nT/>7oY;3Q00Co00000_nT/>00
0ol0003oY:oPojB_h008ojB_h003o`000?nT[mooY:oO00KoY:oO00?o0000ojB_gol000000_l00005
ojB^g`03o`000?nT[]ooY:kO00SoY:kO00?o0000ojB^gonT[]l01OnT[]l3o`0000WoY:kO00?o0000
ojF_gonU[ml01onU[ml00ol0003oYJoOojF_g`03o`0000GoYK3O00?o0000ojF`gonU/=l01onU/=l0
0ol0003oYK3PojF`h005ojF`h0Co00002OnV/^400ol0003oY[?QojJch@07ojJch@03o`000?nV/n;o
000000;o00001OnW]^<00ol0003oYkOTojNgi009ojNgi003o`000?nW]nCo000000;o00001OnX^^H0
0ol0003oZK_WojVki`08ojVki`04o`000?nY_>Oo0000o`0000SoZ/3Z00?o0000oj[1jonZ`N/01onZ
`N/2o`0000_oZlO^00?o0000oj_8kon[b>l00ol00006ojc<l@03o`000?n/c_;o[<kb00Co[<kb0ol0
0002ojgBl`03o`000?n]e?Co[MCd00Ko[MCd0_l00002ojkHmP03o`000?n]f_Oo[M[g00Co[M[g0ol0
0003ojkNn003o`000?n]goWo[Moi00;o[Moi0ol00005ojgSn@04o`000?n/i?[o0000o`0000Co[>Oi
00Co0000ojcWnOl0003o00000on/j_T2o`000003oj_[nOl0003o000000KoZngi0_l00003oj_^n004
o`000?nYk_So0000o`0000?oZ^og0_l00006oj__m`Co000000?oZ^ogo`000?l000001On[koL2o`00
00?o[>kh00?o0000oookJ_oonfX01_oonfX6o`0002gooo]Z0009oookJPCo001o00?ooo]Zo`00Ool0
07l00_l007l3oookJP?o001o7?oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00002OoonfX00ol0003o
Y/3/ojK0k002ojK0k0?o00000onT_n`00ol0003oYKg[ojFmj`07ojFmj`03o`000?nV_>WoY[cY00Co
Y[cY1?l00009ojBij003o`000?nU^>KoYKSV00KoYKSV0ol00007ojBei@03o`000?nT]>CoY;CT00So
Y;CT00?o0000ojBchonT/n<01?l00002oj>bh`03o`000?nT/N;oY;7R00SoY;7R00?o0000ojBahOnT
/N401_nT/N43o`0000OoY;3P00?o0000ojB_h?nT[n001onT[n000ol0003oY:oOojB_g`05ojB_g`?o
00002OnT[]l00ol0003oY:kOojB^g`08ojB^g`03o`000?nT[]ooY:kO00Co00000_nT[]l00ol0003o
Y:kOojB^g`08ojB^g`03o`000?nU[mooYJoO00KoYJoO0ol00008ojF`g`03o`000?nU/=ooYK3O00So
YK3O00?o0000ojF`h?nU/>001?l00002ojJbh@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojJchOnV
/n401_nV/n43o`0000WoYkKS00?o0000ojNgi?nW]n@02?nW]n@2o`0000WoZ;[V00?o0000ojVkionY
^nL01onY^nL2o`0000[oZ/3Z00?o0000oj[1jonZ`N/01?nZ`N/3o`0000;oZlG]00?o0000oj_7k_n[
anh02?n[anh3o`0000[o[<ca00?o0000ojc>l_n/c_800ol00006ojgBl`03o`000?n]e?Co[MCd00;o
[MCd0ol00005ojkHmP03o`000?n]f_Oo[M[g00?o00001on^g_P01?l0003o[Moio`000?l00008ojgS
n@?o00001On/ioT2o`0000Ko[>[i0ol00004oj_]n@?o00001On[k_P4o`000003oj[_mol0003o0000
00KoZnog0_l00003ojc`m`;o00001?n[koL3o`0000Go[>kh0ol00007oookJPKo0000;?oonfX000[o
oo]Z2?l007l2oookJPKo001o6_oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00002_oonfX01?l0003o
Y/3/o`000?l00007ojBok003o`000?nU_N_oYKg[00OoYKg[00?o0000ojJljOnV_>T00ol00004ojBj
j@03o`000?nT^NSoY;WX00OoY;WX00?o0000ojFhi_nU^>H00_nU^>H3o`0000;oXkKV00?o0000ojBe
iOnT]ND01_nT]ND00ol0003oY;CTojBdi007ojBdi0?o00001onS/^<00ol0003oY;7RojBahP07ojBa
hP03o`000?nT/N7oY;7Q00?oY;7Q0ol000000onS/>7o0000ojB`h008ojB`h003o`000?nT[n3oY:oP
00OoY:oP00?o0000ojB_gonT[ml01?l00002ojB^g`03o`000?nT[]ooY:kO00SoY:kO00?o0000ojB^
gonT[]l01onT[]l3o`0000OoY:kO00?o0000ojB^gonT[]l01onT[]l00ol0003oYJoOojF_g`03ojF_
g`?o000000?oYJoOo`000?nU/=l02OnU/=l00ol0003oYK3OojF`g`07ojF`g`?o00001onV/^400ol0
003oY[;QojJbh@08ojJbh@03o`000?nV/n7oY[?Q00Go00000_nW]N<00ol0003oYkKSojNfh`08ojNf
h`03o`000?nW]nCoYkOT00CoYkOT0ol000000onX^NGo0000ojRjiP09ojRjiP03o`000?nY^nOoZK_W
00?oZK_W0ol00002ojZoj@03o`000?nZ`>[oZ/3Z00SoZ/3Z00?o0000oj[1jonZ`N/00ol00006oj_5
k@03o`000?n[ankoZlO^00CoZlO^0ol000000on/bo3o0000ojc<l@0:ojc<l@?o00002_n]d_<01?l0
003o[MCdo`000?l00008ojkHmP?o00002_n^g_P3o`0000Ko[N?i0ol00003ojkVn@;o000000Go[>Oi
o`000?l0003o[>[io`000004ojcZn@;o00000on]k?P01?l0003oZngio`000?l00006oj_^n0;o0000
0on/koL3o`0000CoZnog0ol00003ojc`m`;o00000_n]koL01?l0003oZnogo`000?l00006ojc^n0;o
00000on]kOP00ol0003ooo]ZoookJP05oookJPKo0000:ooonfX000_ooo]Z0ol007l01?oonf[o001o
o`00Ool007l2oookJPKo001o6_oonfX3o`00O`?ooo]Z0ol007l5oookJPGo00002ooonfX2o`0000Wo
Y;o/00?o0000ojFmjonU_N/01OnU_N/4o`0000SoY;[Y00?o0000ojBij?nT^NP01onT^NP01?l0003o
YKSVo`000?l00006oj>fiP03o`000?nT]NGoY;GU00KoY;GU00?o0000ojBdi?nT]>@00onT]>@3o`00
0003oj>ci?l0003oXk;S00SoXk;S00?o0000ojBah_nT/N801onT/N800ol0003oY;7Qo`000002o`00
00GoXk3Q00?o0000ojB`h?nT/>001onT/>000ol0003oY:oPojB_h006ojB_h0Co00001_nT[]l00ol0
003oY:kOojB^g`07ojB^g`03o`000?nT[]ooY:kO00CoY:kO0ol000000onT[]oo0000ojB^g`08ojB^
g`03o`000?nT[]ooY:kO00OoY:kO00?o0000ojF_gol000000_l00005ojF_g`03o`000?nU/=ooYK3O
00SoYK3O00?o0000ojF`gonU/=l00onU/=l3o`000003ojJahOl0003oY[;Q00SoY[;Q00?o0000ojJb
hOnV/^401onV/^43o`0000SoYkGS00?o0000ojNfhonW]^<02?nW]^<00ol0003oYkOTojNgi003o`00
00GoZ;WU00?o0000ojRji_nX^^H02?nX^^H00ol0003oZK_Wo`000002o`0000KoZ[oY00?o0000oj[0
j_nZ`>X01onZ`>X3o`0000[oZlG]00?o0000oj_7k_n[anh00ol00005ojc;l003o`000?n/c?7o[<ca
00Ko[<ca0_l00002ojkAlP03o`000?n]d_?o[M;c00So[M;c0ol00007ojkHmP;o00000on_gOL00ol0
003o[]khojkNn004ojkNn0?o00000on^h_P2o`000004ojgSnOl0003o0000o`0000Oo[^Ki0ol00003
ojcZn@Co00001On]k?P3o`0000CoZnkh0ol00003ojc_m`;o00000on]koL01?l0003oZnogo`000?l0
0003ojc`m`?o00001?n]koL3o`0000Co[>kh0ol00005ojg]n0?o00001OoonfX6o`0002_ooo]Z000?
oookJP?o001o0ooonfX3o`00Oagooo]Z0ol007l01?oonf[o001oo`00Ool007l6oookJPCo00003_oo
nfX00ol0003oY;o/ojBok007ojBok003o`000?nU_N_oYKg[00Co00000_nS_>/00ol0003oY;[YojBj
j@08ojBjj@03o`000?nT^NSoY;WX00GoY;WX0ol00009oj>fiP03o`000?nT]NGoY;GU00KoY;GU00?o
0000ojBdi?l000000_l00005oj>ci003o`000?nS/^?oXk;S00OoXk;S00?o0000ojBah_nT/N801OnT
/N83o`0000WoXk3Q00?o0000ojB`h?nT/>001_nT/>000ol0003oY:oPojB_h003ojB_h0Go00002OnT
[]l00ol0003oY:kOojB^g`07ojB^g`03o`000?nT[]ooY:kO00?o00001OnT[]l00ol0003oY:kOojB^
g`07ojB^g`03o`000?nT[]ooY:kO00KoY:kO0_l00009ojF_g`03o`000?nU/=ooYK3O00OoYK3O00?o
0000ojF`gonU/=l00ol00005ojJah@03o`000?nV/^7oY[;Q00OoY[;Q00?o0000ojJbhOnV/^400onV
/^43o`000003ojNdh_l0003oYkGS00WoYkGS00?o0000ojNfhonW]^<01onW]^<3o`0000WoZ;WU00?o
0000ojRji_nX^^H01onX^^H2o`0000[oZ[oY00?o0000oj[0j_nZ`>X00onZ`>X3o`0000;oZlC/00?o
0000oj_5kOn[aNd02?n[aNd3o`0000Wo[<_`00?o0000ojc<lOn/c?400_n/c?43o`0000Go[]7b00?o
0000ojgBlon]d_<01?n]d_<3o`0000?o[]Oe00?o0000ojkHm_n^f?H00_n^f?H2o`0000Ko[mgg00?o
0000ojkNn?n^g_P00ol00007ojkRn0;o00002?n^i_T2o`0000?o[^Wi00?o0000ojcZnOl000000_l0
0005ojg/n0;o00000on]kOP01?l0003oZnkho`000?l00004ojc_m`;o00001On]koL4o`000003ojc`
mol0003o000000Go[Nog0_l00003ojk_m`04o`000?n/k_So0000o`0000Go[Ngh0ol00002ojk/n0;o
00001OoonfX6o`0002[ooo]Z000?oookJP?o001o0ooonfX3o`00Oagooo]Z1ol007l6oookJPCo0000
3ooonfX00ol0003oY;o/ojBok006ojBok0?o00001onS_>/00ol0003oY;[YojBjj@08ojBjj@03o`00
0?nT^NSoY;WX00Co00000_nS^>P00ol0003oXkKVoj>fiP08oj>fiP03o`000?nT]NGoY;GU00CoY;GU
0ol00009oj>ci003o`000?nS/^?oXk;S00OoXk;S00?o0000ojBah_nT/N801?l00002oj>`hP03o`00
0?nS/>7oXk3Q00SoXk3Q00?o0000ojB`h?nT/>001_nT/>000ol0003oY:oPo`000004o`0000?oXjoP
00?o0000ojB^gonT[]l01onT[]l00ol0003oY:kOojB^g`05ojB^g`Co00002OnT[]l00ol0003oY:kO
ojB^g`06ojB^g`03o`000?nT[]ooY:kO00?oY:kO0ol000000onU[moo0000ojF_g`09ojF_g`03o`00
0?nU/=ooYK3O00KoYK3O0ol00009ojJah@03o`000?nV/^7oY[;Q00OoY[;Q00?o0000ojJbhOl00000
0_l00005ojNdhP03o`000?nW]N?oYkGS00SoYkGS00?o0000ojNfhonW]^<00onW]^<3o`000003ojRi
iOl0003oZ;WU00WoZ;WU00?o0000ojRji_nX^^H01?nX^^H3o`000003ojZnj?l0003oZ[oY00[oZ[oY
00?o0000oj[0j_l000000_l00006oj_4k003o`000?n[aNgoZlG]00GoZlG]0_l00002ojg9k`03o`00
0?n/bo3o[<_`00So[<_`00Co0000ojc<lOl0003o00002On^dO800ol0003o[M;cojgBl`03o`0000Oo
[]Oe00Co0000ojkHm_l0003o00002?n_gOL3o`0000So[^;h0_l00002ojoUn@03o`000?n^i_Wo[^Ki
00;o[^Ki0ol00005ojkYn@?o00000_n]k?P00ol0003o[Nchojg/n002o`0000Go[Ngh1?l00002ojc_
m`;o00001On]koL2o`0000?o[_3g0ol00004ojg_m`;o00001On^koL4o`0000;o[Ngh0ol00003ojk/
n0;o00000_n_jOT00ol0003ooo]ZoookJP03oookJPKo0000:OoonfX000oooo]Z0ol007lToookJPGo
001o1ooonfX4o`00013ooo]Z00?o0000ojBok?nT_n`00_nT_n`3o`0000;oXKk^00?o0000oj>ljonS
_>/01_nS_>/00ol0003oY;[YojBjj@07ojBjj@?o00001onS^>P00ol0003oXkKVoj>fiP08oj>fiP03
o`000?nT]NGoY;GU00?o00000onR]>D00ol0003oXk?Toj>ci007oj>ci003o`000?nS/^?oXk;S00Ko
Xk;S0ol00007oj>`hP03o`000?nS/>7oXk3Q00OoXk3Q00?o0000ojB`h?nT/>001OnT/>05o`0000Oo
XjoP00?o0000ojB^gonT[]l01onT[]l00ol0003oY:kOojB^g`04o`0000;oY:kO00?o0000ojB^gonT
[]l02OnT[]l00ol0003oY:kOojB^g`06ojB^g`03o`000?nT[]oo000000;o00001OnU[ml00ol0003o
YJoOojF_g`07ojF_g`03o`000?nU/=ooYK3O00?oYK3O0ol000000onU/N3o0000ojJah@0:ojJah@03
o`000?nV/^7oY[;Q00KoY[;Q0_l00009ojNdhP03o`000?nW]N?oYkGS00SoYkGS00?o0000ojNfhol0
00000_l00005ojRii@03o`000?nX^NGoZ;WU00SoZ;WU00?o0000ojRji_nX^^H00ol00005ojZnj003
o`000?nZ_nWoZ[oY00SoZ[oY0_l0000:oj_4k003o`000?n[aNgoZlG]00;oZlG]0_l00005ojg9k`03
o`000?n/bo3o[<_`00Oo[<_`0_l0000;ojkAlP?o00002_n^eoD3o`0000Oo[mgg0_l00003ojoPn003
o`000?n^h_So[^;h00;o[^;h0ol00005ojoUn@04o`000?n^i_Wo0000o`0000Ko[^Wi0_l00003ojo[
n0Go00001On]kOP2o`0000Co[^og0ol00004ojg_m`;o00000on^l?L2o`0000?o[o3g00Co0000ojg_
mol0003o00001?n^koL3o`0000?o[nkg0ol00004ojk/n0;o00001On_jOT00ol0003ooo]ZoookJP02
oookJPKo0000:OoonfX0047ooo]Z1Ol0000AoookJP04o`000?nT_nco0000o`0000KoXKk^00?o0000
oj>ljonS_>/01_nS_>/00ol0003oY;[YojBjj@03ojBjj@?o000000?oX[WZo`000?nS^>P02?nS^>P0
0ol0003oXkKVoj>fiP07oj>fiP?o00001onR]>D00ol0003oXk?Toj>ci007oj>ci003o`000?nS/^?o
Xk;S00;oXk;S0ol000000onR/N?o0000oj>`hP08oj>`hP03o`000?nS/>7oXk3Q00OoXk3Q00?o0000
ojB`h?nT/>001ol0000:oj>_h003o`000?nT[]ooY:kO00KoY:kO0ol00007ojB^g`03o`000?nT[]oo
Y:kO00SoY:kO00?o0000ojB^gonT[]l01OnT[]l3o`0000WoYJoO00?o0000ojF_gonU[ml01onU[ml0
0ol0003oYK3Oo`000002o`0000GoYK7P00?o0000ojJahOnV/N402?nV/N400ol0003oY[;QojJbh@03
ojJbh@?o000000?oYkCRo`000?nW]>802OnW]>800ol0003oYkGSojNeh`07ojNeh`;o00002OnX^ND0
0ol0003oZ;WUojRii@07ojRii@?o00002OnZ_^P00ol0003oZ[oYojZoj@04ojZoj@?o000000?oZl?[
o`000?n[a>`02_n[a>`01?l0003oZlG]o`000?l00008ojg9k`03o`000?n/bo3o[<_`00?o[<_`0ol0
0002ojk?l@03o`000?n^dO;o[]7b00Ko[]7b0_l00002ojoEm003o`000?n^eoGo[]Oe00Ko[]Oe0_l0
0003ojoKmP03o`000?n_gOOo[mgg00;o[mgg0_l00006ojoPn004o`000?n^h_So0000o`0000So[nGi
0ol00005ojkYn@;o00001_n_joP3o`0000Co[Ngh0_l00004ojk_m`;o00000on_koL01?l0003o[Nog
o`000?l00003ojk`m`;o00001On_l?L4o`000004ojk_mol0003o0000o`0000Co[nkg0_l00003ok3]
n004o`000?n^k?So0000o`0000Oo[nWi0ol00003oookJPKo0000:?oonfX0047ooo]Z1Ol0000Boook
JP03o`000?nQ_^koXKk^00OoXKk^00?o0000oj>ljonS_>/01_nS_>/00ol0003oY;[Yo`000002o`00
00GoX[WZ00?o0000oj>hj?nS^>P01onS^>P00ol0003oXkKVoj>fiP03oj>fiP?o000000?oX[GVo`00
0?nR]>D02?nR]>D00ol0003oXk?Toj>ci007oj>ci004o`000?nS/^?o0000o`0000GoX[7S00?o0000
oj>`h_nS/>801onS/>800ol0003oXk3Qoj>`h@06oj>`h@Ko00001?nS[n000ol0003oXjoPoj>_h007
oj>_h003o`000?nT[]ooY:kO00?oY:kO0ol000000onS[]oo0000ojB^g`08ojB^g`03o`000?nT[]oo
Y:kO00SoY:kO00?o0000ojB^gonT[]l01?l00002ojB_g`03o`000?nU[mooYJoO00SoYJoO00?o0000
ojF_gonU[ml01_nU[ml2o`0000WoYK7P00?o0000ojJahOnV/N402?nV/N400ol0003oY[;Qo`000002
o`0000GoYkCR00?o0000ojNdh_nW]>801onW]>800ol0003oYkGSojNeh`04ojNeh`?o000000?oZ;ST
o`000?nX^ND02OnX^ND00ol0003oZ;WUojRii@03ojRii@?o00000_nY_>L00ol0003oZ[kXojZnj008
ojZnj003o`000?nZ_nWoZ[oY00?o00001On[`n/00ol0003oZlC/oj_4k008oj_4k0;o00002on]bNl0
0ol0003o[<_`o`000002o`0000Ko[/oa00?o0000ojkAl_n^dO800_n^dO83o`0000Go[mGd00?o0000
ojkGmOn^eoD00_n^eoD3o`0000Ko[m_f00Co0000ojoMmol0003o00002?n_h?P3o`0000Oo[nGi0_l0
0003ok3Xn0;o000000?o[^Wio`000?l000001_n_joP2o`0000?o[ngh00Co0000ojg]n?l0003o0000
0on^koL3o`0000Go[nog1?l000000on^l?Oo0000o`000005ojo`m`;o00000on`koL3o`0000Co[nkg
0_l00005ok3]n0?o00001On_jOT3o`0000?o[nOi00Co0000oookJ_oonf[ooo]Z1_l0000WoookJP00
@OoonfX5o`0001?ooo]Z00?o0000oj6nk_nQ_^h01onQ_^h00ol0003oXkc[oj>lj`04oj>lj`Co0000
2?nR^NX00ol0003oXkSXoj>hj007oj>hj003o`000?nS]^Ko000000;o00001OnR]NH00ol0003oX[CU
oj:di@07oj:di@03o`000?nS/nCoXk?T00GoXk?T0ol00008oj:ah`03o`000?nS/>;oXk3R00KoXk3R
00?o0000oj>`hOnS/>400onS/>46o`0000SoXjoP00?o0000oj>_h?nS[n001onS[n000ol0003oY:kO
o`000002o`0000GoXjkO00?o0000ojB^gonT[]l01onT[]l00ol0003oY:kOojB^g`07ojB^g`?o0000
1onT[ml00ol0003oYJoOojF_g`07ojF_g`03o`000?nU[mooYJoO00?oYJoO0ol000000onU/>3o0000
ojFah009ojFah003o`000?nV/N7oY[7Q00OoY[7Q0_l00009ojNdhP03o`000?nW]>;oYkCR00OoYkCR
00?o0000ojNehonW]N<00ol00005ojRhi003o`000?nX^NGoZ;WU00SoZ;WU00?o0000ojRiiOl00000
0_l00006ojVli`03o`000?nZ_^SoZ[kX00OoZ[kX0ol00009oj_3j`03o`000?n[a>coZlC/00CoZlC/
0ol00002ojg8kP03o`000?n]bNoo[LW_00So[LW_0_l0000:ojk?l@04o`000?n^dO;o0000o`0000Wo
[mGd00Co0000ojkGmOl0003o00002On_foH2o`0000So[n3h0_l00003ok3Tn003o`000?n_iOWo[nGi
00;o[nGi0_l00006ok3Xn0?o00001?n_joP3o`0000Go[ngh1?l000000on^koOo0000o`000006ojo_
m`;o00000on`l?H3o`0000Co[o3g0_l00003ok3_m`;o00000onakoL01?l0003o[nkgo`000?l00005
ok3]n0;o00000on`joP00ol0003o[nWio`000002o`0000Ko[nOi0ol000000ooonf[o0000o`000004
o`0002Oooo]Z0011oookJPCo00005OoonfX00ol0003oXKk^oj6nkP07oj6nkP03o`000?nS_>_oXkc[
00?o00001?nP^n`00ol0003oX[WZoj:ijP06oj:ijP03o`000?nS^>SoXkSX00GoXkSX0ol00009oj:e
iP03o`000?nR]>GoX[CU00OoX[CU00?o0000oj>ci?nS/n@01?l00002oj:bi003o`000?nR/N?oX[7S
00OoX[7S00?o0000oj>`h_nS/>801_nS/>800ol0003oXk3Qo`000005o`0000;oXZoQ00?o0000oj>_
h?nS[n001onS[n000ol0003oXjoPoj>_h005oj>_h0?o00002OnS[]l00ol0003oY:kOojB^g`06ojB^
g`03o`000?nT[]ooY:kO00CoY:kO0ol000000onT[]oo0000ojB_g`08ojB_g`03o`000?nU[mooYJoO
00OoYJoO00?o0000ojF_gol000000_l00005ojF`h003o`000?nU/N3oYK7P00OoYK7P00?o0000ojJa
hOnV/N401?nV/N43o`000003ojJchOl0003oYkCR00WoYkCR00?o0000ojNdh_nW]>801_nW]>83o`00
00WoZ;ST00?o0000ojRiiOnX^ND01onX^ND2o`0000[oZKcW00?o0000ojZnj?nZ_^P00onZ_^P3o`00
00;oZl7Z00?o0000oj_3jon[`n/02?n[`n/00ol0003oZlC/oj_4k003o`0000Ko[LS^00?o0000ojg9
kon]bNl01?n]bNl3o`0000;o[/k`00?o0000ojk?lOn^co401on^co43o`0000[o[mGd0ol00008ojoK
mP;o00000_n`goL00ol0003o[n3hojoPn002ojoPn0?o00001_n`i?P01?l0003o[nGio`000?l00006
ok3Xn0;o00000onaj_P01?l0003o[n_ho`000?l00006ojo]n0;o000000?o/>kgo`000?n`k_L00ol0
0004ojo_m`?o00000on`l?H2o`0000?o/O3f00Co0000ojo`mol0003o00000on`koL2o`0000Go/Nog
0ol00004ok3]n0;o00001On`joP3o`0000Go[nOi0ol00003ojoTn@03o`000?oonf[o000000Go0000
9_oonfX0047ooo]Z1?l0000FoookJP03o`000?nQ_^koXKk^00GoXKk^1?l00008oj2kk003o`000?nR
^N[oX[WZ00KoX[WZ00?o0000oj>hj?nS^>P01?l00002oj2gj003o`000?nR]NKoX[GV00SoX[GV00?o
0000oj:diOnR]>D01OnR]>D4o`0000OoX[;T00?o0000oj:ahonR/N<01onR/N<00ol0003oXk3Roj>`
hP04oj>`hPKo00001_nR[n400ol0003oXjoPoj>_h007oj>_h003o`000?nS[n3oXjoP00Co00000_nS
[^000ol0003oXjkOoj>^g`08oj>^g`03o`000?nT[]ooY:kO00KoY:kO00?o0000ojB^gonT[]l00ol0
0005ojB^g`03o`000?nT[mooY:oO00OoY:oO00?o0000ojF_gonU[ml01OnU[ml3o`0000WoYK3P00?o
0000ojFah?nU/N001onU/N000ol0003oY[7QojJah@03o`0000GoY[?Q00?o0000ojNdh_nW]>801onW
]>800ol0003oYkCRojNdhP03ojNdhP?o000000?oZ;OTo`000?nX^>@02OnX^>@00ol0003oZ;WUojRi
i@04ojRii@?o000000?oZK_Vo`000?nY_>L02_nY_>L00ol0003oZ[kXo`000002o`0000KoZl7Z00?o
0000oj_3jon[`n/01on[`n/3o`0000[o[LS^00?o0000ojg9kon]bNl00ol00006ojk>l003o`000?n^
co7o[/oa00?o[/oa0ol00003ojoCl`03o`000?n_eOCo[mGd00Co[mGd0ol00003ok3Im@03o`000?n_
foKo[m_f00;o[m_f0ol00005ok3Om`04o`000?n_h?So0000o`0000Wo/>Ch0ol00004ok3Xn0?o0000
1Onaj_P3o`0000Go[ngh0_l00003ok3^m`;o00000onakoL01?l0003o[nogo`000?l00004ok3`mP;o
00001Onal?H4o`000003ok3_mol0003o000000Go/Nog0_l00003ok7^m`04o`000?n`kOSo0000o`00
00Go/>_h0_l00003ok3Yn003o`000?n_ioWo000000;o00001_n_i?T2o`000003oookJ_l0003o0000
00?o00009_oonfX0047ooo]Z1?l0000GoookJP03o`000?nQ_^koXKk^00Co00000onM_Nl00ol0003o
X;_/oj2kk007oj2kk003o`000?nR^N[oX[WZ00CoX[WZ1?l00007oj2gj003o`000?nR]NKoX[GV00So
X[GV00?o0000oj:diOnR]>D01?l00002oj6ci@03o`000?nR/^CoX[;T00OoX[;T00?o0000oj:ahonR
/N<01onR/N<00ol0003oXk3Roj>`hP03o`000004oj:`h_l0003o0000o`0000WoXZoQ00?o0000oj>_
h?nS[n001_nS[n03o`0000OoXjkP00?o0000oj>^gonS[]l01onS[]l00ol0003oY:kOojB^g`05ojB^
g`Co00002OnT[]l00ol0003oY:oOojB_g`07ojB_g`03o`000?nU[mooYJoO00Co00000_nU/>000ol0
003oYK3PojF`h008ojF`h003o`000?nU/N3oYK7P00KoYK7P0ol00008ojJch@03o`000?nW]>;oYkCR
00SoYkCR00?o0000ojNdh_l000000_l00005ojRgi003o`000?nX^>CoZ;ST00SoZ;ST00?o0000ojRi
iOnX^ND00ol00005ojVkiP03o`000?nY_>OoZKcW00SoZKcW0_l0000:oj_1jP03o`000?n[`n_oZl?[
00?oZl?[0ol00002ojg6k@03o`000?n]b>ko[LS^00So[LS^0ol0000:ojk>l003o`000?n^co7o0000
00;o00001on_do<00ol0003o[mGdojoEm003o`0000Oo/=We00Co0000ojoKm_l0003o00002?n`goL3
o`0000So/>Ch0_l00003ok7Vn004o`000?n`j?So0000o`0000Ko/N[h0_l00003ok7/m`;o000000?o
[ngho`000?l000000on`k_L2o`0000;o/Nog00?o0000ok7_monakoL01?l00002ok3`mP;o00001Ona
l?H2o`0000?o/_3f0ol00004ok7_m`;o00001Onak_L3o`0000Co/>_h0_l00005ok3Yn0?o00001On_
i?T3o`0000;o[^7i1ol0000UoookJP00@?oonfX5o`0001Sooo]Z0_l00008oifmk`03o`000?nP^nco
X;_/00OoX;_/00?o0000oj:ij_nR^NX00ol00003oinhjP03o`000?nP]nSoX;OX00KoX;OX00?o0000
oj:ei_nR]NH01onR]NH3o`0000OoXK?U00?o0000oj:bi?nR/^@01onR/^@00ol0003oX[7Soj:ah`05
oj:ah`Co000000CoX[3Ro`000?l0003o00000onR/>800ol0003oXZoQoj:_h@06oj:_h@03o`000?nS
[n3oXjoP00?oXjoP0ol000000onR[^3o0000oj>^h008oj>^h003o`000?nS[]ooXjkO00OoXjkO00?o
0000ojB^gonT[]l01?l00002ojB^g`03o`000?nT[]ooY:kO00WoY:kO00?o0000ojB_gonT[ml01_nT
[ml3o`0000OoYK3P00?o0000ojF`h?nU/>001onU/>000ol0003oYK7PojFah003ojFah0?o000000?o
Y[;Qo`000?nV/n402OnV/n400ol0003oYkCRojNdhP07ojNdhP;o00002OnX]n@00ol0003oZ;STojRh
i007ojRhi0?o00002OnY^nH00ol0003oZKcWojVli`04ojVli`?o000000?oZl3Yo`000?n[`NX02_n[
`NX00ol0003oZl?[o`000002o`0000Ko[LK]00?o0000ojg8k_n]b>h01On]b>h2o`000003ojk<kol0
003o[/k`00[o[/k`0_l0000:ojoCl`?o00002_n`fOD3o`0000Oo/=og0_l00003ok;Rm`03o`000?n`
i?So/>Ch00;o/>Ch0ol00005ok7Vn0?o00001Onaj_P2o`0000Ko/Ncg1?l000000on`k_Oo0000o`00
0005ok7_m`;o00001?nbl?H3o`0000Co/O3f0_l00004ok;`mP06o`000?nckoKo/nofok?_m_l0003o
/Nog0_l00005ok7^m`;o00000onbk?L01?l0003o/>_ho`000?l00005ok3Yn0;o00000on`ioP00ol0
003o[nCio`000002o`0000Ko[^7i1ol0000ToookJP00@?oonfX5o`0001[ooo]Z00?o0000oifmkonM
_Nl01_nM_Nl00ol0003oX;_/oj2kk005oj2kk0Co00001onO^>X00ol0003oX;OXoj2gj006oj2gj003
o`000?nR]NKoX[GV00?oX[GV0ol000000onO]>Oo0000oj6ci@08oj6ci@03o`000?nR/^CoX[;T00Oo
X[;T00?o0000oj:ahonR/N<01?l00002oj6`h`?o00001onR/>800ol0003oXZoQoj:_h@06oj:_h@03
o`000?nS[n3o000000;o00001OnR[^000ol0003oXjkPoj>^h007oj>^h003o`000?nS[]ooXjkO00Ko
XjkO0ol00007ojB^g`03o`000?nT[]ooY:kO00SoY:kO00?o0000ojB_gonT[ml00onT[ml3o`000003
ojF_gol0003oYK3P00SoYK3P00?o0000ojF`h?nU/>001onU/>000ol0003oYK7Po`000002o`0000Go
Y[;Q00?o0000ojJchOnV/n402?nV/n400ol0003oYkCRojNdhP03ojNdhP?o000000?oZ;KSo`000?nX
]n@02OnX]n@00ol0003oZ;STojRhi003ojRhi0?o000000?oZK[Vo`000?nY^nH02_nY^nH00ol0003o
ZKcWojVli`03o`0000GoZl3Y00?o0000oj_1j_n[`NX02?n[`NX2o`0000[o[LK]00?o0000ojg8k_n]
b>h00_n]b>h2o`0000Co[/c_00?o0000ojk>l?n^c_001_n^c_02o`0000;o/=7b00?o0000ojoClon_
do<01On_do<2o`0000;o/MOd00?o0000ok3ImOn`fOD01_n`fOD2o`0000?o/Mgf00?o0000ok3Omon`
goL00_n`goL2o`0000Ko/^;g00Co0000ok3Tn?l0003o00001_nai_P2o`0000?o/^Wh0_l000000ona
j_So0000o`000006ok7/m`;o00000onbkOL3o`0000Co/Nog0ol00003ok;`mP;o00000oncl?H01?l0
003o/O3fo`000?l00004ok;`mP;o00001?nckoH3o`0000Co/Nkg0_l00005ok;/m`?o00001?n`jOP2
o`0000Go/>Oh0_l00009ojkQn@Oo00004?oonfX3o`00O`Gooo]Z1Ol007l7oookJP001?oonfXIo`00
Ob?ooo]Z1Ol0000KoookJP03o`000?nM_NooWKg_00KoWKg_00?o0000oj2kk?nP^n`01?l00002oibj
k@03o`000?nO^>[oWkSZ00OoWkSZ00?o0000oj2gj?nP]nP01_nP]nP00ol0003oX[GVo`000002o`00
00GoWkCW00?o0000oj6ciOnQ/nD01onQ/nD00ol0003oX[;Toj:bi005oj:bi0Co00000onQ/><3o`00
0003oj6`hol0003oX[3R00SoX[3R00?o0000oj:_hOnR[n401?nR[n43o`0000WoXZkP00?o0000oj>^
h?nS[^001_nS[^000ol0003oXjkOoj>^g`03oj>^g`?o000000?oXjkOo`000?nT[]l02?nT[]l00ol0
003oY:kOojB^g`08ojB^g`03o`000?nT[moo000000;o00001OnU[ml00ol0003oYK3PojF`h007ojF`
h003o`000?nU/>3oYK3P00GoYK3P0ol00009ojJbh@03o`000?nV/n7oY[?Q00OoY[?Q00?o0000ojNd
h_nW]>800ol00005ojRfh`03o`000?nX]nCoZ;OT00SoZ;OT00?o0000ojRhi?l000000_l00005ojVj
iP03o`000?nY^nKoZK_V00SoZK_V0ol00009oj_0j@03o`000?n[`N[oZl7Z00GoZl7Z0_l000000on]
aN_o0000ojg6k@0:ojg6k@04o`000?n]b>ko0000o`0000Oo[/c_00?o0000ojk>l?n^c_000_n^c_03
o`0000Go/=7b00?o0000ojoClon_do<00_n_do<2o`0000Go/MOd00?o0000ok3ImOn`fOD00_n`fOD3
o`0000Ko/Mgf00Co0000ok3Omol0003o00002?nbh_L3o`0000Go/NKh0_l00006ok;Yn0?o00001?na
k?L3o`0000Co/^gg00Ko0000ok?_m_nckoKo/nofo`000?nakoL2o`0000?o/_3f0ol00005ok?`mP?o
00000onbl?H2o`0000Co/nof0_l00003ok?_mP04o`000?nak_Oo0000o`0000Go/^cg0_l00003ok;[
m`04o`000?n`jOSo0000o`0000Go/>Oh0_l00002ok3Tn003o`000?n^hOWo[^7i00?o[^7i0ol00002
ojgNn0Ko00003ooonfX3o`00O`Cooo]Z1ol007l6oookJP00@?oonfX4o`0001gooo]Z00?o0000oifm
konM_Nl01?nM_Nl4o`0000OoW;[]00?o0000oinhj_nO^>X01onO^>X00ol0003oX;OXoj2gj004oj2g
j0?o00002OnO]>L00ol0003oXK?Uoj6ci@07oj6ci@03o`000?nR/^CoX[;T00Co00000_nP/N@00ol0
003oXK3So`000002o`0000GoXK3S00?o0000oj:`h_nR/>801onR/>800ol0003oXZoQoj:_h@03o`00
00;oXZoQ00?o0000oj:^h?nR[^002?nR[^000ol0003oXjkPoj>^h006oj>^h003o`000?nS[]oo0000
00;o00001OnS[]l00ol0003oY:kOojB^g`07ojB^g`03o`000?nT[]ooY:kO00OoY:kO0_l00009ojF_
g`03o`000?nU/>3oYK3P00OoYK3P00?o0000ojF`h?nU/>001?l00002ojJah@03o`000?nV/^7oY[;Q
00SoY[;Q00?o0000ojJchOnV/n401OnV/n44o`0000WoZ;KS00?o0000ojRgi?nX]n@01onX]n@2o`00
00WoZK[V00?o0000ojVki_nY^nH01OnY^nH2o`000003oj^nj?l0003oZl3Y00WoZl3Y00?o0000oj_1
j_n[`NX00_n[`NX3o`0000Co[LG[00?o0000ojg6kOn]a^d02?n]a^d2o`0000[o[/c_00Co0000ojk>
l?l0003o00002On`dO801?l0003o[m?co`000?l00008ok7Gm004o`000?n`fOGo0000o`0000Wo/Mgf
0ol00006ok;Rm`?o00000onciOL2o`000003ok7Vn?l0003o000000Ko/^Wh0_l00003ok?[m`04o`00
0?nak?Oo0000o`0000Go/^gg0_l00004ok?_mP?o00001?nbl?H2o`0000Co/o3f0_l00003okC`mP03
o`000?nbl?Ko000000Co/nof0_l00005ok?_mP?o00001?nbk?L2o`0000Go/^_g0ol00004ok3Wn0;o
00001On`i?P00ol0003o[^7io`000002o`0000Go[Mkh1ol0000>oookJP?o001o1?oonfX3o`00O`04
oookJ_l007oo001oo`00O`Kooo]Z0010oookJPCo00007_oonfX00ol0003oWKg_oifmk`03o`0000Co
VKc`00?o0000oibjkOnL^^d01OnL^^d00ol0003oWkSZoinhjP07oinhjP03o`000?nP]nSoX;OX00?o
00000onN]NT00ol0003oWkCWoindi`07oindi`03o`000?nQ/nGoXK?U00KoXK?U0ol00005oj2ai0?o
00002OnQ/><00ol0003oX[3Roj:`hP06oj:`hP?o00001_nR[n400ol0003oXZkPoj:^h007oj:^h003
o`000?nS[^3oXjkP00GoXjkP0ol00009oj>^g`03o`000?nT[]ooY:kO00KoY:kO00?o0000ojB^gonT
[]l01?nT[]l3o`000003ojB_gol0003oYJoO00WoYJoO00?o0000ojF`h?nU/>001_nU/>03o`0000Oo
Y[7Q00?o0000ojJbhOnV/^402?nV/^400ol0003oY[?QojJch@04o`0000;oYkGR00?o0000ojRfhonX
]^<02?nX]^<00ol0003oZ;OTojRgi004ojRgi0?o000000?oZKWUo`000?nY^^H02OnY^^H00ol0003o
ZK_VojVkiP02ojVkiP;o00001?n[_^P00ol0003oZl3Yoj_0j@08oj_0j@04o`000?n[`N[o0000o`00
00So[LG[00?o0000ojg6kOn]a^d01?n]a^d3o`0000;o[/[^00?o0000ojk<kon^c>l01on^c>l3o`00
00[o/=7b0ol00009ok7Gm0?o00002?nagOH2o`0000?o/n3f0_l000001?nbh_Oo0000o`000?l00007
ok?Um`?o00001?nbjOP3o`0000Go/n_g0ol00004ok;]m`;o00001?nckoH2o`0000?o]>of00Ko0000
ok;`m_l0003o0000ok?`m_l00002ok?`mP;o00001Ondl?H4o`000003ok?_m_l0003o000000Go/nof
0_l00003okC]mP04o`000?nbk?Oo0000o`0000Co/^_g0ol00003ok;Yn004o`000?n`ioSo0000o`00
00Oo/>Ch0_l00005ojgNn0?o00000_n/f_P5o`0000kooo]Z0ol007l3oookJP?o001o0ooonfX3o`00
O`Gooo]Z0010oookJPCo00007ooonfX2o`0000SoVKc`00?o0000oibjkOnL^^d01OnL^^d00ol0003o
WkSZoinhjP05oinhjPCo00001onN]NT00ol0003oWkCWoindi`06oindi`03o`000?nQ/nGoXK?U00?o
XK?U0ol000000onO/^Go0000oj2ai002oj2ai0?o00000onP/N@00ol0003oXK3Soj6`h`06oj6`h`03
o`000?nR/>;oX[3R00?oX[3R0ol000000onQ[n;o0000oj:_h@07oj:_h@03o`000?nR[^3oXZkP00Oo
XZkP00?o0000oj>^h?nS[^001?l00002oj>^h003o`000?nS[]ooXjkO00SoXjkO00?o0000ojB^gonT
[]l01_nT[]l00ol0003oY:kOojB^g`03o`0000GoY:oO00?o0000ojF_gonU[ml01onU[ml00ol0003o
YK3PojF`h003ojF`h0?o000000?oYK7Po`000?nV/N402?nV/N400ol0003oY[;QojJbh@07ojJbh@?o
00001onW]N800ol0003oZ;KSojRfh`08ojRfh`03o`000?nX]nCoZ;OT00?o00001OnY^ND00ol0003o
ZK[VojVjiP08ojVjiP04o`000?nY^nKo0000o`0000OoZkkX00?o0000oj_0jOn[`>T01on[`>T3o`00
00[o[LG[00?o0000ojg6kOn]a^d00ol00006ojk:kP03o`000?n^c>oo[/c_00?o[/c_0ol00003ok3@
l@03o`000?n`dO;o/=7b00Co/=7b0ol00003ok7El`03o`000?naeoCo/MOd00?o/MOd0ol00003ok;K
m@03o`000?nagOKo/Mgf00;o/Mgf0ol00006ok?PmP;o00002?nciOL2o`0000?o]>Og00Co0000ok;Y
n?l0003o00001_ncjoL2o`0000?o]>gg0_l000000onbkOOo0000ok?_mP03ok?_mP;o00001OndkoH4
o`0000;o/o3f0_l00005okC`mP;o00000onel?D3o`0000Co/nof0_l00005okC]mPCo000000Co/^_g
o`000?l0003o00001_nbjOP3o`0000Go/>Ch0ol00002ojoQn003o`000?n]g_So000000;o00001_n/
f_P5o`0000gooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z000ooookJPGo00008OoonfX0
0ol0003oVKc`oiVll006oiVll003o`000?nL^^goW;[]00GoW;[]00?o0000oinhj_nO^>X01?l00003
oibgj`03o`000?nN]NWoW[GY00KoW[GY00?o0000oindionO]>L01_nO]>L00ol0003oXK?Uo`000002
o`0000GoWk;U0ol00007oj2ai003o`000?nQ/>?oXK3S00KoXK3S00?o0000oj:`h_l000000_l00005
oj6_hP03o`000?nR[n7oXZoQ00KoXZoQ00?o0000oj:^h?nR[^001_nR[^03o`0000OoXjkP00?o0000
oj>^gonS[]l01onS[]l00ol0003oY:kOojB^g`05ojB^g`Co00002?nT[ml00ol0003oYJoOojF_g`08
ojF_g`03o`000?nU/>3o000000;o00001OnU/N000ol0003oY[7QojJah@07ojJah@03o`000?nV/^7o
Y[;Q00?oY[;Q0ol000000onW]>;o0000ojNehP08ojNehP03o`000?nX]^?oZ;KS00OoZ;KS0ol00009
ojVii@03o`000?nY^^KoZK[V00OoZK[V0_l0000:oj^nj003o`000?n[`>WoZl3Y00?oZl3Y0ol00003
ojg3jP03o`000?n]aN_o[LG[00Oo[LG[0ol0000:ojk:kP03o`000?n^c>oo000000;o00001on`d?40
0ol0003o/=7bok3AlP03o`0000Oo/MGc00?o0000ok7Gm?l000000_l00007ok;Km@04o`000?nagOKo
0000o`0000Oo/n3f0_l00002okCSmP03o`000?nciOOo/nGg00;o/nGg0ol00005okCWm`?o00001Onc
joL2o`0000Ko]>gg1?l000000onckoKo0000o`000005okC_mP;o00001?nel?D4o`0000?o]?3f0_l0
0003okG`m@;o00000onfkoH01?l0003o/nofo`000?l00005okC]mP;o00000ondk?L3o`0000Go/^Wh
0ol00003ok;Vn003o`000?n`i?So000000;o00001On_hOP2o`0000Wo[=[h1_l0000<oookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007l5oookJP00?ooonfX7o`00023ooo]Z00?o0000oiVll?nI_?001_nI
_?000ol0003oW;[]oibjk@02oibjk@Go00002?nL]n/00ol0003oW[GYoijej@06oijej@03o`000?nO
]>OoWkCW00CoWkCW0ol00006oinbi@;o000000?oWk;Uo`000?nP/N@01onP/N@00ol0003oXK3Soj6`
h`05oj6`h`?o00002OnQ[n800ol0003oXZoQoj:_h@06oj:_h@03o`000?nR[^3oXZkP00;oXZkP0ol0
00000onR[^3o0000oj>^h008oj>^h003o`000?nS[]ooXjkO00OoXjkO00?o0000ojB^gonT[]l01?l0
0002ojB_g`03o`000?nT[mooY:oO00SoY:oO00?o0000ojF_gonU[ml01onU[ml2o`0000WoYK7P00?o
0000ojJahOnV/N401onV/N400ol0003oY[;Qo`000002o`0000GoYkCR00?o0000ojNeh_nW]N801onW
]N800ol0003oZ;KSojRfh`03ojRfh`?o000000?oZKSTo`000?nY^ND02OnY^ND00ol0003oZK[VojVj
iP04ojVjiP?o000000?oZkgWo`000?n[_^P02_n[_^P00ol0003oZl3Yo`000002o`0000Oo[L?Z00?o
0000ojg5jon]aN/00on]aN/3o`000003ojk8kOl0003o[/[^00[o[/[^0_l0000:ok3@l@?o00002_na
eO<3o`0000Wo/]_e0ol00005ok?PmP?o00001OndhoH01?l0003o/nGgo`000?l00006okCWm`;o0000
0onej_L2o`000003ok?[mol0003o000000Ko]>gg0_l00003okK^mP?o00001?ndkoH2o`0000Co]O3e
0_l00003okK`m@Co00000onel?D2o`0000Go]^of0ol00004okC]mP;o00000ondk?L2o`0000?o]>_g
00?o0000ok;Yn?l000000_l00006ok;Vn0;o00001On_hOP3o`0000;o[]kh00?o0000ojcJn?n/f_P0
0on/f_P3o`0000;oZ]Kg1?l0000<oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJP004_oo
nfX4o`00ObWooo]Z1Ol0000SoookJP03o`000?nI_?3oVKc`00CoVKc`1_l00005oiRikP03o`000?nL
]n_oW;O[00KoW;O[00?o0000oijejOnN]NT01_nN]NT00ol0003oWkCWoindi`03o`0000?oWK?W00?o
0000oinbiOnO/^D00ol00004oinbi@03o`000?nP/NCoX;7T00KoX;7T00?o0000oj6`honQ/><01?l0
0002oj2_h`03o`000?nQ[n;oXJoR00SoXJoR00?o0000oj:_hOnR[n401_nR[n401?l0003oXZkPo`00
0?l00005oj:^h003o`000?nS[^3oXjkP00OoXjkP00?o0000oj>^gonS[]l01_nS[]l3o`0000OoY:oO
00?o0000ojB_gonT[ml02?nT[ml00ol0003oYJoOojF_g`03ojF_g`?o000000?oYK3Po`000?nU/N00
2OnU/N000ol0003oY[7QojJah@06ojJah@;o00002OnW]>800ol0003oYkGRojNehP07ojNehP03o`00
0?nX]^?o000000;o00001OnY^>@00ol0003oZKWUojVii@08ojVii@03o`000?nY^^KoZK[V00?o0000
1On[_NL00ol0003oZkkXoj^nj008oj^nj0;o00002on]`nX00ol0003o[LG[o`000002o`0000Go[/S]
00?o0000ojk:k_n^b^h01_n^b^h2o`0000;o/<k_00?o0000ok3@lOn`d?401On`d?42o`0000;o/]?b
00?o0000ok7ElonaeO<01_naeO<2o`0000?o/mWd00?o0000ok;KmOnbfoD00onbfoD3o`0000?o]=ke
0_l000000onch?Ko0000o`000008okCSmP?o00001OndioL2o`0000Ko]N[g0ol00004okC]m`?o0000
1?nfk_H01_l0003o]noeokO_mOngkoGo0000okC_mP;o00001?nel?D2o`0000Go]_3e1?l000000one
l?Go0000o`000005okK_mP;o00000onfk_H01?l0003o]>gfo`000?l00003okC/m`;o00001OndjoL2
o`0000Oo/^Kh0_l00002ok7Tn003o`000?n_hOSo000000;o00001_n^g_P00ol0003o[=[ho`000002
o`0000KoZ]Kg1?l0000;oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l5oookJP004_oonfX5o`00
ObSooo]Z1?l0000UoookJP03o`000?nI_?3oVKc`00?o00000onD^_800ol0003oV;W^oiRikP06oiRi
kP03o`000?nL]n_oW;O[00KoW;O[00?o0000oijejOnN]NT00_nN]NT6o`0000KoWK?W0ol00007oinb
i@03o`000?nP/NCoX;7T00GoX;7T1?l00007oj2_h`03o`000?nQ[n;oXJoR00OoXJoR00?o0000oj:_
hOnR[n401OnR[n43o`0000SoXZkP00?o0000oj>^h?nS[^001_nS[^000ol0003oXjkOoj>^g`03oj>^
g`?o000000?oXjkPo`000?nT[ml02?nT[ml00ol0003oY:oOojB_g`07ojB_g`03o`000?nU[mooYJoO
00?o00001OnU/>000ol0003oYK7PojFah007ojFah003o`000?nV/N7oY[7Q00?oY[7Q0ol000000onW
/n7o0000ojNdhP09ojNdhP03o`000?nW]N;oYkGR00KoYkGR0_l00009ojVhi003o`000?nY^NGoZKWU
00OoZKWU0ol00009oj^mi`03o`000?n[_^SoZkkX00CoZkkX0ol000000on]`^Wo0000ojg3jP0:ojg3
jP;o00002On^b>d00ol0003o[/[^ojk:kP02ojk:kP?o00001On`c^l00ol0003o/=3aok3@l@02ok3@
l@;o00001Onbdo800ol0003o/MGcok7El`02ok7El`?o00001_ncfO@00ol0003o/]_eo`000002o`00
00Oo]=ke0ol00007okCSmP;o00000onfi_H2o`000003okCWmol0003o000000Ko]N[g0_l00003okO/
mP04o`000?ndkOOo0000o`0000Go]^kf0_l00004okO_m@?o00001?nel?D00ol0003o]_3eokK`m@03
okK`m@;o00000_ngl?D4o`0000Co]^of0_l00005okK^mPCo000000?o]>cgo`000?l000001OndjoL2
o`0000;o]>Sg00?o0000ok;Vn?nbi_P00_nbi_P2o`0000Co/NCh0_l00009ojkNn0;o00002OnZe_L5
o`0000[ooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`Gooo]Z000EoookJP?o001o6OoonfX5o`00
O`Wooo]Z1?l0000VoookJP;o00001onD^_800ol0003oV;W^oiRikP06oiRikP03o`000?nL]n_oW;O[
00CoW;O[1_l00005oi^dj@04o`000?nM/nOoWK?Woifci`?o00000_nM/nL00ol0003oWk;Uoinbi@06
oinbi@03o`000?nP/NCoX;7T00Co00000_nO/>@00ol0003oX:oSoj2_h`07oj2_h`03o`000?nQ[n;o
XJoR00OoXJoR00?o0000oj:_hOnR[n401?l00002oj6^h@03o`000?nR[^3oXZkP00OoXZkP00?o0000
oj>^h?nS[^001_nS[^000ol0003oXjkOo`000002o`0000GoXjkP00?o0000ojB_gonT[ml01onT[ml0
0ol0003oY:oOojB_g`05ojB_g`Co00002?nU/>000ol0003oYK7PojFah008ojFah003o`000?nV/N7o
000000;o00001OnW/n400ol0003oYkCRojNdhP07ojNdhP03o`000?nW]N;oYkGR00?oYkGR0ol00000
0onX]n?o0000ojVhi009ojVhi003o`000?nY^NGoZKWU00?oZKWU0ol00002oj^liP03o`000?n[_NOo
ZkgW00SoZkgW00?o0000oj^nj?n[_^P00ol00005ojg2j@03o`000?n]`n[o[L?Z00Ko[L?Z0_l00000
0on^a^co0000ojk8k@09ojk8k@04o`000?n^b^ko0000o`0000Wo/<k_00Co0000ok3@lOl0003o0000
2?nbdo801?l0003o/MGco`000?l00009ok?Im0?o00001ondg_D2o`0000?o]N;f00?o0000okCSm_nd
hoH00_ndhoH2o`0000Ko]^Kf0ol00005okGZm`;o00001Ongk?H3o`0000Co]^kf0_l00004okO_m@;o
00000onhkoD01?l0003o]O3eo`000?l00004okK`m@;o00001?ngl?D2o`0000;o^?3d00Co0000okK_
m_l0003o00001Onfk_H2o`0000?o]ngf0ol00004okC[m`;o00001Ondj?L01?l0003o/^Kho`000?l0
0004ok7Tn0;o00000_n`hOP00ol0003o[]khojkNn003ojkNn0?o00000_n/f_L00ol0003oZ]Kgoj[F
m`03oj[Fm`?o000000?oZ=;fo`000?l000000_l00007oookJPKo001o0ooonfX3o`00O`?ooo]Z0ol0
07l5oookJP005OoonfX3o`00OaSooo]Z1ol007l8oookJPCo00009ooonfX00ol0003oU;[boiBjlP06
oiBjlP03o`000?nH^NkoV;W^00KoV;W^00?o0000oibgjonL]n/00ol00003oiRek003o`000?nK]>Wo
VkCY00KoVkCY0ol00006oifci`03o`000?nO/^GoWk;U00CoWk;U1?l00007oin`i003o`000?nP[n?o
X:oS00OoX:oS00?o0000oj6_h_nQ[n801OnQ[n84o`0000OoXJkQ00?o0000oj:^h?nR[^001_nR[^00
0ol0003oXjkPoj>^h005oj>^h0?o00002OnS[^000ol0003oY:oOojB_g`07ojB_g`03o`000?nT[moo
Y:oO00Co00000_nT/>000ol0003oYK3PojF`h008ojF`h003o`000?nU/N3oYK7P00OoYK7P0_l00009
ojNch@03o`000?nW]>;oYkCR00OoYkCR00?o0000ojNeh_l000000_l00005ojRgh`03o`000?nY^>Co
ZKST00SoZKST00?o0000ojViiOl000000_l00006oj^liP03o`000?n[_NOoZkgW00OoZkgW0ol00009
ojg2j@03o`000?n]`n[o[L?Z00;o[L?Z0ol00004ojk6k003o`000?n^b>go[/S]00Oo[/S]0ol0000:
ok3>k`;o00002_nbdo83o`0000So/mWd0_l00003okGLm003o`000?ndg_Go]=ke00;o]=ke0_l00006
okGRmP04o`000?ndhoKo0000o`0000Ko]^Kf0_l00003okOXmP;o000000?o]N[go`000?l000001Ong
k?H2o`0000?o^>ge0_l000000onfk_Ko0000okO_m@03okO_m@;o00001OnhkoD4o`0000;o]_3e0_l0
0004okO`m@;o00000_nhl?@00ol0003o^?3do`000002o`0000Co]^kf0_l00003okO]mP;o00000ong
k?H01?l0003o]>_go`000?l00007okCXm`;o00001?nai?P2o`0000Go/>7h00?o0000ojkNn?l00000
0_l00006ojcJm`03o`000?nZe_Oo000000;o00001OnXd_H3o`0000Oooo]Z1_l007l4oookJP?o001o
00Cooo]Zo`00Ool007oo001o1_oonfX000Wooo]Z0ol007l01?oonf[o001oo`00Ool007l4oookJPGo
001o5_oonfX4o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1Ol0000XoookJP03o`000?nD^_;oU;[b
00KoU;[b00?o0000oiRik_nH^Nh00_nH^Nh6o`0000OoV;G/00?o0000oi^djOnK]>T00_nK]>T3o`00
0003oi^djOl0003oWK?W00OoWK?W00?o0000oinbiOnO/^D00ol00002oifai@03o`000?nO/>CoWk3T
00OoWk3T00?o0000oj2_honP[n<01onP[n<00ol0003oXJoRoj6_hP04o`0000;oX:kR00?o0000oj6^
hOnQ[^401onQ[^400ol0003oXZkPoj:^h006oj:^h003o`000?nS[^3oXjkP00Co00000_nR[^000ol0
003oXjkPoj>^h008oj>^h003o`000?nT[mooY:oO00KoY:oO0ol00007ojB`h003o`000?nU/>3oYK3P
00SoYK3P00?o0000ojFah?nU/N000onU/N03o`000003ojJbhOl0003oYk?Q00SoYk?Q00?o0000ojNd
h_nW]>801_nW]>83o`0000WoZ;OS00?o0000ojVhi?nY^>@01onY^>@2o`0000[oZkcV00?o0000oj^m
ion[_NL00on[_NL3o`0000;o[<3X00?o0000ojg2jOn]`^T02?n]`^T01?l0003o[L?Zo`000?l00008
ojk6k003o`000?n^b>go[/S]00?o[/S]0ol00003ok3<kP03o`000?n`c^oo/<k_00Go/<k_0_l00002
ok;Al003o`000?nbdo;o/]?b00Go/]?b0_l00003ok?GlP03o`000?ncfOCo/mWd00;o/mWd0ol00006
okGLm004o`000?ndg_Go0000o`0000So]N;f0ol00005okKVmP;o00001_ngj?H3o`0000Co]ncf0_l0
0006okS]m@Co000000?o]noeo`000?l000001OnhkoD2o`0000Co^O3d0ol00003okO`m@;o00001?nh
l?@2o`0000?o^Nod00Co0000okK^m_l0003o00000ongkOH2o`0000Go]ncf0ol00005okCXm`?o0000
0_nci_L01?l0003o/NCho`000?l00007ok3Qn0;o00002On/f_L2o`0000WoZ=;f0_l00009oookJPCo
001o1?oonfX7o`00O`Kooo]Z0008oookJPSo001o1?oonfX5o`00OaKooo]Z0ol007l3oookJP?o001o
1_oonfX5o`0002Wooo]Z00?o0000oiBjl_nD^_801?nD^_86o`0000GoU;O_00?o0000oiRek?nH]N`0
1_nH]N`4o`0000GoVkCY00?o0000oifcionM/nL00_nM/nL6o`0000KoWK7U00?o0000oin`i?nO/>@0
1onO/>@00ol0003oX:oSoj2_h`05oj2_h`Co00001onP[^800ol0003oXJkQoj6^h@07oj6^h@03o`00
0?nR[^3oXZkP00CoXZkP1?l00007oj:^h003o`000?nS[^3oXjkP00OoXjkP00?o0000ojB_gonT[ml0
0onT[ml3o`000003ojB_h?l0003oY;3P00SoY;3P00?o0000ojF`h?nU/>001onU/>000ol0003oYK7P
ojFah003o`0000GoY[;Q00?o0000ojNchOnW/n401onW/n400ol0003oYkCRojNdhP05o`0000;oZ;KS
00?o0000ojRghonX]n<02?nX]n<00ol0003oZKSTojVhi003ojVhi0?o00000_nZ^^D00ol0003oZkcV
oj^liP08oj^liP03o`000?n[_NOo000000;o00001_n/`>P00ol0003o[L;Yojg2j@07ojg2j@;o0000
2on^a^`00ol0003o[/S]o`000002o`0000Oo/<c^00?o0000ok3>kon`c^l00_n`c^l2o`0000Go/]7`
00?o0000ok;Cl_nbdo800_nbdo82o`0000Ko/mOb00Co0000ok?Im?l0003o00002Oneg?@3o`0000Oo
]N;f0_l00003okOTm@;o000000?o]^Kfo`000?l000001_ngj?H2o`0000?o^>[e00Co0000okO/m_l0
003o00001_nhkOD2o`0000?o^Nke0ol00004okS_m@;o00001Onil?@01ol0003o^_3dok[`m?njl?Co
0000okO`mOl000001?nhl?@2o`000003okW_m?l0003o^Nod00;o^Nod1?l000000ongkOKo0000o`00
0005okO/mP;o00000ongj_H00ol0003o]>Sgo`000002o`0000Go/nKg0ol00005ok3Qn0?o00000_n_
g_L00ol0003o[=[gojcJm`03ojcJm`?o00000_n[eoL00ol0003oZ=;fojSBmP05ojSBmP?o00002_oo
nfX3o`00O`Gooo]Z1Ol007l7oookJP001ooonfX4o`00O`03oookJ_l007oo001o00;o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00Oa_ooo]Z0ol007l6oookJPGo0000:_oonfX00ol0003oU;[boiBj
lP03o`0000?oS[Sc00?o0000oiBgkonD]nl01_nD]nl00ol0003oV;G/oiRek003oiRek0Co00001_nK
]>T6o`0000CoVk;W00?o0000oifaiOnM/ND01_nM/ND00ol0003oWk3Toin`i007oin`i003o`000?nP
[n?oX:oS00Co00000_nO[n<00ol0003oX:kRoj2^hP07oj2^hP03o`000?nQ[^7oXJkQ00OoXJkQ00?o
0000oj:^h?nR[^000ol00002oj:^h003o`000?nR[^3oXZkP00OoXZkP00?o0000oj>^h?nS[^001onS
[^000ol0003oY:oOo`000002o`0000GoY:oP00?o0000ojB`h?nT/>001onT/>000ol0003oYK3PojF`
h005ojF`h0Co00002OnV/^400ol0003oYk?QojNch@06ojNch@?o00002?nX]^<00ol0003oZ;OSojRg
h`08ojRgh`03o`000?nY^>Co000000;o00001_nZ^^D00ol0003oZkcVoj^liP07oj^liP;o00002_n/
`>P00ol0003o[L;Yojg2j@03ojg2j@?o00000_n^aNX00ol0003o[/K/ojk6k008ojk6k0;o00002on`
c>h01?l0003o/<k_o`000?l00008ok;Al004o`000?nbdo;o0000o`0000So/mOb0ol00008okGLm0;o
00000onfgo@00ol0003o]N;fokGRmP02okGRmP;o00001_ngi?D2o`0000Ko]nSf0_l00005okSZm@?o
00001OnhkOD2o`0000Co^Nke00Ko0000ok[_m?njkoCo^^odo`000?nhkoD2o`0000Go^O3d0_l00004
ok[`m0Co000000?o^?3do`000?l000001?niko@3o`0000?o^Nkd0ol00004okO/mP;o00001Ongj_H3
o`0000Co/nKg0ol00003ok?Tm`03o`000?n`hOSo000000;o00001_n_g_L00ol0003o[=[go`000002
o`0000KoZmOg00?o0000ojSBm_nXd_H01?l00002oookJP03o`000?oonf[ooo]Z01cooo]Z0007oook
JP?o001o0ooonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007lKoookJP?o001o1_oonfX4
o`0002cooo]Z0_l00007ohjhl`03o`000?nD]nooU;O_00KoU;O_00?o0000oiRek?l000000_l00004
oiRek003o`000?nK]>WoVkCY00?o00000_nH/nX00ol0003oVk;Woi^bi`06oi^bi`03o`000?nM/NGo
WK7U00KoWK7U00?o0000oin`i?nO/>@01OnO/>@4o`0000OoWjoS00?o0000oj2^h_nP[^801onP[^80
0ol0003oXJkQoj6^h@05oj6^h@Co00001_nR[^000ol0003oXZkPoj:^h007oj:^h003o`000?nS[^3o
XjkP00GoXjkP0ol00009ojB_h003o`000?nT/>3oY;3P00OoY;3P00?o0000ojF`h?nU/>001?l00002
ojJah@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojNchOnW/n400onW/n43o`000003ojRdh_l0003o
Z;KS00WoZ;KS00?o0000ojRghonX]n<01onX]n<2o`0000[oZ[[U00?o0000oj^li_n[_>H00on[_>H3
o`000003ojbniol0003o[<3X00[o[<3X00?o0000ojg2jOl000000_l00006ojk5jP03o`000?n^a^co
[/K/00Co[/K/0ol00002ok3:k@03o`000?n`c>ko/<c^00So/<c^0_l0000:ok;Al0?o00001onceo82
o`0000?o]M[c00?o0000okGLm?neg?@00_neg?@3o`0000Ko]]od00Co0000okGRm_l0003o00001_ng
i?D2o`0000;o^NKe00?o0000okOXm_ngj?H00_ngj?H00ol0003o^>[eokSZm@04okSZm@04o`000?nj
k?Go^^ceok[/m@;o000000?o^>geo`000?l000001?nik_D2o`0000Co^^od0ol00004okW`m0;o0000
1?njl?@2o`0000?o^o3d0ol00004okW_m0;o00001?nik_@01_l0003o^NgeokW]mOnikOGo0000okO/
mP;o00001Ongj_H2o`0000?o]^Sf00Co0000ok?Vmol0003o00001_nci?L2o`0000Wo[mkg0ol00007
oj_Gm`Co00001_oonfX00ol0003ooo]ZoookJP0LoookJP001ooonfX3o`00O`?ooo]Z0ol007l3oook
JP?o001o00Cooo]Zo`00Ool007oo001o5_oonfX2o`00O`;ooo]Z1?l007l6oookJPCo0000;_oonfX0
0ol0003oS[Scohjhl`05ohjhl`03o`000?nD]nooU;O_00GoU;O_0_l00004oiRek0Ko00001_nH/nX0
0ol0003oVk;Woi^bi`06oi^bi`03o`000?nM/NGoWK7U00KoWK7U00?o0000oin`i?nO/>@01?l00002
oif_i003o`000?nO[n?oWjoS00OoWjoS00?o0000oj2^h_nP[^801onP[^800ol0003oXJkQoj6^h@04
o`0000;oXJkQ00?o0000oj:^h?nR[^001_nR[^000ol0003oXZkPoj:^h007oj:^h003o`000?nS[^3o
XjkP00Co00000_nS[n000ol0003oY:oPojB_h008ojB_h003o`000?nT/>3oY;3P00KoY;3P0ol00007
ojJah@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojNchOl000000_l00005ojRdhP03o`000?nX]^?o
Z;KS00OoZ;KS00?o0000ojRghonX]n<01?nX]n<3o`000003ojZii?l0003oZ[[U00[oZ[[U00?o0000
oj^li_l000000_l00005ojbni`03o`000?n/`>So[<3X00So[<3X0_l0000:ojk5jP03o`000?n^a^co
[/K/00?o00001_n`b^d00ol0003o/<c^ok3<kP04ok3<kP?o00000_nbcnl00ol0003o/]7`ok;Al005
ok;Al0;o00000ondeO400ol0003o/mObok?GlP02ok?GlP;o00001_nef_<01?l0003o]Mcdo`000?l0
0009okKOm0;o00001_ngi?D2o`0000Go^NKe00Co0000okOXm_l0003o00001Onhj_D2o`0000Go^^ce
0ol00003okW^m@;o00001?njko@2o`0000?o^noc0_l000000onil?Co0000ok[`m003ok[`m0;o0000
1?nkl?@01_l0003o^nocok__lonkko?o0000okW_m0;o00000_nik_@01?l0003o^Nkdo`000?l00004
okW]m@?o00001?ngj_H2o`0000Go]^Sf0_l00005ok?Tm`?o00000_nahOL00ol0003o[mkgojoNm`03
ojoNm`?o00000on]f_L00ol0003oZmOgoj_Gm`04o`0000[ooo]Z00?o0000oookJ_oonfX07?oonfX0
00Oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00OaKooo]Z1ol007l7
oookJPCo0000;ooonfX2o`0000KoS[Sc00Co0000oiBgkonD]nooU;O_2Ol00004oiBdk@03o`000?nH
/n[oV;?Z00KoV;?Z00?o0000oi^bionK/^L01_nK/^L00ol0003oWK7Uoifai@04oifai@Co00001onM
[n@00ol0003oWjoSoin_h`07oin_h`03o`000?nP[^;oX:kR00GoX:kR1?l00007oj6^h@03o`000?nR
[^3oXZkP00KoXZkP00?o0000oj:^h?nR[^001_nR[^03o`0000OoXjoP00?o0000ojB_h?nT[n001onT
[n000ol0003oY;3PojB`h003ojB`h0?o000000?oYK3Po`000?nV/N402?nV/N400ol0003oY[;QojJb
h@07ojJbh@;o00002OnX]>800ol0003oZ;KSojRfh`07ojRfh`03o`000?nX]n?oZ;OS00?o00001OnZ
^N@00ol0003oZ[[UojZji@08ojZji@;o00002On/_^L00ol0003o[<3Xojc0j004ojc0j0?o000000?o
[/?Yo`000?n^aNX02On^aNX3o`0000[o/<[]00?o0000ok3<k_n`c>h00ol00006ok;?k`03o`000?nb
dO3o/]7`00;o/]7`0_l00006okCEl@04o`000?nceo;o0000o`0000So]M[c0ol00008okKOm0;o0000
0_nhh_@00ol0003o]nCeokOTm@02okOTm@03o`000?nii_Go^NKe00Go^NKe0ol00004okSZm@;o0000
1Onjk?D2o`0000?o^ngd00?o0000okW^mOl000001?njko@2o`0000Ko^noc1?l000000onjl?Co0000
o`000004ok_`m0;o00001?nkko<3o`0000?o^Nkd0_l00004okW]m@;o00000onik?D01?l0003o]n[f
o`000?l00005okKXmP;o00000_nfi_H00ol0003o/nCgo`000002o`0000Ko/N7g00?o0000ojoNmol0
00000_l00006ojgJm`?o00003_oonfX00ol0003ooo]ZoookJP0LoookJP001ooonfX3o`00O`?ooo]Z
0ol007l2oookJP?o001o0ooonfX3o`00OaGooo]Z1_l007l7oookJPGo0000<OoonfX00ol0003oS[Sc
ohjhl`04ohjhl`Ko00000on?]O000ol0003oU;C]oiBdk@05oiBdk@03o`000?nH/n[oV;?Z00KoV;?Z
00?o0000oi^bionK/^L01_nK/^L00ol0003oWK7Uoifai@03o`0000?oVk3V00?o0000oif_i?nM[n@0
1_nM[n@00ol0003oWjoSoin_h`07oin_h`03o`000?nP[^;oX:kR00Co00000_nO[^800ol0003oXJkQ
oj6^h@07oj6^h@03o`000?nR[^3oXZkP00GoXZkP00?o0000oj:^h?nR[^000onR[^03o`000003oj:^
h?l0003oXjoP00SoXjoP00?o0000ojB_h?nT[n001onT[n000ol0003oY;3Po`000002o`0000GoYK3P
00?o0000ojJahOnV/N401onV/N400ol0003oY[;QojJbh@03ojJbh@?o000000?oYk?Qo`000?nX]>80
2OnX]>800ol0003oZ;KSojRfh`06ojRfh`?o00002OnZ^N@00ol0003oZ[[UojZji@04ojZji@?o0000
00?o[;gVo`000?n/_^L02On/_^L00ol0003o[<3Xojc0j003o`0000Go[/?Y00?o0000ojk5j_n^aNX0
1On^aNX2o`0000;o/<S[00?o0000ok3:kOn`b^d02?n`b^d3o`0000[o//o_00Co0000ok;Al?l0003o
00002?ndeO43o`0000Oo]M[c0_l00003okOMl`03o`000?nfgoCo]]od00;o]]od0ol00005okSRm004
o`000?ngi?Go0000o`0000Ko^NKe0_l00003ok[Xm0;o000000?o^>[eo`000?njk?D01?njk?D2o`00
00Go^ngd1?l000000onjkoCo0000o`000006ok__l`;o00000onll?<3o`0000?o^o3d0_l00004ok__
l`;o00000onlko<00ol0003o^Nkdo`000002okW]m@04o`000?nikOGo0000o`0000Go^Nce0ol00004
okKXmP;o00001?nfi_H2o`0000Wo/N7g0ol00005ojgJm`?o00004OoonfX00ol0003ooo]ZoookJP0L
oookJP001ooonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`?ooo]Z0ol007lEoook
JP;o001o2ooonfX5o`0003;ooo]Z2Ol00007ohnel003o`000?nD]>goU;C]00GoU;C]00?o0000oiRc
j_nH/nX01_nH/nX00ol0003oVk;Woi^bi`02oi^bi`Ko00001onK/>H00ol0003oWJoToif_i006oif_
i003o`000?nO[n?oWjoS00GoWjoS1?l00007oin^hP03o`000?nQ[^7oXJkQ00OoXJkQ00?o0000oj:^
h?nR[^001OnR[^000ol0003oXZkPo`000002o`0000GoXZkP00?o0000oj>_h?nS[n001onS[n000ol0
003oY:oPojB_h005ojB_h0?o00002OnU/>000ol0003oY[7QojJah@07ojJah@03o`000?nV/^7o0000
00;o00001OnW/n400ol0003oZ;CRojRdhP07ojRdhP03o`000?nX]^?oZ;KS00?oZ;KS0ol00002ojVh
h`03o`000?nZ^NCoZ[WT00SoZ[WT00?o0000ojZjiOnZ^^D00ol00005ojbmiP03o`000?n/_^Oo[;kW
00Oo[;kW0ol00009ojk3j@03o`000?n^aN[o[/GZ00;o[/GZ0_l00005ok38j`03o`000?n`b^go/<[]
00Go/<[]0_l00002ok;=kP03o`000?nbcnoo//o_00So//o_0ol00007okCEl@;o00000onff?800ol0
003o]M[cokGJl`02okGJl`;o00001_nggO<01?l0003o]]odo`000?l00008okSRm0?o00001Onii_D2
o`0000Ko^^Sd0ol00004ok[/m@03o`000?nkkOCo^ngd00?o^ngd0_l00003okc^l`?o00001Onkko<2
o`0000Co_?3c00Oo0000okg`lonml??o_O3co`000?nkl?Co000000Co^noc0_l00005okc_l`Co0000
00?o^Ngeo`000?l000001Onik?D2o`0000?o^N_e00Co0000okKXm_l0003o00001?nfi_H2o`0000;o
]>Cf00?o0000ok7QmonahOL00onahOL3o`0000?o/=kg00?o0000ojgJmol000000_l0000DoookJP03
o`000?oonf[ooo]Z01cooo]Z0008oookJPSo001o0_oonfX3o`00O`?ooo]Z0ol007lEoookJP;o001o
2ooonfX5o`0003;ooo]Z0ol00005ohNfm003o`000?n?]O3oSkG`00KoSkG`00?o0000oiBdkOnD]>d0
1OnD]>d00ol0003oV;?ZoiRcjP04oiRcjPKo00001?nI/>P00ol0003oVk3Voi^`iP07oi^`iP03o`00
0?nM[nCoWJoT00KoWJoT00?o0000oin_honO[n<01?l00002oij^h`03o`000?nO[^;oWjkR00OoWjkR
00?o0000oj6^hOnQ[^401_nQ[^400ol0003oXZkPoj:^h004oj:^h0?o00002OnR[^000ol0003oXjoP
oj>_h007oj>_h003o`000?nT[n3oY:oP00Co00000_nT/>000ol0003oYK3PojF`h008ojF`h003o`00
0?nV/N7oY[7Q00KoY[7Q0_l00009ojNch@03o`000?nX]>;oZ;CR00OoZ;CR00?o0000ojRfhol00000
0_l00006ojVhh`03o`000?nZ^NCoZ[WT00OoZ[WT0ol00009ojbmiP03o`000?n/_^Oo[;kW00Co[;kW
0_l00002ojk1j003o`000?n^`nWo[/?Y00So[/?Y00Co0000ojk5j_l0003o00002?n`b>/00ol0003o
/<[]ok3:k@02ok3:k@;o00001OnbcNh00ol0003o//o_ok;?k`04ok;?k`?o00000ondd_000ol0003o
]=GaokCEl@02okCEl@;o00001_nff?801?l0003o]M[co`000?l00008okOMl`?o00001onhh_@2o`00
00?o^^Gd0_l000000onii_Go0000o`000006ok[Xm0;o00000onlj_@01?l0003o^^ceo`000?l00004
ok_]m0;o00001?nlk_<01?l0003o_^ocokk_lonnko<2o`000003ok__lol0003o000000Co_?3c0_l0
0004okg`l`Co000000?o^noco`000?l000001Onlko<2o`0000?o_>kc1?l00003okW/m@;o00001Oni
joD3o`0000Co]^Kf00?o0000okCTm_ndi?H00ondi?H00ol0003o/N7go`000002o`0000Ko/=kg0_l0
000GoookJP03o`000?oonf[ooo]Z01cooo]Z0009oookJP?o001o00Gooo]Zo`00Ool007oo001ooook
JP03o`00O`Gooo]Z0ol007lEoookJPOo001o1OoonfX4o`00033ooo]Z0ol00002oookJP03o`000?n7
]_CoQkKd00CoQkKd00?o0000ohnel?n?]O001_n?]O000ol0003oU;C]oiBdk@05oiBdk@03o`000?nH
/n[oV;?Z00?o00000onE/N/00ol0003oVK3XoiV`j005oiV`j003o`000?nK/>KoVk3V00OoVk3V00?o
0000oif_i?nM[n@01?nM[n@4o`0000OoWZkS00?o0000oin^h_nO[^801onO[^800ol0003oXJkQoj6^
h@06oj6^h@03o`000?nR[^3oXZkP00?o00000_nQ[^400ol0003oXZkPoj:^h008oj:^h003o`000?nS
[n3oXjoP00KoXjoP0ol00007ojB`h003o`000?nU/>3oYK3P00OoYK3P00?o0000ojJahOnV/N400onV
/N43o`000003ojJbhOl0003oYk?Q00WoYk?Q00?o0000ojRdh_nX]>801OnX]>83o`0000[oZKSS00?o
0000ojZii?nZ^N@00onZ^N@3o`000003oj^kiOl0003o[;gV00Wo[;gV00?o0000ojbnion/_^L00_n/
_^L2o`0000Go[/7X00?o0000ojk3jOn^`nT01on^`nT2o`0000_o/<S[00Co0000ok3:kOl0003o0000
2?nbcNh00ol0003o//o_ok;?k`03o`0000Oo]=;`00Co0000okCElOl0003o00002?nff?83o`0000Oo
]mgc0_l00003okWPl`03o`000?nhh_Co^>;d00;o^>;d0_l00006ok[Um0?o00001Onjj?@2o`0000Go
_>[d1?l00002ok_]m0;o00001?nlk_<2o`0000Go_^oc0ol00003okc`l`;o00001?nml?<2o`0000?o
__3b0ol00004okc_l`;o00001?nlk_<01?l0003o_>gcokc]lonlkO<4o`0000Go^N_e0_l00003okWY
m@04o`000?nfi_Ko0000o`0000Ko]>Cf0ol00005ok3Nm`?o00006_oonfX00ol0003ooo]ZoookJP0K
oookJP003OoonfX3o`00Ob7ooo]Z1ol007l5oookJPCo0000;OoonfX3o`0000Kooo]Z00?o0000ohNf
m?n7]_@01?n7]_@00ol0003oSkG`ohnel006ohnel003o`000?nD]>goU;C]00;oU;C]1Ol00007oiFa
j`03o`000?nI/>SoVK3X00GoVK3X00?o0000oi^`i_nK/>H01onK/>H00ol0003oWJoToif_i003o`00
00;oW:kT00?o0000oij^honN[^<01onN[^<00ol0003oWjkRoin^hP06oin^hP03o`000?nQ[^7oXJkQ
00GoXJkQ1?l00006oj6^h@03o`000?nR[^3oXZkP00OoXZkP00?o0000oj>_h?nS[n000onS[n03o`00
0003oj>_h?l0003oY;3P00SoY;3P00?o0000ojF`h?nU/>001onU/>000ol0003oY[7Qo`000002o`00
00GoY[;Q00?o0000ojNchOnW/n402?nW/n400ol0003oZ;CRojRdhP04o`0000?oZKKS00?o0000ojVh
honY^><02?nY^><00ol0003oZ[WTo`000002o`0000GoZk_U00?o0000ojbmi_n/_NH02?n/_NH01?l0
003o[;kWo`000?l00008ojk1j003o`000?n^`nWo[/?Y00?o[/?Y0ol00002ok36jP03o`000?n`b>_o
/<S[00So/<S[0_l0000:ok;=kP?o00002_ndd_03o`0000Oo]]Sb0_l00003okSKlP03o`000?nggO?o
]mgc00;o]mgc0_l00006okWPl`04o`000?nhh_Co0000o`0000Ko^^Gd0_l00003okcWl`;o000000?o
^^Sdo`000?l000001Onlj_@2o`0000Co_Ncc0ol00003okc^l`;o00001_nnko<01ol0003o_noboko_
l_noko;o0000okc`lol000001?nml?<2o`0000Co__3b00Ko0000okk_l_nnko;o_^obo`000?nlko<2
o`0000Co_>kc0_l00004okc]l`?o00001?nijoD2o`0000Go^NWe0ol00004okCTmP?o00000onch_L0
0ol0003o/=kgo`000002o`0001gooo]Z00?o0000oookJ_oonfX06ooonfX000gooo]Z0ol007l]oook
JPCo0000:_oonfX3o`0000[ooo]Z00?o0000ohNfm?n7]_@01?n7]_@00ol0003oSkG`ohnel002ohne
l0So00001?n@/^h00ol0003oUK7[oiFaj`06oiFaj`03o`000?nI/>SoVK3X00GoVK3X00?o0000oi^`
i_nK/>H01OnK/>H4o`0000KoW:kT00?o0000oij^honN[^<01onN[^<00ol0003oWjkRoin^hP06oin^
hP03o`000?nQ[^7oXJkQ00Co00000_nP[^400ol0003oXJkQoj6^h@06oj6^h@03o`000?nR[^3oXZkP
00OoXZkP00?o0000oj>_h?l000000_l00005oj>_h003o`000?nT/>3oY;3P00OoY;3P00?o0000ojF`
h?nU/>001OnU/>03o`0000WoY[;Q00?o0000ojNchOnW/n401onW/n43o`0000SoZKKS00?o0000ojVh
honY^><01onY^><2o`0000WoZk_U00?o0000ojbmi_n/_NH01on/_NH2o`0000_o[/7X00?o0000ojk3
jOl000000_l00006ok36jP03o`000?n`b>_o/<S[00Co/<S[0ol00002ok;;k003o`000?nbcNko//g^
00Go//g^0_l00002okC@kP03o`000?ndd_3o]=;`00Ko]=;`0_l00003okKFl003o`000?nff?;o]]Sb
00;o]]Sb0_l00006okSKlP04o`000?nggO?o0000o`0000So^N3c0ol00005ok[Um0;o00001_nlio<3
o`0000Co_>[d0_l00005okg/l`07o`000?nnkO;o_^gbokk]l_l0003o_>kco`000006okk_l`;o0000
1?noko84o`000003okg`lol0003o000000Co__3b0_l00004okk_lP?o00000onlk_<2o`0000Co_>gc
0_l00002okc/m0;o000000?o^N_eo`000?l000001OnijOD2o`0000?o^>Oe00Co0000okCTm_l0003o
00001_nch_L2o`00023ooo]Z00?o0000oookJ_oonfX06ooonfX000gooo]Z0ol007l]oookJPCo0000
:?oonfX2o`0000kooo]Z2ol00005ohVcl@03o`000?n@/^koT;;^00GoT;;^00?o0000oiFajonE/N/0
1_nE/N/00ol0003oVK3XoiV`j005oiV`j003o`000?nK/>KoVk3V00Co00000_nI[nH00ol0003oW:kT
oib^i006oib^i003o`000?nN[^?oWZkS00KoWZkS00?o0000oin^h_nO[^801OnO[^84o`0000OoX:kQ
00?o0000oj6^hOnQ[^401_nQ[^400ol0003oXZkPoj:^h005oj:^h0?o00002OnS[n000ol0003oY;3P
ojB`h007ojB`h003o`000?nU/>3oYK3P00Co00000_nV/N400ol0003oY[;QojJbh@08ojJbh@03o`00
0?nW/n7oYk?Q00?oYk?Q0ol000000onX]N;o0000ojVfh`09ojVfh`03o`000?nY^>?oZKSS00?oZKSS
0ol000000on[^^Co0000oj^ki@09oj^ki@03o`000?n/_NKo[;gV00?o[;gV0ol00002ojfoi`03o`00
0?n^`NSo[/7X00So[/7X0_l0000:ok36jP03o`000?n`b>_o/<S[00?o00001_nbbn`00ol0003o//g^
ok;=kP02ok;=kP;o00001Ondd>h00ol0003o]=;`okCBl002okCBl0?o00001_nfe_001?l0003o]]Sb
o`000?l00008okSKlP?o00001onih?<2o`0000?o^n?c0_l000000onjiOCo0000o`000007okcWl`06
o`000?nmj??o_NScokgXlol0003o_>[d0_l00005okg/l`;o00001?nnkO83o`0000Co_^oc0_l00004
oko_lP;o00000oo0ko83o`0000?o__3b0_l00004okk_lP;o00000onoko800ol0003o_>kco`000004
okc]l`;o00001Onlk?@3o`0000Co^NWe0_l00005okSWm@;o00001Onch_L3o`0002;ooo]Z00?o0000
oookJ_oonfX06ooonfX003cooo]Z1_l0000ToookJP?o00004OoonfX00ol0003oP;?eoh2cm@05oh2c
m@03o`000?n9/o7oRK?a00GoRK?a00?o0000oi2bk_n@/^h01On@/^h00ol0003oUK7[oiFaj`06oiFa
j`03o`000?nI/>SoVK3X00;oVK3X1Ol00007oiV_iP03o`000?nL[^CoW:kT00KoW:kT00?o0000oij^
honN[^<01_nN[^<00ol0003oWjkRoin^hP04o`0000;oWZkR00?o0000oj2^hOnP[^401onP[^400ol0
003oXJkQoj6^h@06oj6^h@03o`000?nR[^3oXZkP00Co00000_nR[n000ol0003oXjoPoj>_h008oj>_
h003o`000?nT/>3oY;3P00KoY;3P0ol00007ojJah@03o`000?nV/^7oY[;Q00SoY[;Q00?o0000ojNc
hOl000000_l00005ojRehP03o`000?nY]^?oZKKS00SoZKKS00?o0000ojVhhol000000_l00005oj^j
i003o`000?n[^nGoZk_U00SoZk_U00?o0000ojbmi_l000000_l00006ojfoi`03o`000?n^`NSo[/7X
00Go[/7X0_l000000on`a>Wo0000ok36jP09ok36jP?o00002_nbbn`01?l0003o//g^o`000?l00008
okC@kP04o`000?ndd_3o0000o`0000Wo]]K`0_l00009okSKlP05o`000?njg_;o^]kbok[Nl_l00000
1?nih?<2o`0000Ko^n?c0ol00006okcWl`;o00001?nmj?<3o`0000Co_Ncc0_l00005okk]lP04o`00
0?o0k_;o`>kbol3^lP;o000000?o_^oco`000?noko800onoko82o`0000Co`>ob00Oo0000ol7_lOo1
ko7o`Noao`000?nnl?;o000000Go_^ob00?o0000oko_l_noko800onoko84o`000003okc]lol0003o
000000Go_>cd0_l000001OnljoCo0000okc[m?l0003o^NWe00;o00001OnhioD2o`0000;o]nGf00?o
0000ok?Rmol000000_l0000UoookJP03o`000?oonf[ooo]Z01_ooo]Z000loookJPGo00008_oonfX3
o`0001Gooo]Z00?o0000oh2cmOn0/oD01On0/oD00ol0003oRK?aohVcl@05ohVcl@03o`000?n@/^ko
T;;^00GoT;;^00?o0000oiFajonE/N/00_nE/N/8o`0000?oUZoX00?o0000oiV_i_nI[nH01onI[nH0
0ol0003oW:kToib^i005oib^i003o`000?nN[^?oWZkS00GoWZkS1?l00007oij^hP03o`000?nP[^7o
X:kQ00KoX:kQ00?o0000oj6^hOnQ[^401OnQ[^44o`0000OoXZoP00?o0000oj>_h?nS[n001onS[n00
0ol0003oY;3PojB`h003ojB`h0?o000000?oYK7Po`000?nV/N402?nV/N400ol0003oY[;QojJbh@07
ojJbh@;o00002OnX]N800ol0003oZKKSojVfh`07ojVfh`;o00002On[^^@00ol0003oZk_Uoj^ki@07
oj^ki@;o00002_n]_nL00ol0003o[/7Xojk1j002ojk1j0;o00001?n`a>T00ol0003o/<KZok36jP05
ok36jP;o00000_nbbN/00ol0003o//_/ok;;k008ok;;k0;o00002_ndd>h3o`0000So]]K`0_l00002
okWIl003o`000?nhfo;o^=_b00Co^=_b0_l00005ok[NlP04o`000?nih??o0000o`0000Oo^n?c00Go
0000okgUl_nmiO;o_NGbo`000003okcWl`;o00001Onmj?<01?l0003o_n[bokoZl_noj_82o`000003
okg/lol0003o_^gb00Co_^gb0_l00005ol3^lPCo000000?o_nobo`000?l000001?o0ko82o`0000Co
`Noa1?l00002okk_lP;o00001?noko82o`0000?o_nkb0ol00004okc/m0;o00001?nljo@4o`0000Co
^>Oe0_l00004okOUmP;o0000:?oonfX00ol0003ooo]ZoookJP0KoookJP00??oonfX5o`0001oooo]Z
0ol0000IoookJP03o`000?n0/oGoP;?e00GoP;?e00?o0000ohVclOn9/o401On9/o400ol0003oT;;^
oi2bkP02oi2bkPOo00001?nA/>/00ol0003oUZoXoiJ_j005oiJ_j003o`000?nI[nKoVJoV00OoVJoV
00?o0000oib^i?nL[^@01OnL[^@00ol0003oWZkSoij^h`04o`0000;oWJkS00?o0000oij^h_nN[^80
1onN[^800ol0003oX:kQoj2^h@06oj2^h@03o`000?nQ[^7oXJkQ00Co00000_nQ[^400ol0003oXZoP
oj:_h007oj:_h003o`000?nS[n3oXjoP00OoXjoP00?o0000ojB`h?l000000_l00005ojFah003o`00
0?nV/N7oY[7Q00OoY[7Q00?o0000ojJbhOnV/^400onV/^43o`000003ojNdhOl0003oZ;GR00WoZ;GR
00?o0000ojVfhonY]^<00onY]^<3o`000003ojZhhol0003oZk[T00WoZk[T00?o0000oj^kiOn[^nD0
0on[^nD3o`000003ojfmi_l0003o[KoW00[o[KoW00Co0000ojk1j?l0003o00001on`a>T00ol0003o
/<KZok36jP02ok36jP;o00001OnbbN/00ol0003o//_/ok;;k005ok;;k0;o00000_ndc^d00ol0003o
]=3^okC@kP05okC@kP;o00000ongdnl2o`0000Co]]K`0_l00005okWIl004o`000?nhfo;o^=_bokSK
lP;o00001onjg_83o`0000Ko^n?c0_l00005okgUlP03o`000?nlio?o000000Go_NSc0_l00005okoZ
lP?o00000onnkO82o`0000Ko`>kb00Co0000ol7^lOo1k_7o`Nka0ol00003ol3_lP;o00001Oo1ko40
0ol0003o`^oaol;_l@02ol;_l@?o00001?noko800ol0003o_nkboko^lP02oko^lP06o`000?nokO;o
_ngboko]l_l0003o_>cd0_l00005okc[m0;o00000onkjO@01?l0003o^>Oeo`000?l00004okOUmP;o
0000:_oonfX00ol0003ooo]ZoookJP0KoookJP00??oonfX4o`0001gooo]Z0ol0000MoookJP03o`00
0?n0/oGoP;?e00GoP;?e00?o0000ohVclOn9/o400_n9/o47o`0000?oRk3_00?o0000oi6`jonA/>/0
1_nA/>/00ol0003oUZoXoiJ_j005oiJ_j003o`000?nI[nKoVJoV00OoVJoV00?o0000oib^i?nL[^@0
0_nL[^@5o`0000OoWJkS00?o0000oij^h_nN[^801onN[^800ol0003oX:kQoj2^h@04oj2^h@Co0000
1onQ[^400ol0003oXZoPoj:_h007oj:_h003o`000?nS[n3oXjoP00GoXjoP0ol00009ojFah003o`00
0?nV/N7oY[7Q00OoY[7Q00?o0000ojJbhOl000000_l00005ojNdh@03o`000?nX]N;oZ;GR00SoZ;GR
00?o0000ojVfhol000000_l00005ojZhh`03o`000?n[^^CoZk[T00SoZk[T00?o0000oj^kiOl00000
0_l00005ojfmiP03o`000?n]_nOo[KoW00So[KoW0_l0000:ok34j@04o`000?n`a^[o0000o`0000So
//W[00?o0000ok;;k?nbbn`00_nbbn`2o`0000Go]<k]00?o0000okC@k_ndd>h00_ndd>h2o`0000Oo
]m?_00Co0000okKFl?l0003o00002?nifO000ol0003o^=_bo`000007ok[NlP;o00000onlh?401?l0
003o^n?cok_Slonkho<2o`0000Oo_NGb0ol00003okgXl`;o00001_noj_801ol0003o`N_bol7[l_o1
jo;o0000okk]l_l000001_o0k_82o`0000?o`Nka00Oo0000ol;_lOo2ko7o`^oao`000?o0ko;o0000
00Go`Noa0_l00004ol;_l@06o`000?o2ko7o`^oaol;_lOl0003o_nob0_l00003oko^lP;o00001?no
kO83o`0000Co_>_d0_l00002ok_Ym003o`000?nkjOCo^nWd00?o00001?ngiOH00ol0003ooo]Zoook
JP0[oookJP03o`000?oonf[ooo]Z01[ooo]Z000loookJPCo00006_oonfX3o`00027ooo]Z3?l00004
oh>`lP03o`000?n;/>ooRk3_00CoRk3_00?o0000oi6`jonA/>/01_nA/>/00ol0003oUZoXoiJ_j005
oiJ_j003o`000?nI[nKoVJoV00GoVJoV1_l00003oiZ^i@03o`000?nM[^?oWJkS00OoWJkS00?o0000
oij^h_nN[^801onN[^800ol0003oX:kQoj2^h@03o`0000;oX:kQ00?o0000oj6^hOnQ[^401onQ[^40
0ol0003oXZoPoj:_h007oj:_h003o`000?nS[n3oXjoP00Co00000_nT/>000ol0003oYK7PojFah008
ojFah003o`000?nV/N7oY[7Q00KoY[7Q0_l00009ojNdh@03o`000?nX]N;oZ;GR00OoZ;GR0_l00009
ojZhh`03o`000?n[^^CoZk[T00OoZk[T0_l00009ojfmiP03o`000?n]_nOo[KoW00Co[KoW0ol00002
ojo2i`03o`000?n`a>Wo/<CY00Oo/<CY0ol0000:ok;9j`04o`000?nbbnco0000o`0000So]<k]00Co
0000okC@k_l0003o00002Ongdnl2o`0000[o^MW`0ol00005ok[NlP;o00001_nlh?400ol0003o^n?c
o`000007okgUlP;o00000onoio800ol0003o_NSco`000006okoZlP;o00001?o1jo83o`0000Co`>kb
0_l00003ol7^l@;o00001?o2ko43o`0000Co`Noa00?o0000ol;_lOo2ko400_o2ko42o`0000Co`^oa
0ol00003oko^lP03o`000?nokO;o_ngb00;o_ngb0_l00003oko/lP04o`000?nljoCo0000o`0000Go
^nWd0_l00003ok[Wm004o`000?ngiOKo0000o`0002kooo]Z00?o0000oookJ_oonfX06_oonfX003co
oo]Z1?l0000GoookJP?o00009_oonfX00ol0003oN;3fogR`mP04ogR`mP03o`000?n3/?;oPk3b00Go
Pk3b00?o0000oh^`kon;/>l01?n;/>l00ol0003oTK3[oi6`j`06oi6`j`03o`000?nF[nSoUZoX00Go
UZoX00?o0000oiV_i_nI[nH01?l00002oiN^i`03o`000?nJ[^GoVZkU00GoVZkU00?o0000oif^honM
[^<01onM[^<00ol0003oWZkRoij^hP05oij^hPCo00001_nP[^400ol0003oXJkQoj6^h@07oj6^h@03
o`000?nR[n3oXZoP00KoXZoP0ol00007ojB`h003o`000?nU/N3oYK7P00OoYK7P00?o0000ojJahOnV
/N400onV/N43o`000003ojNbhOl0003oYkCQ00WoYkCQ00?o0000ojReh_nX]N800onX]N83o`000003
ojVgh_l0003oZ[SS00SoZ[SS00?o0000oj^ji?n[^^@01?n[^^@3o`000003ojfliOl0003o[KgV00Wo
[KgV00?o0000ojfoion]_nL00ol00006ojo2i`03o`000?n`a>Wo/<CY00?o/<CY0ol00003ok;6j@03
o`000?nbbN_o//W[00Oo//W[0_l0000:okC>k@;o00002Ongdnl2o`0000;o^MK_00?o0000okWIl?ni
fO001OnifO02o`0000?o^m_`0_l000000onjg_;o0000o`000008okcPl@?o00001OnmiO82o`0000Go
_nOb0ol00004okoZlP;o00001Oo1jo801?l0003o`^caol;/lOo2k?42o`000003ol3^l_l0003o`Nka
00;o`Nka0_l00005ol;_l@04o`000?o3ko3o`no`ol?_l0;o000000?o`Noao`000?o2ko400_o2ko42
o`0000Go`^oa00Oo0000ol?_lOo3ko7o`noao`000?nok_;o000000Co_ngb00?o0000oko/l_nok?80
0onok?83o`0000Co^nWd0ol00004ok[Wm0;o0000<?oonfX00ol0003ooo]ZoookJP0JoookJP00>ooo
nfX6o`0001?ooo]Z0ol0000ZoookJP;o00001Omh/?H00ol0003oPk3boh>`lP05oh>`lP03o`000?n;
/>ooRk3_00CoRk3_00?o0000oi6`jonA/>/01_nA/>/00ol0003oUZoXoiJ_j002oiJ_j0Go00001onG
[^L00ol0003oVZkUoiZ^i@05oiZ^i@03o`000?nM[^?oWJkS00OoWJkS00?o0000oij^h_nN[^801?l0
0002oij]hP03o`000?nP[^7oX:kQ00KoX:kQ00?o0000oj6^hOnQ[^401_nQ[^400ol0003oXZoPoj:_
h003oj:_h0?o000000?oXjoPo`000?nT/>002?nT/>000ol0003oYK7PojFah007ojFah003o`000?nV
/N7o000000;o00001OnW/^400ol0003oYkCQojNdh@08ojNdh@03o`000?nX]N;o000000;o00001OnY
]n800ol0003oZ[SSojZhh`07ojZhh`03o`000?n[^^CoZk[T00?o00001On]_>D00ol0003o[KgVojfm
iP07ojfmiP?o00002_n_`^L00ol0003o/<CYo`000002o`0000Oo//KY00?o0000ok;9jonbbN/00onb
bN/3o`0000;o]<c[00?o0000okC>kOndc^d01Ondc^d2o`0000;o]m7]00?o0000okOCkongdnl01?ng
dnl2o`0000Go^MK_00?o0000okWIl?nifO000_nifO02o`0000Ko^m_`0ol00007okcPl@;o00000onn
h_42o`000003okgUl_l0003o000000Go_nOb0_l00003ol7Xl@;o000000?o_n[bo`000?o1jo801?o1
jo82o`0000Go`^ca1?l000000oo1k_7o0000ol;_l@04ol;_l@;o00001Oo3ko04o`000003ol;_lOl0
003o`^oa00Co`^oa0_l00004ol?_l@Co000000?o_ngbo`000?l000001?nok?82o`0000?o_n_b00Co
0000ok_Ym?l0003o00000onjio@01?l0003o^^Odo`000?l0000boookJP03o`000?oonf[ooo]Z01[o
oo]Z000koookJPGo00004_oonfX2o`0002oooo]Z00?o0000ogR`m_mh/?H00omh/?H00ol0003oPk3b
oh>`lP05oh>`lP03o`000?n;/>ooRk3_00CoRk3_00?o0000oi6`jonA/>/00_nA/>/8o`0000?oTjkY
00?o0000oiN^ionG[^L01onG[^L00ol0003oVZkUoiZ^i@05oiZ^i@03o`000?nM[^?oWJkS00GoWJkS
1?l00007oij]hP03o`000?nP[^7oX:kQ00KoX:kQ00?o0000oj6^hOnQ[^401_nQ[^400ol0003oXZoP
o`000002o`0000GoXjoP00?o0000ojB`h?nT/>001onT/>000ol0003oYK7PojFah005ojFah0?o0000
2OnW/^400ol0003oYkCQojNdh@07ojNdh@;o00002OnY]n800ol0003oZ[SSojZhh`06ojZhh`?o0000
2On]_>D00ol0003o[KgVojfmiP03ojfmiP?o00000_n_`>H00ol0003o[l;Wojo2i`08ojo2i`;o0000
2onba^T00ol0003o//W[o`000002o`0000Ko]<c[00?o0000okC>kOndc^d00_ndc^d2o`0000Go]m7]
00?o0000okOCkongdnl00_ngdnl00ol0003o^MK_okWFk`06okWFk`04o`000?nifO3o0000o`0000Oo
^m_`00Go0000okgNl?nmg_3o_Mk`o`000004okcPl@;o00001_nnh_43o`0000Co_nOb0_l00006ol7X
l@?o00000oo1jo82o`0000Go`^ca0_l00003olC]l0?o00001?o2ko400ol0003o`no`ol?_l004ol?_
l004o`000?o4ko3oa>o`olC_l0?o00000oo2ko42o`0000Co`noa0_l00003ol?^l0?o00001?nok?80
0ol0003o_n_boko[lP03oko[lP?o00001?njio@2o`0003Cooo]Z00?o0000oookJ_oonfX06_oonfX0
03_ooo]Z1Ol0000?oookJP?o0000<_oonfX5o`000003ogR`m_l0003oPk3b00?oPk3b3_l00004ohj^
k003o`000?nC[^WoTjkY00GoTjkY00?o0000oiN^ionG[^L01onG[^L00ol0003oVZkUoiZ^i@05oiZ^
i@03o`000?nM[^?oWJkS00Co00000_nL[N<00ol0003oWZgRoij]hP07oij]hP03o`000?nP[^7oX:kQ
00GoX:kQ00?o0000oj6^hOnQ[^401OnQ[^43o`0000WoXjoP00?o0000ojB`h?nT/>001onT/>000ol0
003oYK7PojFah004o`0000;oY[7Q00?o0000ojNbhOnW/^402?nW/^400ol0003oYkCQojNdh@03ojNd
h@?o000000?oZKGRo`000?nY]n802?nY]n800ol0003oZ[SSojZhh`03ojZhh`?o000000?o[;[To`00
0?n]_>D02_n]_>D00ol0003o[KgVo`000002o`0000Ko[l3V00?o0000ojo2ion_`^L01On_`^L2o`00
0003ok74j?l0003o//KY00[o//KY0_l0000:okC<j`04o`000?ndc^go0000o`0000So]m7]00Co0000
okOCkol0003o00002Onie^l3o`0000Ko^m_`0_l00005okgNl004o`000?nlh?7o0000o`0000Ko_^;a
0_l00003ol3Tl@04o`000?noio;o0000o`0000Ko`NSa0_l00003ol?Yl003o`000?o1jo;o000000Go
`^ca0_l00004olC]l004o`000?o5k^ooaNk_olG^k`;o000000?o`^oao`000?o3ko001?o3ko02o`00
00?oa>o`00Oo0000olG_koo5knooaNo_o`000?o2ko7o000000Co`noa0_l00004ol?^l006o`000?o3
kO3o`ng`ol?]l?l0003o_ncb0_l00004oko[lP;o00000onnjO<01?l0003o^^Odo`000?l00002oook
JP03o`000?oonf[ooo]Z037ooo]Z00?o0000oookJ_oonfX06_oonfX003_ooo]Z1?l0000=oookJP?o
0000=_oonfX01?l0003oKZcfofj/m_m^[?H6o`0000?oO:kc00?o0000ohJ^kon6[^l01On6[^l00ol0
003oSZk/ohj^k005ohj^k003o`000?nC[^WoTjkY00GoTjkY00?o0000oiN^ionG[^L01_nG[^L00ol0
003oVZkUoiZ^i@04oiZ^i@Co00001onL[N<00ol0003oWZgRoij]hP07oij]hP03o`000?nP[^7oX:kQ
00GoX:kQ00?o0000oj6^hOnQ[^401?l00002oj6^h@03o`000?nS[n3oXjoP00SoXjoP00?o0000ojB`
h?nT/>001_nT/>03o`0000OoY[7Q00?o0000ojNbhOnW/^402?nW/^400ol0003oYkCQo`000002o`00
00GoZKGR00?o0000ojVgh_nY]n801onY]n800ol0003oZ[SSo`000002o`0000Go[;[T00?o0000ojfl
iOn]_>D02?n]_>D2o`0000[o[l3V00?o0000ojo2ion_`^L00_n_`^L2o`0000Co/LCX00?o0000ok;6
jOnba^T01_nba^T2o`000003okC9j_l0003o]<c[00Wo]<c[0_l0000:okOAk@?o00002?nie^l2o`00
00?o^mW_00Co0000ok_Kl?nkfo3o^m_`0_l00007okgNl0;o00001_nnh_42o`0000Go`>Ca0ol00005
ol7Xl@;o00001Oo3jO04o`0000;o`^ca0_l00004olC]l0;o00001Oo5k^l3o`0000?o`no`0_l00003
olC_l0;o00001?o5knl4o`000003ol?_lOl0003o000000Co`nk`0_l00004ol?]l0?o00001?nojo80
0ol0003o_^WcokkYl`03okkYl`;o00001?oonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[o
oo]Z01[ooo]Z000koookJPCo00002_oonfX3o`0003[ooo]Z00?o0000ofj/m_m^[?H00om^[?H00ol0
003oO:kcogb^l`04ogb^l`03o`000?n6[^ooQZk_00GoQZk_00?o0000ohj^k?n>[^`01On>[^`00ol0
003oTjkYoi>^j@05oi>^j@03o`000?nG[^OoUjkW00KoUjkW00?o0000oiZ^iOnJ[^D00ol00002oiV]
i@03o`000?nL[N?oW:gS00OoW:gS00?o0000oij]h_nN[N801_nN[N800ol0003oX:kQoj2^h@04oj2^
h@Co00001onQ[^400ol0003oXjoPoj>_h007oj>_h003o`000?nT/>3oY;3P00?oY;3P0ol000000onU
/>7o0000ojJah@08ojJah@03o`000?nW/^7oYk;Q00OoYk;Q0_l00009ojVehP03o`000?nY]n;oZKOR
00KoZKOR0_l00009ojbji003o`000?n]_>Go[KcU00Go[KcU0_l00002ojjni@03o`000?n_`>Ko[l3V
00So[l3V00Co0000ojo2iol0003o00001onaa>P00ol0003o//KYok;6j@02ok;6j@?o00001?ndbNX0
0ol0003o]<c[okC<j`05okC<j`;o00000_ngc^`00ol0003o]m7]okOAk@05okOAk@;o00000onidnd0
0ol0003o^MK_okWFk`02okWFk`?o00001_nkfNl00ol0003o^m_`o`000008okgNl004o`000?noh?3o
_n3`o`0000Co_^;a00?o0000ol3TlOo0i?401?o0i?401?l0003o`^K`ol;Vl?o2i_02o`000003ol7X
lOl0003o000000Ko`nW`00?o0000olC[l?o4jo000_o4jo03o`0000?oa>g`0_l00006olG^k`07o`00
0?o6k^ooa^k_olK^kol0003o`no`o`000003olC_l0;o00001Oo5knl01?l0003oa^o_olK_koo6knl3
o`0000?o`nk`0_l00005ol?]l006o`000?o3k?7o`ncaol?/lOl0003o_n_b0_l00004okkYl`;o0000
1ooonfX00ol0003ooo]ZoookJP0aoookJP03o`000?oonf[ooo]Z01Wooo]Z000koookJPKo00001Ooo
nfX3o`0003kooo]Z00?o0000ofj/m_m^[?H00om^[?H00ol0003oO:kcogb^l`04ogb^l`03o`000?n6
[^ooQZk_00GoQZk_00?o0000ohj^k?n>[^`01On>[^`00ol0003oTjkYoi>^j@05oi>^j@03o`000?nG
[^OoUjkW00;oUjkW1_l00006oiV]i@03o`000?nL[N?oW:gS00OoW:gS00?o0000oij]h_nN[N801_nN
[N800ol0003oX:kQoj2^h@03o`0000;oWjkQ00?o0000oj6^hOnQ[^401onQ[^400ol0003oXjoPoj>_
h007oj>_h003o`000?nT/>3o000000;o00001OnU/>400ol0003oY[7QojJah@07ojJah@03o`000?nW
/^7oYk;Q00?oYk;Q0ol000000onX]>7o0000ojVehP08ojVehP03o`000?nY]n;oZKOR00?oZKOR0ol0
00000on[^>?o0000ojbji009ojbji003o`000?n]_>Go[KcU00;o[KcU0_l00005ojjni@03o`000?n_
`>Ko[l3V00Oo[l3V0_l0000:ok74j004o`000?nba^Wo0000o`0000So]<WZ00?o0000okC<jondc>/0
0_ndc>/2o`0000Go]lk/00?o0000okOAkOngdNd00_ngdNd2o`0000Ko^M?]00Co0000okWFkol0003o
00002OnkfNl3o`0000Ko_Mk`0_l00004okoPl004o`000?nnh_7o0000o`0000Go`>Ca0_l00005ol;V
l0?o00001Oo3jO02o`0000Coa>_`00Oo0000olK/koo6k>ooa^c_o`000?o4kO3o000000KoaNk_0_l0
0004olK^k`Co000000?oa>o`o`000?o5knl01?o5knl2o`0000?oa^o_00Oo0000olK^koo6k^ooa^k_
o`000?o3k_3o000000Go`ng`0_l00004ol?/l@?o00001?nnjO<00ol0003ooo]ZoookJP08oookJP03
o`000?oonf[ooo]Z033ooo]Z00?o0000oookJ_oonfX06OoonfX003[ooo]Z1Ol00004oookJP?o0000
@_oonfX00ol0003oKZcfofj/mP03ofj/mP03o`000?ml[_?oO:kc00CoO:kc00?o0000ohJ^kon6[^l0
1On6[^l00ol0003oSZk/ohj^k005ohj^k003o`000?nC[^WoTjkY00;oTjkY1ol00004oiF]i`03o`00
0?nI[NGoVJgU00KoVJgU00?o0000oib]honL[N<01_nL[N<00ol0003oWZgRoij]hP05oij]hPCo0000
1_nO[^400ol0003oXJkQoj6^h@07oj6^h@03o`000?nS[n3oXjoP00GoXjoP0ol00009ojF`h@03o`00
0?nV/N7oY[7Q00OoY[7Q00?o0000ojNbhOl000000_l00005ojRdh@03o`000?nY]N;oZKGR00OoZKGR
00?o0000ojVgh_l000000_l00005oj^hh`03o`000?n/^^Co[;[T00So[;[T00Co0000ojfliOl0003o
00002?n^_^D00ol0003o[l3Vojo0iP03ojo0iP?o000000?o/L;Wo`000?naa>P02Onaa>P3o`0000[o
]<WZ00Co0000okC<jol0003o00002?ngc^`01?l0003o]m7]o`000?l00008okWCk@?o00002?nkfNl2
o`0000?o_M__00Co0000okgNl?nmg_3o_Mk`0_l00006okoPl0?o00001?o0i?42o`0000Ko`^K`00Go
0000olCWkoo4inooa>O_o`000003ol?Yl003o`000?o4jo3oa>_`00;oa>_`0_l00004olK/k`?o0000
1?o5k^l2o`0000Goa^k_00Co0000olO^k_o7k^koank^0ol00003olG_k`;o00000oo6knl2o`0000Co
a^k_0ol00003ol?]l0;o00001?o3k?42o`0000?o`^_a00Co0000okkYlol0003o00003?oonfX00ol0
003ooo]ZoookJP0_oookJP03o`000?oonf[ooo]Z01Wooo]Z000joookJPGo000000Cooo]Zo`000?l0
003o0000A_oonfX5o`000003ofj/m_l0003oO:kc00GoO:kc00?o0000ohJ^kon6[^l00_n6[^l?o`00
00?oT:gY00?o0000oiF]ionE[NL01_nE[NL00ol0003oVJgUoiV]i@06oiV]i@03o`000?nL[N?oW:gS
00KoW:gS00?o0000oij]h_nN[N801?l00002oif]hP03o`000?nO[^7oWjkQ00KoWjkQ00?o0000oj6^
hOnQ[^401onQ[^400ol0003oXjoPoj>_h004o`0000;oXjoQ00?o0000ojF`hOnU/>402?nU/>400ol0
003oY[7QojJah@05ojJah@?o00002OnX]>400ol0003oZKGRojVehP06ojVehP;o00002On[^><00ol0
003o[;[Tojbji007ojbji0;o00002on^_^D00ol0003o[l3Vo`000002o`0000Go/L;W00?o0000ok74
j?naa>P01Onaa>P2o`0000?o]<OX00?o0000okC9j_ndbNX01ondbNX2o`0000[o]lk/0ol00007okWC
k@;o00000onke^d2o`0000Co^mW_0_l00006okgKk`03o`000?nmg_3o000000Ko_n3`0_l00003ol7R
k`;o000000?o`>Cao`000?o2i_001Oo2i_02o`0000Goa>O_00?o0000ol?Yl?l000000oo4jo02o`00
00Goa^c_00Co0000olO/k_o7k>koanc^0_l000000oo5k^oo0000olK^k`04olK^k`;o00000oo7k^h0
1ol0003ob>k^olS^k_o8k^ko0000olG_kol000000oo6knl2o`0000Goa^k_00Oo0000olK^koo6k^oo
a^k_o`000?o3kO3o000000Co`nca0_l00005ol;[l@;o00003_oonfX00ol0003ooo]ZoookJP0_oook
JP03o`000?oonf[ooo]Z01Wooo]Z000UoookJP?o001o1OoonfX5o`00O`Sooo]Z1_l0001:oookJP04
o`000?mTYoKoI:OfofBWmPgo00001?n1[?000ol0003oRJg]ohV]k@05ohV]k@03o`000?n@[NWoT:gY
00CoT:gY00?o0000oiF]ionE[NL01_nE[NL00ol0003oVJgUoiV]i@06oiV]i@03o`000?nL[N?oW:gS
00;oW:gS1_l00007oif]hP03o`000?nO[^7oWjkQ00KoWjkQ00?o0000oj6^hOnQ[^401OnQ[^44o`00
00OoXjoQ00?o0000ojF`hOnU/>402?nU/>400ol0003oY[7QojJah@04o`0000;oYk;Q00?o0000ojRd
hOnX]>401onX]>400ol0003oZKGRojVehP03ojVehP?o000000?oZ[ORo`000?n[^><02On[^><00ol0
003o[;[Tojbji003ojbji0?o00000_n^_>@00ol0003o[[kUojjni@08ojjni@;o00002Ona`^L00ol0
003o/LCXok74j002ok74j0;o00001_ndanP00ol0003o]<WZokC9jP03okC9jP?o00000_ngc>X00ol0
003o]lk/okO>k005okO>k0;o00000onidN`00ol0003o^M?]okWCk@02okWCk@;o00001onke^d01?l0
003o^mW_o`000?l00008okgKk`?o00001?noh?02o`0000Ko`N;_0ol00004ol;Vl0;o00001oo4inl4
o`000003olC[l?l0003oa^c_00Coa^c_0_l00005olO/kP?o00000oo6k^l2o`0000?oank^0_l00004
olS^kPCo000000?oa^o_o`000?o6k^l01?o6k^l2o`0000Coa^k_1?l000000oo3k?7o0000o`000005
ol;[l@;o00004OoonfX00ol0003ooo]ZoookJP0^oookJP03o`000?oonf[ooo]Z01Wooo]Z000Uoook
JP?o001o1?oonfX7o`00O`Oooo]Z1?l0001=oookJP03o`000?mTYoKoI:Of00CoI:Of00?o0000ogBZ
lomdZ_<00omdZ_<00ol0003oPJc`oh6/l005oh6/l003o`000?n9[NgoRJg]00GoRJg]00?o0000oi2]
jOn@[NT01?n@[NT00ol0003oUJgWoiF]i`06oiF]i`03o`000?nI[NGoVJgU00CoVJgU1_l00004oi^]
i003o`000?nM[N;oWJgR00OoWJgR00?o0000oin^hOnO[^401_nO[^400ol0003oXJkQoj6^h@04o`00
00;oXZoQ00?o0000oj>_hOnS[n401onS[n400ol0003oYK3QojF`h@07ojF`h@?o00001onW/^400ol0
003oZ;CQojRdh@07ojRdh@03o`000?nY]N;o000000;o00001OnZ]n800ol0003oZkSSoj^hh`08oj^h
h`03o`000?n/^^Co000000;o00001_n^_>@00ol0003o[[kUojjni@05ojjni@;o000000?o/<3Uo`00
0?na`^L02Ona`^L01?l0003o/LCXo`000?l00009okC7j003o`000?ndbN[o000000;o00001_ngc>X0
0ol0003o]lk/okO>k002okO>k0;o00001_nidN`01?l0003o^M?]o`000?l00009ok_Fk@?o00001onm
fnl2o`0000?o`=g^00Co0000okoPl?l0003o00001oo1h^l01?l0003o`nC^ol?Tk_o3i>h2o`000003
ol;Vl?l0003oa>O_00Ooa>O_00Co0000olKYk_o6jNkoa^W^0ol00004olK/k`03o`000?o7k>koanc^
00Coanc^00Oo0000olS]kOo8kNgob>g]o`000?o6k^oo000000?oank^0_l00005olS^kP04o`000?o9
k^gobNk]olW^k@?o00001?o6k^l00ol0003oa^k_olK^k`03olK^k`04o`000?o6kNooa^g_olK]k`?o
00001?o2jo42o`0001Cooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003ooo]ZoookJP0IoookJP00
9OoonfX3o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l7oookJPGo0000COoonfX00ol0003o
I:OfofBWmP04ofBWmP03o`000?mdZ_?oM:[c00?oM:[c00?o0000oh6/l?n1[?001On1[?000ol0003o
RJg]ohV]k@05ohV]k@03o`000?n@[NWoT:gY00CoT:gY00?o0000oiF]ionE[NL01_nE[NL00ol0003o
VJgUoiV]i@03o`0000;oUjcU00?o0000oi^]i?nK[N@01_nK[N@00ol0003oWJgRoif]hP07oif]hP03
o`000?nO[^7oWjkQ00CoWjkQ1?l00007oj:_h@03o`000?nS[n7oXjoQ00OoXjoQ00?o0000ojF`hOnU
/>400onU/>43o`000003ojFahOl0003oYk;Q00SoYk;Q00?o0000ojRdhOnX]>401_nX]>42o`0000Wo
Z[OR00?o0000oj^hhon[^><01on[^><2o`0000[o[[cT00?o0000ojjniOn^_^D00_n^_^D2o`0000Co
/<3U00?o0000ok72iona`^L01ona`^L3o`0000[o]<OX0_l0000:okO<jP04o`000?ngc^co0000o`00
00So^M7/0_l00009ok_Fk@;o00000onnf>d00ol0003o_M__okgKk`02okgKk`;o00001Oo0gNh3o`00
00Ko`N;_0_l00005ol?TkP?o00001_o4inl2o`0000?oa^W^00Co0000olSZkOo8j^gob>[]0_l00000
0oo6k>oo0000olO/kP04olO/kP;o00001?o8kNd4o`000003olO^k_l0003ob>k^00Cob>k^0_l00003
olW^k@04o`000?o9k^gobNk]olW^k@;o000000?oa^k_o`000?o6k^l00oo6k^l2o`0000?oa^g_00Ko
0000olK/koo6k>ooa^c_o`000?o2jo42o`0001Kooo]Z00?o0000oookJ_oonfX0;OoonfX00ol0003o
oo]ZoookJP0IoookJP009OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX4o`000003oook
J_l0003ooo]Z04cooo]Z00?o0000ofBWm_mTYoH01?mTYoH00ol0003oM:[cogBZl`03ogBZl`03o`00
0?n1[?3oPJc`00GoPJc`00?o0000ohV]kOn9[Nd01On9[Nd00ol0003oT:gYoi2]j@04oi2]j@03o`00
0?nE[NOoUJgW00;oUJgW1_l00006oiN/i@03o`000?nK[NCoVjgT00KoVjgT00?o0000oif]h_nM[N80
1onM[N800ol0003oWjkQoin^h@03o`0000;oWjkQ00?o0000oj:_hOnR[n401onR[n400ol0003oXjoQ
oj>_h@07oj>_h@03o`000?nU/>7o000000;o00001OnU/N400ol0003oYk;QojNbh@06ojNbh@03o`00
0?nX]>7oZ;CQ00?oZ;CQ0ol000000onY]N7o0000ojZghP09ojZghP03o`000?n[^>?oZkSS00?oZkSS
0ol000000on]^^?o0000ojjli00:ojjli004o`000?n^_^Go0000o`0000Oo/<3U00?o0000ok72iona
`^L00ona`^L3o`0000?o/lCW00?o0000okC7j?ndanP01OndanP2o`000003okK9j?l0003o]lcZ00Wo
]lcZ0ol00007okWAk0;o00000_nkdn`00ol0003o^mK]ok_Fk@04ok_Fk@;o00001_nnf>d01?l0003o
_M__o`000?l00006ol3MkP05o`000?o2gnko`]o^ol;Ok_l000000oo1h^l2o`0000Ko`nC^00Go0000
olGUk_o5iNkoaNG^o`000003olCWk`;o00001?o6jNh00ol0003ob>[]olSZk@03olSZk@?o00000oo7
k>h2o`0000Gob>g]00Co0000ol[]kOo:kNgob^g]0ol00004olS^kP04o`000?o9k^gobNk]olW^k@;o
00001Oo9k^d3o`0000?oa^k_00Co0000olK]koo6kNooa^g_0_l00004olK/k`;o00006OoonfX00ol0
003ooo]ZoookJP0]oookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJP?o001o0ooonfX3o`00O`?o
oo]Z0ol007l<oookJP03o`000?oonf[ooo]Z04_ooo]Z3?l000000omdZ_?o0000oh6/l006oh6/l003
o`000?n9[NgoRJg]00;oRJg]3_l00004oi>/i`03o`000?nG[>GoUjcU00KoUjcU00?o0000oi^]i?nK
[N@01_nK[N@00ol0003oWJgRoif]hP05oif]hPCo00001_nO[^400ol0003oXZoQoj:_h@07oj:_h@03
o`000?nS[n7oXjoQ00GoXjoQ0ol00008ojFah@03o`000?nW/^7oYk;Q00OoYk;Q00?o0000ojRdhOl0
00000_l00005ojVeh@03o`000?nZ]n;oZ[OR00SoZ[OR00?o0000oj^hhol000000_l00005ojfjh`03
o`000?n^_>Co[[cT00So[[cT0_l0000:ok30i@03o`000?na`^Oo000000;o00001onca>L00ol0003o
]<OXokC7j002okC7j0;o00001?nfbNP00ol0003o]lcZokO<jP05okO<jP;o00000onic^X00ol0003o
^M7/okWAk002okWAk0;o00001Onkdn`00ol0003o^mK]ok_Fk@02ok_Fk@03o`000?nnf>go_]S]00Ko
_]S]0_l00006ol3MkP;o00001Oo2gnh00ol0003o`N;_o`000006ol?TkP;o00001Oo5iNh00ol0003o
a>O_o`000004olKYkP;o00001Oo8j^d01ol0003obN_]olW[kOo9jngo0000olO/k_l000001Oo8kNd2
o`0000?ob^g]00Co0000ol_]k?o;kNcobng/0_l000000oo8k^ko0000olW^k@02olW^k@03o`000?o9
k^gobNk]00CobNk]00Oo0000ol[^kOo:k^gob^k]o`000?o6k^oo000000?oa^g_00?o0000olK/koo6
k>l00oo6k>l00ol0003ooo]ZoookJP0JoookJP03o`000?oonf[ooo]Z02cooo]Z00?o0000oookJ_oo
nfX06?oonfX002Gooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`gooo]Z0_l0001=oookJP03o`00
0?mIX_GoFJ;e00?oFJ;e00Co0000ofbVm?m/Y_CoK:Kd3_l00003ohF[k@03o`000?n=[>[oSJcZ00Co
SJcZ00?o0000oi>/ionC[>L01_nC[>L00ol0003oUjcUoiN/i@06oiN/i@03o`000?nK[NCoVjgT00Ko
VjgT00?o0000oif]h_nM[N801?l00002oif]hP03o`000?nO[^7oWjkQ00KoWjkQ00?o0000oj:_hOnR
[n401onR[n400ol0003oXjoQoj>_h@04o`0000;oY;3Q00?o0000ojFahOnU/N401onU/N400ol0003o
Yk;QojNbh@06ojNbh@;o00002OnY]N400ol0003oZ[ORojZghP07ojZghP;o00002On]^^<00ol0003o
[[cTojjli004ojjli0?o000000?o/;kTo`000?n``>D02On``>D2o`0000_o/lCW00Co0000okC7j?l0
003o00001onfbNP00ol0003o]lcZokO<jP02okO<jP;o00001_nic^X01?l0003o^M7/o`000?l00008
ok_Ck004o`000?nke^go0000o`0000Oo_]S]0_l00002ol3Jk@04o`000?o0gNko`=g^ol3MkP;o0000
1oo2gnh3o`0000Co`nC^0_l00007olGUkP?o00000oo6jNh00ol0003ob>[]olSZk@04olSZk@03o`00
0?o9jngobN_]00;obN_]0ol00003olS]k@;o00001?o:kNd00ol0003obng/ol_]k003ol_]k0Co0000
00?obNk]o`000?o9k^d01?o9k^d2o`0000Cob^k]1?l000000oo6kNoo0000olK/k`03olK/k`;o0000
7_oonfX00ol0003ooo]ZoookJP0[oookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l?oookJP03o`000?oonf[ooo]Z04_ooo]Z00?o0000oeVRmOmIX_D00omI
X_D00ol0003oK:KdofbVm003ofbVm003o`000?mjZO7oNZWa00GoNZWa00?o0000ohF[kOn5Znd01?n5
Znd00ol0003oSJcZohf/jP04ohf/jP03o`000?nC[>OoTjcW00KoTjcW00?o0000oiN/iOnG[>D01_nG
[>D00ol0003oVjgToi^]i002oi^]i0Ko00001onM[N800ol0003oWjkQoin^h@06oin^h@03o`000?nR
[n7oXZoQ00GoXZoQ1?l00007ojB`h@03o`000?nU/N7oYK7Q00OoYK7Q00?o0000ojNbhOnW/^400_nW
/^43o`000003ojRchOl0003oZKGQ00WoZKGQ00?o0000ojZgh_nZ]n800onZ]n83o`000003ojbhh_l0
003o[K[S00Wo[K[S00?o0000ojjli?n^_>@00ol00005ok2ni003o`000?n``>Go/<3U00Go/<3U0_l0
00000onb`^Go0000ok?4i`0:ok?4i`;o00002_nfbNP01?l0003o]lcZo`000?l00008okW>jP;o0000
2_nkdn`3o`0000Ko_]S]0_l00005ol3Jk@03o`000?o0gNko000000So`]o^00Co0000olCQkOo4hNgo
a>7]0_l000000oo3i>ko0000olGUkP07olGUkP07o`000?o7i^goanK]olOVkOl0003oa^W^o`000005
olSZk@;o00001?o9jnd01ol0003obn_/ol_[k?o;jnco0000olS]kOl000001Oo:kNd00ol0003obng/
ol_]k003ol_]k004o`000?o<kN_oc>g[olc]j`?o00000oo9k^d2o`0000Gob^k]00Co0000ol[]k?o:
kNcob^g/0ol00003olK/k`03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0:ooonfX00ol0
003ooo]ZoookJP0HoookJP009OoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o4?oonfX00ol0003o
oo]ZoookJP1;oookJP03o`000?mIX_GoFJ;e00?oFJ;e00?o0000ofbVm?m/Y_@00om/Y_@00ol0003o
NZWaogZYl@05ogZYl@03o`000?n5ZngoQJ_]00CoQJ_]00?o0000ohf/j_n=[>X01?n=[>X00ol0003o
TjcWoi>/i`06oi>/i`03o`000?nG[>GoUjcU00CoUjcU1_l00004oiZ/i003o`000?nM[N;oWJgR00Oo
WJgR00?o0000oin^hOnO[^401_nO[^400ol0003oXZoQoj:_h@04o`0000;oXZoQ00?o0000ojB`hOnT
/>401onT/>400ol0003oYK7QojFah@06ojFah@03o`000?nW/^7o000000;o00001OnX/n400ol0003o
ZKGQojVeh@08ojVeh@03o`000?nZ]n;o000000;o00001On/^>800ol0003o[K[Sojfjh`07ojfjh`?o
00002On`_^@00ol0003o/<3Uok30i@02ok30i@;o00001?nb`^D00ol0003o/lCWok?4i`06ok?4i`;o
000000?o]/KWo`000?nfbNP02OnfbNP2o`0000Wo^LkZ00Co0000ok_@j_nkd>[o00001onkdn`2o`00
00?o_]G[00?o0000okkHkOnnf>d00_nnf>d00ol0003o`=[]ol3Jk@05ol3Jk@?o00001_o2gnh2o`00
00Goa>7]0ol00006olGUkP;o00001?o7i^d3o`0000Cob>[]00?o0000olW[kOo9jnd00_o9jnd2o`00
00Cobn_/0ol00004ol[]k@03o`000?o;kNcobng/00;obng/0_l00003olc]j`07o`000?o<kN_oc>g[
olc]jol0003obNk]o`000005ol[^k@;o00000oo:kN`01ol0003ob^g/ol[]k?o:kNco0000olK/kol0
00008_oonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z01Sooo]Z000UoookJP?o001o
0ooonfX3o`00O`?ooo]Z0ol007lAoookJP03o`000?oonf[ooo]Z04_ooo]Z1Ol000000omIX_Go0000
ofbVm004ofbVm003o`000?mjZO7oNZWa00GoNZWa00?o0000ohF[kOn5Znd01?n5Znd00ol0003oSJcZ
ohf/jP04ohf/jP03o`000?nC[>OoTjcW00KoTjcW00?o0000oiN/iOnG[>D00ol00002oiJ/i@03o`00
0?nJ[>CoVZcT00KoVZcT00?o0000oif]h_nM[N801_nM[N800ol0003oWjkQoin^h@05oin^h@Co0000
1onR[n400ol0003oY;3QojB`h@06ojB`h@03o`000?nU/N7oYK7Q00GoYK7Q0ol00009ojRch@03o`00
0?nY]N7oZKGQ00OoZKGQ0_l00009ojbhhP03o`000?n]^^?o[K[S00?o[K[S0ol00002ojnkh`03o`00
0?n`_^Co/;kT00So/;kT00Co0000ok30iOl0003o00001onb`^D00ol0003o/lCWok?4i`02ok?4i`?o
00001?nfa^L00ol0003o]/WXokK9j005okK9j0;o00000_nhbnP00ol0003o^LkZokW>jP04okW>jP;o
00001?nkd>X00ol0003o^m?/ok_Ck002ok_Ck0;o00001_nneN/01?l0003o_]S]o`000?l00007ol3J
k@05o`000?o3g>co`mc/ol?Lk?l000000oo2gnh2o`0000Koa>7]00Go0000olKRk?o6h^coa^;/o`00
0003olGUkP;o00001Oo7i^d01?l0003obNO/olWWk?o9in`2o`000003olSZkOl0003obN_]00;obN_]
0_l00005ol_[k004o`000?o<k>_oc>c[olc/j`;o000000?ob^g]o`000?o;kN`00_o;kN`2o`0000Co
c>g[00?o0000olc]joo<kN/00_o<kN/3o`0000?ob^k]0_l00003ol[]k0;o00001?o:kN`2o`0002Co
oo]Z00?o0000oookJ_oonfX0:OoonfX00ol0003ooo]ZoookJP0HoookJP008_oonfX6o`00O`?ooo]Z
0ol007l3oookJP?o001o4_oonfX2o`0004gooo]Z00?o0000odfLm?m=W?@01ol000000om/Y_Co0000
ogZYl@06ogZYl@03o`000?n5ZngoQJ_]00CoQJ_]00?o0000ohf/j_n=[>X01?n=[>X00ol0003oTjcW
oi>/i`02oi>/i`Ko00001_nF[>D00ol0003oVZcToiZ/i006oiZ/i003o`000?nM[N;oWJgR00KoWJgR
00?o0000oin^hOnO[^401?l00002oin^hP03o`000?nR[n7oXZoQ00OoXZoQ00?o0000ojB`hOnT/>40
1_nT/>400ol0003oYK7QojFah@04o`0000?oY[;Q00?o0000ojRchOnX/n401onX/n400ol0003oZKGQ
ojVeh@03ojVeh@?o000000?oZkKQo`000?n/^>802On/^>800ol0003o[K[So`000002o`0000Ko[k_S
00?o0000ok2ni?n`_^@01on`_^@2o`0000[o//;U00Co0000ok?4iol0003o00002?nfa^L00ol0003o
]/WXokK9j002okK9j0;o00001OnhbnP01?l0003o^LkZokW>j_nic^X2o`0000Oo^m3Z00Co0000ok_C
k?l0003o00002?nneN/3o`0000Ko`=[]0_l00005ol?Lk003o`000?o2gnko000000Koa>7]0_l00005
olKRk003o`000?o5iNko000000GoanK]0_l00005olWWk0Co000000?obN_]o`000?o;jn`01?o;jn`2
o`0000Goc>c[1?l000000oo;kNco0000olc]j`03olc]j`;o00001?o<kN/01ol0003ocNgZolg]j_o=
kN[o0000ol[^kOl000000oo:kN`2o`0000Gob^g/00?o0000oookJ_oonfX09OoonfX00ol0003ooo]Z
oookJP0XoookJP03o`000?oonf[ooo]Z01Sooo]Z000RoookJPKo001o1?oonfX3o`00O`04oookJ_l0
07oo001oo`00OaGooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003oCIcdodfLm002odfLm004o`00
0?mSX_?oHj;cof>Rlaco00001?nAZnP00ol0003oUZcUoiJ/i@06oiJ/i@03o`000?nJ[>CoVZcT00Ko
VZcT00?o0000oif]h_nM[N801?nM[N84o`0000OoWjkR00?o0000oj:_hOnR[n401onR[n400ol0003o
Y;3QojB`h@04ojB`h@Co00002?nV/^400ol0003oZ;?QojRch@07ojRch@03o`000?nY]N7o000000;o
00001On[]^400ol0003o[;SRojbhhP07ojbhhP;o00002_n_^n<00ol0003o/;kTok2ni003ok2ni0?o
000000?o/[oTo`000?nb`^D02Onb`^D2o`0000_o]/KW00Co0000okK9j?l0003o00002?nhbnP00ol0
003o^LkZo`000009ok_@jP?o00001onneN/2o`0000?o`MO[00Co0000ol3JkOo0f^go`=[]0_l00007
ol?Lk0?o00001?o4hNd2o`0000Ooa^;/0ol00003olOVk@;o00001_o9in`01?l0003obnS[ol_Xjoo;
j>/3o`0000Cobn_/00?o0000olc/joo<k>/01?o<k>/01?l0003ocNcZolg/j_o=k>X3o`0000?oc>g[
00?o0000olc]joo<kN/00_o<kN/2o`0000CocNgZ1?l000000oo:kNco0000ol[]k004ol[]k0;o0000
:?oonfX00ol0003ooo]ZoookJP0YoookJP03o`000?oonf[ooo]Z01Oooo]Z000ToookJPCo001o1?oo
nfX7o`00OaKooo]Z00?o0000oookJ_oonfX0BooonfX00ol0003oCIcdodfLm002odfLm003o`000?mS
X_?oHj;c00?oHj;c00?o0000ogBVlOmdY_401?mdY_400ol0003oPJW^oh6YkP04oh6YkP03o`000?n:
Z^_oRZ[[00GoRZ[[00?o0000oi6[j?nAZnP01OnAZnP00ol0003oUZcUoiJ/i@06oiJ/i@03o`000?nJ
[>CoVZcT00KoVZcT00?o0000oif]h_nM[N800ol00002oif]h`03o`000?nO[^;oWjkR00OoWjkR00?o
0000oj:_hOnR[n401onR[n400ol0003oY;3QojB`h@03o`0000;oYK7Q00?o0000ojJbhOnV/^402?nV
/^400ol0003oZ;?QojRch@05ojRch@?o00002On[]^400ol0003o[;SRojbhhP03ojbhhP?o000000?o
[[WRo`000?n_^n<02_n_^n<00ol0003o/;kTo`000002o`0000Go/[oT00?o0000ok;2iOnb`^D01Onb
`^D2o`0000;o]LCU00?o0000okK6ionfa^L02?nfa^L2o`0000[o^<_X0ol00007ok_@jP;o00000onn
d^T00ol0003o_]G[okkEj`02okkEj`;o00001_o1en/00ol0003o`=[]o`000008ol?Lk004o`000?o5
g^_oaMk[olGNj`;o000000?oa>7]o`000?o6h^`01oo6h^`01ol0003ob>C[olSTjoo8i>_o0000olOV
kOl000001_o9in`2o`0000?obnS[00Co0000olgYj_o=jN[ocNWZ0_l000000oo;jnco0000olc/j`04
olc/j`;o00000oo=k>X01ol0003oc^cYolk/jOo>k>Wo0000olc]jol000001?o<kN/00ol0003ocNgZ
olg]jP03olg]jP04o`000?o>kN[oc^gZolk]jP?o00000oo:kN`2o`0002_ooo]Z00?o0000oookJ_oo
nfX0:?oonfX00ol0003ooo]ZoookJP0GoookJP009OoonfX3o`00O`Gooo]Z1Ol007lHoookJP03o`00
0?oonf[ooo]Z04_ooo]Z00?o0000odfLm?m=W?@00_m=W?@00ol0003oHj;cof>Rl`03of>Rl`03o`00
0?mdY_7oM:Ka00CoM:Ka00?o0000oh6Yk_n1ZNh01?n1ZNh00ol0003oRZ[[ohZZj`05ohZZj`03o`00
0?nAZnSoTJ_X00GoTJ_X00?o0000oiJ/iOnF[>D01OnF[>D00ol0003oVZcToiZ/i005oiZ/i0Co0000
1_nM[N<00ol0003oWjkRoin^hP07oin^hP03o`000?nR[n7oXZoQ00KoXZoQ0ol00006ojFah@03o`00
0?nV/^7oY[;Q00SoY[;Q00?o0000ojRchOnX/n401?l00003ojVdh@03o`000?n[]^7oZkKQ00OoZkKQ
00?o0000ojbhh_l000000_l00005ojjihP03o`000?n_^n?o[k_S00So[k_S0_l00009ok:oi003o`00
0?nb`^Go//;U00;o//;U0_l00005okG4i@03o`000?nfa^Oo]/KW00Go]/KW0_l00002okS8i`03o`00
0?nhbnSo^<_X00Go^<_X0_l00003ok_=j003o`000?nkd>[o^m3Z00;o^m3Z0_l00006okkBj@04o`00
0?nneN_o0000o`0000So`MO[0ol00006ol?Lk0;o00001Oo5g^/3o`0000Koa^;/0_l00004olSTj`?o
00001?o9in`2o`0000CobnS[00?o0000olgYj_o=jNX00oo=jNX3o`0000?oc>c[0_l00004olg/jP03
o`000?o>k>Woc^cY00;oc^cY1?l00002olc]j`03o`000?o=kN[ocNgZ00;ocNgZ0_l00003olk]jP07
o`000?o>kN[oc^gZolk]j_l0003ob^g/o`00000^oookJP03o`000?oonf[ooo]Z02Oooo]Z00?o0000
oookJ_oonfX05ooonfX004_ooo]Z00?o0000oookJ_oonfX0BooonfX4o`000003odfLm?l0003oHj;c
00CoHj;c00?o0000ogBVlOmdY_401?mdY_400ol0003oPJW^oh6YkP04oh6YkP03o`000?n:Z^_oRZ[[
00GoRZ[[00?o0000oi6[j?nAZnP01OnAZnP00ol0003oUZcUoiJ/i@05oiJ/i@03o`000?nJ[>CoVZcT
00Co00000_nI[>@00ol0003oWJgSoif]h`06oif]h`03o`000?nO[^;oWjkR00KoWjkR00?o0000oj:_
hOnR[n400onR[n43o`000003oj:_hOl0003oYK7Q00OoYK7Q00?o0000ojJbhOnV/^401onV/^43o`00
00SoZKCQ00?o0000oj^fhOn[]^401_n[]^42o`0000Wo[[WR00?o0000ojnkhon_^n<01On_^n<2o`00
0003ok6mhol0003o/[oT00Wo/[oT00Co0000ok;2iOl0003o00002?nea>D00ol0003o]/KWokK6i`02
okK6i`;o00001Onhb>L00ol0003o^<_XokS;j002okS;j0;o00001_nkcNP01?l0003o^m3Zo`000?l0
0008okkBj@?o00002?o1en/01Ol0003o`mWZol?Ij_o3fN[o000000?o`mc/0_l00006olGNj`05o`00
0?o7gn[oamoZolOOj_l000000oo6h^`2o`0000Gob>C[00Co0000ol_Uj_o;iN[obnGZ0_l000000oo9
inco0000ol_Xj`04ol_Xj`03o`000?o=jN[ocNWZ00?ocNWZ00Oo0000olkYjOo>jNWoc^WYo`000?o<
k>_o000000GocNcZ00?o0000olk/jOo>k>T00_o>k>T00ol0003ocncYolo/j@02olo/j@?o00000oo=
kNX00ol0003oc^gZolk]jP02olk]jP03o`000?o>kN[oc^gZ00;oc^gZ0_l0000`oookJP03o`000?oo
nf[ooo]Z02Kooo]Z00?o0000oookJ_oonfX05ooonfX004cooo]Z0_l0001=oookJP03o`000?m1UO7o
000000Ko000000?oHj;co`000?mdY_401OmdY_400ol0003oPJW^oh6YkP04oh6YkP03o`000?n:Z^_o
RZ[[00GoRZ[[00?o0000oi6[j?nAZnP01OnAZnP00ol0003oUZcUoiJ/i@02oiJ/i@Go00001onI[>@0
0ol0003oWJgSoif]h`06oif]h`03o`000?nO[^;oWjkR00KoWjkR00?o0000oj:_hOl000000_l00005
oj:_h@03o`000?nU/N7oYK7Q00KoYK7Q00?o0000ojJbhOnV/^400onV/^43o`000003ojNchOl0003o
ZKCQ00WoZKCQ00?o0000oj^fhOn[]^400_n[]^43o`000003ojbhhOl0003o[[WR00Wo[[WR00?o0000
ojnkhon_^n<00_n_^n<2o`0000Co/KgS00?o0000ok:oi?nb_n@01onb_n@3o`0000[o]LCU00Co0000
okK6iol0003o00002?nhb>L01?l0003o^<_Xo`000?l00008ok_=j0?o00002?nnd^T01Ol0003o`=CY
ol3DjOo0e>Wo000000Go`MO[0_l00005ol?IjP03o`000?o3g>co000000KoaMk[0_l00005olOOjP03
o`000?o6h^co000000Gob>C[0_l00005ol_UjP?o00001?o;j>/00ol0003ocNWZolgYjP03olgYjP03
o`000?o>jNWoc^WY00;oc^WY0ol00004olg/jP04o`000?o>k>Woc^cYolk/j@;o00001?o?k>T01ol0
003od>cXom3/j?o@k>So0000olg]j_l000001?o>kNX00ol0003oc^gZolk]jP02olk]jP03o`000?oo
nf[ooo]Z033ooo]Z00?o0000oookJ_oonfX09_oonfX00ol0003ooo]ZoookJP0GoookJP00C_oonfX0
0ol0003ooo]ZoookJP1;oookJP05o`000?m1UO7o@IGaod6ElOl000000omIWO<7o`0000;oM:Ka00?o
0000oh6Yk_n1ZNh01?n1ZNh00ol0003oRZ[[ohZZj`02ohZZj`oo00000onDZnH00ol0003oVJcToiV/
i007oiV/i003o`000?nM[N?oWJgS00GoWJgS00?o0000oin^h_nO[^801OnO[^83o`0000SoXZoQ00?o
0000ojFahOnU/N401onU/N400ol0003oY[;Qo`000002o`0000GoYk?Q00?o0000ojVdhOnY]>402?nY
]>401?l0003oZkKQo`000?l00005ojbhh@03o`000?n^^N;o[[WR00So[[WR00Co0000ojnkhol0003o
00001ona_N<00ol0003o/[oTok:oi003ok:oi0?o00000ond`N@00ol0003o]LCUokG4i@07okG4i@;o
00002_nhb>L2o`0000Wo^lgX00Go0000okg?j?nmcnSo_LoXo`000005okkBj@;o00001Oo0e>T01Ol0
003o`MO[ol7Gjoo1en_o000000Oo`mWZ0ol00004olGNj`;o00001oo7gnX3o`0000Cob>C[00?o0000
ol_Uj_o;iNX01?o;iNX01?l0003oc>KYolcVjOo<i^T2o`000003ol_Xjol0003ocNWZ00?ocNWZ0_l0
0004olkYj@04o`000?o?j^Socn[XoloZj0;o000000?ocNcZo`000?o>k>T00_o>k>T00ol0003ocncY
olo/j@03olo/j@03o`000?o@k>Sod>cX00;od>cX0ol00003olk]jP04o`000?o>kN[oc^gZolk]jP;o
0000=?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[ooo]Z01Oooo]Z001?oookJP03o`00
0?oonf[ooo]Z04_ooo]Z00Go0000od6ElOm1UO7o@IGao`000005oeVMl`04o`000?m]Xo7oKJ?aoffS
l@ko00000on6Z>/00ol0003oSj[XohnZj005ohnZj003o`000?nDZnKoU:_V00GoU:_V00?o0000oiV/
i?nI[>@01_nI[>@00ol0003oWJgSoif]h`06oif]h`03o`000?nO[^;oWjkR00Co00000_nP[^800ol0
003oXZoQoj:_h@07oj:_h@03o`000?nU/N7oYK7Q00KoYK7Q0_l00009ojNch@03o`000?nY]>7oZKCQ
00OoZKCQ0_l00008ojbhh@03o`000?n^^N;o[[WR00Oo[[WR0_l0000:ok6mh`03o`000?nb_nCo0000
00;o00001ond`N@00ol0003o]LCUokG4i@03okG4i@?o00000_nga^D00ol0003o^<SWokS8i`05okS8
i`;o00000_njbnH00ol0003o^lgXok_=j004ok_=j0;o00001OnmcnP01Ol0003o_];YokkBjOnnd^Wo
000000So`=CY00?o0000ol7Gjol000001oo3fNX01?l0003oaM_YolGKjOo5fnT2o`000003olGNjol0
003oamoZ00OoamoZ00Co0000olWQjOo9hNWobN7Y0_l000000oo8i>_o0000ol_UjP04ol_UjP;o0000
1Oo<i^T3o`0000?ocNWZ00?o0000olkYjOo>jNT00oo>jNT00ol0003ocn[XoloZj003oloZj0Co0000
00?oc^cYo`000?o?k>T00oo?k>T2o`0000Cod>cX00Oo0000om7/iooAk>OodNcWo`000?o>kN[o0000
00?oc^gZ00?o0000oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z
01Oooo]Z001@oookJP03o`000?oonf[ooo]Z04_ooo]Z0ol000000om1UO7o0000oeVMl`04oeVMl`03
o`000?m]Xo7oKJ?a00CoKJ?a00?o0000ogbVk_mlY^h01?mlY^h00ol0003oQZS[ohJXj`04ohJXj`03
o`000?n?Z^SoSj[X00GoSj[X00?o0000oiB[i_nDZnH01OnDZnH00ol0003oVJcToiV/i006oiV/i003
o`000?nM[N?oWJgS00;oWJgS1_l00007oj2^hP03o`000?nR[n7oXZoQ00OoXZoQ00?o0000ojFahOnU
/N400_nU/N43o`000003ojFahOl0003oYk?Q00WoYk?Q00?o0000ojVdhOnY]>400onY]>43o`000003
oj^fhOl0003o[;SQ00So[;SQ00?o0000ojjih_n^^N800on^^N83o`000003ojnkh_l0003o/KgS00Wo
/KgS0_l0000;okC1i003o`000?nea>Go000000;o00001_nga^D00ol0003o^<SWokS8i`02okS8i`;o
00001OnjbnH01?l0003o^lgXok_=j?nkcNP2o`0000So_LoX00?o0000okkBjOl000002Oo0e>T2o`00
00Ko`mWZ0_l00005olGKj@?o00001_o7gnX2o`0000GobN7Y0ol00003ol_UjP;o00001_o<i^T01ol0
003oc^KXolkVj?o>i^So0000olgYj_l000001Oo>jNT00ol0003ocn[XoloZj003oloZj004o`000?oA
j^OodN[Wom7Zi`?o00000oo?k>T00ol0003od>cXom3/j003om3/j003o`000?oAk>OodNcW00;odNcW
1?l000000oo>kN[o0000oookJP0goookJP03o`000?oonf[ooo]Z02Gooo]Z00?o0000oookJ_oonfX0
5_oonfX0057ooo]Z0_l0001=oookJPCo00001OmIWO<00ol0003oKJ?aoffSl@04offSl@03o`000?ml
Y^koO:K^00CoO:K^00?o0000ohJXjon6Z>/01?n6Z>/00ol0003oSj[XohnZj005ohnZj003o`000?nD
ZnKoU:_V00GoU:_V00?o0000oiV/i?nI[>@01?nI[>@6o`0000CoW:gS00?o0000oj2^h_nP[^801onP
[^800ol0003oXZoQoj:_h@06oj:_h@03o`000?nU/N7o000000;o00001OnU/N400ol0003oYk?QojNc
h@08ojNch@03o`000?nY]>7o000000;o00001On[]^400ol0003o[;SQojbhh@07ojbhh@03o`000?n^
^N;o000000;o00001On_^n800ol0003o/KgSok6mh`05ok6mh`;o00000_nc_n<00ol0003o]<7TokC1
i008okC1i0;o00002_nga^D01?l0003o^<SWo`000?l00008ok[;iP03o`000?nkcNSo000000[o_LoX
0ol00007ol3Dj@;o00000_o3e^P01?l0003o`mWZol?Ij_o3fNX2o`0000KoaM_Y00Go0000olOLj?o7
g>SoamcXo`000003olOOjP;o00001_o9hNT01ol0003obn;Xol_Rj?o;h^So0000ol_Uj_l000001oo<
i^T00ol0003oc^KXolkVj002olkVj0?o00001?o>jNT00ol0003ocn[XoloZj003oloZj005o`000?oA
j^OodN[Wom7Ziol000000ooBjnH00ol0003ocncYo`000004om3/j0;o00001?oAk>L01?l0003odNcW
om7/iooAk>L2o`0003[ooo]Z00?o0000oookJ_oonfX09?oonfX00ol0003ooo]ZoookJP0FoookJP00
DooonfX00ol0003ooo]ZoookJP1;oookJP03o`000?lbSNko<Xg^00Go000000?oFIgco`000?m]Xo40
1Om]Xo400ol0003oO:K^ogbVkP04ogbVkP03o`000?n6Z>_oQZS[00CoQZS[00?o0000ohnZj?n?Z^P0
1?n?Z^P00ol0003oU:_VoiB[iP06oiB[iP03o`000?nI[>CoVJcT00?o00000_nH[>@00ol0003oW:gS
oib]h`06oib]h`03o`000?nP[^;oX:kR00OoX:kR00?o0000oj:_hOnR[n401?nR[n43o`0000WoYK7Q
00?o0000ojNchOnW/n401onW/n42o`0000WoZkKQ00?o0000ojbhhOn/^>401_n/^>42o`0000Wo[k_R
00?o0000ok6mhona_N<00_na_N<2o`0000Go/koS00?o0000okC1i?nd`N@01Ond`N@2o`000003okK3
i?l0003o]lKU00Wo]lKU0_l0000:ok[;iP?o00002?nmcnP2o`0000?o`=7W00?o0000ol3DjOo0e>T0
0_o0e>T2o`0000Go`mKX00?o0000ol?Ij_l000001oo5fnT00ol0003oamcXolOLj003olOLj003o`00
0?o7gn[o000000OobN7Y00?o0000ol_Rj?o;h^P00_o;h^P3o`0000Goc>KY0_l00004olkVj004o`00
0?o@inOod>OWom3Wi`;o000000?oc^WYo`000?o?j^P00oo?j^P2o`0000?odN[W00?o0000om;[i_oB
jnH00_oBjnH3o`0000?od>cX00?o0000om7/iooAk>L00_oAk>L2o`0000?odNcW00?o0000oookJ_oo
nfX0>ooonfX00ol0003ooo]ZoookJP0SoookJP03o`000?oonf[ooo]Z01Kooo]Z001DoookJP03o`00
0?oonf[ooo]Z04_ooo]Z00Co0000oc:=k_lbSNko00000om?V?87o`0000;oKJ?a00?o0000ogbVk_ml
Y^h01?mlY^h00ol0003oQZS[ohJXj`04ohJXj`03o`000?n?Z^SoSj[X00CoSj[X00?o0000oiB[i_nD
ZnH00_nDZnH6o`0000KoV:cT00?o0000oib]honL[N<01_nL[N<00ol0003oX:kRoj2^hP07oj2^hP03
o`000?nR[n7oXZoQ00?o00000_nS/>400ol0003oYK7QojFah@08ojFah@03o`000?nW/n7oYk?Q00?o
Yk?Q0ol000000onY]>7o0000oj^fh@08oj^fh@03o`000?n/^>7o[;SQ00?o[;SQ0ol00002ojjih@03
o`000?n_^n;o[k_R00Oo[k_R00Co0000ok6mhol0003o00002?nc_n<00ol0003o]<7TokC1i002okC1
i0;o00001?nf`n@00ol0003o]lKUokO6i@05okO6i@;o00000_njb>D00ol0003o^/_Vok[;iP05ok[;
iP;o00000onmc>H2o`0000Co_LoX0_l00006ol3Ai`04o`000?o0e>Wo0000o`0000Oo`mKX0ol00005
olGKj@;o00001_o7g>P3o`0000GobN7Y0_l00004ol_Rj005o`000?o=hnOocN?WolgSiol000000oo<
i^T00ol0003oc^KXolkVj003olkVj003o`000?o@inOod>OW00?od>OW0ol00003oloZj004o`000?oA
j^OodN[Wom7Zi`;o00001?oBjnH01ol0003odn_Vom?[i_oCjnKo0000om3/j?l000001?oAk>L00ol0
003odNcWom7/i`02om7/i`03o`000?oonf[ooo]Z03gooo]Z00?o0000oookJ_oonfX08_oonfX00ol0
003ooo]ZoookJP0FoookJP00EOoonfX00ol0003ooo]ZoookJP1;oookJP;o000000?o<Xg^o`000?m?
V?801?m?V?801?l0003oIIoaofFOlOmUWo4Lo`0000CoTj_V00?o0000oiR/i?nH[>@01_nH[>@00ol0
003oW:gSoib]h`06oib]h`03o`000?nP[^;oX:kR00GoX:kR1?l00006oj>`h@03o`000?nU/N7oYK7Q
00SoYK7Q00?o0000ojNchOl000000_l00005ojVdh@03o`000?n[]^7oZkKQ00OoZkKQ00?o0000ojbh
hOl000000_l00006ojjih@03o`000?n_^n;o[k_R00Ko[k_R0_l0000;ok>oh`04o`000?nd`NCo0000
o`0000Oo]/?T00?o0000okO6iOnga^D00_nga^D2o`0000Go^/SU00?o0000ok[;i_njbnH00_njbnH2
o`0000Oo_LcV00Co0000okg?j?l0003o00002?o0dNL2o`0000So`mKX00Go0000olGHioo5f>OoaMSW
o`000003olGKj@03o`000?o7g>SoamcX00GoamcX00Go0000ol[Nioo:g^Oob]kWo`000003olWQj@03
o`000?o;h^Sobn;X00?obn;X00?o0000olgSioo=hnL00oo=hnL00ol0003oc>KYo`000004olkVj0;o
00001Oo@inL01ol0003odNSVom7Xi_oAj>Ko0000oloZj?l000000ooAj^L00ol0003od^_Vom;[iP03
om;[iP03o`000?oCjnKodn_V00;odn_V1?l00002om7/i`03o`000?oAk>OodNcW00;odNcW00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01Kooo]Z001Foook
JP;o0000C?oonfX4o`0000GoCiSb00?o0000ofFOlOmUWo400omUWo400ol0003oMjC_ogNTk`04ogNT
k`03o`000?n3YncoPjO/00CoPjO/00?o0000ohbYjOn<ZNT01?n<ZNT00ol0003oTj_Voi>[iP06oi>[
iP03o`000?nH[>CoV:cT00KoV:cT00?o0000oib]honL[N<01_nL[N<00ol0003oX:kRoj2^hP04o`00
00;oX:kR00?o0000oj>`hOnS/>401_nS/>400ol0003oYK7QojFah@07ojFah@;o00002OnY]>400ol0
003oZkKQoj^fh@06oj^fh@;o00002_n^^N400ol0003o[k_RojnkhP02ojnkhP?o00000_na_>800ol0
003o/koSok>oh`08ok>oh`;o00002_nf`n@01?l0003o]lKUo`000?l00008ok[8i@04o`000?njbnKo
0000o`0000Wo_LcV0_l00009ol3Ai`04o`000?o2dnOo`]?Wo`0000Go`mKX0_l00005olGHi`03o`00
0?o5fnWo000000KoamcX0_l00005ol[Ni`03o`000?o9hNWo000000Gobn;X00?o0000olgSioo=hnL0
1?o=hnL3o`0000?oc^KX00?o0000om3Wioo@inL01?o@inL00ol0003odNSVom7XiP02om7XiPCo0000
00?odN[Wo`000?oBjnH01?oBjnH00ol0003odn_Vom?[iP02om?[iP03o`000?oDjnGoe>_U00;oe>_U
0ol00003om7/i`03o`000?oonf[ooo]Z043ooo]Z00?o0000oookJ_oonfX08OoonfX00ol0003ooo]Z
oookJP0FoookJP00F?oonfX00ol0003ooo]ZoookJP1:oookJP04o`000?lTQ>[o0000o`0000GoCiSb
00?o0000ofFOlOmUWo400omUWo400ol0003oMjC_ogNTk`04ogNTk`03o`000?n3YncoPjO/00CoPjO/
00?o0000ohbYjOn<ZNT01?n<ZNT00ol0003oTj_Voi>[iP06oi>[iP03o`000?nH[>CoV:cT00KoV:cT
00?o0000oib]honL[N<00_nL[N<6o`0000OoX:kR00?o0000oj>`hOnS/>401_nS/>400ol0003oYK7Q
ojFah@03ojFah@?o000000?oYk;Qo`000?nY]>402?nY]>400ol0003oZkKQoj^fh@03oj^fh@?o0000
00?o[;OQo`000?n^^N402_n^^N401?l0003o[k_Ro`000?l00006ok6lhP03o`000?nc_n?o/koS00Go
/koS0_l000000one`N?o0000okK3i009okK3i0;o00002_njb>D3o`0000Wo_LcV00Co0000oko>iOno
c^Go00001_o0dNL2o`0000Co`]?W00Go0000ol?Fj?o3e^So`mKXo`000007olGHi`?o00001?o7g>P2
o`0000Oob]kW0ol00004ol_Rj003o`000?o=hnOocN?W00CocN?W00Oo0000oloTi_o?i>KocnCVo`00
0?o>i^So000000God>OW0_l00004om7XiP04o`000?oBj>God^SUom;Xi@?o00001?oBjnH00ol0003o
dn_Vom?[iP02om?[iP03o`000?oDjnGoe>_U00;oe>_U00Oo0000omC[i?oDjnCoe>_To`000?oAk>Oo
000004Cooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0FoookJP00FOoonfX00ol0
003ooo]ZoookJP1:oookJP03o`000?lTQ>[o98CZ00Go000000?oCiSbo`000?mUWo401?mUWo400ol0
003oMjC_ogNTk`04ogNTk`03o`000?n3YncoPjO/00CoPjO/00?o0000ohbYjOn<ZNT01?n<ZNT00ol0
003oTj_Voi>[iP06oi>[iP03o`000?nH[>CoV:cT00CoV:cT1_l00004oib]h`03o`000?nP[^;oX:kR
00OoX:kR00?o0000oj>`hOnS/>401_nS/>400ol0003oYK7Qo`000002o`0000GoYk;Q00?o0000ojVd
hOnY]>401onY]>400ol0003oZkKQo`000002o`0000Go[;OQ00?o0000ojjihOn^^N402?n^^N42o`00
00Wo/KcR00?o0000ok>ohonc_n<00_nc_n<2o`0000Co]L7S00?o0000okK3i?nf`n@01Onf`n@2o`00
00;o^LGT00?o0000ok[8iOnjb>D01Onjb>D2o`0000?o_<WT00?o0000okg<i_nmc>H01?nmc>H2o`00
00Co_lkU00Co0000ol3Aioo0dNOo`=7W0_l00007ol;Ci`03o`000?o3e^So000000OoaMSW00Co0000
olSIioo8fNOob=WW0_l000000oo7g>So0000ol[Ni`07ol[Ni`04o`000?o<gnKoc=oVolcOiP;o0000
00?obn;Xo`000?o=hnL01?o=hnL2o`0000CocnCV0ol00004om3Wi`03o`000?oAj>KodNSV00;odNSV
0_l00003om;Xi@04o`000?oDj>Coe>STomCXi0;o000000?od^_Vo`000?oCjnH00ooCjnH00ol0003o
e>_UomC[i@02omC[i@03o`000?oDjnCoe>_T00;oe>_T0_l00016oookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX05OoonfX005[ooo]Z00?o0000oookJ_oonfX0B_oonfX01Ol0003o98CZ
obB4j_lTQ>[o000000;oA9;`1ol000000omUWo7o0000ogNTk`05ogNTk`03o`000?n3YncoPjO/00Co
PjO/00?o0000ohbYjOn<ZNT01?n<ZNT00ol0003oTj_Voi>[iP06oi>[iP03o`000?nH[>CoV:cT00?o
00000_nH[>@00ol0003oW:gSoib]h`06oib]h`03o`000?nP[^;oX:kR00KoX:kR00?o0000oj>`hOnS
/>401OnS/>43o`0000WoYk;Q00?o0000ojVdhOnY]>401_nY]>42o`0000Wo[;OQ00?o0000ojjihOn^
^N401On^^N42o`000003ok2jhOl0003o/KcR00Wo/KcR00Co0000ok>ohol0003o00001one`N<00ol0
003o]/?TokK3i002okK3i0;o00001OniaN@00ol0003o^/SUok[8i@02ok[8i@;o00001_nlbN@01?l0
003o_LcVokg<i_nmc>H2o`0000Oo_lkU00?o0000ol3Aiol000002Oo2dnL3o`0000GoaMSW0_l00005
olSIi`?o00001_o:g^L2o`0000Goc=oV0ol00003olgSi`;o00001Oo?i>H01?l0003odNCUom7TiOoA
i>D2o`000003om3Wiol0003odNSV00;odNSV0_l00004om;Xi@03o`000?oDj>Coe>ST00?oe>ST0ol0
0003om?[iP04o`000?oDjnGoe>_UomC[i@;o00001?oDjn@00ol0003ooo]ZoookJP16oookJP03o`00
0?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX05OoonfX005_ooo]Z0_l0001;oookJP?o000000?o
98CZo`000?m4T_000om4T_001?l0003oGI_aoefKlOmMVo47o`0000;oMjC_00?o0000oh>Wk?n3Yn`0
1?n3Yn`00ol0003oS:WYohbYj@04ohbYj@03o`000?nCZnKoTj_V00;oTj_V1_l00006oiR/i003o`00
0?nL[N?oW:gS00KoW:gS00?o0000oj2^h_nP[^801_nP[^800ol0003oXk3Qoj>`h@04o`0000?oY;3Q
00?o0000ojNbhOnW/^401_nW/^400ol0003oZKCQojVdh@03ojVdh@?o000000?oZ[GPo`000?n/]n40
2On/]n400ol0003o[[WQojjih@02ojjih@;o00001?n`^^400ol0003o/KcRok6lhP07ok6lhP;o0000
2_ne`N<01?l0003o]/?To`000?l00008okW5i004o`000?njb>Go0000o`0000Wo_<WT00?o0000okg<
i_l000002Onoc^D2o`0000Wo`]?W00Go0000olGDi_o5e>KoaMCVo`000003olGHi`03o`000?o8fNOo
b=WW00Cob=WW00Go0000ol[Ki_o:fnKob]_Vo`000003ol[Ni`;o00001_o<gnH01ol0003oc^3UolkP
iOo>h>Go0000olgSiol000001Oo?i>H2o`0000GodNCU1?l000000ooAj>Ko0000om;Xi@04om;Xi@03
o`000?oDj>Coe>ST00?oe>ST00Oo0000omGXhooEj>?oeNSSo`000?oCjnKo000000?oe>_U00?o0000
omC[i?oDjn@00ooDjn@00ol0003ooo]ZoookJP18oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX05OoonfX005gooo]Z00?o0000oookJ_oonfX0BOoonfX00ol0003o57[To`000002o`00
00CoA9;`00?o0000oefKlOmMVo400_mMVo400ol0003oLJ;_og6Rk`02og6RkaGo00001?nBZ^H00ol0
003oV:cToiR/i006oiR/i003o`000?nL[N?oW:gS00KoW:gS00?o0000oj2^h_nP[^801?nP[^84o`00
00SoY;3Q00?o0000ojNbhOnW/^401_nW/^400ol0003oZKCQo`000002o`0000GoZ[GP00?o0000ojbg
hOn/]n402?n/]n401?l0003o[[WQo`000?l00007ok2jh@03o`000?na_>;o/KcR00Co/KcR0_l00000
0onc_^;o0000okG1h`09okG1h`?o00002OniaN@3o`0000[o_<WT0_l00009oko>i@04o`000?o2d>Go
`]3Uo`0000Ko`]?W0_l00005olGDiP03o`000?o5f>Oo000000Kob=WW00?o0000ol[Ki_o:fnH00oo:
fnH00ol0003ob]kWo`000007olcOiP03o`000?o>h>Goc^3U00;oc^3U0ol00004oloTiP03o`000?oA
i>GodNCU00CodNCU00?o0000om;Ui?oBiN@00_oBiN@2o`0000Cod^SU00?o0000omCXi?oDj>@00ooD
j>@00ol0003oeNSSomGXh`02omGXh`Co000000?oe>_Uo`000?oDjn@00ooDjn@2o`0004cooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0EoookJP00G_oonfX00ol0003ooo]ZoookJP19
oookJP04o`000?lDN^Co57[ToaAji0?o00000_m4T_000ol0003oGI_aoefKl@02oefKl@03o`000?ma
X^ooLJ;_00CoLJ;_00?o0000ognUk?moYN`01?moYN`00ol0003oRZSYohZXj@05ohZXj@03o`000?nB
Z^KoTZ[V00GoTZ[V00?o0000oiR/i?nH[>@01_nH[>@00ol0003oW:gSoib]h`06oib]h`03o`000?nP
[^;oX:kR00?o00000_nQ[n800ol0003oY;3QojB`h@08ojB`h@03o`000?nW/^7oYk;Q00CoYk;Q0ol0
0009ojZeh003o`000?n/]n7o[;OQ00Oo[;OQ0_l00009ok2jh@03o`000?na_>;o/KcR00;o/KcR0_l0
0004ok>nhP03o`000?ne`N?o]L7S00Go]L7S0_l00003okO2hP03o`000?niaNCo^LGT00Co^LGT0_l0
0003ok_6h`03o`000?nlbNCo_<WT00Go_<WT0_l00002okk;i003o`000?noc^Go_lkU00Co_lkU0_l0
0004ol;@i@04o`000?o2dnOo`]?Wol;Ci`;o00001oo5e>H3o`0000Gob=WW00?o0000ol[Ki_o:fnH0
1?o:fnH3o`0000Goc=oV0_l00004olkPi@04o`000?o@hNCod>7Tom3Qi0;o000000?ocnCVo`000?oA
i>D01OoAi>D00ol0003od^GTom;Ui002om;Ui003o`000?oDiN?oe>GS00;o000000?od^SUo`000?oD
j>@00ooDj>@2o`0000CoeNSS00?o0000omKXh_oFj>800_oFj>82o`0000?oe>_T00?o0000oookJ_oo
nfX0C?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01Gooo]Z001OoookJP03o`00
0?oonf[ooo]Z04Wooo]Z00Ko0000oaAji?lDN^Co57[To`000?lgRnd4o`0000CoGI_a00?o0000og6R
komaX^l01?maX^l00ol0003oOjG/ognUk004ognUk003o`000?n:Z>WoRZSY00GoRZSY00?o0000oi:Z
i_nBZ^H01OnBZ^H00ol0003oV:cToiR/i006oiR/i003o`000?nL[N?oW:gS00;oW:gS1_l00006oj6_
hP03o`000?nT/>7oY;3Q00SoY;3Q00?o0000ojNbhOnW/^400ol00002ojRch003o`000?nZ]N3oZ[GP
00SoZ[GP00?o0000ojbghOn/]n400on/]n43o`000003ojjhh?l0003o/;[Q00Wo/;[Q00Co0000ok6l
h_l0003o00001onc_^800ol0003o]L7SokG1h`02okG1h`;o00001_ng`^800ol0003o^LGTokW5i002
okW5i003o`000?nka^?o^lKS00Co^lKS00?o0000okc9i?nlbN@00_nlbN@2o`0000Go_/_T00Co0000
oko>iOnoc^Go_lkU0_l00007ol;@i@03o`000?o2dnOo000000SoaMCV00Go0000olOFiOo7e^GoamKU
o`000003olSIi`03o`000?o:fnKob]_V00Cob]_V00Go0000olcLiOo<g>Goc=cUo`000003olcOiP03
o`000?o>h>Goc^3U00?oc^3U00?o0000om3Qi?o@hN@00oo@hN@2o`0000GodNCU0_l00004om;Ui003
o`000?oDiN?oe>GS00;oe>GS0ol00003omCXi003o`000?oEj>?oeNSS00?oeNSS00?o0000omKXh_oF
j>800_oFj>801_l0003oenSRomOXh_l0003oe>_To`00053ooo]Z00?o0000oookJ_oonfX07OoonfX0
0ol0003ooo]ZoookJP0EoookJP00H?oonfX00ol0003ooo]ZoookJP19oookJP;o00000_lDN^@01?l0
003o=h_]ocN;kOlgRnd4o`0000;oGI_a00?o0000og6RkomaX^l01?maX^l00ol0003oOjG/ognUk004
ognUk003o`000?n:Z>WoRZSY00GoRZSY00?o0000oi:Zi_nBZ^H01?nBZ^H00ol0003oV:cToiR/i005
oiR/i0Ko00001?nL[N<00ol0003oXJoRoj6_hP06oj6_hP03o`000?nT/>7oY;3Q00OoY;3Q0ol00006
ojRch003o`000?nZ]N3oZ[GP00SoZ[GP00?o0000ojbghOl000000_l00005ojjhh003o`000?n`^^7o
/;[Q00Oo/;[Q0_l0000:ok>nhP04o`000?ne`N?o0000o`0000Wo]l;R00Co0000okW5i?l0003o0000
2?nka^<01?l0003o_<WTo`000?l00008okk;i003o`000?noc^Go000000Wo`]3U0ol00006olGDiP;o
00001Oo7e^D00ol0003ob=WWo`000006ol[KiP03o`000?o<g>Goc=cU00?oc=cU00?o0000olcOi_l0
00001Oo>h>D00ol0003od>7Tom3Qi003om3Qi004o`000?oBh^?od^;So`0000?odNCU00?o0000om;U
i?oBiN@00ooBiN@00ol0003oe>GSomCUh`02omCUh`07o`000?oFi^;oe^KRomKVh_l0003oe>STo`00
0005omGXh`03o`000?oFj>;oe^SR00;oe^SR00Co0000omOXh_oGj>;oenSR0_l0001BoookJP03o`00
0?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX05OoonfX0067ooo]Z0_l0001;oookJPCo00001?lg
Rnd00ol0003oEIO`o`000003o`0000GoLJ;_00?o0000ognUk?moYN`01OmoYN`00ol0003oRZSYohZX
j@05ohZXj@03o`000?nBZ^KoTZ[V00CoTZ[V00?o0000oiR/i?nH[>@01?l00002oiN[i003o`000?nL
[N?oW:gS00KoW:gS00?o0000oj6_h_nQ[n801_nQ[n800ol0003oY;3QojB`h@03ojB`h@?o000000?o
YK7Qo`000?nX/n001onX/n000ol0003oZ[GPojZeh007ojZeh0;o00002On^^>000ol0003o/;[Qok2j
h@03ok2jh@?o000000?o/[_Qo`000?nc_^802Onc_^82o`0000_o]l;R0_l0000:ok_6h`;o00002_nn
bn@2o`0000Wo`]3U00Go0000olCAi?o4dNCoa=7To`000003olGDiP;o00001oo7e^D2o`0000Gob]_V
0_l00006olcLi@?o00001?o>h>D00ol0003od>7Tom3Qi003om3Qi003o`000?oBh^?od^;S00;od^;S
00?o0000om7TiOl000001OoBiN@00ol0003oe>GSomCUh`02omCUh`03o`000?oFi^;oe^KR00?oe^KR
0_l00004omGXh`03o`000?oFj>;oe^SR00;oe^SR00Go0000omOXh_oGj>;oenSRo`00001EoookJP03
o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX05?oonfX006?ooo]Z00?o0000oookJ_oonfX0
BOoonfX01?l0003o173No`000?l00004ocN;k@04o`000?mEUo3oEIO`oeFGl0Ko000000?oLJ;_o`00
0?moYN`01_moYN`00ol0003oRZSYohZXj@02ohZXj@co00001onGZn@00ol0003oW:gSoib]h`06oib]
h`03o`000?nQ[n;oXJoR00KoXJoR00?o0000ojB`hOl000000_l00005ojFah@03o`000?nX/n3oZ;?P
00KoZ;?P00?o0000ojZeh?nZ]N000onZ]N03o`000003ojbfh?l0003o[[SP00Wo[[SP00?o0000ok2j
hOl000000_l00005ok:kh@03o`000?nc_^;o/kkR00Go/kkR0_l00002okJoh@03o`000?ng`^;o]l;R
00Oo]l;R00?o0000ok[3h_l000002Onka^<00ol0003o_LSRo`000009okk;i004o`000?o1cN?o`LgS
o`0000Ko`]3U0_l00005olCAi003o`000?o5e>Ko000000SoamKU00Co0000olWGi?o9enCo00000oo:
fnH00ol0003oc=cUolcLi@05olcLi@04o`000?o>gN?oc]gSolkMh`;o000000?oc^3Uo`000?o@hN@0
1?o@hN@00ol0003od^;Som;Rh`03om;Rh`?o00001?oBiN@00ol0003oe>GSomCUh`02omCUh`03o`00
0?oFi^;oe^KR00?oe^KR00?o0000omOVhOoGi^400_l000000ooEj>?o0000omKXhP03omKXhP05o`00
0?oGj>;oenSRomOXh_l00000E_oonfX00ol0003ooo]ZoookJP0LoookJP03o`000?oonf[ooo]Z01Co
oo]Z001ToookJP03o`000?oonf[ooo]Z04Wooo]Z00?o0000o`A`g_l4L=h00ol00002ocN;k@03o`00
0?mEUo3oEIO`00;oEIO`00Co0000of^Okom[WnooJio_3_l00003ohRWj@03o`000?nAZNOoTJWW00Co
TJWW00?o0000oiN[i?nGZn@01onGZn@00ol0003oW:gSoib]h`05oib]h`03o`000?nQ[n;oXJoR00Go
XJoR0ol00009ojFah@03o`000?nX/n3oZ;?P00KoZ;?P00?o0000ojZeh?l000000_l00005ojbfh003
o`000?n^^>3o[[SP00Oo[[SP0_l00009ok:kh@03o`000?nc_^;o/kkR00;o/kkR0_l00005okJoh@03
o`000?ng`^;o]l;R00Co]l;R0_l00003ok[3hP03o`000?nka^?o^lKS00Co^lKS0_l00003okg8hP03
o`000?nnbnCo_/_T00Co_/_T0_l00004ol7=h`04o`000?o2d>Go`]3Uol;@i@;o00001oo4dN@3o`00
00KoamKU0_l00004olWGi003o`000?o:fnKo000000Koc=cU0_l00005olkMh`;o00001Oo@hN@00ol0
003od^;Som;Rh`03om;Rh`04o`000?oCh^;odn;Rom?RhP;o000000?od^GTo`000?oDiN<00ooDiN<0
0ol0003oe^KRomKVhP03omKVhP03o`000?oGi^7oenKQ00;oenKQ0ol00003omKXhP05o`000?oGj>;o
enSRomOXh_l00000F?oonfX00ol0003ooo]ZoookJP0KoookJP03o`000?oonf[ooo]Z01Cooo]Z001U
oookJP03o`000?oonf[ooo]Z04Wooo]Z0_l00002o`A`gPGo00001?mEUo000ol0003oJio_of^Ok`03
of^Ok`03o`000?mlY>coO:C/00CoO:C/00?o0000ohRWjOn8YnT01On8YnT00ol0003oTJWWoi6Yi`04
oi6Yi`03o`000?nGZnCoUj_T00OoUj_T00?o0000oib]honL[N<01OnL[N<00ol0003oXJoRoj6_hP04
o`0000;oXJoR00?o0000ojFahOnU/N401onU/N400ol0003oZ;?PojRch005ojRch0?o00002On/]^00
0ol0003o[[SPojjhh003ojjhh0?o00000_n`^N000ol0003o/[_Qok:kh@07ok:kh@04o`000?nc_^;o
0000o`0000So][oQ00Co0000okO2h_ng`^;o]l;R0_l00006ok[3hP04o`000?nka^?o^lKSok_6h`;o
00001_nmb>801?l0003o_/_Tokk;i?nnbn@2o`0000Oo`LgS00?o0000ol;@iOl000002?o4dN@01Ol0
003oam?SolOChoo7dn?o000000?oamKU0_l00006olWGi0?o00001?o<g>D2o`0000Koc]gS00Co0000
om3Mh_o@gN;o00000oo@hN@00ol0003od^;Som;Rh`03om;Rh`03o`000?oCh^;odn;R00?odn;R0ol0
0003omCUh`03o`000?oFi^;oe^KR00?oe^KR00?o0000omOVhOoGi^400_oGi^401ol0003of>KPomSV
h?oHi^3o0000omKXh_l000000ooGj>800ol0003ooo]ZoookJP1HoookJP03o`000?oonf[ooo]Z01[o
oo]Z00?o0000oookJ_oonfX05?oonfX006Kooo]Z0_l0001;oookJPCo00000_l[Q>X4o`0000;oEIO`
00?o0000of^Okom[Wnl00om[Wnl00ol0003oO:C/ogbTk004ogbTk003o`000?n8YnWoR:OY00GoR:OY
00?o0000oi6YionAZNL01?nAZNL00ol0003oUj_ToiN[i007oiN[i003o`000?nL[N?oW:gS00;oW:gS
1Ol00007oj6_hP03o`000?nU/N7oYK7Q00OoYK7Q00?o0000ojRch?nX/n001?l00003ojVch003o`00
0?n/]^3o[;KP00Oo[;KP00?o0000ojjhh?l000000_l00006ok2ih003o`000?nb^n7o/[_Q00Ko/[_Q
0_l0000;okJoh@03o`000?ng`^;o000000Wo^/?R00?o0000ok_6hol000002Onmb>800ol0003o_/_T
o`000009ol7=h`?o00001_o4dN@2o`0000Goam?S00?o0000olOFiOl000001oo9en@01?l0003oc=SS
olcHhoo<f><2o`000003olcLiOl0003oc]gS00Koc]gS00?o0000om3Mh_o@gN800_o@gN800ol0003o
d>7To`000005om;Rh`03o`000?oCh^;odn;R00?odn;R00Oo0000omGShOoEhn7oeN?Qo`000?oDiN?o
000000Goe^KR00?o0000omOVhOoGi^400_oGi^400ol0003of>KPomSVh002omSVh0Co000000?oenSR
o`000?oonfX0FooonfX00ol0003ooo]ZoookJP0IoookJP03o`000?oonf[ooo]Z01Cooo]Z001Xoook
JP03o`000?oonf[ooo]Z04Wooo]Z00Co0000o`1Ue_l0003o00000ol[Q>X00ol0003oC9;_o`000003
o`0000GoJio_00?o0000ogbTk?mlY>`01?mlY>`00ol0003oR:OYohRWj@05ohRWj@03o`000?nAZNOo
TJWW00CoTJWW00?o0000oiN[i?nGZn@01OnGZn@6o`0000?oWJgS00?o0000oj6_h_nQ[n801onQ[n80
0ol0003oYK7QojFah@06ojFah@?o00002?nY/n000ol0003o[;KPojbfh006ojbfh0;o00002_n`^N00
0ol0003o/[_Qok:kh@02ok:kh@?o00000_nd_N000ol0003o][oQokJoh@08okJoh@;o00002_nj`n82
o`0000[o_LSR0ol00007ol7=h`;o00000oo3c^801?l0003oa=7TolCAi?o4dN@2o`0000Ooam?S0ol0
0005olWGi0;o00001Oo<f><3o`0000Goc]gS0_l00005om3MhP?o00001?oBh^<00ol0003odn;Rom?R
hP03om?RhP03o`000?oEhn7oeN?Q00;oeN?Q0ol00004omKVhP04o`000?oGi^7oenKQomOVh@;o0000
1?oHi^000ol0003ofNKOomWVg`02omWVg`03o`000?oonf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0
6OoonfX00ol0003ooo]ZoookJP0DoookJP00JOoonfX00ol0003ooo]ZoookJP19oookJP03o`000?l0
IMKo06GF00;o00000_l[Q>X01?l0003oC9;_odbBkom<T^l6o`000003of^Okol0003oO:C/00GoO:C/
00?o0000ohRWjOn8YnT01On8YnT00ol0003oTJWWoi6Yi`04oi6Yi`03o`000?nGZnCoUj_T00Co0000
0_nGZnD00ol0003oWJgSoif]h`05oif]h`03o`000?nQ[n;oXJoR00OoXJoR00?o0000ojFahOnU/N40
0_nU/N43o`000003ojJahOl0003oZK?P00WoZK?P00?o0000ojbfh?n/]^000_n/]^03o`000003ojfg
h?l0003o/;WP00[o/;WP00Co0000ok:khOl0003o00001_nd_N000ol0003o][oQokJoh@05okJoh@;o
00000_nh`N400ol0003o^/?Rok[3hP05ok[3hP;o00000_nlaN400ol0003o_LSRokg8hP05okg8hP;o
00000oo0bN800ol0003o`LgSol7=h`02ol7=h`;o00001_o3c^800ol0003oa=7To`000008olOCh`05
o`000?o9e>;obMCRolWDh_l000000oo9en@00ol0003oc=SSolcHh`04olcHh`05o`000?o>fN;oc]WR
olkIh_l000000oo>gN<00ol0003od=gRom3MhP04om3MhP04o`000?oBg^7od]kQom;Nh@;o000000?o
d^;So`000?oCh^801?oCh^800ol0003oeN?QomGSh@02omGSh@04o`000?oGhmooen?OomOSg`;o0000
00?oe^KRo`000?oGi^400_oGi^400ol0003of>KPomSVh003omSVh003o`000?oIi]oofNKO00;ofNKO
00?o0000oookJ_oonfX0GOoonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z01Cooo]Z
001ZoookJP03o`000?oonf[ooo]Z04Wooo]Z0_l000000ol0IMKo0000o`000003o`0000CoC9;_00Co
0000ofFLkomUW>ooIIc_6_l00007oiN[i@03o`000?nM[N?oWJgS00GoWJgS00?o0000oj6_h_nQ[n80
1onQ[n801?l0003oYK7Qo`000?l00005ojJah@03o`000?nY/n3oZK?P00SoZK?P00Co0000ojbfh?l0
003o00001On]]n000ol0003o/;WPok2ih008ok2ih0;o00002Ond_N000ol0003o][oQokJoh@02okJo
h@;o00001Onh`N400ol0003o^/?Rok[3hP02ok[3hP;o00001OnlaN400ol0003o_LSRokg8hP02okg8
hP;o00001_o0bN801?l0003o`LgSo`000?l00008ol?>hP;o00002?o7dn<00ol0003obMCRolWDhP03
olWDhP03o`000?o9enCo000000Koc=SS00?o0000olkIh_o>fN800oo>fN800ol0003oc]gSo`000006
om3MhP03o`000?oBg^7od]kQ00?od]kQ0ol00004om?RhP03o`000?oEhn7oeN?Q00;oeN?Q00?o0000
omOSgooGhml00ooGhml4o`000003omOVhOl0003of>KP00Cof>KP00?o0000omWVgooIi]l00_oIi]l0
0ol0003ooo]ZoookJP1OoookJP03o`000?oonf[ooo]Z01Sooo]Z00?o0000oookJ_oonfX04ooonfX0
06_ooo]Z0_l0001;oookJP?o00000_lMNnH2o`0000CoC9;_00?o0000ofFLkomUW>l00omUW>l00ol0
003oN:;]ogRRk@03ogRRk@03o`000?n5Y^[oQJKZ00GoQJKZ00?o0000ohnYion?ZNL01On?ZNL00ol0
003oUj_UoiN[i@06oiN[i@03o`000?nM[N?oWJgS00GoWJgS00?o0000oj6_h_nQ[n801OnQ[n83o`00
00SoY[7Q00?o0000ojVch?nY/n001onY/n02o`0000So[KOP00?o0000ok2ih?n`^N001On`^N02o`00
0003ok:jgol0003o];gP00Wo];gP00Co0000okJohOl0003o00002?nh`N401?l0003o^/?Ro`000?l0
0008okc5h@04o`000?nmb>;o0000o`0000So`<WR0_l00009ol?>hP04o`000?o6cn7oa/oQo`0000Go
am?S0_l00006olWDhP?o00001Oo<f><00ol0003oc]WRolkIhP04olkIhP?o00001Oo@gN800ol0003o
d]kQom;Nh@03om;Nh@04o`000?oDgn3oe=oPomCOh0;o000000?odn;Ro`000?oEhn400ooEhn400ol0
003oen?OomOSg`03omOSg`03o`000?oHhmkof>?N00;of>?N0_l00004omSVh003o`000?oIi]oofNKO
00;ofNKO00?o0000oookJ_oonfX0H?oonfX00ol0003ooo]ZoookJP0HoookJP03o`000?oonf[ooo]Z
01?ooo]Z001]oookJP03o`000?oonf[ooo]Z04Wooo]Z0ol00003oaekiP?o00000_m<T^l00ol0003o
IIc_ofFLk`03ofFLk`03o`000?mhX^goN:;]00?oN:;]00?o0000ohFVj_n5Y^X01On5Y^X00ol0003o
SjWWohnYi`05ohnYi`03o`000?nGZnGoUj_U00GoUj_U00?o0000oif]honM[N<01_nM[N<00ol0003o
XJoRoj6_hP04o`0000;oXZoQ00?o0000ojJahOnV/N401onV/N400ol0003oZK?PojVch003ojVch0?o
000000?oZkCPo`000?n]]n002?n]]n000ol0003o/;WPok2ih002ok2ih0;o00001?nb^]l00ol0003o
];gPokBmh007okBmh0;o00002_nh`N42o`0000[o_<GQ0_l00009ol39hP04o`000?o2bn7o`/_Qo`00
00Ko`lkR0_l00004olK?h@05o`000?o7dn?oam?SolOChol000001oo9e>801Ol0003obmGQol_EhOo;
eN7o000000?oc=SS00?o0000olkIh_o>fN801?o>fN801Ol0003od=[Pom3Jh?o@f^3o000000?od=gR
00?o0000om;NhOoBg^400ooBg^400ol0003oe=oPomCOh003omCOh0?o00000ooEhn400ol0003oen?O
omOSg`03omOSg`03o`000?oHhmkof>?N00;of>?N00?o0000omWSgOoIhmd00_l000000ooHi^3o0000
omWVg`03omWVg`03o`000?oonf[ooo]Z06;ooo]Z00?o0000oookJ_oonfX05ooonfX00ol0003ooo]Z
oookJP0CoookJP00K_oonfX00ol0003ooo]ZoookJP19oookJP?o00000olMNnH00ol0003o@Xg]o`00
0003o`0000GoIIc_00?o0000ogRRkOmhX^d00omhX^d00ol0003oQJKZohFVjP05ohFVjP03o`000?n?
ZNOoSjWW00GoSjWW00?o0000oiN[iOnGZnD01OnGZnD00ol0003oWJgSoif]h`02oif]h`Ko00001onR
[n400ol0003oY[7QojJah@07ojJah@03o`000?nY/n3o000000;o00001On[]>000ol0003o[KOPojfg
h007ojfgh004o`000?n`^N3o0000o`0000Oo/[[O00?o0000okBmh?nd_N000ond_N03o`0000;o][kP
00?o0000okS1hOnh`N401Onh`N42o`000003ok[2h?l0003o_<GQ00So_<GQ00Co0000okk6h?nna^3o
00001_o0bN82o`0000Co`/_Q00Co0000ol?>h_o3c^;o`lkR0_l00007olK?h@03o`000?o7dn?o0000
00OobMCR00?o0000ol_EhOo;eN400oo;eN400ol0003oc=SSo`000006olkIhP03o`000?o@f^3od=[P
00?od=[P00?o0000om3Mh_l000001?oBg^42o`0000Goe=oP00Oo0000omKOg_oFgmkoe]oNo`000?oE
hn7o000000Goen?O00?o0000omSSg_oHhmh00_oHhmh00ol0003ofN?MomWSg@02omWSg@?o00000ooI
i]l00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX04ooo
nfX006oooo]Z00?o0000oookJ_oonfX0BOoonfX4o`0000;o7G_V00Co0000od:=kOm2SNgo@Xg]1_l0
00000omUW>oo0000ogRRk@04ogRRk@03o`000?n5Y^[oQJKZ00CoQJKZ00?o0000ohnYion?ZNL01_n?
ZNL00ol0003oUj_UoiN[i@02oiN[i@Oo00001?nM[N<00ol0003oXZoQoj:_h@07oj:_h@03o`000?nV
/N7oY[7Q00GoY[7Q0ol00009oj^dh003o`000?n]]n3o[KOP00Ko[KOP0_l0000:ok:jg`03o`000?nd
_N3o000000;o00001_nf_^000ol0003o^<7QokS1h@02okS1h@;o00001?nj`^000ol0003o_<GQokc5
h@04okc5h@;o00001?nna^001?l0003o`<WRol39h_o0bN82o`0000Oo`/_Q00?o0000ol?>h_l00000
2Oo6cn43o`0000GobMCR0_l00006ol_Eh@;o00001Oo>fN82o`0000Kod=[P0ol00003om;Nh@03o`00
0?oDgn3oe=oP00Coe=oP00?o0000omKOg_oFgmh00ooFgmh2o`0000Coen?O00?o0000omSSg_oHhmh0
0_oHhmh00ol0003ofN?MomWSg@02omWSg@07o`000?oJhmcof^?Lom[Sg?l0003ofNKOo`00001Xoook
JP03o`000?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX04ooonfX0073ooo]Z0_l0001:oookJPOo
00000om2SNd00ol0003oGiS_oenHk`02oenHk`Oo000000?oN:;]o`000?n5Y^X01On5Y^X00ol0003o
SjWWohnYi`02ohnYi`So00000onGZnD00ol0003oWJgSoif]h`06oif]h`03o`000?nR[n7oXZoQ00Oo
XZoQ00?o0000ojJahOnV/N401?l00002ojNbh003o`000?n[]>3oZkCP00OoZkCP00?o0000ojfgh?n]
]n000on]]n03o`000003ojnhgol0003o/[[O00Wo/[[O0_l0000:okJnh004o`000?nh`N7o0000o`00
00Oo^/;P00Co0000okc5hOnlaN7o_<GQ0_l00007okk6h003o`000?o0bN;o000000Wo`/_Q0_l00009
olK?h@05o`000?o8d>3ob=3PolS@h?l000000oo9e>800ol0003obmGQol_Eh@05ol_Eh@04o`000?o=
e^3ocMKPo`0000?oc]WR00?o0000om3Jh?o@f^001Oo@f^001ol0003od]_Oom;KgooBfmoo0000om;N
hOl000001_oDgn000ol0003oe]oNomKOgP03omKOgP03o`000?oGh=goen3M00;o000000?oen?Oo`00
0?oHhmh00ooHhmh00ol0003ofN?MomWSg@02omWSg@03o`000?oJhmcof^?L00?of^?L00?o0000oook
J_oonfX0IooonfX00ol0003ooo]ZoookJP0EoookJP03o`000?oonf[ooo]Z01?ooo]Z001boookJP03
o`000?oonf[ooo]Z04Sooo]Z0ol00002o`mbh@;o00000om2SNd00ol0003oGiS_oenHk`03oenHk`03
o`000?mdX>goM:3]00;oM:3]3Ol00004ohjXi`03o`000?nGZnGoUj_U00GoUj_U00?o0000oif]honM
[N<01_nM[N<00ol0003oXZoQoj:_h@05oj:_h@Co00001onW/^000ol0003oZkCPoj^dh007oj^dh003
o`000?n]]n3o000000;o00001On_^=l00ol0003o/[[Ook:jg`05ok:jg`;o000000?o];_Oo`000?nf
_^002Onf_^02o`0000[o^/;P00?o0000okc5hOl000002Onna^02o`0000Wo`/_Q00Co0000olC<h?o4
c>3o00001_o6cn42o`0000Gob=3P00?o0000olWDh_l000001oo;eN400ol0003ocMKPolgFh002olgF
h003o`000?o>fN;o000000Ood=[P00?o0000om;KgooBfml00ooBfml2o`0000Goe=oP00?o0000omKO
g_oFgmh00ooFgmh00ol0003oen3MomOPg@02omOPg@?o00000ooHhmh00ol0003ofN?MomWSg@02omWS
g@03o`000?oJhmcof^?L00?of^?L00?o0000oookJ_oonfX0JOoonfX00ol0003ooo]ZoookJP0Doook
JP03o`000?oonf[ooo]Z01?ooo]Z001coookJP03o`000?oonf[ooo]Z04Sooo]Z00?o0000o`1=`ol0
00000ol?L^43o`000003od:=kOl0003oGiS_00CoGiS_00?o0000ogBPkOmdX>d00omdX>d00ol0003o
PjGZoh>UjP04oh>UjP03o`000?n>Z>OoSZSW00KoSZSW00?o0000oiN[iOnGZnD01OnGZnD00ol0003o
WJgSoif]h`06oif]h`03o`000?nR[n7oXZoQ00Co00000_nS/>400ol0003oYk;PojNbh007ojNbh003
o`000?n[]>3oZkCP00KoZkCP0_l00009ojnhg`03o`000?nb^]oo/[[O00;o/[[O0_l00004okBkg`03
o`000?nf_^3o][kP00Go][kP0_l000000onh_moo0000ok[2h009ok[2h0?o00002?nna^001?l0003o
`LOOol77gol00006ol;;h@;o00001?o4c>001?l0003oa/oQolK?hOo6cn42o`0000Oob=3P0ol00005
ol_Eh@;o00001Oo=e^03o`0000God=[P0_l00005om;Kg`04o`000?oDfmkoe=_No`0000?oe=oP00?o
0000omKOg_oFgmh00ooFgmh00ol0003oen3MomOPg@02omOPg@07o`000?oIh=cofN3LomWPg?l0003o
f>?No`000004omWSg@03o`000?oJhmcof^?L00?of^?L00?o0000oookJ_oonfX0JooonfX00ol0003o
oo]ZoookJP0DoookJP03o`000?oonf[ooo]Z01;ooo]Z001doookJP03o`000?oonf[ooo]Z04Sooo]Z
00Ko0000o`1=`ol0003o0000o`mbhOl00002ocR7j`?o00001OmOV>l00ol0003oM:3]ogBPk@03ogBP
k@03o`000?n3YN[oPjGZ00CoPjGZ00?o0000ohjXion>Z>L01_n>Z>L00ol0003oUj_UoiN[i@05oiN[
i@03o`000?nM[N?oWJgS00CoWJgS1?l00007oj>`h@03o`000?nW/^3oYk;P00KoYk;P00?o0000oj^d
h?n[]>000on[]>03o`000003ojbegol0003o[kSO00Wo[kSO00Co0000ok:jgol0003o00001ond^ml0
0ol0003o][kPokJnh002okJnh0;o00001?nh_ml00ol0003o^/;Pok[2h005ok[2h0;o00000onl`ml0
0ol0003o_/KPokk6h003okk6h0;o00001?o1aml01?l0003o`/_Qol;;hOo2bn42o`0000Ooa<cP00?o
0000olK?hOl000002?o8d>001Ol0003ob]7Ool[Agoo:dMoo000000?obmGQ00?o0000olgFh?o=e^00
1?o=e^001Ol0003od=ONom3Gg_o@emko000000?od=[P00?o0000om;KgooBfml01?oBfml00ol0003o
e=_NomCKgP02omCKgP03o`000?oDgn3o000000Goe]oN00?o0000omOPgOoGh=d00_oGh=d00ol0003o
fN3LomWPg003omWPg0;o00000ooIhmd00ol0003of^?Lom[Sg003om[Sg003o`000?oonf[ooo]Z06go
oo]Z00?o0000oookJ_oonfX04ooonfX00ol0003ooo]ZoookJP0BoookJP00MOoonfX00ol0003ooo]Z
oookJP18oookJPKo00001?lhQn/3o`0000?oGiS_00?o0000ogBPkOmdX>d00omdX>d00ol0003oPjGZ
oh>UjP04oh>UjP03o`000?n>Z>OoSZSW00GoSZSW00?o0000oiN[iOnGZnD01_nGZnD00ol0003oWJgS
oif]h`03o`0000;oWJkS00?o0000oj>`hOnS/>401onS/>400ol0003oYk;PojNbh006ojNbh003o`00
0?n[]>3o000000;o00001On/]Ml00ol0003o[kSOojnhg`07ojnhg`;o00002_nd^ml01?l0003o][kP
o`000?l00007okRog`03o`000?nj`^3o^/;P00;o^/;P0_l00006okc3g`05o`000?nna^3o_/KPokk6
h?l000001oo1aml00ol0003o`/_Qo`000009olC<h0;o00002?o8d>000ol0003ob]7Ool[Ag`03ol[A
g`03o`000?o;eN7o000000KocMKP00?o0000om3Gg_o@emh00oo@emh00ol0003od=[Po`000006om;K
g`03o`000?oDfmkoe=_N00?oe=_N0ol00004omKOgP03o`000?oGh=goen3M00;oen3M00?o0000omWP
g?oIh=`00ooIh=`01_l0003of^3Kom[Pfol0003ofN?Mo`0000Gof^?L00?o0000oookJ_oonfX0K_oo
nfX00ol0003ooo]ZoookJP0CoookJP03o`000?oonf[ooo]Z01;ooo]Z001foookJP;o0000BOoonfX3
o`000003o`5Yfol0003o000000Co>8O[00?o0000oeREk_l000001?l00005ogBPk@03o`000?n3YN[o
PjGZ00CoPjGZ00?o0000ohjXion>Z>L01On>Z>L00ol0003oUj_UoiN[i@02oiN[i@Ko00001_nM[^<0
0ol0003oXk3Qoj>`h@07oj>`h@03o`000?nW/^3oYk;P00CoYk;P0ol00009ojbeg`03o`000?n_^=oo
[kSO00?o[kSO0ol00002ok6ig`03o`000?nd^moo];_O00Oo];_O0_l0000:okRog`04o`000?nj`^3o
0000o`0000Wo_<?O00?o0000okk6h?l000002?o1aml3o`0000Soa<cP00Co0000olO=goo7cMoo0000
1Oo8d>02o`0000Kob]7O0ol00005olgFh003o`000?o@emkod=ON00Cod=ON0ol00005om;Kg`03o`00
0?oDfmkoe=_N00?oe=_N00Co0000omKLg?oFg=coe]cL0_l000000ooFgmko0000omOPg@03omOPg@03
o`000?oIh=cofN3L00?ofN3L00?o0000om[PfooJh=/00_oJh=/2o`0000Cof^?L00?o0000oookJ_oo
nfX0L?oonfX00ol0003ooo]ZoookJP0BoookJP03o`000?oonf[ooo]Z01;ooo]Z001hoookJP03o`00
0?oonf[ooo]Z04Oooo]Z0ol000000ol1JM_o0000o`000004ocR7j`03o`000?mHUNkoF9G^00;oF9G^
1_l000000omdX>go0000oh>UjP05oh>UjP03o`000?n>Z>OoSZSW00;oSZSW1ol00004oiJ[i@03o`00
0?nM[^?oWJkS00KoWJkS00?o0000oj>`hOnS/>401onS/>400ol0003oYk;PojNbh003o`0000?oZ;?P
00?o0000ojbegon/]Ml01on/]Ml00ol0003o[kSOo`000002o`0000Ko/KWO00?o0000okBkgond^ml0
1?nd^ml2o`0000;o][cN00?o0000okRogonh_ml01onh_ml2o`0000_o_<?O0_l00008ol77g`05o`00
0?o3b=ko`lSNol?8g_l000001Oo4c>02o`0000CoalgO00Go0000olS@h?o8d>3ob=3Po`000007ol[A
g`05o`000?o=d]kocM;NolgBg_l000000oo=e^000ol0003od=ONom3GgP04om3GgP05o`000?oAemgo
dMOMom7GgOl000000ooBfml00ol0003oe=_NomCKgP03omCKgP03o`000?oFg=coe]cL00?oe]cL0ol0
0003omOPg@03o`000?oIh=cofN3L00?ofN3L00?o0000om[PfooJh=/00_oJh=/00ol0003ofn3Jom_P
fP02o`000003om[Sg?l0003ooo]Z07?ooo]Z00?o0000oookJ_oonfX04OoonfX00ol0003ooo]Zoook
JP0BoookJP00NOoonfX00ol0003ooo]ZoookJP17oookJP03o`000?l0@;So000000;o0FWK0ol00002
ocR7j`03o`000?mHUNkoF9G^00;oF9G^00?o0000og2NkOm`W^d00_m`W^d=o`0000?oSJSW00?o0000
oiJ[iOnFZnD01_nFZnD00ol0003oWJkSoif^h`06oif^h`03o`000?nS/>7oXk3Q00GoXk3Q1?l00007
ojRch003o`000?n/]Moo[;GO00Ko[;GO0_l0000:ok6ig`03o`000?nd^moo];_O00;o];_O00?o0000
okJlg_nf_=h00onf_=h00ol0003o^;oOokRog`04okRog`;o00000_nj`=h00ol0003o_<?Ookc3g`07
okc3g`04o`000?noa=ko_lCNo`0000Go`LOO0_l00005ol?8gP05o`000?o4c>3oa<cPolC<h?l00000
1oo7cMl00ol0003ob=3Po`000007ol[Ag`03o`000?o=d]kocM;N00?ocM;N00?o0000olgFh?l00000
1_o@emh00ol0003odMOMom7Gg@03om7Gg@03o`000?oBfmoo000000Goe=_N00?o0000omKLg?oFg=`0
0ooFg=`01ol0003oemcKomOLfooGg=_o0000omOPgOl000001OoIh=`00ol0003of^3Kom[Pf`02om[P
f`03o`000?oKh=[ofn3J00?ofn3J00?o0000oookJ_oonfX0M?oonfX00ol0003ooo]ZoookJP0@oook
JP03o`000?oonf[ooo]Z01;ooo]Z001joookJP03o`000?oonf[ooo]Z04Oooo]Z1?l000000ol1JM_o
0000obf1j004o`0000CoF9G^00?o0000og2NkOm`W^d00om`W^d00ol0003oPJCZoh6TjP05oh6TjP03
o`000?n=Z>OoSJSW00CoSJSW00?o0000oiJ[iOnFZnD01_nFZnD00ol0003oWJkSoif^h`06oif^h`03
o`000?nS/>7oXk3Q00Co00000_nT/>400ol0003oZ;?PojRch007ojRch003o`000?n/]Moo[;GO00;o
[;GO0ol000000on^]]oo0000ok6ig`0:ok6ig`04o`000?nd^moo0000o`0000Oo][cN00?o0000okRo
gonh_ml00_nh_ml00ol0003o^/3Nok[0gP03ok[0gP03o`000?nl`moo_<?O00Co_<?O0_l00004oko4
gP05o`000?o1amoo`LOOol77gol000002?o3b=h00ol0003oa<cPo`000008olO=g`?o00001Oo:dMl2
o`0000KocM;N0ol00005om3GgP03o`000?oAemgodMOM00CodMOM0ol00004omCKgP03o`000?oFg=co
e]cL00?oe]cL00?o0000omOLfooGg=/00ooGg=/2o`0000CofN3L00?o0000om[PfooJh=/00_oJh=/0
0ol0003ofn3Jom_PfP04om_PfP03o`000?oonf[ooo]Z07Cooo]Z00?o0000oookJ_oonfX04?oonfX0
0ol0003ooo]ZoookJP0BoookJP00NooonfX2o`0004Wooo]Z1Ol00003obf1j0Co00000_mHUNh00ol0
003oL9k]og2Nk@03og2Nk@03o`000?n1Y>[oPJCZ00GoPJCZ00?o0000ohfXion=Z>L01?n=Z>L00ol0
003oUZ_UoiJ[i@06oiJ[i@03o`000?nM[^?oWJkS00CoWJkS1?l00007ojB`h@03o`000?nX/n3oZ;?P
00OoZ;?P00Co0000ojbegol0003o00001On^]]l00ol0003o/KWOok6ig`08ok6ig`;o00002_nf_=h0
1?l0003o^;oOo`000?l00007ok[0gP04o`000?nl`moo_<?Ookc3g`;o00001onoa=h00ol0003o`LOO
o`000009ol?8gP;o00002?o7cMl01Ol0003obLkNolW>g_o9c]ko000000?ob]7O00?o0000olgBg_o=
d]h01Oo=d]h01Ol0003ocm?MoloCgOo?dmgo000000?od=ON00?o0000om7GgOoAemd01?oAemd01?l0
003odmSLom?Hg?oCf=`2o`000003omCKg_l0003oe]cL00Coe]cL00?o0000omOLfooGg=/00ooGg=/0
0ol0003ofMgJomWMfP02o`000003omWPg?l0003of^3K00?of^3K00?o0000om_Pf_oKh=X01?oKh=X0
0ol0003ooo]ZoookJP1foookJP03o`000?oonf[ooo]Z013ooo]Z00?o0000oookJ_oonfX04OoonfX0
07gooo]Z00?o0000oookJ_oonfX0AooonfX5o`0000Co;H7X00?o0000oe6AkOl000000ol00005og2N
k@03o`000?n1Y>[oPJCZ00GoPJCZ00?o0000ohfXion=Z>L01?n=Z>L00ol0003oUZ_UoiJ[i@06oiJ[
i@03o`000?nM[^?oWJkS00?o00000_nN[^<00ol0003oY;3QojB`h@07ojB`h@03o`000?nX/n3oZ;?P
00KoZ;?P0_l00008ojjfg`03o`000?na^Moo/KWO00Go/KWO0_l000000onc^Mko0000okJlgP09okJl
gP;o00002_nj`=h00ol0003o_<?Oo`000009oko4gP;o00002Oo3b=h01?l0003oaLWMolG9gOl00005
olO=g`;o00001Oo9c]h00ol0003ob]7Oo`000007olgBgP03o`000?o?dmgocm?M00?ocm?M00?o0000
om3Gg_l000001_oAemd00ol0003odmSLom?Hg003om?Hg0;o00001OoFg=`00ol0003oemcKomOLf`03
omOLf`03o`000?oIgM[ofMgJ00?ofMgJ0_l00003om[Pf`03o`000?oKh=[ofn3J00Cofn3J00?o0000
oookJ_oonfX0N?oonfX00ol0003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z017ooo]Z001noook
JP03o`000?oonf[ooo]Z04Oooo]Z1Ol00004obf1j004o`000?mATNgoDI7]oe6Ak@Ko000000?oL9k]
o`000?n1Y>X01_n1Y>X00ol0003oSJSWohfXi`04ohfXi`03o`000?nFZnGoUZ_U00;oUZ_U1_l00006
oij^h`03o`000?nT/>7oY;3Q00KoY;3Q00?o0000ojRch?nX/n000onX/n03o`000003ojZch?l0003o
[[KO00So[[KO00?o0000ok6igona^Ml00_na^Ml2o`0000Co/kWN00?o0000okJlg_nf_=h01Onf_=h2
o`000003okRmg_l0003o^/3N00Wo^/3N0_l00009oko4gP04o`000?o1aMgo`LGMo`0000Ko`lSN0_l0
0004olG9g@05o`000?o7cMooalgOolO=gol000001oo9c]h3o`0000GocM;N0_l00006oloCg@;o0000
1OoAemd2o`0000GodmSL00Co0000omGHf_oEf=[o00000ooFg=`00ol0003oemcKomOLf`03omOLf`03
o`000?oIgM[ofMgJ00?ofMgJ00Ko0000om[Mf?oJgMSo0000om[Pfol00006om_PfP03o`000?oonf[o
oo]Z07Wooo]Z00?o0000oookJ_oonfX03ooonfX00ol0003ooo]ZoookJP0AoookJP00OooonfX00ol0
003ooo]ZoookJP17oookJPOo00000_l]PNP00ol0003oDI7]oe6Ak@02oe6Ak@04o`000?m[W>goJic]
of^LkAGo00001?nFZnD00ol0003oWZkSoij^h`06oij^h`03o`000?nT/>7oY;3Q00KoY;3Q00?o0000
ojRch?l000000_l00005ojZch003o`000?n^]]oo[[KO00Oo[[KO00Co0000ok6igol0003o00001onc
^Mh00ol0003o][cNokJlgP02okJlgP;o00001?nh_Mh00ol0003o^/3Nok[0gP05ok[0gP;o00000_nl
`Md00ol0003o_lCNoko4gP04oko4gP;o00001?o1aMd01?l0003o`lSNol?8g_o3b=h2o`0000OoaLWM
00?o0000olO=gol000001oo9c]h01Ol0003obloLol_?g?o;cmco000000?ocM;N00?o0000oloCgOo?
dmd01Oo?dmd01?l0003odMCKom7Dfol00003om7Gg@03o`000?oCf=codmSL00CodmSL00?o0000omGH
f_oEf=X00_oEf=X00ol0003oe]cLo`000005omOLf`03o`000?oIgM[ofMgJ00?ofMgJ00?o0000om[M
f?oJgMP00_oJgMP2o`0000Gofn3J00?o0000oookJ_oonfX0NooonfX00ol0003ooo]ZoookJP0>oook
JP03o`000?oonf[ooo]Z017ooo]Z0020oookJP;o0000B?oonfX2o`000003o`1Dc?l0003o000000Go
00001?mATNd00ol0003oJic]of^Lk@02of^Lk@03o`000?mnXn_oOZ?[00GoOZ?[00?o0000ohbWion<
YnL01?n<YnL00ol0003oUZ_UoiJ[i@06oiJ[i@03o`000?nN[^?oWZkS00KoWZkS00?o0000ojB`hOnT
/>401?nT/>43o`0000WoZ[?P00?o0000ojjfgon^]]l01_n^]]l2o`0000[o/kWN00Co0000okJlg_l0
003o00001onh_Mh00ol0003o^/3Nok[0gP02ok[0gP;o00001Onl`Md01?l0003o_lCNoko4g_noa=h2
o`0000Oo`LGM00?o0000ol?8g_l000002Oo5bMd2o`0000OobLkN00?o0000ol_?g?o;cm`00oo;cm`0
0ol0003ocM;No`000007oloCg@03o`000?oAe=_odMCK00;odMCK00?o0000om7GgOl000001_oCf=`0
0ol0003oeMSJomGHfP04omGHfP;o00001?oGg=/00ol0003ofMgJomWMfP03omWMfP03o`000?oJgMSo
f]gH00?of]gH00?o0000omcMeol000000ooKh=X00ol0003ooo]ZoookJP1moookJP03o`000?oonf[o
oo]Z00gooo]Z00?o0000oookJ_oonfX04OoonfX008;ooo]Z00?o0000oookJ_oonfX0A_oonfX2o`00
00;o05C<0_l00002ob9ji@Co00000_mATNd00ol0003oJic]of^Lk@02of^Lk@03o`000?mnXn_oOZ?[
00GoOZ?[00?o0000ohbWion<YnL01?n<YnL00ol0003oUZ_UoiJ[i@06oiJ[i@03o`000?nN[^?oWZkS
00KoWZkS00?o0000ojB`hOnT/>400ol00003ojFah@03o`000?nZ/n3oZ[?P00KoZ[?P00?o0000ojjf
gon^]]l00on^]]l3o`000003ojngg_l0003o/kWN00Wo/kWN0_l0000:okRmgP04o`000?nj`=ko0000
o`0000So_<7M00?o0000oko4g_l000002Oo1aMd2o`0000WoaLWM00Co0000olO;g?o7bmco00001Oo9
c]h00ol0003obloLol_?g004ol_?g0;o00001oo?dmd00ol0003odMCKom7Df`04om7Df`;o00001OoC
f=`00ol0003oeMSJomGHfP04omGHfP03o`000?oGfMWoemWI00;o000000?oemcKo`000?oIgMX01?oI
gMX00ol0003of]gHom[Mf003om[Mf007o`000?oLgMOog=gGomcMeol0003ofn3Jo`000021oookJP03
o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX04OoonfX008?ooo]Z00?o0000oookJ_oonfX0
A_oonfX2o`0000;o05C<0_l00002ob9ji@03o`000?m9SNcoBHg/00Co00001?m[W>d00ol0003oOZ?[
ogjSj`05ogjSj`03o`000?n<YnOoS:OW00CoS:OW00?o0000oiJ[iOnFZnD01OnFZnD00ol0003oWZkS
oij^h`05oij^h`Co00001onU/N400ol0003oZ[?PojZch006ojZch003o`000?n^]]oo000000;o0000
1On_]mh00ol0003o/kWNok>igP05ok>igP;o000000?o]K[No`000?nh_Mh02Onh_Mh2o`0000[o_<7M
0_l00009ol75g@03o`000?o3a]co000000SoaLWM00?o0000olO;g?o7bm`00_o7bm`01Ol0003obLkN
olW>g_o9c]ko000000KobloL00Co0000olg@foo=d=_o00001Oo?dmd00ol0003odMCKom7Df`04om7D
f`04o`000?oBe=[od]CJo`0000?odmSL00?o0000omGHf_oEf=X01?oEf=X00ol0003oemWIomOIf@02
omOIf@;o00001OoIgMX00ol0003of]gHom[Mf003om[Mf003o`000?oLgMOog=gG00;og=gG0_l00022
oookJP03o`000?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX04OoonfX008Cooo]Z00?o0000oook
J_oonfX0A_oonfX2o`0000?o05C<0_l000000olRN^Go0000odV=k003odV=k0Co00000_m[W>d00ol0
003oOZ?[ogjSj`04ogjSj`03o`000?n<YnOoS:OW00GoS:OW00?o0000oiJ[iOnFZnD01OnFZnD00ol0
003oWZkSoij^h`04o`0000;oWZkS00?o0000ojFahOnU/N401onU/N400ol0003oZ[?PojZch004ojZc
h0?o00002On_]mh00ol0003o/kWNok>igP02ok>igP;o00001?ne^]h00ol0003o^;gNokRmgP05okRm
gP;o000000?o^[kMo`000?nl`Md02?nl`Md00ol0003o_l;Mo`000008ol75g@05o`000?o3a]co`lKL
ol?6g?l000001Oo5bMd2o`0000Koal_L00?o0000olW>g_l000001_o;cm`00ol0003ocM3Kolg@f`02
olg@f`05o`000?o?dmgocm?MoloCgOl000001_oAe=/00ol0003od]CJom;DfP02om;DfP03o`000?oC
f=co000000KoeMSJ00?o0000omOIfOoGfMT00_oGfMT01?l0003ofMWHomWIf?l00003omWMfP03o`00
0?oJgMSof]gH00?of]gH00?o0000omcMeooLgML00_oLgML00ol0003ooo]ZoookJP23oookJP03o`00
0?oonf[ooo]Z00cooo]Z00?o0000oookJ_oonfX04?oonfX008Gooo]Z0_l00018oookJP;o000000?o
05C<o`000?lFL^400ol00004odV=k003o`000?mWV^goIi[]00Co00001_mnXn/00ol0003oS:OWohbW
i`05ohbWi`03o`000?nFZnGoUZ_U00;oUZ_U1Ol00007oij^h`03o`000?nU/N7oYK7Q00OoYK7Q00?o
0000ojZch?nZ/n000ol00003oj^dg`03o`000?n_]mko[kON00Oo[kON00Co0000ok>ig_l0003o0000
1one^]h00ol0003o^;gNokRmgP02okRmgP;o00001?nj_]d00ol0003o_<7Mokc1g@04okc1g@;o0000
0ono`]d00ol0003o`LGMol75g@03ol75g@;o00001Oo3a]`01Ol0003oaLWMolG9gOo5bMgo000000So
al_L0ol00005ol_?g003o`000?o=d=_ocM3K00CocM3K00?o0000oloCgOl000001_oAe=/00ol0003o
d]CJom;DfP04om;DfP;o00001OoEf=X00ol0003oemWIomOIf@02omOIf@03o`000?oIfMSofMWH00;o
fMWH00?o0000omWMf_l000001OoJgMP00ol0003og=gGomcMe`02omcMe`03o`000?oonf[ooo]Z08Go
oo]Z00?o0000oookJ_oonfX02ooonfX00ol0003ooo]ZoookJP0@oookJP00QooonfX00ol0003ooo]Z
oookJP16oookJPCo00000_lFL^42o`0000CoBHg/00?o0000ofNJkOmWV^d00_mWV^dDo`0000CoUZ_U
00?o0000oij^honN[^<01_nN[^<00ol0003oYK7QojFah@06ojFah@?o00001on[]=l00ol0003o[kON
ojnggP06ojnggP;o00002_ne^]h01?l0003o^;gNo`000?l00007okZng@04o`000?nl`Mgo_<7Mokc1
g@;o00001_no`]d01Ol0003o`LGMol75gOo1aMgo000000So`lKL00?o0000olG9gOl000002?o7bm`0
1Ol0003obL_KolW;foo9bm_o000000?obloL00?o0000olg@foo=d=/01Oo=d=/3o`0000GodMCK00?o
0000om;Df_oBe=X01?oBe=X01?l0003oe=GIomCEfOl00003omGHfP03o`000?oGfMWoemWI00;oemWI
00?o0000omWIf?oIfMP01?oIfMP2o`0000Cof]gH00?o0000omcMeooLgML00_oLgML00ol0003ooo]Z
oookJP27oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04?oonfX008Sooo]Z00?o
0000oookJ_oonfX0A_oonfX4o`0000?o5W;Q0_l00003odV=k003o`000?mWV^goIi[]00?oIi[]00?o
0000ogbRjomlX^/00omlX^/00ol0003oRjOXoh^Wj005oh^Wj003o`000?nFZnGoUZ_U00KoUZ_U00?o
0000oij^honN[^<01OnN[^<00ol0003oYK7QojFah@03ojFah@?o000000?oY[7Qo`000?n[]=l02?n[
]=l00ol0003o[kONojnggP02ojnggP?o00000_na^=h00ol0003o]K[NokFjgP07okFjgP;o00002_nj
_]d00ol0003o_<7Mo`000009oko2g@03o`000?o1aMgo000000Wo`lKL0ol00006olO;g0;o00001Oo9
bm/00ol0003obloLo`000007olg@f`05o`000?o?d=[ocm3Jolo@f_l000000ooAe=/00ol0003od]CJ
om;DfP04om;DfP03o`000?oDeMWoe=GI00;oe=GI00?o0000omGHf_l000001?oGfMT00ol0003ofMWH
omWIf004omWIf003o`000?oJfMKof]WF00;o000000?of]gHo`000?oLgML00ooLgML00ol0003ooo]Z
oookJP28oookJP03o`000?oonf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX04?oonfX008Wooo]Z00?o
0000oookJ_oonfX0A_oonfX4o`0000?o5W;Q1Ol00006ofNJk@03o`000?mlX^_oO:;[00?oO:;[00?o
0000oh^Wj?n;YnP01On;YnP00ol0003oUZ_UoiJ[i@06oiJ[i@03o`000?nN[^?oWZkS00GoWZkS00?o
0000ojFahOl000000_l00005ojJah@03o`000?n[]=ooZkCO00OoZkCO00Co0000ojngg_l0003o0000
1_na^=h00ol0003o]K[NokFjgP04okFjgP;o00000_ng^md00ol0003o^[kMokZng@07okZng@;o0000
2_no`]d2o`0000Wo`lKL00Go0000olG7foo5am_oaLOKo`000003olO;g0;o00001oo9bm/2o`0000Oo
cM3K00?o0000olo@f_o?d=X00oo?d=X00ol0003odMCKo`000006om;DfP03o`000?oDeMWoe=GI00?o
e=GI0ol00003omOIf@03o`000?oIfMSofMWH00CofMWH00?o0000om[Ie_oJfMH00ooJfMH2o`0000?o
g=gG00?o0000oookJ_oonfX0R_oonfX00ol0003ooo]ZoookJP09oookJP03o`000?oonf[ooo]Z013o
oo]Z002:oookJP03o`000?oonf[ooo]Z04Oooo]Z1?l00002oaIbh@03o`000?m2RN_o@XW[00;o0000
1_mWV^d00ol0003oO:;[ogbRj`03ogbRj`03o`000?n;YnSoRjOX00GoRjOX00?o0000oiJ[iOnFZnD0
1_nFZnD00ol0003oWZkSoij^h`02oij^h`Co00002OnV/N400ol0003oZkCOoj^dg`06oj^dg`;o0000
2Ona^=h00ol0003o]K[NokFjgP02okFjgP03o`000?ng^mgo]k_M00?o]k_M00?o0000okZngOnj_]d0
1?nj_]d2o`0000;o_;oL00?o0000oko2gOno`]d01Ono`]d2o`0000;o`L?L00?o0000ol?6g?o3a]`0
1?o3a]`2o`0000GoaLOK00?o0000olO;g?l000002?o9bm/01?l0003oc<cJolc<f_l00005olg@f`03
o`000?o?d=[ocm3J00Cocm3J0ol00005om;DfP03o`000?oDeMWoe=GI00?oe=GI00Oo0000omKEeooF
eMOoe]GGo`000?oGfMWo000000KofMWH00?o0000om[Ie_oJfMH00ooJfMH01_l0003ofm[Eom_JeOl0
003og=gGo`0008kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0@oookJP00Rooo
nfX2o`0004Sooo]Z1ol00003od:9j`Go00000_mWV^d00ol0003oO:;[ogbRj`03ogbRj`03o`000?n;
YnSoRjOX00GoRjOX00?o0000oiJ[iOnFZnD00_nFZnD8o`0000?oWjkR00?o0000ojJahOnV/N401onV
/N400ol0003oZkCOoj^dg`03oj^dg`?o000000?o[KGOo`000?na^=h02Ona^=h01?l0003o]K[No`00
0?l00007okNkg@03o`000?nj_]go^[kM00;o^[kM00?o0000okbog?nl_m`00onl_m`00ol0003o_l;M
oko2g@02oko2g@;o00001Oo1`m`01?l0003o`lKLol?6g?o3a]`2o`0000OoaLOK0_l00008olW;f`03
o`000?o<c=[oc<cJ00;oc<cJ00Go0000olg@foo=d=_ocM3Ko`000006olo@fP05o`000?oAdMWodM7I
om7AfOl000000ooBe=X00ol0003oe=GIomCEf@03omCEf@03o`000?oFeMOoe]GG00?oe]GG0_l00005
omWIf003o`000?oJfMKof]WF00?of]WF00?o0000om_JeOoKf]D00_oKf]D00ol0003ooo]ZoookJP2=
oookJP03o`000?oonf[ooo]Z00Sooo]Z00?o0000oookJ_oonfX04?oonfX008gooo]Z00?o0000oook
J_oonfX0A_oonfX3o`0000;o2V_M0_l00003od:9j`04o`000?mRUngoHYO]of:Gk@So000000?oO:;[
o`000?n;YnP00on;YnP7o`0000CoUZ_U00?o0000oin^h_nO[^801OnO[^800ol0003oY[7QojJah@07
ojJah@03o`000?n[]=oo000000;o00001On]]Ml00ol0003o/KSNok6hgP07ok6hgP;o00002_ng^md0
1?l0003o^[kMo`000?l00007okbog004o`000?no`]go0000o`0000So`L?L00?o0000ol?6g?l00000
2?o5am/01?l0003oalSJolO8f_l00005olW;f`;o00001_o<c=X00ol0003ocM3Ko`000006olo@fP03
o`000?oAdMWodM7I00?odM7I00?o0000om;Df_l000001OoDeMT00ol0003oe]GGomKEe`04omKEe`03
o`000?oHe]Ko000000?ofMWH00?o0000om[Ie_oJfMH00ooJfMH00ol0003ofm[Eom_Je@03om_Je@03
o`000?oonf[ooo]Z08kooo]Z00?o0000oookJ_oonfX02?oonfX00ol0003ooo]ZoookJP0?oookJP00
S_oonfX00ol0003ooo]ZoookJP16oookJP03o`000?l0?[[o000000?o2V_M0_l00002od:9j`03o`00
0?mRUngoHYO]00?oHYO]00?o0000ogZQjomjXN/00_mjXN/6o`0000?oRZOX00?o0000oiJ[iOnFZnD0
1_nFZnD00ol0003oWjkRoin^hP05oin^hP03o`000?nV/N7oY[7Q00GoY[7Q0ol00009ojfeg`03o`00
0?na^=ko/KSN00?o/KSN0ol000000onc^=go0000okNkg@09okNkg@;o00002Onl_m`2o`0000[o`L?L
0_l00008olG7f`03o`000?o7b=[oalSJ00;oalSJ00Go0000olW;foo9bm_obL_Ko`000008olc<fP;o
00001Oo?d=X2o`0000KodM7I0_l00005omCEf@03o`000?oFeMOoe]GG00Coe]GG00Oo0000omSFe_oH
e]Kof=KFo`000?oIfMSo000000Gof]WF00?o0000om_JeOoKf]D00ooKf]D00ol0003ooo]ZoookJP2@
oookJP03o`000?oonf[ooo]Z00Oooo]Z00?o0000oookJ_oonfX03ooonfX008oooo]Z00?o0000oook
J_oonfX0A_oonfX3o`0000;o2V_M00?o0000ocZ4jOl000000ol00005of:Gk@03o`000?mjXN_oNZ7[
00?oNZ7[00?o0000ohZWj?n:YnP01On:YnP00ol0003oUZ_UoiJ[i@06oiJ[i@03o`000?nO[^;oWjkR
00GoWjkR00?o0000ojJahOnV/N401?l00002ojNbh003o`000?n]]Moo[KGO00So[KGO00?o0000ok6h
g_l000000_l00005ok>hg@03o`000?ng^mgo]k_M00Go]k_M0_l000000oni_=co0000okbog007okbo
g004o`000?nn`=_o_/3Ko`0000So`L?L00Co0000ol?4foo3a=_o00001Oo5am/2o`0000KoalSJ00?o
0000olW;fol000002?o<c=X01?l0003oc/gIolk=fOl00003olo@fP03o`000?oAdMWodM7I00GodM7I
00Co0000om?AeooCdMOo00000ooDeMT00ol0003oe]GGomKEe`04omKEe`03o`000?oHe]Kof=KF00?o
f=KF0_l00004om[IeP03o`000?oKf]Gofm[E00?ofm[E00?o0000oookJ_oonfX0T_oonfX00ol0003o
oo]ZoookJP06oookJP03o`000?oonf[ooo]Z00oooo]Z002@oookJP;o0000B?oonfX3o`000003o`Y[
gOl0003o>XCY00;o>XCY0_l00005of:Gk@03o`000?mjXN_oNZ7[00?oNZ7[00?o0000ohZWj?n:YnP0
1On:YnP00ol0003oUZ_UoiJ[i@05oiJ[i@03o`000?nO[^;oWjkR00CoWjkR1?l00007ojNbh003o`00
0?n]]Moo[KGO00Oo[KGO0_l00009ok>hg@03o`000?ng^mgo]k_M00;o]k_M0_l00004okVlg003o`00
0?nl_mco_;oL00?o_;oL0_l00004okk0f`03o`000?o1`mco`L?L00?o`L?L0_l00004ol?4f`05o`00
0?o5am_oaLOKolG7fol000002?o7b=X2o`0000Soc<cJ00?o0000olk=fOo>cMT00_o>cMT00ol0003o
cm3Jo`000007om7Af@03o`000?oCdMOodm7G00;odm7G00?o0000omCEfOl000001_oFeML00ol0003o
f=KFomSFeP03omSFeP03o`000?oIe]CofMKD00;o000000?of]WFo`000?oKf]D01?oKf]D00ol0003o
oo]ZoookJP2CoookJP03o`000?oonf[ooo]Z00Kooo]Z00?o0000oookJ_oonfX03ooonfX009;ooo]Z
00?o0000oookJ_oonfX0A_oonfX5o`0000Co>XCY1Ol000000omRUngo0000ogZQj`04ogZQj`03o`00
0?n:YnSoRZOX00GoRZOX00?o0000oiJ[iOnFZnD01OnFZnD00ol0003oWjkRoin^hP03o`0000;oWjoR
00?o0000ojNbh?nW/^001onW/^000ol0003o[KGOojfeg`03ojfeg`?o000000?o[[KNo`000?nc^=d0
2Onc^=d01?l0003o]k_Mo`000?l00007okVlg005o`000?nl_mco_;oLokbog?l000001onn`=/01Ol0
003o`L?Lol73g?o1`mco000000Oo`lCK00?o0000olG7fol000002?o7b=X01?l0003obLWIolW9fOl0
0005olc<fP;o00001_o>cMT00ol0003odM7Iom7Af@05om7Af@03o`000?oCdMOodm7G00Codm7G0_l0
0005omKEe`03o`000?oHe]Kof=KF00?of=KF00?o0000omWFe?oIe]@00ooIe]@00ol0003ofm[Eom_J
e@03om_Je@03o`000?oonf[ooo]Z09Gooo]Z00?o0000oookJ_oonfX01OoonfX00ol0003ooo]Zoook
JP0?oookJP00TooonfX00ol0003ooo]ZoookJP15oookJP?o000000?o06?Ho`000?l000000oljQ>T0
0ol0003oGIG]oefEk@02oefEk@Oo000000?oNZ7[o`000?n:YnP01_n:YnP00ol0003oUZ_UoiJ[i@02
oiJ[i@Go00001_nO[n800ol0003oYk;PojNbh007ojNbh003o`000?n]]Moo000000;o00001On^]]h0
0ol0003o/kSMok>hg@07ok>hg@;o00002_ni_=`00ol0003o_;oLo`000009okk0f`03o`000?o1`mco
000000So`lCK0_l00008olO8fP03o`000?o9bMWobLWI00;obLWI00Go0000olc<f_o<c=[oc<cJo`00
0007olk=f@03o`000?o@cMOo000000GodM7I00?o0000om?AeooCdML01?oCdML01?l0003oeM;FomGB
e_l00003omKEe`03o`000?oHe]Kof=KF00?of=KF00?o0000omWFe?oIe]@00ooIe]@00ol0003ofmKC
o`000003om_Je@03o`000?oonf[ooo]Z09Oooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003ooo]Z
oookJP0?oookJP00U?oonfX00ol0003ooo]ZoookJP15oookJP?o00000_l0HmP2o`0000;o>XCY00?o
0000oefEkOmMUNd00omMUNd00ol0003oMio[ogNOj`02ogNOj`ko00000onFZnD00ol0003oWjoRoin_
hP06oin_hP03o`000?nW/^3oYk;P00KoYk;P0_l00009ojjfgP03o`000?nc^=go/kSM00Co/kSM0_l0
00000ond^Mgo0000okVlg009okVlg0;o00002_nn`=/2o`0000So`lCK00Co0000olG5f_o5aM[o0000
1Oo7b=X2o`0000KobLWI00?o0000olc<f_l000001oo>cMT01Ol0003od<gGom3=eoo@cMOo000000?o
dM7I00?o0000om?AeooCdML01?oCdML00ol0003oeM;FomGBeP02omGBeP03o`000?oFeMOo000000Go
f=KF00?o0000omWFe?oIe]@00ooIe]@01ol0003ofmKCom_FdooKe]?o0000om_JeOl00000VooonfX0
0ol0003ooo]ZoookJP03oookJP03o`000?oonf[ooo]Z00oooo]Z002EoookJP;o0000A_oonfX4o`00
0003o`1Sf?l0003o000000?o00001OmMUNd00ol0003oMio[ogNOj`03ogNOj`03o`000?n9Y^SoRJKX
00GoRJKX00?o0000oiJ[iOnFZnD01OnFZnD00ol0003oWjoRoin_hP06oin_hP03o`000?nW/^3oYk;P
00;oYk;P0ol000000onX/^3o0000ojjfgP08ojjfgP03o`000?nc^=go/kSM00;o/kSM0_l00004okBi
g@03o`000?ni_=co^KcL00Go^KcL0_l000000onj_M_o0000okk0f`08okk0f`04o`000?o0`M[o`<7J
o`0000Go`lCK0_l00004olG5fP05o`000?o7b=[oalSJolO8f_l000002?o9bMT2o`0000Ooc/gI00?o
0000om3=eoo@cML00oo@cML00ol0003odM7Io`000006om?Ae`03o`000?oEd]KoeM;F00CoeM;F0_l0
0004omSFeP03o`000?oIe]CofMKD00?ofMKD00?o0000om_FdooKe]<00ooKe]<00ol0003ooo]Zoook
JP2JoookJP03o`000?oonf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX03_oonfX009Oooo]Z00?o0000
oookJ_oonfX0A?oonfX2o`000004o`1Jd_l0003o0000o`0000;o<GoW0_l00005oefEk@03o`000?mg
Wn_oMio[00?oMio[00?o0000ohVVj?n9Y^P01On9Y^P00ol0003oUZ_UoiJ[i@05oiJ[i@03o`000?nO
[n;oWjoR00KoWjoR00Co0000ojNbh?l0003o00001OnX/^000ol0003o[[KNojjfgP07ojjfgP04o`00
0?nc^=go0000o`0000Oo];WM00?o0000okVlg?ni_=`00_ni_=`2o`0000Co^[gK00?o0000okk0fonn
`=/01?nn`=/2o`0000Co`<7J00Go0000ol?4foo3a=_o`lCKo`000007olG5fP03o`000?o7b=[o0000
00SobLWI00Co0000olc9f?o<bMSo00001Oo>cMT00ol0003od<gGom3=e`04om3=e`?o00001OoCdML0
0ol0003oeM;FomGBeP04omGBeP03o`000?oGd]Coem;D00;o000000?of=KFo`000?oIe]@01?oIe]@0
0ol0003ofmKCom_Fd`04om_Fd`03o`000?oonf[ooo]Z09_ooo]Z00?o0000oookJ_oonfX00ooonfX0
0ol0003ooo]ZoookJP0>oookJP00V?oonfX00ol0003ooo]ZoookJP14oookJP;o00000_l0F]82o`00
00?o<GoW0ol00002oefEk@03o`000?mgWn_oMio[00CoMio[00?o0000ohVVj?n9Y^P01On9Y^P00ol0
003oUZ_UoiJ[i@05oiJ[i@03o`000?nO[n;oWjoR00;oWjoR1Ol00008ojRbh003o`000?n^]]ko[[KN
00Ko[[KN0_l0000:okBig@04o`000?ni_=co0000o`0000Oo^[gK00Co0000okk0fonn`=_o_/3K0_l0
0007ol31fP03o`000?o3a=_o000000SoaLGJ0_l00008olW9f@03o`000?o<bMSoc<WH00;oc<WH00Go
0000olk=fOo>cMWoc/gIo`000006om3=e`05o`000?oAc]KodLkFom7>e_l000000ooCdML00ol0003o
eM;FomGBeP04omGBeP03o`000?oGd]Coem;D00?oem;D00?o0000omWFe?oIe]@00ooIe]@00ol0003o
fmKCom_Fd`04om_Fd`03o`000?oonf[ooo]Z09gooo]Z00?o0000oookJ_oonfX00_oonfX00ol0003o
oo]ZoookJP0>oookJP00VOoonfX00ol0003ooo]ZoookJP14oookJP;o00000_l0F]82o`0000?o<GoW
00?o0000oeVBk?l000000ol00006ogNOj`03o`000?n9Y^SoRJKX00GoRJKX00?o0000oiJ[iOnFZnD0
0_nFZnD7o`0000CoX:oR00?o0000ojRbh?nX/^001onX/^000ol0003o[[KNojjfgP02ojjfgP?o0000
0_n`]]h00ol0003o];WMokBig@07okBig@;o00002_nj_M/00ol0003o_/3Ko`000009ol31fP;o0000
2?o5aMX01?l0003oalGHolO5f?l00005olW9f@;o00001_o<bMP00ol0003oc/gIo`000006om3=e`03
o`000?oAc]KodLkF00?odLkF00?o0000om?Aeol000001_oEd]H00ol0003oem;DomOBe004omOBe0;o
00000ooIe]@00ol0003ofmKCom_Fd`04om_Fd`03o`000?oonf[ooo]Z09oooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000@oookJP00V_oonfX2o`0004Gooo]Z0_l00003o`1JdP;o00000_laOnL01?l0003o
FI;/oeVBk?mIT^`6o`0000;oMio[00?o0000ohVVj?n9Y^P00_n9Y^P7o`0000?oUZ_U00?o0000oj2_
h_nP[n801_nP[n800ol0003oZ;;PojRbh007ojRbh004o`000?n^]]ko0000o`0000Ko/;KN00?o0000
okBigOnd^Md01?nd^Md2o`000003okJjg?l0003o^[gK00Wo^[gK0_l00009ol31fP03o`000?o2`]Wo
000000OoaLGJ00?o0000olO5f?o7aMP00_o7aMP01Ol0003obLWIolW9fOo9bMWo000000Soc<WH0ol0
0005om3=e`03o`000?oAc]KodLkF00GodLkF0_l00005omGBeP03o`000?oGd]Coem;D00Coem;D00Ko
0000omSBdooHd]?o0000omWFe?l00006om_Fd`03o`000?oonf[ooo]Z0:3ooo]Z00Go0000oookJ_oo
nf[ooo]Zo`00000@oookJP00W?oonfX00ol0003ooo]ZoookJP14oookJP;o000000?o05[Bo`000?lX
N^D01?l00004oeVBk004o`000?meW^_oMIk[ogFNj`Oo00000on8Y^P00ol0003oUZ_UoiJ[i@05oiJ[
i@03o`000?nP[n;oX:oR00KoX:oR00?o0000ojRbh?nX/^001OnX/^03o`0000Wo/;KN00?o0000okBi
gOnd^Md00_nd^Md00ol0003o][[LokJjg002okJjg003o`000?nj_M_o^[gK00Go^[gK0_l00002okbn
f`03o`000?o0`M[o`<7J00Co`<7J0_l00003ol;2f@03o`000?o5aM[oaLGJ00?oaLGJ00?o0000olO5
f?o7aMP01?o7aMP00ol0003obLWIo`000008olc9f005o`000?o=b]OocL[Golg:eol000000oo@cML0
0ol0003odLkFom7>eP05om7>eP04o`000?oCc]GodlkEo`0000?oeM;F00?o0000omOBe?oGd]@01?oG
d]@00ol0003of=;ComSBd`02omSBd`;o00001OoKe]<00ol0003ooo]ZoookJP2RoookJP04o`000?oo
nf[ooo]Zo`00013ooo]Z002MoookJP03o`000?oonf[ooo]Z04Cooo]Z1?l00003obQji@;o00001?mI
T^`00ol0003oMIk[ogFNj`03ogFNj`03o`000?n8Y^SoR:KX00GoR:KX00?o0000oiJ[iOnFZnD01OnF
ZnD00ol0003oX:oRoj2_hP06oj2_hP03o`000?nX/^3oZ;;P00Co00000_nY/ml00ol0003o/;KNok2f
gP08ok2fgP04o`000?nd^Mgo0000o`0000Ko][[L00?o0000okZmfonj_M/00_nj_M/2o`0000Go_;kK
00Co0000ol31f_o0`M[o`<7J0_l00006ol;2f@05o`000?o5aM[oaLGJolG5f_l000001oo7aMP2o`00
00Soc<WH00?o0000olg:eoo=b]L00oo=b]L00ol0003od<gGo`000007om7>eP03o`000?oCc]GodlkE
00;odlkE00?o0000omGBe_l000001_oGd]@00ol0003of=;ComSBd`03omSBd`03o`000?oJd];o0000
00?ofmKC00?o0000oookJ_oonfX0Y?oonfX00ol0003ooo]Zo`00000@oookJP00W_oonfX00ol0003o
oo]ZoookJP14oookJPCo00001?lXN^D3o`0000;oFI;/00?o0000ogFNjomeW^/00omeW^/00ol0003o
R:KXohRVj005ohRVj003o`000?nFZnGoUZ_U00GoUZ_U00?o0000oj2_h_nP[n801?nP[n84o`0000Oo
ZK?O00?o0000ok2fg_n`]]h01on`]]h2o`0000Wo][[L00Co0000okZmfol0003o00002?nl_]/00ol0
003o`<7Jo`000009ol;2f@03o`000?o5aM[o000000OoalGH00Co0000olW6eoo9a]Oo00001Oo<bMP2
o`0000KocL[G0_l00007om7>eP03o`000?oCc]GodlkE00?odlkE0ol00005omOBe003o`000?oHd]?o
f=;C00?of=;C00Oo0000om[Bd_oJd];of];Bo`000?oKe]?o00000:Oooo]Z00Co0000oookJ_oonf[o
00003ooonfX009oooo]Z0_l00015oookJPCo00000olXN^D00ol0003oE93/oeB@k004o`0000GoMIk[
00?o0000ohRVj?n8Y^P01?n8Y^P00ol0003oUZ_UoiJ[i@06oiJ[i@03o`000?nP[n;oX:oR00?o0000
0_nQ[n800ol0003oZK?OojVcg`07ojVcg`03o`000?n`]]ko/;KN00?o/;KN0ol000000ona]mgo0000
okJjg008okJjg0;o00002_nl_]/2o`0000[o`/;I0_l00007olO5f003o`000?o9a]OobLKG00;obLKG
00Go0000olc9f?o<bMSoc<WHo`000007olg:e`04o`000?o?bmGocl_Eo`0000GodLkF00?o0000om?>
eOoCc]D00ooCc]D01Ol0003oeLoComG?dooEcm?o000000?oem;D00?o0000omSBdooHd]<00ooHd]<0
0ol0003of];Bom[BdP03om[BdP03o`000?oonf[ooo]Z0:Oooo]Z00?o0000oookJ_l000003ooonfX0
0:7ooo]Z00?o0000oookJ_oonfX0@ooonfX5o`0000;o:7[U00?o0000oeB@k?mDT>`00_mDT>`6o`00
0003ogFNjol0003oR:KX00GoR:KX00?o0000oiJ[iOnFZnD00_nFZnD6o`0000KoXJoR00?o0000ojVc
gonY/ml01onY/ml00ol0003o/;KNo`000002o`0000Go/KOM00?o0000okJjg?nf^]`01?nf^]`2o`00
00;o^;_K00?o0000okbnfonl_]/01_nl_]/00ol0003o_[kJo`000009ol;2f@04o`000?o4`]Soa<;H
o`0000GoalGH00?o0000olW6eoo9a]L01?o9a]L00ol0003oc<WHo`000007olg:e`03o`000?o?bmGo
cl_E00;ocl_E00Go0000om7>e_oAc]KodLkFo`000005om?>e@03o`000?oEcm?oeLoC00?oeLoC00?o
0000omOBe?l000001OoHd]<00ol0003of];Bom[BdP04om[BdP03o`000?oonf[ooo]Z0:Sooo]Z0_l0
000?oookJP00X_oonfX00ol0003ooo]ZoookJP13oookJP03o`000?l0B<Co000000Go00001?mDT>`0
0ol0003oLYg[og:Mj`02og:Mj`go00001?nFZnD00ol0003oXJoRoj6_hP06oj6_hP03o`000?nY/moo
ZK?O00KoZK?O0_l00009ok6gg@03o`000?nf^]co][[L00;o][[L00?o0000okRkfonh^m/00onh^m/0
0ol0003o_;kKokbnf`03okbnf`;o00000onn_]X00ol0003o`/;Iol;2f@04ol;2f@;o00001?o4`]P0
1Ol0003oalGHolO5f?o7aMSo000000OobLKG0_l00007olg:e`03o`000?o?bmGocl_E00Cocl_E00?o
0000om7>e_l000001OoCc]D00ol0003oeLoComG?d`04omG?d`;o00001OoHd]<00ol0003of];Bom[B
dP04om[BdP03o`000?oonf[ooo]Z0:Sooo]Z0ol0000?oookJP00XooonfX00ol0003ooo]ZoookJP13
oookJP04o`000?l0B<Co0000o`0000;o87GS0_l00004oeB@k003o`000?mbWN_oLYg[00?oLYg[00?o
0000ohNVj?n7Y^P01On7Y^P00ol0003oUZ_UoiJ[i@05oiJ[i@03o`000?nQ[n;oXJoR00KoXJoR00?o
0000ojVcgonY/ml00_nY/ml3o`000003oj^cgol0003o/KOM00Wo/KOM00Co0000okJjg?l0003o0000
1onh^m/01Ol0003o_;kKokbnfonl_]_o000000Ko_[kJ00Co0000ol;2fOo2`]Wo`/;I0_l00007olC2
f003o`000?o7aMSo000000OobLKG00Co0000ol_7e_o;amKo00001Oo=b]L00ol0003ocl_Eolo;e@05
olo;e@;o00001OoCc]D00ol0003oeLoComG?d`04omG?d`04o`000?oFcm;oe/oBo`0000?of=;C00?o
0000om[Bd_oJd]801?oJd]800ol0003ooo]ZoookJP2UoookJPCo00004_oonfX00:Cooo]Z00?o0000
oookJ_oonfX0@ooonfX01?l0003o04S4o`18a?l00003ob1eh`?o00000_mDT>`00ol0003oLYg[og:M
j`03og:Mj`03o`000?n7Y^SoQjKX00GoQjKX00?o0000oiJ[iOnFZnD01OnFZnD00ol0003oXJoRoj6_
hP06oj6_hP04o`000?nY/moo0000o`0000GoZk?O00?o0000ok6ggOna]md01ona]md2o`0000[o^;_K
00?o0000okbnfol000002?nn_]X00ol0003o`/;Io`000009olC2f0;o00001oo9a]L00ol0003oblOF
ol_7eP02ol_7eP05o`000?o=b]OocL[Golg:eol000001oo?bmD01?l0003odL_Dom7;e?l00003om?>
e@03o`000?oEcm?oeLoC00CoeLoC00?o0000omK?d_oFcm800_oFcm800ol0003of=;Co`000006om[B
dP03o`000?oonf[ooo]Z0:;ooo]Z1?l0000FoookJP00YOoonfX2o`0004Cooo]Z00Co0000o`18a?l0
B<Co00000olPMN<00ol0003oChg[o`000003o`0000GoLYg[00?o0000ohNVj?n7Y^P01On7Y^P00ol0
003oUZ_UoiJ[i@05oiJ[i@03o`000?nQ[n;oXJoR00;oXJoR1Ol00008oj^cg`03o`000?na]mgo/KOM
00?o/KOM0ol000000onc]mgo0000okRkf`09okRkf`;o00002Onn_]X2o`0000Woa<;H00Co0000olK3
eoo6`mOo00001Oo9a]L00ol0003oblOFol_7eP04ol_7eP03o`000?o=b]Oo000000Oocl_E00?o0000
om7;e?oAbm@00_oAbm@00ol0003odlkEo`000006omG?d`03o`000?oFcm;oe/oB00Coe/oB0_l00005
om[BdP03o`000?oonf[ooo]Z0:3ooo]Z0ol0000JoookJP00YooonfX00ol0003ooo]ZoookJP12oook
JP;o000000?o04S4o`000?l000000_lPMN<01?l0003oChg[odn=jom?SN/6o`000003og:Mjol0003o
QjKX00KoQjKX00?o0000oiJ[iOnFZnD00_nFZnD7o`0000CoX[3R00?o0000oj^cgon[/ml01on[/ml0
0ol0003o/KOMo`000002o`0000Go/kOM00?o0000okRkfonh^m/01Onh^m/2o`000003okZkf_l0003o
_[kJ00Oo_[kJ00Co0000ol2ofOo0_mWo00001_o4`]P2o`0000Coa/?G00Go0000olW6eoo9a]OobLKG
o`000007ol_7eP;o00001oo?bmD00ol0003odL_Dom7;e004om7;e0;o00001OoEcm<00ol0003oe/oB
omK?dP05omK?dP03o`000?oHcm7o000000?of];B00?o0000oookJ_oonfX0WOoonfX4o`0001gooo]Z
002XoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol000000olGKmoo0000o`000002o`0000?oChg[00?o
0000og2Ljom`W>/00_m`W>/>o`0000?oUj_U00?o0000oj:`h_nR/>801_nR/>800ol0003oZk?Ooj^c
g`06oj^cg`;o00002Onc]md00ol0003o^;_KokRkf`02okRkf`;o00001?nj^mX00ol0003o_[kJokjn
fP03okjnfP;o00001?o0_mT01?l0003oa<;HolC2f?o4`]P2o`0000Ooa/?G00?o0000olW6eol00000
1oo;amH01?l0003ocLOEolg7eOl00005olo;e@03o`000?oAbmCodL_D00CodL_D00Co0000om?;d_oC
bm;o00000ooEcm<00ol0003oe/oBomK?dP05omK?dP07o`000?oHcm7of<oAomS?dOl0003of];Bo`00
002LoookJPCo00008OoonfX00:Wooo]Z00?o0000oookJ_oonfX0@_oonfX3o`0000?o5foO0_l00003
odn=j`03o`000?m`W>_oL9c[00?oL9c[00?o0000ohNUj?n7YNP01On7YNP00ol0003oUj_UoiN[i@05
oiN[i@03o`000?nR/>;oX[3R00KoX[3R00?o0000oj^cgon[/ml00_n[/ml3o`000003ojbdg_l0003o
/kOM00Wo/kOM00Co0000okRkfol0003o00001onj^mX01Ol0003o_[kJokjnf_nn_][o000000Oo`;oI
00?o0000olC2f?l000002Oo6`mL2o`0000OoblOF00?o0000olg7eOo=amD00_o=amD01Ol0003ocl_E
olo;eOo?bmGo000000KodL_D00?o0000om?;d_oCbm800_oCbm800ol0003oeLoCo`000007omK?dP03
o`000?oHcm7of<oA00?of<oA00?o0000oookJ_oonfX0UooonfX4o`0002Gooo]Z002ZoookJP;o0000
@ooonfX3o`0000Co5foO0_l00002odn=j`03o`000?m`W>_oL9c[00?oL9c[00?o0000ohNUj?n7YNP0
1On7YNP00ol0003oUj_UoiN[i@05oiN[i@03o`000?nR/>;oX[3R00KoX[3R00Co0000oj^cgol0003o
00001On/]=h00ol0003o/kOMok>gg@07ok>gg@;o00002_nj^mX00ol0003o_[kJo`000008ol2of@;o
00002Oo6`mL01?l0003ob<?FolS3e_l00005ol_7eP03o`000?o=amGocLOE00CocLOE00?o0000olo;
eOl000001_oAbm@00ol0003odl_Bom?;dP04om?;dP03o`000?oFcm;oe/oB00Goe/oB00?o0000omS?
dOoHcm401?oHcm400ol0003ooo]ZoookJP2CoookJPCo0000:OoonfX00:cooo]Z00?o0000oookJ_oo
nfX0@OoonfX3o`0000?o5foO00?o0000odV:j_l000000ol00005og2Lj`03o`000?n7YNSoQjGX00Go
QjGX00?o0000oiN[iOnGZnD01?nGZnD00ol0003oX[3Roj:`hP05oj:`hP?o00002?n/]=h00ol0003o
/kOMok>gg@04ok>gg@;o000000?o];SLo`000?nj^mX02Onj^mX2o`0000So`;oI00?o0000ol:of?l0
00002?o6`mL00ol0003ob<?FolS3eP02olS3eP05o`000?o;amKoblOFol_7e_l000001oo=amD3o`00
00GodL_D00?o0000om?;d_oCbm801OoCbm82o`0000Goe/oB00?o0000omS?dOoHcm401?oHcm400ol0
003ooo]ZoookJP2AoookJP?o0000;OoonfX00:gooo]Z00?o0000oookJ_oonfX0@OoonfX01?l0003o
03Feo`000?l00002oaM_g`04o`000?m9R^[oBH[ZodV:jP;o00001Om`W>/00ol0003oQjGXohNUj004
ohNUj003o`000?nGZnGoUj_U00GoUj_U00?o0000oj:`h_nR/>801?l00002oj>`h@03o`000?n/]=ko
[;CN00Oo[;CN00?o0000ok>ggOnc]md00_nc]md00ol0003o];SLokBhg002okBhg003o`000?nj^m[o
^[_J00Go^[_J0_l00002okblfP03o`000?o0_mWo`;oI00?o`;oI0_l00003ol:of003o`000?o6`mOo
a/?G00?oa/?G0_l00006olS3eP03o`000?o;amKo000000OocLOE00Go0000olk7doo>am?oc/OCo`00
0003om7;e003o`000?oCbm;odl_B00Godl_B00Co0000omC<dOoDc=7o00000ooFcm800ol0003of<oA
omS?d@04omS?d@03o`000?oonf[ooo]Z08kooo]Z1?l0000`oookJP00[_oonfX00ol0003ooo]Zoook
JP11oookJP03o`000?l0=KGo000000Co00001?m9R^X5o`000003og2Ljol0003oQjGX00GoQjGX00?o
0000oiN[iOnGZnD00_nGZnD5o`0000OoXk3Q00?o0000ojbdg_n/]=h01on/]=h01?l0003o/kOMo`00
0?l00006okBhg003o`000?nj^m[o^[_J00;o^[_J0_l00005okblfP05o`000?o0_mWo`;oIol2ofOl0
00001_o2_mP01Ol0003oa/?GolK3eoo6`mOo000000Sob<?F0_l00007olg7e@03o`000?o>am?oc/OC
00?oc/OC00?o0000om7;e?l000001ooCbm800ol0003oe<cAomC<d@02omC<d@03o`000?oFcm;o0000
00Kof<oA00?o0000oookJ_oonfX0RooonfX4o`0003Cooo]Z002_oookJP;o0000@_oonfX00ol0003o
03Feo`000002o`eYg0;o00000om9R^X00ol0003oKI_/offKk002offKk0go00001?nG[>D00ol0003o
Xk3Qoj>`h@06oj>`h@03o`000?n/]=ko[;CN00Go[;CN0ol00009okBhg004o`000?nj^m[o0000o`00
00So_;cJ00?o0000ol2ofOl000002?o2_mP00ol0003oa/?Go`000008olS3eP04o`000?o9a=GobLCE
o`0000GocLOE00?o0000olk7doo>am<01Oo>am<00ol0003odl_Bom?;dP05om?;dP03o`000?oDc=7o
e<cA00Coe<cA0_l00005omS?d@03o`000?oonf[ooo]Z08Sooo]Z1?l0000hoookJP00/OoonfX00ol0
003ooo]ZoookJP10oookJP03o`000?l0=KGo000000?o3FWL0_l00002odV:jP03o`000?m]VncoKI_/
00?oKI_/00?o0000ohJUj?n6YNP01?n6YNP00ol0003oUjcUoiN/i@06oiN/i@03o`000?nS/>7oXk3Q
00KoXk3Q00?o0000ojbdg_n/]=h01?l00002ojfegP03o`000?nd^=co];SL00Oo];SL0_l0000:okbl
fP;o00002Oo2_mP2o`0000Sob<?F00?o0000olW4eOo9a=D00_o9a=D01Ol0003ocLOEolg7eOo=amGo
000000Ooc/OC00?o0000om38d_l000001OoCbm800ol0003oe<cAomC<d@04omC<d@04o`000?oFc=3o
e/c@o`0000?of<oA00?o0000oookJ_oonfX0QOoonfX4o`0003cooo]Z002boookJP03o`000?oonf[o
oo]Z043ooo]Z1?l000000ol=JMco0000odB7j@04o`0000GoKI_/00?o0000ohJUj?n6YNP01?n6YNP0
0ol0003oUjcUoiN/i@06oiN/i@03o`000?nS/>7oXk3Q00CoXk3Q1?l00007ojfegP03o`000?nd^=co
];SL00Co];SL0_l000000onf^M_o0000okblfP08okblfP03o`000?nm_=Wo000000So`[oH00Co0000
olC0eoo4`=Oo00001Oo8`mH2o`0000KobLCE00?o0000olg7eOl000001oo>am<01Ol0003od<SBom38
d_o@b=;o000000?odl_B00?o0000omC<dOoDc=401?oDc=400ol0003oe/c@omK<d002omK<d003o`00
0?oHcm7o000008Gooo]Z0ol00010oookJP00/ooonfX00ol0003ooo]ZoookJP10oookJPKo00000om4
QnT2o`0000GoKI_/00?o0000ohJUj?n6YNP01?n6YNP00ol0003oUjcUoiN/i@06oiN/i@03o`000?nS
/>7oXk3Q00?o00000_nT/N400ol0003o[KGNojfegP07ojfegP03o`000?nd^=co];SL00;o];SL00?o
0000okJifonf^M/00_nf^M/00ol0003o_;cJokblfP04okblfP;o00000onm_=T00ol0003o`[oHol:o
f003ol:of0;o00001?o4`=L01Ol0003ob<?FolS3e_o8`mKo000000SobLCE0_l00007olk7d`03o`00
0?o@b=;od<SB00?od<SB00?o0000om?;d_l000001_oDc=400ol0003oe/c@omK<d004omK<d003o`00
0?oonf[ooo]Z083ooo]Z1?l00013oookJP00]?oonfX2o`00047ooo]Z0ol000000ol4HmSo0000o`00
0004odB7j@Go000000?oKI_/o`000?n6YNP01On6YNP00ol0003oUjcUoiN/i@02oiN/i@Ko00001_nT
/N400ol0003o[KGNojfegP07ojfegP04o`000?nd^=co0000o`0000Ko][WK00Co0000okblf_nl_=[o
_;cJ0_l00006okflf@05o`000?o2_mSo`[oHol:of?l000001oo4`=L00ol0003ob<?Fo`000008olW4
e@04o`000?o;a=CoblCDo`0000Goc/OC00?o0000om38d_o@b=801Oo@b=82o`0000Goe<cA00?o0000
omK<d?oFc=001?oFc=000ol0003ooo]ZoookJP1moookJPCo0000AooonfX00;Kooo]Z00?o0000oook
J_oonfX0?ooonfX01?l0003o02b]o`000?l4HmP2o`0000?oA8OY00?o0000of^Ik?m[VN`00_m[VN`=
o`0000CoUjcU00?o0000ojBahOnT/N401_nT/N400ol0003o[KGNojfegP06ojfegP;o00002Onf^M/0
0ol0003o_;cJo`000009okflf@03o`000?o2_mSo000000Soa<3G0_l00008olW4e@03o`000?o;a=Co
blCD00;oblCD00Go0000olk7doo>am?oc/OCo`000007om38dP04o`000?oBb=7od/SAo`0000?oe<cA
00?o0000omK<d?oFc=001?oFc=000ol0003ooo]ZoookJP1joookJPCo0000BooonfX00;Oooo]Z00?o
0000oookJ_oonfX0?ooonfX3o`0000;o16?H0_l00002odB7j@03o`000?m[VNcoJiW/00?oJiW/00?o
0000ohFUjOn5YNT01On5YNT00ol0003oUjcUoiN/i@05oiN/i@03o`000?nT/N7oY;7Q00GoY;7Q00?o
0000ojfeg_n]]Mh00on]]Mh3o`000003ojnegOl0003o][WK00So][WK0_l0000:okflf@;o00002?o4
`=L01?l0003oa/7FolK1e_l00005olW4e@;o00001_o;a=@00ol0003oc/OCo`000007om38dP03o`00
0?oBb=7od/SA00;od/SA00?o0000omC<dOl000001_oFc=000ol0003ooo]ZoookJP1goookJPCo0000
CooonfX00;Sooo]Z00?o0000oookJ_oonfX0?ooonfX5o`000003ocj4j?l0003o000000;o00001Om[
VN`00ol0003oQJGYohFUj@05ohFUj@03o`000?nG[>GoUjcU00GoUjcU00?o0000ojBahOnT/N401OnT
/N400ol0003o[KGNo`000002o`0000Go[kGM00?o0000okJifonf^M/01?nf^M/2o`000003okRif_l0
003o_KcI00So_KcI00?o0000oknmf?l000001oo4`=L00ol0003oa/7FolK1eP02olK1eP05o`000?o9
a=GobLCEolW4eOl000002?o;a=@2o`0000Ood<SB00?o0000om;8dOoBb=401?oBb=400ol0003oe/c@
omK<d004omK<d003o`000?oonf[ooo]Z07Gooo]Z0ol0001CoookJP00^OoonfX00ol0003ooo]Zoook
JP0ooookJP;o000000?o05cDo`000?l000000olnQ>P2o`0000GoJiW/00?o0000ohFUjOn5YNT01On5
YNT00ol0003oUjcUoiN/i@05oiN/i@03o`000?nT/N7oY;7Q00;oY;7Q1?l00009ojneg@03o`000?nf
^M_o][WK00;o][WK00?o0000okRif_nh^MX00_nh^MX00ol0003o_KcIokflf@04okflf@;o00000ono
_MP00ol0003oa<3GolC0e`03olC0e`03o`000?o6`MKoa/7F00Coa/7F00?o0000olW4eOl000002?o;
a=@01?l0003ocLGBolg5d_l00005om38dP03o`000?oBb=7od/SA00Cod/SA0_l00005omK<d003o`00
0?oonf[ooo]Z07;ooo]Z1?l0001FoookJP00^_oonfX2o`00043ooo]Z0_l000000ol0G=Co0000o`00
0004ocj4j0Go000000?oJiW/o`000?n5YNT01_n5YNT00ol0003oUjcUoiN/i@02oiN/i@Oo00000onU
/N400ol0003o[kGMojneg@08ojneg@04o`000?nf^M_o0000o`0000Ko^;WJ00Co0000okflfOnm_=Wo
_KcI0_l00006oknmf005o`000?o4`=Ooa<3GolC0eol000001oo6`MH2o`0000SoblCD00?o0000olg5
d_o=aM800_o=aM801Ol0003od<SBom38d_o@b=;o000000Kod/SA00Co0000om?8d?oCb=3o00000ooF
c=000ol0003ooo]ZoookJP1_oookJPCo0000F_oonfX00;cooo]Z00?o0000oookJ_oonfX0?_oonfX2
o`0000;o05cD00Go0000ocj4j?lnQ>So?XCXo`000004ofRHk0ko00000onH[>D00ol0003oYK7QojFa
h@05ojFah@03o`000?n_]Mgo[kGM00Oo[kGM0_l00009okRifP03o`000?nm_=Wo000000Wo_kgH00?o
0000olC0eol000001oo6`MH00ol0003oal7Do`000007ol_4e003o`000?o=aM;ocLGB00CocLGB00?o
0000om38d_l000001_oBb=400ol0003odlS@om?8d002om?8d003o`000?oFc=3o000006kooo]Z1?l0
001NoookJP00_OoonfX00ol0003ooo]ZoookJP0moookJP03o`000?l06I_o000000;o05cD0_l00002
ocj4j003o`000?mXV>coJ9S/00CoJ9S/00?o0000ohFTjOn5Y>T01?n5Y>T00ol0003oV:cUoiR/i@05
oiR/i@03o`000?nU/N7oYK7Q00GoYK7Q00?o0000ojnegOn_]Md00on_]Md3o`000003ok2fgOl0003o
^;WJ00So^;WJ0ol00009oknmf0;o00001oo6`MH01Ol0003oal7DolO1e?o7`MCo000000GoblCD00?o
0000olg5d_o=aM801Oo=aM82o`0000Kod/SA00?o0000om?8d?oCb=001?oCb=000ol0003ooo]Zoook
JP1YoookJPCo0000H_oonfX00;kooo]Z00?o0000oookJ_oonfX0?OoonfX01Ol0003o01VKo`000?l0
003o05cD00Go00001_mXV>`00ol0003oQJCYohFTj@04ohFTj@03o`000?nH[>GoV:cU00GoV:cU00?o
0000ojFahOnU/N401OnU/N400ol0003o[kGMo`000002o`0000Go/;KM00?o0000okRif_nh^MX01?nh
^MX2o`0000?o^K[J00?o0000oknmf?no_MP01?no_MP2o`0000;o`KgG00?o0000olK1e_o6`MH00oo6
`MH00ol0003oal7DolO1e003olO1e005o`000?o;a=CoblCDol_4e?l000001oo=aM800ol0003oc/GA
o`000005om;8d@03o`000?oCb=3odlS@00GodlS@00?o0000oookJ_oonfX0IOoonfX4o`0006Kooo]Z
002ooookJP;o0000?_oonfX00ol0003o01VKo`000003o`0000;o>H7W0_l00006ofRHk003o`000?n5
Y>WoQJCY00CoQJCY00?o0000oiR/iOnH[>D01?nH[>D00ol0003oYK7QojFah@04ojFah@?o00002On`
]]d00ol0003o^;WJokRifP02okRifP03o`000?ni^][o^K[J00Co^K[J00?o0000oknmf?no_MP00_no
_MP00ol0003o`KgGol6me`03ol6me`05o`000?o6`MKoa/7FolK1e_l000001oo7`M@00ol0003oblCD
o`000007olg5dP05o`000?o>aM7oc/GAolk5dOl000000ooBb=400ol0003odlS@om?8d005om?8d003
o`000?oonf[ooo]Z06?ooo]Z0ol0001ZoookJP00`OoonfX00ol0003ooo]ZoookJP0loookJP04o`00
0?l06I_o0000o`1Ed0;o00000oliPNL5o`0000;oJ9S/00?o0000ohFTjOn5Y>T00on5Y>T00ol0003o
V:cUoiR/i@05oiR/i@03o`000?nU/N7oYK7Q00?o00000onV/^400ol0003o/;KMok2fg@07ok2fg@04
o`000?nh^M[o0000o`0000So^K[J00Co0000oknmf?l0003o00001oo1_ML00ol0003oa/7Fo`000008
olO1e0;o00001oo=aM800ol0003oc/GAolk5d@03olk5d@03o`000?oBb=7o000000OodlS@00?o0000
oookJ_oonfX0H?oonfX4o`0006gooo]Z0032oookJP03o`000?oonf[ooo]Z03cooo]Z0ol000000ol0
EM3o0000o`000003ocV1i`04o`000?mVUn_oIYO[ofJGj`So000000?oQJCYo`000?nH[>D00onH[>D5
o`0000OoY[;Q00?o0000ok2fgOn`]]d01_n`]]d2o`0000[o^K[J0_l00009ol6me`;o00002?o7`M@0
1?l0003obL;ColW2dol00005olg5dP03o`000?o>aM7oc/GA00Goc/GA00?o0000om?8d?oCb=001OoC
b=000ol0003ooo]ZoookJP1MoookJPCo0000LOoonfX00<?ooo]Z00?o0000oookJ_oonfX0?OoonfX3
o`000003o`1Ed?l0003o000000;o>H7W00?o0000ofJGjomVUn/00omVUn/00ol0003oQ:CYohBTj@02
ohBTj@Ko00000onH[>D00ol0003oY[;QojJbh@07ojJbh@03o`000?n`]]go/;KM00;o/;KM0ol00000
0ona]]co0000okVjfP08okVjfP03o`000?nk^]Wo000000So`KgG00?o0000ol:ne_l000001oo7`M@0
0ol0003obL;ColW2d`02olW2d`05o`000?o=aM;ocLGBolg5d_l000001oo>aM400ol0003od<G@o`00
0005om?8d003o`000?oonf[ooo]Z05[ooo]Z1?l0001eoookJP00a?oonfX2o`0003kooo]Z00Go0000
o`1>bol0003o0000oc=miP04o`0000GoIYO[00?o0000ohBTjOn4Y>T00on4Y>T00ol0003oV:cUoiR/
i@05oiR/i@03o`000?nV/^7oY[;Q00OoY[;Q00Co0000ok2fgOl0003o00001Ona]]`00ol0003o^K[J
okVjfP04okVjfP;o00000onk^]T00ol0003o`KgGol6me`03ol6me`;o00000oo2_]H00ol0003oal7D
olO1e003olO1e003o`000?o9`]?obL;C00CobL;C00?o0000olg5d_l000001oo>aM401Ol0003od<G@
om35d?o@aM3o000000?odlS@00?o0000oookJ_oonfX0EooonfX4o`0007Wooo]Z0036oookJP03o`00
0?oonf[ooo]Z03cooo]Z00Co0000o`1>bol0003o00000olcONH2o`0000GoIYO[00?o0000ohBTjOn4
Y>T00on4Y>T00ol0003oV:cUoiR/i@05oiR/i@03o`000?nV/^7oY[;Q00GoY[;Q0ol00008ok6fg004
o`000?ni^][o^K[JokVjfP;o00001_nk^]T01Ol0003o`KgGol6meoo1_MOo000000Ko`[kF00Go0000
olO1e?o7`MCoal7Do`000007olW2d`;o00001oo>aM400ol0003od<G@om35d003om35d003o`000?oC
b=3o000005Oooo]Z0ol0001moookJP00aooonfX00ol0003ooo]ZoookJP0koookJP;o00000_l0C//0
0ol0003o<ggVoc=miP02oc=miP?o00000_mVUn/00ol0003oQ:CYohBTj@04ohBTj@03o`000?nH[>Go
V:cU00GoV:cU00?o0000ojJbhOnV/^401?l00002ojNbh003o`000?na]]co/KKL00Oo/KKL00?o0000
okVjf_l000002Onk^]T00ol0003o`KgGo`000008ol:neP03o`000?o7`MCo000000OobL;C00Co0000
ol_2d_o;`];o00001Oo>aM400ol0003od<G@om35d005om35d003o`000?oonf[ooo]Z05;ooo]Z1?l0
0020oookJP00b?oonfX00ol0003ooo]ZoookJP0joookJP03o`000?oonf[o000000;o04k;00Go0000
oc=mi_lcONKo<ggVo`000002of>Fj`Co00001_n4Y>T00ol0003oV:cUoiR/i@02oiR/i@Go00001onW
/^000ol0003o/KKLok6fg006ok6fg0;o00002_nk^]T2o`0000Wo`[kF0_l00007olW2d`03o`000?o;
`];obl;B00;obl;B00Go0000olk5dOo>aM7oc/GAo`000007om35d003o`000?oonf[ooo]Z04oooo]Z
1?l00024oookJP00bOoonfX2o`0003[ooo]Z00?o0000oookJ_oonfX00_l000000ol0C/_o0000o`00
0002oc=miP03o`000?mSU^_oHiK[00;oHiK[3?l00003oiV/i003o`000?nW/^3oYk;P00OoYk;P00?o
0000ok6fg?na]]`00_na]]`3o`000003ok>gg?l0003o^k[I00So^k[I00?o0000okbkf?l000002?o2
_]H01?l0003oa;kEolBneOl00005olW2d`03o`000?o;`];obl;B00Cobl;B00?o0000olk5dOl00000
1oo@aM000ol0003ooo]ZoookJP1<oookJPCo0000R?oonfX00<_ooo]Z00?o0000oookJ_oonfX0=ooo
nfX01?l0003ooo]ZoookJ_oonfX3o`000003obeii?l0003o000000;o00001?mSU^/00ol0003oPjCY
oh>Tj@04oh>Tj@03o`000?nI[>CoVJcT00GoVJcT00?o0000ojNbh?nW/^001onW/^001?l0003o/KKL
o`000?l00005ok>gg003o`000?nk^]Wo^k[I00Co^k[I0_l00003okbkf003o`000?o2_]Ko`[kF00?o
`[kF0_l00004olBne@05o`000?o9`]?obL;ColW2dol000001oo;`]82o`0000Ood<G@00?o0000oook
J_oonfX0BOoonfX4o`0008cooo]Z003<oookJP03o`000?oonf[ooo]Z03Kooo]Z00?o0000oookJ_oo
nfX00_oonfX3o`0000?o;GWT0_l00004of>Fj`03o`000?n3Y>WoPjCY00CoPjCY00?o0000oiV/i?nI
[>@01OnI[>@00ol0003oYk;PojNbh005ojNbh0?o00002?nc]m`01?l0003o^k[Iok^jfOnk^]T2o`00
00Ko_;_H00Go0000ol:ne_o2_]Ko`[kFo`000007olBne@03o`000?o9`]?o000000Oobl;B00Co0000
olc2dOo<`]7o00001Oo@aM000ol0003ooo]ZoookJP17oookJP?o0000T?oonfX00<gooo]Z00?o0000
oookJ_oonfX0=OoonfX00ol0003ooo]ZoookJP02oookJP;o000000?o04O5o`000?l]NN@00ol]NN@3
o`0000;oHiK[00?o0000oh>TjOn3Y>T01?n3Y>T00ol0003oVJcToiV/i005oiV/i003o`000?nW/^3o
Yk;P00Co00000_nX/^000ol0003o/kOLok>gg007ok>gg003o`000?nk^]Wo000000Wo_;_H00?o0000
ol:ne_l000002?o4_]D2o`0000Oobl;B00?o0000olc2dOo<`]400_o<`]401Ol0003od<G@om35d?o@
aM3o000004Kooo]Z1?l0002CoookJP00c_oonfX00ol0003ooo]ZoookJP0doookJP03o`000?oonf[o
oo]Z00?ooo]Z1?l00003obeii003o`000?mQU>_oHIC[00Co00001_n3Y>T00ol0003oVJcToiV/i002
oiV/i0Go00001onX/^000ol0003o/kOLok>gg006ok>gg0;o00002_nl^mP2o`0000Soa;kE00Co0000
olJoe?o6_mCo00001Oo;`]800ol0003oc<;Aolc2d@04olc2d@03o`000?o@aM3o000004?ooo]Z1?l0
002GoookJP00cooonfX2o`0003Cooo]Z00?o0000oookJ_oonfX01?oonfX00ol0003o0430o`000002
o`0000;o;GWT00?o0000of6DjomQU>/00_mQU>/<o`0000CoVJgT00?o0000ojRbh?nX/^001_nX/^00
0ol0003o/kOLok>gg002ok>gg0?o00000_nd]m/00ol0003o_;_Hokbkf005okbkf0;o00000_nn^mL0
0ol0003oa;kEolBne@03olBne@;o00001?o6_m@01Ol0003obl;Bol_2d_o;`];o000000Ooc<;A0_l0
0010oookJPCo0000VooonfX00=7ooo]Z00?o0000oookJ_oonfX0<OoonfX00ol0003ooo]ZoookJP05
oookJP03o`000?l0@<3o000000Go00001?mQU>/00ol0003oPjCYoh>Tj@04oh>Tj@03o`000?nI[NCo
VJgT00KoVJgT00?o0000ojRbh?nX/^001_nX/^001?l0003o/kOLo`000?l00006okBgf`03o`000?nl
^mSo_;_H00;o_;_H0_l00005okjke`05o`000?o4_]Goa;kEolBneOl000001oo6_m@00ol0003obl;B
o`000007olc2d@03o`000?oonf[ooo]Z03cooo]Z1?l0002OoookJP00d_oonfX00ol0003ooo]Zoook
JP0`oookJP03o`000?oonf[ooo]Z00Kooo]Z00Co0000o`10`?l0@<3o00000_lWM^<2o`0000CoHIC[
00?o0000oh>TjOn3Y>T01?n3Y>T00ol0003oVJgToiV]i006oiV]i003o`000?nX/^3oZ;;P00CoZ;;P
0ol00009okBgf`04o`000?nl^mSo0000o`0000So_[_G00?o0000olBneOl000002?o6_m@2o`0000Oo
c<;A00?o0000oookJ_oonfX0>OoonfX4o`000:?ooo]Z003CoookJP03o`000?oonf[ooo]Z02kooo]Z
00?o0000oookJ_oonfX02?oonfX01?l0003o0430o`10`?l00003obMfh`?o00000_mQU>/00ol0003o
PjCYoh>Tj@04oh>Tj@03o`000?nI[NCoVJgT00KoVJgT00?o0000ojRbh?nX/^000ol00002ojVcg`03
o`000?nd]m_o];OK00Oo];OK0_l0000:okjke`;o00002?o6_m@01?l0003oakoColNodol00005olc2
d@03o`000?oonf[ooo]Z03Oooo]Z0ol0002WoookJP00e?oonfX2o`0002kooo]Z00?o0000oookJ_oo
nfX02OoonfX2o`000005o`10`?l0003o0000obMfhol000000_mNTn/4o`0000KoPjCY00?o0000oiV]
i?nI[N@00_nI[N@6o`0000KoZK?O00?o0000okBgfond]m/01?nd]m/2o`000003okJhf_l0003o_[_G
00So_[_G00?o0000oknle_l000001oo6_m@00ol0003oakoColNod`02olNod`05o`000?o<`]7oc<;A
olc2dOl00000=_oonfX4o`000:[ooo]Z003FoookJP03o`000?oonf[ooo]Z02_ooo]Z00?o0000oook
J_oonfX02_oonfX3o`000004ob5bhOl0003o0000o`0000CoGY?[3?l00004oiZ]i003o`000?nY/moo
ZK?O00KoZK?O00?o0000okBgfond]m/00_nd]m/00ol0003o][SJokJhfP02okJhfP03o`000?nn^mOo
_[_G00Co_[_G0_l00003oknleP03o`000?o6_mCoa[oD00;oa[oD0_l00006olNod`03o`000?o<`]7o
000003?ooo]Z1?l0002^oookJP00eooonfX00ol0003ooo]ZoookJP0ZoookJP03o`000?oonf[ooo]Z
00_ooo]Z0ol00002ob5bh@;o00001?mNTn/00ol0003oPZ?Yoh:Sj@04oh:Sj@03o`000?nJ[NCoVZgT
00KoVZgT00?o0000ojVcgonY/ml01_nY/ml01?l0003o];OKo`000?l00006okJhfP04o`000?nn^mOo
_[_Gokjke`;o00001_no_=H01?l0003oa[oDolJoe?l00008olNod`;o0000<?oonfX4o`000;;ooo]Z
003HoookJP03o`000?oonf[ooo]Z02Wooo]Z00?o0000oookJ_oonfX03?oonfX00ol0003o03Vjo`00
0002ob5bh@;o00001?mNTn/00ol0003oPZ?Yoh:Sj@04oh:Sj@03o`000?nJ[NCoVZgT00KoVZgT00?o
0000ojVcgonY/ml01?nY/ml3o`0000Wo][SJ00?o0000okjkeol000002?no_=H00ol0003oa[oDo`00
0008olNod`03o`000?oonf[ooo]Z02cooo]Z1?l0002foookJP00fOoonfX2o`0002Wooo]Z00?o0000
oookJ_oonfX03OoonfX3o`0000?o8G;Q0ol00002oejCj`03o`000?n2XnWoPZ?Y00CoPZ?Y00?o0000
oiZ]i?nJ[N@01_nJ[N@00ol0003oZK?OojVcg`03o`0000;oZk?O00?o0000okJhf_nf^=X01onf^=X2
o`0000Wo_kcF0_l00008olNod`03o`000?oonf[ooo]Z02[ooo]Z0ol0002joookJP00fooonfX00ol0
003ooo]ZoookJP0VoookJP03o`000?oonf[ooo]Z00gooo]Z00?o0000o`0b]?l000000_l000001?lQ
L^7o0000oe^BjomKT^/4o`0000KoPZ?Y00?o0000oiZ]i?nJ[N@00_nJ[N@6o`0000KoZk?O00?o0000
okJhf_nf^=X01?nf^=X2o`000003okNhf_l0003o_kcF00Oo_kcF00Co0000ol6le_o1_=Ko00001Oo7
_m<2o`0002Wooo]Z1?l0002moookJP00g?oonfX00ol0003ooo]ZoookJP0UoookJP03o`000?oonf[o
oo]Z00kooo]Z00Co0000o`0b]?l0003o6VkO0ol00004oe^Bj`co00001?nJ[N@00ol0003oZk?Ooj^c
g`06oj^cg`03o`000?nf^=[o][SJ00;o][SJ00?o0000okNhf_ng^=X00_ng^=X00ol0003o_kcFoknl
eP03oknleP;o00001?o1_=H01Ol0003oakoColNodoo7_m?o000002Oooo]Z1?l00031oookJP00gOoo
nfX00ol0003ooo]ZoookJP0ToookJP03o`000?oonf[ooo]Z00oooo]Z00?o0000o`0b]?l000000_lJ
K]l2o`0000CoFi;[00?o0000oh:SjOn2XnT01?n2XnT00ol0003oVZgToiZ]i006oiZ]i003o`000?n[
/mooZk?O00KoZk?O00Co0000okJhf_l0003o00001_ng^=X01Ol0003o_kcFoknle_no_=Ko000000Oo
`KcF00?o0000olNodol000009?oonfX4o`000<Gooo]Z003NoookJP;o00009?oonfX00ol0003ooo]Z
oookJP0@oookJP03o`000?l0<[Co000000;o6VkO0_l00004oe^Bj`03o`000?n2XnWoPZ?Y00CoPZ?Y
00?o0000oiZ]i?nJ[N@01_nJ[N@00ol0003oZk?Ooj^cg`04oj^cg`?o00002Ong^=X00ol0003o_kcF
o`000008ol6leP;o00008OoonfX4o`000<Wooo]Z003PoookJP03o`000?oonf[ooo]Z027ooo]Z00?o
0000oookJ_oonfX04OoonfX3o`0000?o6VkO0ol00002oe^Bj`03o`000?n2XnWoPZ?Y00CoPZ?Y00?o
0000oiZ]i?nJ[N@01_nJ[N@00ol0003oZk?Ooj^cg`03o`0000;o[;CN00?o0000okNhf_ng^=X01ong
^=X2o`0000So`KcF00?o0000oookJ_oonfX07_oonfX3o`000<gooo]Z003QoookJP03o`000?oonf[o
oo]Z023ooo]Z00?o0000oookJ_oonfX04ooonfX3o`000004oaY^gol0003oFI3[oeV@j`Co00001_n2
XnT00ol0003oVZgToiZ]i002oiZ]i0Ko00001_n/]=h00ol0003o]kSJokNhfP04okNhfP;o000000?o
^KWIo`000?o1_=H01_o1_=H00ol0003ooo]ZoookJP0KoookJPCo0000d?oonfX00>;ooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0DoookJPGo00001?mIT>/<o`0000CoVjgT00?o0000
ojbdg_n/]=h01_n/]=h00ol0003o]kSJokNhfP02okNhfP03o`000?ni^MWo^KWI00;o^KWI00?o0000
ol6le_o1_=H00oo1_=H00ol0003ooo]ZoookJP0HoookJPCo0000e?oonfX00>?ooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0FoookJP04o`000?lDJ]go0000o`0000CoFI3[00?o0000
oh:SjOn2XnT01?n2XnT00ol0003oVjgToi^]i006oi^]i003o`000?n/]=ko[;CN00Ko[;CN00Co0000
okNhf_l0003o00001_ni^MT01Ol0003o`KcFol6le_o1_=Ko000001Oooo]Z1?l0003HoookJP00i?oo
nfX2o`0001kooo]Z00?o0000oookJ_oonfX05ooonfX01?l0003o56[Mo`000?l00004oeV@j`03o`00
0?n2XnWoPZ?Y00CoPZ?Y00?o0000oi^]i?nK[N@01_nK[N@00ol0003o[;CNojbdgP04ojbdgP?o0000
2Oni^MT00ol0003o`KcFo`00000DoookJPCo0000g?oonfX00>Kooo]Z00?o0000oookJ_oonfX06ooo
nfX00ol0003ooo]ZoookJP0HoookJP;o000000Co56[Mo`000?l0003o00000_mIT>/00ol0003oPZ?Y
oh:Sj@04oh:Sj@03o`000?nK[NCoVjgT00KoVjgT00?o0000ojbdg_n/]=h00ol00003ojfdgP03o`00
0?ni^MWo^KWI00Ko^KWI0_l0000BoookJP?o0000h?oonfX00>Oooo]Z00?o0000oookJ_oonfX06_oo
nfX00ol0003ooo]ZoookJP0JoookJP?o000000?oEXo[o`000?l000000_l00006oh:Sj@03o`000?nK
[NCoVjgT00;oVjgT1_l00007ojfdgP03o`000?ni^MWo^KWI00;o^KWI0ol0000@oookJPCo0000hooo
nfX00>Sooo]Z00?o0000oookJ_oonfX06OoonfX00ol0003ooo]ZoookJP0LoookJP;o00000omFSn/<
o`0000CoW:kT00?o0000ojfdg_n]]=h01on]]=h01?l0003o^KWIo`000?l0000?oookJPCo0000iooo
nfX00>Wooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z01gooo]Z0_l00003oeJ?j`03o`000?n1XnWo
PJ?Y00CoPJ?Y00?o0000oib^i?nL[^@01_nL[^@00ol0003o[KCNojfdgP06ojfdgP;o00003OoonfX4
o`000>_ooo]Z003[oookJP03o`000?oonf[ooo]Z01Kooo]Z00?o0000oookJ_oonfX07ooonfX2o`00
00;oEXo[00?o0000oh6SjOn1XnT01?n1XnT00ol0003oW:kToib^i006oib^i003o`000?n]]=ko[KCN
00;o[KCN0ol0000;oookJPCo0000kooonfX00>cooo]Z00?o0000oookJ_oonfX05OoonfX00ol0003o
oo]ZoookJP0QoookJPCo00001_n1XnT00ol0003oW:kToib^i006oib^i004o`000?n]]=ko0000o`00
00[ooo]Z1?l0003coookJP00kOoonfX00ol0003ooo]ZoookJP0DoookJP03o`000?oonf[ooo]Z02Co
oo]Z0_l00006oh6Sj@03o`000?nL[^CoW:kT00;oW:kT1Ol00009oookJP?o0000mooonfX00>kooo]Z
0_l0000DoookJP03o`000?oonf[ooo]Z02Kooo]Z2ol0000:oookJPCo0000n_oonfX00?3ooo]Z00?o
0000oookJ_oonfX04OoonfX00ol0003ooo]ZoookJP0goookJPCo0000o_oonfX00?7ooo]Z00?o0000
oookJ_oonfX04?oonfX00ol0003ooo]ZoookJP0coookJPCo0000oooonfX3oookJP00l_oonfX00ol0
003ooo]ZoookJP0?oookJP03o`000?oonf[ooo]Z02oooo]Z1?l0003ooookJPOooo]Z003coookJP;o
00003ooonfX00ol0003ooo]ZoookJP0/oookJP?o0000oooonfX;oookJP00mOoonfX00ol0003ooo]Z
oookJP0;oookJP03o`000?oonf[ooo]Z02Wooo]Z1?l0003ooookJPkooo]Z003foookJP03o`000?oo
nf[ooo]Z00[ooo]Z00?o0000oookJ_oonfX09OoonfX4o`000?oooo]Z4_oonfX00?Oooo]Z00?o0000
oookJ_oonfX02OoonfX00ol0003ooo]ZoookJP0QoookJPCo0000oooonfXFoookJP00n?oonfX00ol0
003ooo]ZoookJP08oookJP03o`000?oonf[ooo]Z01gooo]Z1?l0003ooookJQ[ooo]Z003ioookJP;o
00002?oonfX00ol0003ooo]ZoookJP0JoookJP?o0000oooonfXNoookJP00nooonfX00ol0003ooo]Z
oookJP05oookJP03o`000?oonf[ooo]Z01Kooo]Z1?l0003ooookJR7ooo]Z003loookJP03o`000?oo
nf[ooo]Z00Cooo]Z00?o0000oookJ_oonfX04_oonfX4o`000?oooo]Z9OoonfX00?gooo]Z00?o0000
oookJ_oonfX00ooonfX00ol0003ooo]ZoookJP0>oookJPCo0000oooonfXYoookJP00o_oonfX2o`00
00?ooo]Z00?o0000oookJ_oonfX02_oonfX4o`000?oooo]Z;OoonfX00?oooo]Z0OoonfX01?l0003o
oo]ZoookJ_l00009oookJP?o0000oooonfXaoookJP00oooonfX2oookJP03o`000?oonf[o000000Go
oo]Z1?l0003ooookJSCooo]Z003ooookJP?ooo]Z0_l000000ooonf[o0000o`000002o`000?oooo]Z
>?oonfX00?oooo]Z1?oonfX2o`000?oooo]Z??oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {466.188, 0}} -> {-0.11603, -0.0180113, \
0.00190815, 0.00190815}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlotVectorField[{1, y\ \ Sin[\ \(y\ t\)\/\(t + y + 1\)]}, {t, \ 0, 
        10}, \ {y, 0, 10}, Axes \[Rule] True, 
      AxesLabel \[Rule] {"\<t\>", "\<y\>"}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06347 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0945652 0.0253206 0.0945652 [
[.21294 .01282 -7 -20 ]
[.21294 .01282 7 0 ]
[.40207 .01282 -7 -20 ]
[.40207 .01282 7 0 ]
[.5912 .01282 -7 -20 ]
[.5912 .01282 7 0 ]
[.78033 .01282 -7 -20 ]
[.78033 .01282 7 0 ]
[.96946 .01282 -12 -20 ]
[.96946 .01282 12 0 ]
[1.025 .02532 0 -10 ]
[1.025 .02532 9.9375 10 ]
[.01131 .21445 -14 -10 ]
[.01131 .21445 0 10 ]
[.01131 .40358 -14 -10 ]
[.01131 .40358 0 10 ]
[.01131 .59271 -14 -10 ]
[.01131 .59271 0 10 ]
[.01131 .78184 -14 -10 ]
[.01131 .78184 0 10 ]
[.01131 .97097 -24 -10 ]
[.01131 .97097 0 10 ]
[.02381 1.08847 -7 0 ]
[.02381 1.08847 7 20 ]
[ 0 0 0 0 ]
[ 1 1.06347 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21294 .02532 m
.21294 .03157 L
s
gsave
.21294 .01282 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40207 .02532 m
.40207 .03157 L
s
gsave
.40207 .01282 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.5912 .02532 m
.5912 .03157 L
s
gsave
.5912 .01282 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78033 .02532 m
.78033 .03157 L
s
gsave
.78033 .01282 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.96946 .02532 m
.96946 .03157 L
s
gsave
.96946 .01282 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07109 .02532 m
.07109 .02907 L
s
.11837 .02532 m
.11837 .02907 L
s
.16566 .02532 m
.16566 .02907 L
s
.26022 .02532 m
.26022 .02907 L
s
.30751 .02532 m
.30751 .02907 L
s
.35479 .02532 m
.35479 .02907 L
s
.44935 .02532 m
.44935 .02907 L
s
.49664 .02532 m
.49664 .02907 L
s
.54392 .02532 m
.54392 .02907 L
s
.63848 .02532 m
.63848 .02907 L
s
.68577 .02532 m
.68577 .02907 L
s
.73305 .02532 m
.73305 .02907 L
s
.82761 .02532 m
.82761 .02907 L
s
.8749 .02532 m
.8749 .02907 L
s
.92218 .02532 m
.92218 .02907 L
s
.25 Mabswid
0 .02532 m
1 .02532 L
s
gsave
1.025 .02532 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(t) show
68.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .21445 m
.03006 .21445 L
s
gsave
.01131 .21445 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.02381 .40358 m
.03006 .40358 L
s
gsave
.01131 .40358 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.02381 .59271 m
.03006 .59271 L
s
gsave
.01131 .59271 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.02381 .78184 m
.03006 .78184 L
s
gsave
.01131 .78184 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.02381 .97097 m
.03006 .97097 L
s
gsave
.01131 .97097 -85 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0726 m
.02756 .0726 L
s
.02381 .11989 m
.02756 .11989 L
s
.02381 .16717 m
.02756 .16717 L
s
.02381 .26173 m
.02756 .26173 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .3563 m
.02756 .3563 L
s
.02381 .45086 m
.02756 .45086 L
s
.02381 .49815 m
.02756 .49815 L
s
.02381 .54543 m
.02756 .54543 L
s
.02381 .63999 m
.02756 .63999 L
s
.02381 .68728 m
.02756 .68728 L
s
.02381 .73456 m
.02756 .73456 L
s
.02381 .82912 m
.02756 .82912 L
s
.02381 .87641 m
.02756 .87641 L
s
.02381 .92369 m
.02756 .92369 L
s
.02381 1.01825 m
.02756 1.01825 L
s
.25 Mabswid
.02381 0 m
.02381 1.06347 L
s
gsave
.02381 1.08847 -68 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(y) show
73.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.0001 w
.02381 .02532 m
.03054 .02532 L
s
% Start of user PostScript
0. 0. 0.071160439 0. MAarrowhead1
% End of user PostScript
.02381 .09287 m
.03054 .09287 L
s
% Start of user PostScript
0. 0.71428571 0.071160439 0.71428571 MAarrowhead1
% End of user PostScript
.02381 .16041 m
.03054 .16041 L
s
% Start of user PostScript
0. 1.4285714 0.071160439 1.4285714 MAarrowhead1
% End of user PostScript
.02381 .22796 m
.03054 .22796 L
s
% Start of user PostScript
0. 2.1428571 0.071160439 2.1428571 MAarrowhead1
% End of user PostScript
.02381 .29551 m
.03054 .29551 L
s
% Start of user PostScript
0. 2.8571429 0.071160439 2.8571429 MAarrowhead1
% End of user PostScript
.02381 .36305 m
.03054 .36305 L
s
% Start of user PostScript
0. 3.5714286 0.071160439 3.5714286 MAarrowhead1
% End of user PostScript
.02381 .4306 m
.03054 .4306 L
s
% Start of user PostScript
0. 4.2857143 0.071160439 4.2857143 MAarrowhead1
% End of user PostScript
.02381 .49815 m
.03054 .49815 L
s
% Start of user PostScript
0. 5. 0.071160439 5. MAarrowhead1
% End of user PostScript
.02381 .56569 m
.03054 .56569 L
s
% Start of user PostScript
0. 5.7142857 0.071160439 5.7142857 MAarrowhead1
% End of user PostScript
.02381 .63324 m
.03054 .63324 L
s
% Start of user PostScript
0. 6.4285714 0.071160439 6.4285714 MAarrowhead1
% End of user PostScript
.02381 .70079 m
.03054 .70079 L
s
% Start of user PostScript
0. 7.1428571 0.071160439 7.1428571 MAarrowhead1
% End of user PostScript
.02381 .76833 m
.03054 .76833 L
s
% Start of user PostScript
0. 7.8571429 0.071160439 7.8571429 MAarrowhead1
% End of user PostScript
.02381 .83588 m
.03054 .83588 L
s
% Start of user PostScript
0. 8.5714286 0.071160439 8.5714286 MAarrowhead1
% End of user PostScript
.02381 .90343 m
.03054 .90343 L
s
% Start of user PostScript
0. 9.2857143 0.071160439 9.2857143 MAarrowhead1
% End of user PostScript
.02381 .97097 m
.03054 .97097 L
s
% Start of user PostScript
0. 10. 0.071160439 10. MAarrowhead1
% End of user PostScript
.09136 .02532 m
.09809 .02532 L
s
% Start of user PostScript
0.71428571 0. 0.78544615 0. MAarrowhead1
% End of user PostScript
.09136 .09287 m
.09809 .09387 L
s
% Start of user PostScript
0.71428571 0.71428571 0.78544615 0.72488568 MAarrowhead1
% End of user PostScript
.09136 .16041 m
.09809 .16348 L
s
% Start of user PostScript
0.71428571 1.4285714 0.78544615 1.4610004 MAarrowhead1
% End of user PostScript
.09136 .22796 m
.09809 .23353 L
s
% Start of user PostScript
0.71428571 2.1428571 0.78544615 2.2017921 MAarrowhead1
% End of user PostScript
.09136 .29551 m
.09809 .30381 L
s
% Start of user PostScript
0.71428571 2.8571429 0.78544615 2.9449237 MAarrowhead1
% End of user PostScript
.09136 .36305 m
.09809 .37421 L
s
% Start of user PostScript
0.71428571 3.5714286 0.78544615 3.6893786 MAarrowhead1
% End of user PostScript
.09136 .4306 m
.09809 .44468 L
s
% Start of user PostScript
0.71428571 4.2857143 0.78544615 4.4346496 MAarrowhead1
% End of user PostScript
.09136 .49815 m
.09809 .51521 L
s
% Start of user PostScript
0.71428571 5. 0.78544615 5.1804574 MAarrowhead1
% End of user PostScript
.09136 .56569 m
.09809 .58577 L
s
% Start of user PostScript
0.71428571 5.7142857 0.78544615 5.9266361 MAarrowhead1
% End of user PostScript
.09136 .63324 m
.09809 .65636 L
s
% Start of user PostScript
0.71428571 6.4285714 0.78544615 6.6730814 MAarrowhead1
% End of user PostScript
.09136 .70079 m
.09809 .72697 L
s
% Start of user PostScript
0.71428571 7.1428571 0.78544615 7.4197244 MAarrowhead1
% End of user PostScript
.09136 .76833 m
.09809 .79759 L
s
% Start of user PostScript
0.71428571 7.8571429 0.78544615 8.1665182 MAarrowhead1
% End of user PostScript
.09136 .83588 m
.09809 .86822 L
s
% Start of user PostScript
0.71428571 8.5714286 0.78544615 8.9134293 MAarrowhead1
% End of user PostScript
.09136 .90343 m
.09809 .93886 L
s
% Start of user PostScript
0.71428571 9.2857143 0.78544615 9.6604334 MAarrowhead1
% End of user PostScript
.09136 .97097 m
.09809 1.00951 L
s
% Start of user PostScript
0.71428571 10. 0.78544615 10.407513 MAarrowhead1
% End of user PostScript
.1589 .02532 m
.16563 .02532 L
s
% Start of user PostScript
1.4285714 0. 1.4997319 0. MAarrowhead1
% End of user PostScript
.1589 .09287 m
.16563 .0944 L
s
% Start of user PostScript
1.4285714 0.71428571 1.4997319 0.73050018 MAarrowhead1
% End of user PostScript
.1589 .16041 m
.16563 .16527 L
s
% Start of user PostScript
1.4285714 1.4285714 1.4997319 1.4798839 MAarrowhead1
% End of user PostScript
.1589 .22796 m
.16563 .23691 L
s
% Start of user PostScript
1.4285714 2.1428571 1.4997319 2.2375065 MAarrowhead1
% End of user PostScript
.1589 .29551 m
.16563 .30892 L
s
% Start of user PostScript
1.4285714 2.8571429 1.4997319 2.9989989 MAarrowhead1
% End of user PostScript
.1589 .36305 m
.16563 .38111 L
s
% Start of user PostScript
1.4285714 3.5714286 1.4997319 3.7624193 MAarrowhead1
% End of user PostScript
.1589 .4306 m
.16563 .4534 L
s
% Start of user PostScript
1.4285714 4.2857143 1.4997319 4.5268385 MAarrowhead1
% End of user PostScript
.1589 .49815 m
.16563 .52574 L
s
% Start of user PostScript
1.4285714 5. 1.4997319 5.2917838 MAarrowhead1
% End of user PostScript
.1589 .56569 m
.16563 .5981 L
s
% Start of user PostScript
1.4285714 5.7142857 1.4997319 6.0570035 MAarrowhead1
% End of user PostScript
.1589 .63324 m
.16563 .67048 L
s
% Start of user PostScript
1.4285714 6.4285714 1.4997319 6.8223592 MAarrowhead1
% End of user PostScript
.1589 .70079 m
.16563 .74286 L
s
% Start of user PostScript
1.4285714 7.1428571 1.4997319 7.5877728 MAarrowhead1
% End of user PostScript
.1589 .76833 m
.16563 .81524 L
s
% Start of user PostScript
1.4285714 7.8571429 1.4997319 8.3531997 MAarrowhead1
% End of user PostScript
.1589 .83588 m
.16563 .88762 L
s
% Start of user PostScript
1.4285714 8.5714286 1.4997319 9.1186147 MAarrowhead1
% End of user PostScript
.1589 .90343 m
.16563 .96 L
s
% Start of user PostScript
1.4285714 9.2857143 1.4997319 9.8840038 MAarrowhead1
% End of user PostScript
.1589 .97097 m
.16563 1.03238 L
s
% Start of user PostScript
1.4285714 10. 1.4997319 10.64936 MAarrowhead1
% End of user PostScript
.22645 .02532 m
.23318 .02532 L
s
% Start of user PostScript
2.1428571 0. 2.2140176 0. MAarrowhead1
% End of user PostScript
.22645 .09287 m
.23318 .09472 L
s
% Start of user PostScript
2.1428571 0.71428571 2.2140176 0.73393069 MAarrowhead1
% End of user PostScript
.22645 .16041 m
.23318 .16638 L
s
% Start of user PostScript
2.1428571 1.4285714 2.2140176 1.491671 MAarrowhead1
% End of user PostScript
.22645 .22796 m
.23318 .23897 L
s
% Start of user PostScript
2.1428571 2.1428571 2.2140176 2.2592817 MAarrowhead1
% End of user PostScript
.22645 .29551 m
.23318 .31189 L
s
% Start of user PostScript
2.1428571 2.8571429 2.2140176 3.0304331 MAarrowhead1
% End of user PostScript
.22645 .36305 m
.23318 .38489 L
s
% Start of user PostScript
2.1428571 3.5714286 2.2140176 3.8023334 MAarrowhead1
% End of user PostScript
.22645 .4306 m
.23318 .45784 L
s
% Start of user PostScript
2.1428571 4.2857143 2.2140176 4.5737811 MAarrowhead1
% End of user PostScript
.22645 .49815 m
.23318 .5307 L
s
% Start of user PostScript
2.1428571 5. 2.2140176 5.3442961 MAarrowhead1
% End of user PostScript
.22645 .56569 m
.23318 .60347 L
s
% Start of user PostScript
2.1428571 5.7142857 2.2140176 6.1137285 MAarrowhead1
% End of user PostScript
.22645 .63324 m
.23318 .67613 L
s
% Start of user PostScript
2.1428571 6.4285714 2.2140176 6.882078 MAarrowhead1
% End of user PostScript
.22645 .70079 m
.23318 .74869 L
s
% Start of user PostScript
2.1428571 7.1428571 2.2140176 7.6494088 MAarrowhead1
% End of user PostScript
.22645 .76833 m
.23318 .82116 L
s
% Start of user PostScript
2.1428571 7.8571429 2.2140176 8.4158092 MAarrowhead1
% End of user PostScript
.22645 .83588 m
.23318 .89356 L
s
% Start of user PostScript
2.1428571 8.5714286 2.2140176 9.1813727 MAarrowhead1
% End of user PostScript
.22645 .90343 m
.23318 .96588 L
s
% Start of user PostScript
2.1428571 9.2857143 2.2140176 9.9461887 MAarrowhead1
% End of user PostScript
.22645 .97097 m
.23318 1.03815 L
s
% Start of user PostScript
2.1428571 10. 2.2140176 10.710339 MAarrowhead1
% End of user PostScript
.294 .02532 m
.30073 .02532 L
s
% Start of user PostScript
2.8571429 0. 2.9283033 0. MAarrowhead1
% End of user PostScript
.294 .09287 m
.30073 .09494 L
s
% Start of user PostScript
2.8571429 0.71428571 2.9283033 0.73623093 MAarrowhead1
% End of user PostScript
.294 .16041 m
.30073 .16712 L
s
% Start of user PostScript
2.8571429 1.4285714 2.9283033 1.4994994 MAarrowhead1
% End of user PostScript
.294 .22796 m
.30073 .24025 L
s
% Start of user PostScript
2.8571429 2.1428571 2.9283033 2.2728248 MAarrowhead1
% End of user PostScript
.294 .29551 m
.30073 .31353 L
s
% Start of user PostScript
2.8571429 2.8571429 2.9283033 3.0477816 MAarrowhead1
% End of user PostScript
.294 .36305 m
.30073 .38662 L
s
% Start of user PostScript
2.8571429 3.5714286 2.9283033 3.8206489 MAarrowhead1
% End of user PostScript
.294 .4306 m
.30073 .45937 L
s
% Start of user PostScript
2.8571429 4.2857143 2.9283033 4.5900026 MAarrowhead1
% End of user PostScript
.294 .49815 m
.30073 .53176 L
s
% Start of user PostScript
2.8571429 5. 2.9283033 5.3554868 MAarrowhead1
% End of user PostScript
.294 .56569 m
.30073 .6038 L
s
% Start of user PostScript
2.8571429 5.7142857 2.9283033 6.1172191 MAarrowhead1
% End of user PostScript
.294 .63324 m
.30073 .6755 L
s
% Start of user PostScript
2.8571429 6.4285714 2.9283033 6.875507 MAarrowhead1
% End of user PostScript
.294 .70079 m
.30073 .74692 L
s
% Start of user PostScript
2.8571429 7.1428571 2.9283033 7.6307151 MAarrowhead1
% End of user PostScript
.294 .76833 m
.30073 .81808 L
s
% Start of user PostScript
2.8571429 7.8571429 2.9283033 8.3832051 MAarrowhead1
% End of user PostScript
.294 .83588 m
.30073 .88901 L
s
% Start of user PostScript
2.8571429 8.5714286 2.9283033 9.1333104 MAarrowhead1
% End of user PostScript
.294 .90343 m
.30073 .95975 L
s
% Start of user PostScript
2.8571429 9.2857143 2.9283033 9.8813279 MAarrowhead1
% End of user PostScript
.294 .97097 m
.30073 1.03031 L
s
% Start of user PostScript
2.8571429 10. 2.9283033 10.627517 MAarrowhead1
% End of user PostScript
.36154 .02532 m
.36827 .02532 L
s
% Start of user PostScript
3.5714286 0. 3.642589 0. MAarrowhead1
% End of user PostScript
.36154 .09287 m
.36827 .0951 L
s
% Start of user PostScript
3.5714286 0.71428571 3.642589 0.73787572 MAarrowhead1
% End of user PostScript
.36154 .16041 m
.36827 .16764 L
s
% Start of user PostScript
3.5714286 1.4285714 3.642589 1.5049677 MAarrowhead1
% End of user PostScript
.36154 .22796 m
.36827 .24106 L
s
% Start of user PostScript
3.5714286 2.1428571 3.642589 2.2814 MAarrowhead1
% End of user PostScript
.36154 .29551 m
.36827 .31436 L
s
% Start of user PostScript
3.5714286 2.8571429 3.642589 3.0565191 MAarrowhead1
% End of user PostScript
.36154 .36305 m
.36827 .38709 L
s
% Start of user PostScript
3.5714286 3.5714286 3.642589 3.8255706 MAarrowhead1
% End of user PostScript
.36154 .4306 m
.36827 .45908 L
s
% Start of user PostScript
3.5714286 4.2857143 3.642589 4.5869217 MAarrowhead1
% End of user PostScript
.36154 .49815 m
.36827 .53034 L
s
% Start of user PostScript
3.5714286 5. 3.642589 5.3404452 MAarrowhead1
% End of user PostScript
.36154 .56569 m
.36827 .60091 L
s
% Start of user PostScript
3.5714286 5.7142857 3.642589 6.0866736 MAarrowhead1
% End of user PostScript
.36154 .63324 m
.36827 .67086 L
s
% Start of user PostScript
3.5714286 6.4285714 3.642589 6.8263792 MAarrowhead1
% End of user PostScript
.36154 .70079 m
.36827 .74027 L
s
% Start of user PostScript
3.5714286 7.1428571 3.642589 7.5603746 MAarrowhead1
% End of user PostScript
.36154 .76833 m
.36827 .80921 L
s
% Start of user PostScript
3.5714286 7.8571429 3.642589 8.2894248 MAarrowhead1
% End of user PostScript
.36154 .83588 m
.36827 .87775 L
s
% Start of user PostScript
3.5714286 8.5714286 3.642589 9.0142132 MAarrowhead1
% End of user PostScript
.36154 .90343 m
.36827 .94594 L
s
% Start of user PostScript
3.5714286 9.2857143 3.642589 9.7353345 MAarrowhead1
% End of user PostScript
.36154 .97097 m
.36827 1.01384 L
s
% Start of user PostScript
3.5714286 10. 3.642589 10.453299 MAarrowhead1
% End of user PostScript
.42909 .02532 m
.43582 .02532 L
s
% Start of user PostScript
4.2857143 0. 4.3568747 0. MAarrowhead1
% End of user PostScript
.42909 .09287 m
.43582 .09521 L
s
% Start of user PostScript
4.2857143 0.71428571 4.3568747 0.73910827 MAarrowhead1
% End of user PostScript
.42909 .16041 m
.43582 .16801 L
s
% Start of user PostScript
4.2857143 1.4285714 4.3568747 1.5089462 MAarrowhead1
% End of user PostScript
.42909 .22796 m
.43582 .24158 L
s
% Start of user PostScript
4.2857143 2.1428571 4.3568747 2.2868905 MAarrowhead1
% End of user PostScript
.42909 .29551 m
.43582 .31469 L
s
% Start of user PostScript
4.2857143 2.8571429 4.3568747 3.0600017 MAarrowhead1
% End of user PostScript
.42909 .36305 m
.43582 .38679 L
s
% Start of user PostScript
4.2857143 3.5714286 4.3568747 3.8224347 MAarrowhead1
% End of user PostScript
.42909 .4306 m
.43582 .45771 L
s
% Start of user PostScript
4.2857143 4.2857143 4.3568747 4.5723877 MAarrowhead1
% End of user PostScript
.42909 .49815 m
.43582 .52747 L
s
% Start of user PostScript
4.2857143 5. 4.3568747 5.3100827 MAarrowhead1
% End of user PostScript
.42909 .56569 m
.43582 .59618 L
s
% Start of user PostScript
4.2857143 5.7142857 4.3568747 6.0366277 MAarrowhead1
% End of user PostScript
.42909 .63324 m
.43582 .66396 L
s
% Start of user PostScript
4.2857143 6.4285714 4.3568747 6.7534254 MAarrowhead1
% End of user PostScript
.42909 .70079 m
.43582 .73096 L
s
% Start of user PostScript
4.2857143 7.1428571 4.3568747 7.4618876 MAarrowhead1
% End of user PostScript
.42909 .76833 m
.43582 .79729 L
s
% Start of user PostScript
4.2857143 7.8571429 4.3568747 8.1633099 MAarrowhead1
% End of user PostScript
.42909 .83588 m
.43582 .86306 L
s
% Start of user PostScript
4.2857143 8.5714286 4.3568747 8.8588271 MAarrowhead1
% End of user PostScript
.42909 .90343 m
.43582 .92836 L
s
% Start of user PostScript
4.2857143 9.2857143 4.3568747 9.5494087 MAarrowhead1
% End of user PostScript
.42909 .97097 m
.43582 .99328 L
s
% Start of user PostScript
4.2857143 10. 4.3568747 10.235871 MAarrowhead1
% End of user PostScript
.49664 .02532 m
.50336 .02532 L
s
% Start of user PostScript
5. 0. 5.0711604 0. MAarrowhead1
% End of user PostScript
.49664 .09287 m
.50336 .09531 L
s
% Start of user PostScript
5. 0.71428571 5.0711604 0.74006534 MAarrowhead1
% End of user PostScript
.49664 .16041 m
.50336 .1683 L
s
% Start of user PostScript
5. 1.4285714 5.0711604 1.5119382 MAarrowhead1
% End of user PostScript
.49664 .22796 m
.50336 .24191 L
s
% Start of user PostScript
5. 2.1428571 5.0711604 2.2904126 MAarrowhead1
% End of user PostScript
.49664 .29551 m
.50336 .31472 L
s
% Start of user PostScript
5. 2.8571429 5.0711604 3.0602782 MAarrowhead1
% End of user PostScript
.49664 .36305 m
.50336 .38605 L
s
% Start of user PostScript
5. 3.5714286 5.0711604 3.8146037 MAarrowhead1
% End of user PostScript
.49664 .4306 m
.50336 .45573 L
s
% Start of user PostScript
5. 4.2857143 5.0711604 4.5514995 MAarrowhead1
% End of user PostScript
.49664 .49815 m
.50336 .52384 L
s
% Start of user PostScript
5. 5. 5.0711604 5.2716894 MAarrowhead1
% End of user PostScript
.49664 .56569 m
.50336 .59054 L
s
% Start of user PostScript
5. 5.7142857 5.0711604 5.9770425 MAarrowhead1
% End of user PostScript
.49664 .63324 m
.50336 .65605 L
s
% Start of user PostScript
5. 6.4285714 5.0711604 6.6697769 MAarrowhead1
% End of user PostScript
.49664 .70079 m
.50336 .72057 L
s
% Start of user PostScript
5. 7.1428571 5.0711604 7.3520653 MAarrowhead1
% End of user PostScript
.49664 .76833 m
.50336 .78429 L
s
% Start of user PostScript
5. 7.8571429 5.0711604 8.0258638 MAarrowhead1
% End of user PostScript
.49664 .83588 m
.50336 .84736 L
s
% Start of user PostScript
5. 8.5714286 5.0711604 8.692855 MAarrowhead1
% End of user PostScript
.49664 .90343 m
.50336 .90993 L
s
% Start of user PostScript
5. 9.2857143 5.0711604 9.3544488 MAarrowhead1
% End of user PostScript
.49664 .97097 m
.50336 .97209 L
s
% Start of user PostScript
5. 10. 5.0711604 10.011807 MAarrowhead1
% End of user PostScript
.56418 .02532 m
.57091 .02532 L
s
% Start of user PostScript
5.7142857 0. 5.7854462 0. MAarrowhead1
% End of user PostScript
.56418 .09287 m
.57091 .09538 L
s
% Start of user PostScript
5.7142857 0.71428571 5.7854462 0.74082951 MAarrowhead1
% End of user PostScript
.56418 .16041 m
.57091 .16852 L
s
% Start of user PostScript
5.7142857 1.4285714 5.7854462 1.5142509 MAarrowhead1
% End of user PostScript
.56418 .22796 m
.57091 .24213 L
s
% Start of user PostScript
5.7142857 2.1428571 5.7854462 2.2926482 MAarrowhead1
% End of user PostScript
.56418 .29551 m
.57091 .31456 L
s
% Start of user PostScript
5.7142857 2.8571429 5.7854462 3.0586096 MAarrowhead1
% End of user PostScript
.56418 .36305 m
.57091 .38506 L
s
% Start of user PostScript
5.7142857 3.5714286 5.7854462 3.804171 MAarrowhead1
% End of user PostScript
.56418 .4306 m
.57091 .45346 L
s
% Start of user PostScript
5.7142857 4.2857143 5.7854462 4.5274708 MAarrowhead1
% End of user PostScript
.56418 .49815 m
.57091 .51989 L
s
% Start of user PostScript
5.7142857 5. 5.7854462 5.2299122 MAarrowhead1
% End of user PostScript
.56418 .56569 m
.57091 .58461 L
s
% Start of user PostScript
5.7142857 5.7142857 5.7854462 5.9143303 MAarrowhead1
% End of user PostScript
.56418 .63324 m
.57091 .64793 L
s
% Start of user PostScript
5.7142857 6.4285714 5.7854462 6.583955 MAarrowhead1
% End of user PostScript
.56418 .70079 m
.57091 .71015 L
s
% Start of user PostScript
5.7142857 7.1428571 5.7854462 7.2418873 MAarrowhead1
% End of user PostScript
.56418 .76833 m
.57091 .77152 L
s
% Start of user PostScript
5.7142857 7.8571429 5.7854462 7.8908708 MAarrowhead1
% End of user PostScript
.56418 .83588 m
.57091 .83227 L
s
% Start of user PostScript
5.7142857 8.5714286 5.7854462 8.5332223 MAarrowhead1
% End of user PostScript
.56418 .90343 m
.57091 .89256 L
s
% Start of user PostScript
5.7142857 9.2857143 5.7854462 9.1708411 MAarrowhead1
% End of user PostScript
.56418 .97097 m
.57091 .95256 L
s
% Start of user PostScript
5.7142857 10. 5.7854462 9.8052524 MAarrowhead1
% End of user PostScript
.63173 .02532 m
.63846 .02532 L
s
% Start of user PostScript
6.4285714 0. 6.4997319 0. MAarrowhead1
% End of user PostScript
.63173 .09287 m
.63846 .09544 L
s
% Start of user PostScript
6.4285714 0.71428571 6.4997319 0.74145348 MAarrowhead1
% End of user PostScript
.63173 .16041 m
.63846 .16869 L
s
% Start of user PostScript
6.4285714 1.4285714 6.4997319 1.5160798 MAarrowhead1
% End of user PostScript
.63173 .22796 m
.63846 .24226 L
s
% Start of user PostScript
6.4285714 2.1428571 6.4997319 2.294026 MAarrowhead1
% End of user PostScript
.63173 .29551 m
.63846 .31429 L
s
% Start of user PostScript
6.4285714 2.8571429 6.4997319 3.0557809 MAarrowhead1
% End of user PostScript
.63173 .36305 m
.63846 .38395 L
s
% Start of user PostScript
6.4285714 3.5714286 6.4997319 3.7924329 MAarrowhead1
% End of user PostScript
.63173 .4306 m
.63846 .45108 L
s
% Start of user PostScript
6.4285714 4.2857143 6.4997319 4.5022836 MAarrowhead1
% End of user PostScript
.63173 .49815 m
.63846 .51589 L
s
% Start of user PostScript
6.4285714 5. 6.4997319 5.1876042 MAarrowhead1
% End of user PostScript
.63173 .56569 m
.63846 .57875 L
s
% Start of user PostScript
6.4285714 5.7142857 6.4997319 5.8524044 MAarrowhead1
% End of user PostScript
.63173 .63324 m
.63846 .6401 L
s
% Start of user PostScript
6.4285714 6.4285714 6.4997319 6.5011215 MAarrowhead1
% End of user PostScript
.63173 .70079 m
.63846 .70032 L
s
% Start of user PostScript
6.4285714 7.1428571 6.4997319 7.1379432 MAarrowhead1
% End of user PostScript
.63173 .76833 m
.63846 .75976 L
s
% Start of user PostScript
6.4285714 7.8571429 6.4997319 7.7665127 MAarrowhead1
% End of user PostScript
.63173 .83588 m
.63846 .81871 L
s
% Start of user PostScript
6.4285714 8.5714286 6.4997319 8.3898461 MAarrowhead1
% End of user PostScript
.63173 .90343 m
.63846 .87739 L
s
% Start of user PostScript
6.4285714 9.2857143 6.4997319 9.0103548 MAarrowhead1
% End of user PostScript
.63173 .97097 m
.63846 .93598 L
s
% Start of user PostScript
6.4285714 10. 6.4997319 9.6299165 MAarrowhead1
% End of user PostScript
.69927 .02532 m
.706 .02532 L
s
% Start of user PostScript
7.1428571 0. 7.2140176 0. MAarrowhead1
% End of user PostScript
.69927 .09287 m
.706 .09549 L
s
% Start of user PostScript
7.1428571 0.71428571 7.2140176 0.74197244 MAarrowhead1
% End of user PostScript
.69927 .16041 m
.706 .16883 L
s
% Start of user PostScript
7.1428571 1.4285714 7.2140176 1.5175546 MAarrowhead1
% End of user PostScript
.69927 .22796 m
.706 .24233 L
s
% Start of user PostScript
7.1428571 2.1428571 7.2140176 2.2948226 MAarrowhead1
% End of user PostScript
.69927 .29551 m
.706 .31396 L
s
% Start of user PostScript
7.1428571 2.8571429 7.2140176 3.052286 MAarrowhead1
% End of user PostScript
.69927 .36305 m
.706 .38279 L
s
% Start of user PostScript
7.1428571 3.5714286 7.2140176 3.7801873 MAarrowhead1
% End of user PostScript
.69927 .4306 m
.706 .4487 L
s
% Start of user PostScript
7.1428571 4.2857143 7.2140176 4.4771326 MAarrowhead1
% End of user PostScript
.69927 .49815 m
.706 .512 L
s
% Start of user PostScript
7.1428571 5. 7.2140176 5.1464457 MAarrowhead1
% End of user PostScript
.69927 .56569 m
.706 .57318 L
s
% Start of user PostScript
7.1428571 5.7142857 7.2140176 5.7935098 MAarrowhead1
% End of user PostScript
.69927 .63324 m
.706 .63282 L
s
% Start of user PostScript
7.1428571 6.4285714 7.2140176 6.4241488 MAarrowhead1
% End of user PostScript
.69927 .70079 m
.706 .69142 L
s
% Start of user PostScript
7.1428571 7.1428571 7.2140176 7.0437739 MAarrowhead1
% End of user PostScript
.69927 .76833 m
.706 .74941 L
s
% Start of user PostScript
7.1428571 7.8571429 7.2140176 7.6570125 MAarrowhead1
% End of user PostScript
.69927 .83588 m
.706 .80715 L
s
% Start of user PostScript
7.1428571 8.5714286 7.2140176 8.2676116 MAarrowhead1
% End of user PostScript
.69927 .90343 m
.706 .86492 L
s
% Start of user PostScript
7.1428571 9.2857143 7.2140176 8.8784824 MAarrowhead1
% End of user PostScript
.69927 .97097 m
.706 .92291 L
s
% Start of user PostScript
7.1428571 10. 7.2140176 9.4918047 MAarrowhead1
% End of user PostScript
.76682 .02532 m
.77355 .02532 L
s
% Start of user PostScript
7.8571429 0. 7.9283033 0. MAarrowhead1
% End of user PostScript
.76682 .09287 m
.77355 .09553 L
s
% Start of user PostScript
7.8571429 0.71428571 7.9283033 0.74241074 MAarrowhead1
% End of user PostScript
.76682 .16041 m
.77355 .16894 L
s
% Start of user PostScript
7.8571429 1.4285714 7.9283033 1.5187636 MAarrowhead1
% End of user PostScript
.76682 .22796 m
.77355 .24237 L
s
% Start of user PostScript
7.8571429 2.1428571 7.9283033 2.2952207 MAarrowhead1
% End of user PostScript
.76682 .29551 m
.77355 .3136 L
s
% Start of user PostScript
7.8571429 2.8571429 7.9283033 3.0484382 MAarrowhead1
% End of user PostScript
.76682 .36305 m
.77355 .38163 L
s
% Start of user PostScript
7.8571429 3.5714286 7.9283033 3.7679203 MAarrowhead1
% End of user PostScript
.76682 .4306 m
.77355 .44639 L
s
% Start of user PostScript
7.8571429 4.2857143 7.9283033 4.4527145 MAarrowhead1
% End of user PostScript
.76682 .49815 m
.77355 .5083 L
s
% Start of user PostScript
7.8571429 5. 7.9283033 5.1073679 MAarrowhead1
% End of user PostScript
.76682 .56569 m
.77355 .56801 L
s
% Start of user PostScript
7.8571429 5.7142857 7.9283033 5.7388151 MAarrowhead1
% End of user PostScript
.76682 .63324 m
.77355 .62623 L
s
% Start of user PostScript
7.8571429 6.4285714 7.9283033 6.3544195 MAarrowhead1
% End of user PostScript
.76682 .70079 m
.77355 .68358 L
s
% Start of user PostScript
7.8571429 7.1428571 7.9283033 6.9609204 MAarrowhead1
% End of user PostScript
.76682 .76833 m
.77355 .74061 L
s
% Start of user PostScript
7.8571429 7.8571429 7.9283033 7.5639769 MAarrowhead1
% End of user PostScript
.76682 .83588 m
.77355 .79773 L
s
% Start of user PostScript
7.8571429 8.5714286 7.9283033 8.1680592 MAarrowhead1
% End of user PostScript
.76682 .90343 m
.77355 .85527 L
s
% Start of user PostScript
7.8571429 9.2857143 7.9283033 8.7765217 MAarrowhead1
% End of user PostScript
.76682 .97097 m
.77355 .91345 L
s
% Start of user PostScript
7.8571429 10. 7.9283033 9.3917543 MAarrowhead1
% End of user PostScript
.83437 .02532 m
.8411 .02532 L
s
% Start of user PostScript
8.5714286 0. 8.642589 0. MAarrowhead1
% End of user PostScript
.83437 .09287 m
.8411 .09556 L
s
% Start of user PostScript
8.5714286 0.71428571 8.642589 0.74278577 MAarrowhead1
% End of user PostScript
.83437 .16041 m
.8411 .16904 L
s
% Start of user PostScript
8.5714286 1.4285714 8.642589 1.5197691 MAarrowhead1
% End of user PostScript
.83437 .22796 m
.8411 .24238 L
s
% Start of user PostScript
8.5714286 2.1428571 8.642589 2.2953432 MAarrowhead1
% End of user PostScript
.83437 .29551 m
.8411 .31322 L
s
% Start of user PostScript
8.5714286 2.8571429 8.642589 3.0444368 MAarrowhead1
% End of user PostScript
.83437 .36305 m
.8411 .3805 L
s
% Start of user PostScript
8.5714286 3.5714286 8.642589 3.7559222 MAarrowhead1
% End of user PostScript
.83437 .4306 m
.8411 .44419 L
s
% Start of user PostScript
8.5714286 4.2857143 8.642589 4.4294136 MAarrowhead1
% End of user PostScript
.83437 .49815 m
.8411 .50484 L
s
% Start of user PostScript
8.5714286 5. 8.642589 5.0708321 MAarrowhead1
% End of user PostScript
.83437 .56569 m
.8411 .56328 L
s
% Start of user PostScript
8.5714286 5.7142857 8.642589 5.6888149 MAarrowhead1
% End of user PostScript
.83437 .63324 m
.8411 .62036 L
s
% Start of user PostScript
8.5714286 6.4285714 8.642589 6.2923846 MAarrowhead1
% End of user PostScript
.83437 .70079 m
.8411 .67684 L
s
% Start of user PostScript
8.5714286 7.1428571 8.642589 6.8896764 MAarrowhead1
% End of user PostScript
.83437 .76833 m
.8411 .73337 L
s
% Start of user PostScript
8.5714286 7.8571429 8.642589 7.4873876 MAarrowhead1
% End of user PostScript
.83437 .83588 m
.8411 .79042 L
s
% Start of user PostScript
8.5714286 8.5714286 8.642589 8.0906602 MAarrowhead1
% End of user PostScript
.83437 .90343 m
.8411 .84834 L
s
% Start of user PostScript
8.5714286 9.2857143 8.642589 8.7031917 MAarrowhead1
% End of user PostScript
.83437 .97097 m
.8411 .90737 L
s
% Start of user PostScript
8.5714286 10. 8.642589 9.3274467 MAarrowhead1
% End of user PostScript
.90191 .02532 m
.90864 .02532 L
s
% Start of user PostScript
9.2857143 0. 9.3568747 0. MAarrowhead1
% End of user PostScript
.90191 .09287 m
.90864 .09559 L
s
% Start of user PostScript
9.2857143 0.71428571 9.3568747 0.74311026 MAarrowhead1
% End of user PostScript
.90191 .16041 m
.90864 .16912 L
s
% Start of user PostScript
9.2857143 1.4285714 9.3568747 1.520616 MAarrowhead1
% End of user PostScript
.90191 .22796 m
.90864 .24237 L
s
% Start of user PostScript
9.2857143 2.1428571 9.3568747 2.2952743 MAarrowhead1
% End of user PostScript
.90191 .29551 m
.90864 .31284 L
s
% Start of user PostScript
9.2857143 2.8571429 9.3568747 3.0404086 MAarrowhead1
% End of user PostScript
.90191 .36305 m
.90864 .37941 L
s
% Start of user PostScript
9.2857143 3.5714286 9.3568747 3.7443594 MAarrowhead1
% End of user PostScript
.90191 .4306 m
.90864 .44211 L
s
% Start of user PostScript
9.2857143 4.2857143 9.3568747 4.4074194 MAarrowhead1
% End of user PostScript
.90191 .49815 m
.90864 .50165 L
s
% Start of user PostScript
9.2857143 5. 9.3568747 5.0370109 MAarrowhead1
% End of user PostScript
.90191 .56569 m
.90864 .55901 L
s
% Start of user PostScript
9.2857143 5.7142857 9.3568747 5.6435945 MAarrowhead1
% End of user PostScript
.90191 .63324 m
.90864 .61521 L
s
% Start of user PostScript
9.2857143 6.4285714 9.3568747 6.237938 MAarrowhead1
% End of user PostScript
.90191 .70079 m
.90864 .67116 L
s
% Start of user PostScript
9.2857143 7.1428571 9.3568747 6.8296018 MAarrowhead1
% End of user PostScript
.90191 .76833 m
.90864 .72759 L
s
% Start of user PostScript
9.2857143 7.8571429 9.3568747 7.4262876 MAarrowhead1
% End of user PostScript
.90191 .83588 m
.90864 .78503 L
s
% Start of user PostScript
9.2857143 8.5714286 9.3568747 8.0337154 MAarrowhead1
% End of user PostScript
.90191 .90343 m
.90864 .84386 L
s
% Start of user PostScript
9.2857143 9.2857143 9.3568747 8.6557854 MAarrowhead1
% End of user PostScript
.90191 .97097 m
.90864 .90429 L
s
% Start of user PostScript
9.2857143 10. 9.3568747 9.294863 MAarrowhead1
% End of user PostScript
.96946 .02532 m
.97619 .02532 L
s
% Start of user PostScript
10. 0. 10.07116 0. MAarrowhead1
% End of user PostScript
.96946 .09287 m
.97619 .09562 L
s
% Start of user PostScript
10. 0.71428571 10.07116 0.74339377 MAarrowhead1
% End of user PostScript
.96946 .16041 m
.97619 .16919 L
s
% Start of user PostScript
10. 1.4285714 10.07116 1.5213371 MAarrowhead1
% End of user PostScript
.96946 .22796 m
.97619 .24235 L
s
% Start of user PostScript
10. 2.1428571 10.07116 2.2950727 MAarrowhead1
% End of user PostScript
.96946 .29551 m
.97619 .31246 L
s
% Start of user PostScript
10. 2.8571429 10.07116 3.0364334 MAarrowhead1
% End of user PostScript
.96946 .36305 m
.97619 .37836 L
s
% Start of user PostScript
10. 3.5714286 10.07116 3.7333209 MAarrowhead1
% End of user PostScript
.96946 .4306 m
.97619 .44016 L
s
% Start of user PostScript
10. 4.2857143 10.07116 4.3868018 MAarrowhead1
% End of user PostScript
.96946 .49815 m
.97619 .4987 L
s
% Start of user PostScript
10. 5. 10.07116 5.0059034 MAarrowhead1
% End of user PostScript
.96946 .56569 m
.97619 .55517 L
s
% Start of user PostScript
10. 5.7142857 10.07116 5.6030014 MAarrowhead1
% End of user PostScript
.96946 .63324 m
.97619 .61074 L
s
% Start of user PostScript
10. 6.4285714 10.07116 6.1906606 MAarrowhead1
% End of user PostScript
.96946 .70079 m
.97619 .66646 L
s
% Start of user PostScript
10. 7.1428571 10.07116 6.7798605 MAarrowhead1
% End of user PostScript
.96946 .76833 m
.97619 .72314 L
s
% Start of user PostScript
10. 7.8571429 10.07116 7.3792355 MAarrowhead1
% End of user PostScript
.96946 .83588 m
.97619 .78136 L
s
% Start of user PostScript
10. 8.5714286 10.07116 7.9949543 MAarrowhead1
% End of user PostScript
.96946 .90343 m
.97619 .84151 L
s
% Start of user PostScript
10. 9.2857143 10.07116 8.6309442 MAarrowhead1
% End of user PostScript
.96946 .97097 m
.97619 .90376 L
s
% Start of user PostScript
10. 10. 10.07116 9.2892678 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1.06347 L
0 1.06347 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{541.562, 575.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008M0002?b000`400?l00000o`00003ooooonf[o
oookJQoooo]Z003ooookJ_oooo]Z7ooonfX00?oooo]ZoooonfXOoookJP00oooonf[ooookJQoooo]Z
003ooookJ_oooo]Z7ooonfX00?oooo]ZoooonfXOoookJP00N?oonfX9o`00Oe[ooo]Z0ol007mHoook
JPGo001oFOoonfX5o`00OeKooo]Z0ol007l5oookJPGo001o8OoonfX007Sooo]Z2Ol007mJoookJP?o
001oEooonfX7o`00OeOooo]Z1ol007mEoookJP?o001o1?oonfX7o`00Ob3ooo]Z001hoookJPCo001o
GooonfX3o`00OeOooo]Z0ol007l2oookJP?o001oEOoonfX3o`00O`?ooo]Z0ol007mDoookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00Ob3ooo]Z001ioookJPCo001oFOoonfX9o`00OeGooo]Z
0ol007l3oookJP?o001oEOoonfX3o`00O`?ooo]Z0ol007mDoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007lOoookJP00N_oonfX5o`00OeOooo]Z2Ol007mEoookJP?o001o0ooonfX3o`00OeGooo]Z0ol0
07l3oookJP?o001oE?oonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o7ooonfX007cooo]Z1?l007mF
oookJP;o001o0ooonfX3o`00OeKooo]Z1?l007l2oookJP?o001oEOoonfX3o`00O`?ooo]Z0ol007mD
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lOoookJP00OOoonfX3o`00OeOooo]Z0_l007l2oook
JP?o001oE_oonfX8o`00OeOooo]Z1ol007mEoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007lOoook
JP007ooonfX00ol0003ooo]ZoookJP1LoookJP?o001oE_oonfX3o`00O`04oookJ_l007oo001oo`00
OeKooo]Z0ol007l01?oonf[o001oo`00Ool007mHoookJPOo001oEOoonfX3o`00O`?ooo]Z0ol007l3
oookJP?o001o7ooonfX001oooo]Z00?o0000oookJ_oonfX0E_oonfX3o`00O`?ooo]Z0ol007mGoook
JP;o001o00Cooo]Zo`00Ool007oo001oE_oonfX3o`00Oe_ooo]Z0ol007l3oookJP?o001oE?oonfX3
o`00O`?ooo]Z0ol007l3oookJP?o001o7ooonfX001oooo]Z00?o0000oookJ_oonfX0E_oonfX3o`00
O`?ooo]Z0ol007mHoookJPGo001oE_oonfX3o`00Oe_ooo]Z0ol007l3oookJP?o001oDOoonfX6o`00
O`?ooo]Z0ol007l3oookJP?o001o7ooonfX001oooo]Z00?o0000oookJ_oonfX0E_oonfX4o`00O`;o
oo]Z0ol007mHoookJPGo001oEooonfX3o`00O`;ooo]Z0ol007mEoookJP?o001o0ooonfX3o`00Oe7o
oo]Z1_l007l4oookJP?o001o00Cooo]Zo`00Ool007oo001o8?oonfX001oooo]Z00?o0000oookJ_oo
nfX0EooonfX7o`00Oe[ooo]Z1?l007mGoookJPOo001oEooonfX7o`00OeCooo]Z1?l007l4oookJPOo
001o8?oonfX001oooo]Z00?o0000oookJ_oonfX0F?oonfX5o`00Oecooo]Z0ol007mIoookJPCo001o
FOoonfX5o`00OeKooo]Z0ol007l5oookJPGo001o8OoonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[eoookJPCo001o0ooonfX001Sooo]Z
0ol00004oookJP03o`000?oonf[ooo]Z01Sooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z
0ol0000NoookJP?o00007ooonfX3o`0001kooo]Z0ol0000OoookJP?o00007ooonfX3o`0001kooo]Z
0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o00008ooonfX5o`00O`?ooo]Z
000HoookJPKo000000?ooo]Zo`000?oonfX06OoonfX6o`0001cooo]Z1_l0000KoookJPKo00007?oo
nfX6o`0001_ooo]Z1_l0000LoookJPKo00006ooonfX6o`0001cooo]Z1_l0000LoookJPKo00006ooo
nfX6o`0001cooo]Z1_l0000KoookJPKo00007?oonfX6o`0001cooo]Z1_l0000PoookJP?o001o1Ooo
nfX001Sooo]Z2Ol0000IoookJPWo00006OoonfX9o`0001Sooo]Z2Ol0000IoookJPWo00006?oonfX9
o`0001Wooo]Z2Ol0000HoookJPWo00006OoonfX9o`0001Wooo]Z2Ol0000HoookJPWo00006OoonfX9
o`0001Sooo]Z2Ol0000IoookJPWo00006OoonfX9o`0001gooo]Z0ol007l5oookJP004ooonf[oo`00
0??o00004?oonfX3o`00O`Gooo]Z000HoookJPSo00005ooonfX00ol0003ooo]ZoookJP08o`0000co
oo]Z00?o0000oookJ_oonfX02ooonfX8o`0000;ooo]Z00?o0000oookJ_oonfX05?oonfX8o`00013o
oo]Z00?o0000oookJ_oonfX01ooonfX8o`0000Gooo]Z00?o0000oookJ_oonfX04OoonfX8o`0001?o
oo]Z00?o0000oookJ_oonfX01?oonfX8o`0000Wooo]Z00?o0000oookJ_oonfX03OoonfX8o`0001Oo
oo]Z00?o0000oookJ_oonfX02?l0000<oookJP03o`000?oonf[ooo]Z00_ooo]Z2?l00002oookJP03
o`000?oonf[ooo]Z01Cooo]Z2?l0000@oookJP03o`000?oonf[ooo]Z00Oooo]Z2?l00005oookJP03
o`000?oonf[ooo]Z017ooo]Z2?l0000CoookJP03o`000?oonf[ooo]Z00Cooo]Z2?l00009oookJP03
o`000?oonf[ooo]Z00kooo]Z2?l0000NoookJP?o001o1OoonfX001Sooo]Z0ol00004oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ol0000AoookJP03o`000?oonf[ooo]Z00_ooo]Z
0ol00007oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z00Oooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z017ooo]Z0ol000000ooonf[o0000oookJP0EoookJP03o`00
0?oonf[ooo]Z00Cooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z00gooo]Z0ol00004oookJP03o`00
0?oonf[ooo]Z01Gooo]Z00?o0000oookJ_oonfX00ol0000AoookJP03o`000?oonf[ooo]Z00_ooo]Z
0ol00007oookJP03o`000?oonf[ooo]Z01Cooo]Z0ol0000EoookJP03o`000?oonf[ooo]Z00Oooo]Z
0ol0000:oookJP03o`000?oonf[ooo]Z017ooo]Z0ol000000ooonf[o0000oookJP0EoookJP03o`00
0?oonf[ooo]Z00Cooo]Z0ol0000>oookJP03o`000?oonf[ooo]Z00kooo]Z0ol00003oookJP03o`00
0?oonf[ooo]Z01gooo]Z0ol007l5oookJP007ooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oo
nf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX0FooonfX00ol0003ooo]ZoookJP1KoookJP03o`000?oo
nf[ooo]Z05_ooo]Z00?o0000oookJ_oonfX07OoonfX3o`00O`Gooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]ZlooonfX6o`00O`?ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZlooonfX6o`00
O`?ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zm?oonfX3o`00O`Gooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]Zm?oonfX3o`00O`Gooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooook
J_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0
oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o
0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000Ooook
JP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP?o0000oooonf[loookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0G?oonfX2
o`00023ooo]Z0_l0000PoookJP;o00007ooonfX2o`00023ooo]Z0_l0000PoookJP;o00007ooonfX2
o`00023ooo]Z0_l0000PoookJP;o00007ooonfX2o`00023ooo]Z0_l0000OoookJP;o0000:ooonfX0
01oooo]Z00?o0000oookJ_oonfX06?oonfX2o`00023ooo]Z0_l0000PoookJPCo00007_oonfX4o`00
01kooo]Z0ol0000NoookJP?o00007ooonfX3o`0001oooo]Z0ol0000NoookJP?o00007ooonfX3o`00
01oooo]Z0ol0000NoookJP?o00007ooonfX3o`0001kooo]Z0ol0000ZoookJP006?oonfX4o`0000?o
oo]Z00?o0000oookJ_oonfX06?oonfX5o`0001gooo]Z1Ol0000MoookJPKo00006ooonfX7o`0001_o
oo]Z1Ol0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000LoookJPKo00007?oonfX5o`0001go
oo]Z1Ol0000LoookJPGo00007OoonfX5o`0001cooo]Z1_l0000XoookJP006?oonfX9o`0001Wooo]Z
1ol0000KoookJPOo00006_oonfX8o`0001[ooo]Z2?l0000JoookJPOo00006_oonfX7o`0001_ooo]Z
1ol0000KoookJPOo00006_oonfX7o`0001_ooo]Z1ol0000KoookJPOo00006_oonfX7o`0001_ooo]Z
1ol0000JoookJPOo00009ooonfX001Sooo]Z2ol0000GoookJP[o00005ooonfX;o`0001Oooo]Z2_l0
000HoookJP[o00006?oonfX8o`0001Wooo]Z2Ol0000IoookJPSo00006_oonfX8o`0001Sooo]Z2_l0
000HoookJPWo00006OoonfX9o`0001Sooo]Z2Ol0000IoookJPWo00006?oonfX:o`0002Gooo]Z000H
oookJPSo00006_oonfX;o`0001Kooo]Z3?l0000FoookJP_o00005_oonfX<o`0001Kooo]Z2_l0000H
oookJP[o00005ooonfX:o`0001Sooo]Z2_l0000KoookJPOo00006ooonfX6o`0001cooo]Z1_l0000K
oookJPKo00007?oonfX6o`0001_ooo]Z1ol0000ToookJP006?oonfX5o`0000;ooo]Z00?o0000oook
J_oonfX06?oonfX5o`0008Oooo]Z1Ol0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000Ooook
JP?o00007ooonfX2o`00023ooo]Z0_l0000OoookJP;o00008?oonfX2o`0001oooo]Z0ol0000Soook
JP006?oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000
oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000OoookJP?o0000oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loook
JP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
o?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oo
nf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0
003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z
00?o0000oookJ_oonfX06_oonfX2o`00027ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX2o`00023ooo]Z
0_l0000PoookJP;o00007ooonfX2o`00023ooo]Z0_l0000PoookJP;o00007ooonfX2o`00023ooo]Z
0_l0000PoookJP03o`000?oonf[ooo]Z02Kooo]Z000OoookJP03o`000?oonf[ooo]Z01[ooo]Z0ol0
000PoookJP;o00007ooonfX2o`00023ooo]Z0_l0000PoookJP;o00007ooonfX3o`0001oooo]Z0ol0
000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0
000OoookJP;o0000:?oonfX001oooo]Z00?o0000oookJ_oonfX06OoonfX5o`0001kooo]Z1?l0000M
oookJPCo00007_oonfX4o`0001kooo]Z1?l0000MoookJPGo00007OoonfX5o`0001gooo]Z1Ol0000L
oookJPGo00007OoonfX5o`0001gooo]Z1Ol0000LoookJPGo00007OoonfX5o`0001gooo]Z1?l0000W
oookJP006?oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX06OoonfX6o`0001cooo]Z1_l0000Koook
JPKo00007?oonfX6o`0001cooo]Z1Ol0000LoookJPKo00007?oonfX6o`0001cooo]Z1_l0000Koook
JPKo00007?oonfX6o`0001cooo]Z1_l0000KoookJPKo00007?oonfX6o`0001cooo]Z1Ol0000Woook
JP006?oonfX9o`0001[ooo]Z1ol0000JoookJPSo00007?oonfX5o`0001gooo]Z1Ol0000MoookJPCo
00007OoonfX5o`0001gooo]Z1Ol0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000MoookJPGo
00007?oonfX5o`0001gooo]Z1Ol0000MoookJPCo00009_oonfX001Sooo]Z2ol0000GoookJPWo0000
7?oonfX6o`0001gooo]Z0ol0000OoookJP?o00007_oonfX4o`0001gooo]Z1Ol0000MoookJPCo0000
7_oonfX4o`0001gooo]Z1Ol0000MoookJPCo00007_oonfX4o`0001gooo]Z1?l0000NoookJPCo0000
7_oonfX4o`0002Gooo]Z000HoookJPSo00007_oonfX6o`0001kooo]Z1?l0000NoookJP;o00008?oo
nfX2o`0001kooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o00007_oo
nfX3o`0001oooo]Z0ol0000NoookJP?o00007ooonfX3o`0001oooo]Z0ol0000UoookJP006?oonfX5
o`0000;ooo]Z00?o0000oookJ_oonfX08OoonfX2o`00023ooo]Z0_l0000NoookJP;o00008?oonfX2
o`0001oooo]Z0_l0000OoookJP?o00007ooonfX2o`00023ooo]Z0_l0000OoookJP?o00007ooonfX2
o`00023ooo]Z0_l0000OoookJP;o00008?oonfX2o`00023ooo]Z0_l0000ToookJP006?oonfX2o`00
00Gooo]Z0ol0001UoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0RoookJP007ooonfX00ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z027o
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000
oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000=oookJPWo001o2OoonfX00ol0
003ooo]ZoookJP3ooookJ_cooo]Z000=oookJPWo001o2OoonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000=oookJPCo001o3_oonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000>oookJPCo001o3Ooo
nfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000?oookJPGo001o2ooonfX4o`000?oooo]ZnooonfX0
017ooo]Z1?l007l:oookJP03o`000?oonf[ooo]Z01cooo]Z00?o0000oookJ_oonfX0oooonf[Moook
JP004_oonfX3o`00O`[ooo]Z00?o0000oookJ_oonfX07?oonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01oooo]Z0_l0003ooookJYWooo]Z000CoookJP?o001o2OoonfX00ol0003ooo]Z
oookJP0KoookJP?o00008?oonfX2o`00023ooo]Z0ol0000PoookJP;o00008?oonfX2o`00023ooo]Z
0_l0003ooookJS?ooo]Z000=oookJP?o001o0ooonfX3o`00O`;ooo]Z0ol00004oookJP03o`000?oo
nf[ooo]Z01[ooo]Z1Ol0000NoookJPCo00007_oonfX4o`0001kooo]Z1?l0000NoookJPCo00007_oo
nfX4o`0001oooo]Z0_l0000PoookJP;o00008?oonfX2o`0001oooo]Z0_l0000PoookJP;o00007ooo
nfX2o`00023ooo]Z0_l0000PoookJP;o00009OoonfX000gooo]Z0ol007l3oookJP?o001o0_oonfX6
o`000003oookJ_l0003ooo]Z01[ooo]Z1ol0000LoookJPGo00007OoonfX6o`0001cooo]Z1Ol0000M
oookJPGo00007OoonfX5o`0001gooo]Z1?l0000NoookJPCo00007OoonfX5o`0001gooo]Z1?l0000M
oookJPGo00007OoonfX4o`0001kooo]Z1?l0000MoookJPGo00009OoonfX000gooo]Z1?l007l2oook
JP?o001o0_oonfX9o`0001cooo]Z1Ol0000NoookJPCo00007OoonfX5o`0001cooo]Z1_l0000Loook
JPKo00006ooonfX7o`0001_ooo]Z1Ol0000MoookJPGo00007?oonfX6o`0001cooo]Z1Ol0000Loook
JPKo00007?oonfX5o`0001gooo]Z1Ol0000LoookJPKo00009OoonfX000kooo]Z1ol007l3oookJP_o
00007?oonfX4o`0001kooo]Z1?l0000MoookJPCo00007OoonfX5o`0001gooo]Z1Ol0000LoookJPKo
00006ooonfX6o`0001cooo]Z1_l0000KoookJPOo00006ooonfX6o`0001_ooo]Z1ol0000KoookJPKo
00007?oonfX6o`0001_ooo]Z1ol0000ToookJP003ooonfX5o`00O`Cooo]Z2?l0000RoookJP;o0000
7_oonfX3o`0001kooo]Z1?l0000MoookJPCo00007_oonfX4o`0001gooo]Z1Ol0000LoookJPGo0000
7OoonfX5o`0001cooo]Z1_l0000LoookJPGo00007?oonfX6o`0001cooo]Z1Ol0000MoookJPGo0000
7?oonfX6o`0002Cooo]Z000HoookJP?o00001?oonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oo
nf[ooo]Z01gooo]Z0_l0000NoookJP?o00007_oonfX4o`0001kooo]Z0ol0000NoookJPCo00007Ooo
nfX4o`0001kooo]Z1?l0000MoookJPGo00007OoonfX4o`0001gooo]Z1Ol0000MoookJPCo00007_oo
nfX4o`0001gooo]Z1Ol0000ToookJP007ooonfX00ol0003ooo]ZoookJP13oookJP03o`000?oonf[o
oo]Z01gooo]Z0_l0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000NoookJP?o00007ooonfX3
o`0001kooo]Z1?l0000NoookJP?o00007_oonfX4o`0001kooo]Z0ol0000OoookJP?o00007_oonfX4
o`0002Cooo]Z000OoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX07OoonfX2o`00
01oooo]Z0_l0000OoookJP?o00007ooonfX3o`0001gooo]Z0ol0000OoookJP?o00007ooonfX3o`00
01kooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o00009?oonfX001oo
oo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0NoookJP;o00007ooonfX2o`00023o
oo]Z0_l0000NoookJP?o00007ooonfX3o`0001oooo]Z0ol0000NoookJP?o00007ooonfX3o`0001ko
oo]Z0ol0000OoookJP?o00007ooonfX3o`0002?ooo]Z000OoookJP03o`000?oonf[ooo]Z08Oooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01gooo]Z
0_l0000PoookJP;o00008?oonfX2o`0001oooo]Z0_l0000PoookJP;o00007ooonfX2o`00023ooo]Z
0_l0000PoookJP;o00008ooonfX001oooo]Z00?o0000oookJ_oonfX0jooonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX3o`000?oooo]Z
o?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oo
nf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0
003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z
00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000O
oookJP03o`000?oonf[ooo]Z01gooo]Z0_l0003ooookJ]gooo]Z000OoookJP03o`000?oonf[ooo]Z
01cooo]Z0ol0003ooookJ]gooo]Z000OoookJP03o`000?oonf[ooo]Z01_ooo]Z1Ol0000PoookJP;o
0000oooonfZjoookJP006?oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX06_oonfX6o`0001kooo]Z
1?l0000QoookJP;o0000oooonfY`oookJP;o00009OoonfX001Sooo]Z2Ol0000MoookJPGo00007?oo
nfX5o`0001kooo]Z1Ol0000PoookJP;o00007ooonfX2o`0006?ooo]Z0_l0000PoookJP;o00007ooo
nfX2o`00023ooo]Z0_l0000OoookJP;o00007ooonfX3o`0001gooo]Z1?l0000UoookJP006?oonfX;
o`0001cooo]Z1?l0000LoookJPKo00007?oonfX6o`0001gooo]Z1Ol0000MoookJPCo00007ooonfX3
o`0001kooo]Z0ol0000MoookJPGo00007OoonfX5o`0001cooo]Z1Ol0000MoookJPGo00007?oonfX5
o`0001cooo]Z1_l0000LoookJPGo00009OoonfX001Sooo]Z2?l0000PoookJP?o00007OoonfX5o`00
01cooo]Z1_l0000LoookJPKo00007?oonfX5o`0001cooo]Z1_l0000LoookJPGo00007?oonfX6o`00
01cooo]Z1_l0000KoookJPKo00007?oonfX6o`0001_ooo]Z1_l0000LoookJPKo00007?oonfX5o`00
02Gooo]Z000HoookJPGo00000_oonfX00ol0003ooo]ZoookJP0PoookJP;o00007OoonfX4o`0001go
oo]Z1Ol0000LoookJPKo00007?oonfX5o`0001cooo]Z1_l0000LoookJPGo00007?oonfX6o`0001co
oo]Z1_l0000KoookJPKo00007?oonfX6o`0001_ooo]Z1_l0000MoookJPGo00007OoonfX5o`0002Co
oo]Z000HoookJP;o00001OoonfX00ol0003ooo]ZoookJP0QoookJP03o`000?oonf[ooo]Z01cooo]Z
1?l0000MoookJPCo00007OoonfX5o`0001gooo]Z1?l0000MoookJPGo00007OoonfX4o`0001gooo]Z
1Ol0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000LoookJPGo00007_oonfX4o`0001kooo]Z
1?l0000ToookJP007ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000NoookJPCo00007OoonfX4o`0001gooo]Z1?l0000NoookJPCo00007OoonfX4o`0001kooo]Z1?l0
000NoookJPCo00007OoonfX4o`0001kooo]Z1?l0000MoookJPCo00007_oonfX4o`0001kooo]Z1?l0
000ToookJP007ooonfX00ol0003ooo]ZoookJP12oookJP;o00007_oonfX4o`0001kooo]Z1?l0000M
oookJPCo00007OoonfX4o`0001kooo]Z0ol0000NoookJPGo00007OoonfX5o`0001gooo]Z1?l0000N
oookJPCo00007OoonfX4o`0001kooo]Z1?l0000NoookJP?o00009?oonfX001oooo]Z00?o0000oook
J_oonfX0@ooonfX2o`0001kooo]Z0ol0000NoookJPCo00007_oonfX3o`0001kooo]Z1?l0000Noook
JP?o00007_oonfX4o`0001kooo]Z1?l0000MoookJPCo00007_oonfX4o`0001gooo]Z1?l0000Ooook
JP?o00007ooonfX2o`0002Cooo]Z000OoookJP?o0000A?oonfX00ol0003ooo]ZoookJP0MoookJP;o
00007ooonfX3o`0001kooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o
00007_oonfX3o`0001oooo]Z0ol0000NoookJP?o00007ooonfX3o`0001oooo]Z0ol0000SoookJP00
7ooonfX00ol0003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0000OoookJP;o0000
7ooonfX3o`0001oooo]Z0_l0000OoookJP?o00007ooonfX3o`0001oooo]Z0_l0000PoookJP;o0000
7ooonfX2o`00023ooo]Z0_l0000PoookJP;o00008ooonfX001oooo]Z00?o0000oookJ_oonfX0Qooo
nfX00ol0003ooo]ZoookJP0MoookJP;o00008?oonfX2o`0001oooo]Z0_l0000PoookJP;o00008?oo
nfX2o`00023ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX0
0ol0003ooo]ZoookJP2XoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0bOoonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z
0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]Z
oookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000
oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03
o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_co
oo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooo
nf[loookJP007ooonfX3o`0001kooo]Z0_l0003ooookJ]cooo]Z000HoookJP?o00001?oonfX00ol0
003ooo]ZoookJP0LoookJPCo0000oooonfZeoookJP;o00009OoonfX001Sooo]Z1_l000000ooonf[o
0000oookJP0LoookJPKo0000oooonfYaoookJP;o00007ooonfX2o`0001gooo]Z1Ol0000UoookJP00
6?oonfX9o`0001gooo]Z1Ol0000OoookJP?o0000oooonfX<oookJP;o00008?oonfX2o`0001cooo]Z
1Ol0000MoookJPCo00007?oonfX6o`0002Gooo]Z000HoookJP_o00007?oonfX4o`0001gooo]Z1Ol0
000OoookJP04o`000?oonf[o0000o`0001gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0NoookJPCo00007OoonfX4o`0001gooo]Z1Ol0000KoookJPKo00007?oonfX5o`0001cooo]Z
1ol0000ToookJP006?oonfX8o`00023ooo]Z1?l0000LoookJPGo00007_oonfX5o`0001gooo]Z00Co
0000oookJ_l0003o00007_oonfX00ol0003ooo]ZoookJP0OoookJP04o`000?oonf[o0000o`0001go
oo]Z1?l0000NoookJP?o00007?oonfX6o`0001cooo]Z1Ol0000LoookJPKo00006ooonfX6o`0001co
oo]Z1_l0000LoookJPKo00009?oonfX001Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01oooo]Z
0ol0000MoookJPGo00007?oonfX6o`0001gooo]Z1?l0000NoookJPCo00007OoonfX5o`0001_ooo]Z
1_l0000LoookJPGo00007?oonfX6o`0001cooo]Z1Ol0000LoookJPKo00007?oonfX5o`0001gooo]Z
1Ol0000MoookJPGo00009?oonfX001oooo]Z00?o0000oookJ_oonfX08?oonfX2o`0001kooo]Z1?l0
000LoookJPKo00007?oonfX5o`0001cooo]Z1_l0000LoookJPKo00006ooonfX6o`0001cooo]Z1Ol0
000MoookJPGo00007OoonfX4o`0001gooo]Z1Ol0000MoookJPCo00007_oonfX4o`0001kooo]Z1?l0
000ToookJP007ooonfX00ol0003ooo]ZoookJP0QoookJP;o00007OoonfX4o`0001gooo]Z1Ol0000L
oookJPGo00007?oonfX6o`0001cooo]Z1_l0000LoookJPGo00007OoonfX4o`0001kooo]Z1?l0000M
oookJPCo00007_oonfX4o`0001kooo]Z1?l0000NoookJP?o00007ooonfX3o`0002Cooo]Z000Ooook
JP03o`000?oonf[ooo]Z02;ooo]Z00?o0000oookJ_oonfX07?oonfX3o`0001gooo]Z1Ol0000Moook
JPCo00007OoonfX5o`0001gooo]Z1Ol0000LoookJPGo00007OoonfX4o`0001kooo]Z1?l0000Noook
JPCo00007_oonfX4o`0001gooo]Z1?l0000NoookJP?o00008?oonfX3o`0002?ooo]Z000OoookJP03
o`000?oonf[ooo]Z04;ooo]Z0_l0000NoookJPCo00007_oonfX3o`0001gooo]Z1Ol0000MoookJPGo
00007OoonfX4o`0001kooo]Z0ol0000OoookJPCo00007_oonfX3o`0001kooo]Z1?l0000NoookJP?o
00007ooonfX3o`00023ooo]Z0_l0000SoookJP007ooonfX00ol0003ooo]ZoookJP12oookJP?o0000
7_oonfX3o`0001kooo]Z1?l0000MoookJPCo00007_oonfX4o`0001kooo]Z0ol0000OoookJP?o0000
7ooonfX3o`0001kooo]Z0ol0000OoookJP?o00007ooonfX2o`00023ooo]Z0_l0000QoookJP03o`00
0?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000NoookJP?o00007ooo
nfX3o`0001kooo]Z0ol0000OoookJP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP?o00007ooo
nfX2o`00023ooo]Z0_l0000PoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0@ooo
nfX001oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0MoookJP;o00007ooonfX3
o`0001kooo]Z0ol0000OoookJP?o00007ooonfX2o`00023ooo]Z0_l0000PoookJP;o00007ooonfX2
o`00027ooo]Z00?o0000oookJ_oonfX0Q_oonfX001oooo]Z00?o0000oookJ_oonfX0I?oonfX2o`00
023ooo]Z0_l0000OoookJP;o00008?oonfX2o`0001oooo]Z0_l0000PoookJP;o00008OoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z0:Sooo]Z000OoookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJP;o00008?oonfX2o`00023o
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3[oookJP007ooonfX00ol0003ooo]Z
oookJP2XoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0oooonfX_oookJP007ooo
nfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
01oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP004_oonfX3o`00O`[ooo]Z00?o0000oookJ_oo
nfX0oooonf[loookJP004_oonfX3o`00O`[ooo]Z00?o0000oookJ_oonfX0oooonf[loookJP004_oo
nfX3o`00O`[ooo]Z00?o0000oookJ_oonfX0oooonf[loookJP003OoonfX9o`00O`Wooo]Z00?o0000
oookJ_oonfX0oooonf[loookJP003OoonfX9o`00O`Wooo]Z1?l0003ooookJ__ooo]Z000=oookJP;o
001o0ooonfX3o`00O`[ooo]Z00?o0000oookJ_oonfX0oooonf[loookJP003_oonfX2o`00O`;ooo]Z
0ol007l:oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX000kooo]Z0ol007l01?oonf[o001oo`00
Ool007l:oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX000oooo]Z0_l007l01?oonf[o001oo`00
Ool007l:oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0013ooo]Z1Ol007l:oookJP03o`000?oo
nf[ooo]Z0?oooo]Zo?oonfX0013ooo]Z1Ol007l:oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX0
017ooo]Z1?l007l:oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001;ooo]Z0ol007l:oookJP03
o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfZboookJP;o0000
7ooonfX2o`0002Oooo]Z000OoookJP03o`000?oonf[ooo]Z01oooo]Z0_l0003ooookJW3ooo]Z0_l0
000NoookJP?o00007OoonfX4o`0002Oooo]Z000HoookJPCo00000ooonfX00ol0003ooo]ZoookJP0L
oookJPGo0000oooonfY?oookJP;o00007OoonfX4o`0001gooo]Z1?l0000LoookJPKo00009_oonfX0
01Sooo]Z2Ol0000LoookJPKo0000oooonfX^oookJP;o00007OoonfX4o`0001cooo]Z1Ol0000Loook
JPKo00007OoonfX4o`0002Kooo]Z000HoookJP_o00006_oonfX7o`0001kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07_oonfX01?l0003ooo]Zo`000?l0000LoookJPGo00007?oonfX5o`0001cooo]Z1_l0000Loook
JPGo00007_oonfX4o`0002Gooo]Z000HoookJPSo00007_oonfX6o`0001kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07OoonfX5o`0001_ooo]Z1_l0000LoookJPKo00007?oonfX5o`0001gooo]Z1?l0000OoookJP?o
00009OoonfX001Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z01gooo]Z1Ol0000OoookJP?o0000
7_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z1?l0000KoookJPKo0000
6ooonfX6o`0001gooo]Z1Ol0000MoookJPCo00007_oonfX4o`0001oooo]Z0_l0000UoookJP006?oo
nfX2o`0000Gooo]Z00?o0000oookJ_oonfX07_oonfX4o`0001cooo]Z1_l0000OoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01kooo]Z0ol0000LoookJPKo00006ooonfX6o`0001cooo]Z1Ol0000NoookJPCo00007_oo
nfX3o`0001oooo]Z0ol0000PoookJP;o00009?oonfX001oooo]Z00?o0000oookJ_oonfX07ooonfX3
o`0001cooo]Z1_l0000OoookJP?o00007_oonfX01?l0003ooo]Zo`000?l0000NoookJP?o00007ooo
nfX3o`0001_ooo]Z1_l0000LoookJPKo00007?oonfX5o`0001gooo]Z1?l0000OoookJP?o00007_oo
nfX3o`00023ooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03o`000?oonf[o
oo]Z023ooo]Z0ol0000LoookJPGo00007?oonfX6o`0001gooo]Z1Ol0000LoookJPGo00007?oonfX6
o`0001_ooo]Z1_l0000MoookJPGo00007OoonfX4o`0001kooo]Z1?l0000NoookJP?o00007ooonfX3
o`00023ooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[ooo]Z
027ooo]Z0_l0000MoookJPCo00007?oonfX6o`0001cooo]Z1_l0000LoookJPGo00007?oonfX6o`00
01cooo]Z1Ol0000MoookJPGo00007OoonfX5o`0001gooo]Z1?l0000OoookJP?o00007ooonfX2o`00
027ooo]Z00?o0000oookJ_oonfX0@ooonfX001oooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003o
oo]ZoookJP0KoookJPCo00007OoonfX5o`0001cooo]Z1_l0000MoookJPCo00007OoonfX5o`0001co
oo]Z1Ol0000NoookJPCo00007_oonfX4o`0001kooo]Z0ol0000PoookJP;o00008?oonfX00ol0003o
oo]ZoookJP1UoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPCo00007?oonfX5o`0001gooo]Z
1Ol0000MoookJPCo00007OoonfX5o`0001gooo]Z1?l0000OoookJP?o00007ooonfX3o`0001oooo]Z
0_l0000QoookJP03o`000?oonf[ooo]Z08Kooo]Z000OoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0
000MoookJPCo00007OoonfX5o`0001gooo]Z1?l0000NoookJPCo00007_oonfX3o`0001oooo]Z0ol0
000OoookJP?o00008?oonfX00ol0003ooo]ZoookJP2XoookJP007ooonfX3o`0004;ooo]Z0ol0000N
oookJP?o00007_oonfX4o`0001kooo]Z0ol0000OoookJP?o00007_oonfX3o`00023ooo]Z0_l0000P
oookJP;o0000booonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001kooo]Z0ol0000Ooook
JP?o00007_oonfX3o`0001oooo]Z0ol0000OoookJP;o00008?oonfX2o`00027ooo]Z00?o0000oook
J_oonfX0bOoonfX001oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0MoookJP;o
00007ooonfX3o`0001oooo]Z0_l0000PoookJP;o00007ooonfX2o`00027ooo]Z00?o0000oookJ_oo
nfX0jooonfX001oooo]Z00?o0000oookJ_oonfX0I?oonfX2o`00023ooo]Z0_l0000OoookJP;o0000
8?oonfX2o`00023ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP007ooonfX00ol0003ooo]Zoook
JP1UoookJP03o`000?oonf[ooo]Z01kooo]Z0_l0000OoookJP;o00008OoonfX00ol0003ooo]Zoook
JP3ooookJRoooo]Z000OoookJP03o`000?oonf[ooo]Z08Oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP3ooookJU7ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[l
oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oo
oo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oook
J_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`00
0?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfY^oookJP;o00007ooo
nfX00ol0003ooo]ZoookJP0LoookJP;o0000C?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfY]
oookJP?o00007_oonfX2o`0001kooo]Z0ol0001;oookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JTkooo]Z0_l0000LoookJPGo00007?oonfX4o`0001cooo]Z1Ol0000LoookJP?o0000:ooonfX001So
oo]Z1?l00003oookJP03o`000?oonf[ooo]Z023ooo]Z0_l0003ooookJR[ooo]Z1?l0000KoookJPKo
00006ooonfX6o`0001_ooo]Z1_l0000KoookJPKo0000:?oonfX001Sooo]Z2Ol0000NoookJPGo0000
oooonfX:oookJP?o00007?oonfX5o`0001gooo]Z1?l0000MoookJPCo00006_oonfX8o`0001[ooo]Z
2Ol0000UoookJP006?oonfX;o`0001_ooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01cooo]Z1Ol0
000LoookJPKo00007OoonfX4o`0001gooo]Z1?l0000LoookJPKo00006?oonfX<o`0002?ooo]Z000H
oookJPSo00007_oonfX6o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000LoookJPGo00007OoonfX5o`0001kooo]Z0ol0000O
oookJP;o00007ooonfX4o`0001Oooo]Z2?l0000WoookJP006?oonfX3o`0000Cooo]Z00?o0000oook
J_oonfX07OoonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JP04o`000?oonf[o0000o`0001cooo]Z1Ol0000MoookJPGo00007OoonfX4o`0001oooo]Z0ol0000P
oookJP03o`000?oonf[ooo]Z01oooo]Z0_l0000FoookJP?o0000;?oonfX001oooo]Z00?o0000oook
J_oonfX07_oonfX4o`0001oooo]Z00Co0000oookJ_l0003o00007OoonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0L
oookJPGo00007?oonfX5o`0001kooo]Z1?l0000NoookJP?o00008?oonfX2o`00027ooo]Z00?o0000
oookJ_oonfX0IOoonfX001oooo]Z00?o0000oookJ_oonfX07ooonfX4o`0001gooo]Z1Ol0000Noook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Ooook
JP?o00006ooonfX6o`0001gooo]Z1?l0000NoookJPCo00007_oonfX3o`00027ooo]Z00?o0000oook
J_oonfX0QooonfX001oooo]Z00?o0000oookJ_oonfX07ooonfX4o`0001cooo]Z1_l0000NoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPKo
00006ooonfX6o`0001gooo]Z1?l0000OoookJP?o00007ooonfX3o`00027ooo]Z00?o0000oookJ_oo
nfX0Q_oonfX001oooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001cooo]Z1_l0000NoookJPCo0000
7OoonfX4o`0001kooo]Z1?l0000KoookJPKo00007?oonfX5o`0001kooo]Z0ol0000PoookJP;o0000
8?oonfX2o`000:[ooo]Z000OoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0000MoookJPGo00007?oo
nfX6o`0001_ooo]Z1_l0000LoookJPKo00007?oonfX5o`0001cooo]Z1Ol0000OoookJP?o00007ooo
nfX3o`00023ooo]Z00?o0000oookJ_oonfX0Z?oonfX001oooo]Z00?o0000oookJ_oonfX08_oonfX0
0ol0003ooo]ZoookJP0KoookJPGo00007?oonfX6o`0001_ooo]Z1_l0000LoookJPKo00007?oonfX5
o`0001gooo]Z1?l0000OoookJP?o00008?oonfX2o`000<_ooo]Z000OoookJP03o`000?oonf[ooo]Z
047ooo]Z1?l0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000MoookJPCo00007_oonfX3o`00
023ooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z0<Wooo]Z000OoookJP03o`000?oonf[ooo]Z04;o
oo]Z0ol0000MoookJPGo00007?oonfX5o`0001gooo]Z1Ol0000MoookJPCo00007_oonfX3o`00023o
oo]Z0_l0003]oookJP007ooonfX00ol0003ooo]ZoookJP12oookJP?o00007_oonfX4o`0001gooo]Z
1?l0000NoookJPCo00007_oonfX3o`0001oooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z0>_ooo]Z
000OoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000NoookJP?o00007_oonfX4o`0001kooo]Z0ol0
000OoookJP?o00007ooonfX2o`000?oooo]Z4?oonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2
o`0001kooo]Z0ol0000OoookJP?o00007_oonfX3o`00023ooo]Z0_l0000PoookJP03o`000?oonf[o
oo]Z0?oooo]Z3_oonfX001oooo]Z00?o0000oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0Moook
JP;o00007ooonfX3o`0001oooo]Z0_l0000PoookJP;o0000oooonfXaoookJP007ooonfX00ol0003o
oo]ZoookJP1ToookJP;o00008?oonfX2o`0001oooo]Z0_l0000QoookJP03o`000?oonf[ooo]Z0?oo
oo]Z;ooonfX001oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP0NoookJP;o0000
8?oonfX00ol0003ooo]ZoookJP3ooookJU7ooo]Z000OoookJP03o`000?oonf[ooo]Z08Oooo]Z00?o
0000oookJ_oonfX0oooonfYboookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000Ooook
JP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP00
7ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oo
nfX001oooo]Z0ol0003ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfY<
oookJP03o`000?oonf[ooo]Z08Sooo]Z0_l0000SoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JTcooo]Z00?o0000oookJ_oonfX06ooonfX2o`0006[ooo]Z0ol0000SoookJP007ooonfX00ol0003o
oo]ZoookJP3ooookJRcooo]Z0_l0000MoookJP?o00007?oonfX3o`0004Sooo]Z0_l0000NoookJP?o
00009?oonfX001Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z0?oooo]Z:_oonfX4o`0001cooo]Z
1?l0000LoookJPGo0000AOoonfX3o`0001gooo]Z1?l0000ToookJP006?oonfX6o`000003oookJ_l0
003ooo]Z0?oooo]Z:_oonfX5o`0001_ooo]Z1_l0000JoookJPOo00007ooonfX6o`0001gooo]Z1?l0
000MoookJPGo00009?oonfX001Sooo]Z2Ol0000QoookJP;o0000j?oonfX3o`0001_ooo]Z1_l0000L
oookJPGo00006OoonfX9o`0001Sooo]Z2Ol0000NoookJPGo00007?oonfX5o`0002Gooo]Z000Hoook
JP_o00007?oonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01cooo]Z1_l0000LoookJPGo00007OoonfX4o`0001Wooo]Z2_l0000Goook
JPSo00007OoonfX6o`0001cooo]Z1_l0000UoookJP006?oonfX8o`0001kooo]Z1_l0000NoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0LoookJPKo
00007OoonfX4o`0001oooo]Z0ol0000NoookJPGo00005ooonfX6o`0001gooo]Z1_l0000LoookJPKo
00009_oonfX001Sooo]Z0ol00004oookJP03o`000?oonf[ooo]Z01cooo]Z1_l0000NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX4o`0001cooo]Z1Ol0000NoookJPCo0000
8?oonfX00ol0003ooo]ZoookJP0hoookJPCo00007_oonfX7o`0001kooo]Z1?l0000VoookJP007ooo
nfX00ol0003ooo]ZoookJP0MoookJPGo00007ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01_ooo]Z1_l0000MoookJPCo00007ooonfX3o`00027ooo]Z00?o0000oookJ_oonfX0=ooo
nfX3o`00027ooo]Z1?l0000PoookJP?o00009_oonfX001oooo]Z00?o0000oookJ_oonfX07_oonfX4
o`0001oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0KoookJPKo00007OoonfX4
o`00023ooo]Z0_l0001LoookJP03o`000?oonf[ooo]Z027ooo]Z0ol0000QoookJP03o`000?oonf[o
oo]Z02Gooo]Z000OoookJP03o`000?oonf[ooo]Z01kooo]Z1Ol0000NoookJPCo00007_oonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX3o`00
01cooo]Z1Ol0000NoookJPCo00008?oonfX2o`00083ooo]Z00?o0000oookJ_oonfX0B?oonfX001oo
oo]Z00?o0000oookJ_oonfX07ooonfX4o`0001cooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPKo00007?oonfX5o`0001oo
oo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0<Wooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z
0ol0000LoookJPKo00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z
1?l0000KoookJPKo00007OoonfX4o`0001oooo]Z0ol0003]oookJP007ooonfX00ol0003ooo]Zoook
JP0PoookJP?o00007OoonfX5o`0001kooo]Z1?l0000NoookJP?o00007?oonfX6o`0001cooo]Z1Ol0
000NoookJP?o00008?oonfX2o`000>gooo]Z000?oookJPGo001o2ooonfX00ol0003ooo]ZoookJP0Q
oookJP;o00007OoonfX5o`0001cooo]Z1_l0000KoookJPKo00007?oonfX6o`0001cooo]Z1Ol0000N
oookJP?o00008OoonfX00ol0003ooo]ZoookJP3[oookJP003_oonfX7o`00O`[ooo]Z00?o0000oook
J_oonfX08_oonfX00ol0003ooo]ZoookJP0LoookJPCo00007?oonfX6o`0001_ooo]Z1_l0000Moook
JPGo00007OoonfX4o`0001oooo]Z0_l0003ooookJQ3ooo]Z000>oookJP?o001o0_oonfX3o`00O`Wo
oo]Z00?o0000oookJ_oonfX0@OoonfX4o`0001gooo]Z1Ol0000LoookJPGo00007OoonfX5o`0001ko
oo]Z0ol0000OoookJP;o0000oooonfX@oookJP003OoonfX3o`00O`?ooo]Z0ol007l9oookJP03o`00
0?oonf[ooo]Z04;ooo]Z0ol0000MoookJPGo00007?oonfX5o`0001kooo]Z1?l0000NoookJP?o0000
8?oonfX00ol0003ooo]ZoookJP3ooookJPkooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z1?l0
0011oookJP?o00007_oonfX4o`0001gooo]Z1?l0000NoookJP?o00008?oonfX2o`000?oooo]Z<Ooo
nfX000gooo]Z1?l007l2oookJP?o001o2OoonfX00ol0003ooo]ZoookJP13oookJP;o00007_oonfX3
o`0001oooo]Z0ol0000NoookJP?o00008?oonfX2o`000?oooo]Z<OoonfX000gooo]Z2?l007l:oook
JP03o`000?oonf[ooo]Z04?ooo]Z0_l0000NoookJP?o00007ooonfX3o`0001oooo]Z0_l0000Qoook
JP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX000gooo]Z0ol007l01?oonf[o001oo`00Ool007l;oook
JP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX07OoonfX2o`00023ooo]Z0_l0000Ooook
JP;o0000oooonfYCoookJP003OoonfX3o`00O`oooo]Z00?o0000oookJ_oonfX0I?oonfX2o`00023o
oo]Z0_l0000PoookJP03o`000?oonf[ooo]Z0?oooo]ZDOoonfX000gooo]Z0ol007l?oookJP03o`00
0?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3ooookJW;ooo]Z
000>oookJP?o001o0_oonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX0oooonf[loookJP003_oonfX7
o`00O`[ooo]Z00?o0000oookJ_oonfX0oooonf[loookJP004?oonfX4o`00O`_ooo]Z00?o0000oook
J_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ]Sooo]Z00?o0000oookJ_oo
nfX08OoonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[HoookJP03o`000?oonf[ooo]Z027ooo]Z
000OoookJP03o`000?oonf[ooo]Z0?oooo]Z]_oonfX00ol0003ooo]ZoookJP0NoookJP;o00008ooo
nfX001oooo]Z00?o0000oookJ_oonfX0oooonfZfoookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000S
oookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ[Gooo]Z0_l0000OoookJP?o00008ooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfZDoookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000NoookJPCo
00008ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfXZoookJP03o`000?oonf[ooo]Z06Oooo]Z
00?o0000oookJ_oonfX07OoonfX3o`0001gooo]Z1?l0000ToookJP007ooonfX00ol0003ooo]Zoook
JP3ooookJRWooo]Z0_l0001XoookJP;o00007_oonfX4o`0001gooo]Z1?l0000ToookJP007ooonfX0
0ol0003ooo]ZoookJP3ooookJP_ooo]Z0_l0000KoookJPCo0000A_oonfX2o`0001kooo]Z0_l0000N
oookJPCo00007OoonfX5o`0002Cooo]Z000HoookJPCo00000ooonfX00ol0003ooo]ZoookJP3ooook
JPWooo]Z1?l0000JoookJPKo00006_oonfX4o`0002Gooo]Z1?l0000MoookJP?o00007_oonfX4o`00
01cooo]Z1_l0000ToookJP006?oonfX9o`000?oooo]Z2OoonfX5o`0001cooo]Z1?l0000JoookJPWo
00007_oonfX5o`0001gooo]Z1?l0000MoookJPGo00007ooonfX3o`0002Cooo]Z000HoookJP_o0000
7_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0LoookJPKo00007?oonfX4o`0001Wooo]Z2ol0000KoookJPKo0000
7?oonfX5o`0001cooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z02Gooo]Z000HoookJPSo00008Ooo
nfX01?l0003ooo]Zo`000?l0000MoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7_oonfX01?l0003ooo]Zo`000?l0000LoookJPGo00007_oonfX3o`0001Sooo]Z2?l0000LoookJPOo
00007?oonfX6o`00023ooo]Z0_l00016oookJP006?oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX0
7_oonfX5o`0001gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo0000
7OoonfX4o`0001oooo]Z0_l0000HoookJPGo00007_oonfX7o`0001oooo]Z0ol0001YoookJP006?oo
nfX2o`0000Gooo]Z0ol0000MoookJPKo00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oo
nf[ooo]Z01_ooo]Z1_l0000NoookJP?o00008OoonfX00ol0003ooo]ZoookJP0EoookJP;o00008_oo
nfX6o`00023ooo]Z0_l0001YoookJP007ooonfX00ol0003ooo]ZoookJP0MoookJPKo00007_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01_ooo]Z1_l0000NoookJP?o00008_oonfX0
0ol0003ooo]ZoookJP0ioookJPCo00008_oonfX00ol0003ooo]ZoookJP1WoookJP007ooonfX00ol0
003ooo]ZoookJP0NoookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP?o00007?oonfX5o`00
01oooo]Z0ol0001NoookJP?o0000S?oonfX001oooo]Z00?o0000oookJ_oonfX07_oonfX5o`0001ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX07?oonfX6o`0001gooo]Z1?l0000PoookJP;o0000GooonfX00ol0003o
oo]ZoookJP2;oookJP007ooonfX00ol0003ooo]ZoookJP0OoookJPCo00007_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0LoookJPKo00007OoonfX4o`00027ooo]Z00?o0000oookJ_oonfX0jooonfX001oooo]Z00?o
0000oookJ_oonfX08?oonfX3o`0001oooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo00007_oonfX3o`000?oooo]Z4?oo
nfX001oooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001cooo]Z1_l0000NoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX4o`0001cooo]Z1Ol0000NoookJP?o0000oooonfX@
oookJP007ooonfX00ol0003ooo]ZoookJP0QoookJP;o00007?oonfX6o`0001kooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPKo00007OoonfX4o`0001oooo]Z0_l0003ooook
JQ3ooo]Z000OoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0000MoookJPGo00007ooonfX3o`0001ko
oo]Z1?l0000KoookJPKo00007_oonfX3o`00023ooo]Z00?o0000oookJ_oonfX0oooonfX>oookJP00
7ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01_ooo]Z1Ol0000LoookJPKo0000
7?oonfX6o`0001cooo]Z1Ol0000NoookJP?o0000oooonfXaoookJP007ooonfX00ol0003ooo]Zoook
JP11oookJPCo00007?oonfX6o`0001cooo]Z1_l0000LoookJPGo00007ooonfX2o`000?oooo]Z<Ooo
nfX001oooo]Z00?o0000oookJ_oonfX0@OoonfX4o`0001gooo]Z1Ol0000MoookJPGo00007OoonfX4
o`0001oooo]Z0_l0003ooookJS7ooo]Z000OoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000Moook
JPGo00007OoonfX5o`0001gooo]Z0ol0000QoookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX001oo
oo]Z00?o0000oookJ_oonfX0@_oonfX3o`0001kooo]Z1?l0000NoookJPCo00007OoonfX3o`000?oo
oo]ZDooonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001kooo]Z0ol0000OoookJP?o0000
7ooonfX2o`000?oooo]Z;ooonfX00ol0003ooo]ZoookJP0QoookJP007ooonfX00ol0003ooo]Zoook
JP13oookJP;o00007_oonfX3o`0001oooo]Z0ol0000OoookJP;o0000oooonfX_oookJP03o`000?oo
nf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX07OoonfX2
o`00023ooo]Z0_l0000PoookJP03o`000?oonf[ooo]Z0?oooo]Z2ooonfX00ol0003ooo]ZoookJP0N
oookJP;o00008ooonfX001oooo]Z00?o0000oookJ_oonfX0I?oonfX2o`00023ooo]Z0_l0003ooook
JRkooo]Z00?o0000oookJ_oonfX07_oonfX2o`0002?ooo]Z000OoookJP03o`000?oonf[ooo]Z06Go
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP3ooookJR_ooo]Z0_l0000OoookJP?o
00008ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfZDoookJP03o`000?oonf[ooo]Z01kooo]Z
0_l0000NoookJPCo00008ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfZDoookJP03o`000?oo
nf[ooo]Z01gooo]Z0ol0000NoookJPCo00008ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfZC
oookJP;o00007_oonfX4o`0001gooo]Z1Ol0000SoookJP007ooonfX00ol0003ooo]ZoookJP3ooook
JW?ooo]Z00?o0000oookJ_oonfX07OoonfX2o`0001kooo]Z1?l0000MoookJPGo00008ooonfX001oo
oo]Z00?o0000oookJ_oonfX0oooonfYcoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000MoookJPGo
00007?oonfX6o`0002?ooo]Z000OoookJP?o0000oooonfYboookJP;o00007OoonfX4o`0001gooo]Z
1Ol0000OoookJP?o00008ooonfX001oooo]Z00?o0000oookJ_oonfX0oooonfYaoookJP;o00007_oo
nfX4o`0001cooo]Z1_l0000OoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[o
oo]Z0?oooo]Z2OoonfX2o`0004Gooo]Z0_l0000OoookJP;o00007OoonfX5o`0001oooo]Z0ol0000N
oookJP03o`000?oonf[ooo]Z02Cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z2?oonfX3o`00
04Cooo]Z0ol0000NoookJP?o00007OoonfX5o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0ToookJP006?oonfX3o`0000Cooo]Z00?o0000oookJ_oonfX0oooonfX7oookJPGo
0000@_oonfX3o`0001kooo]Z1?l0000LoookJPKo00007ooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z02Cooo]Z000HoookJPKo000000?ooo]Zo`000?oonfX0oooonfX7oookJPKo0000
6_oonfX6o`00027ooo]Z1?l0000NoookJPCo00007ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0ToookJP006?oonfX9o`000>_ooo]Z0_l0000KoookJPGo00006Ooo
nfX;o`0001_ooo]Z1Ol0000MoookJPCo00007ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09OoonfX001Sooo]Z2ol0000NoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo00007?oonfX4
o`0001Wooo]Z2Ol0000LoookJPGo00007OoonfX5o`0001oooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Gooo]Z000HoookJPSo00008OoonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07?oonfX6o`00
01gooo]Z0ol0000IoookJPKo00007_oonfX6o`00023ooo]Z0_l0002:oookJP006?oonfX3o`0000Co
oo]Z00?o0000oookJ_oonfX07ooonfX01?l0003ooo]Zo`000?l0000MoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07?oonfX6o`0001oooo]Z0_l0000HoookJPCo00007ooonfX6o`00
0:gooo]Z000OoookJP03o`000?oonf[ooo]Z01kooo]Z1Ol0000MoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z023o
oo]Z00?o0000oookJ_oonfX07?oonfX5o`00023ooo]Z00?o0000oookJ_oonfX05_oonfX00ol0003o
oo]ZoookJP0RoookJPCo0000[OoonfX001oooo]Z00?o0000oookJ_oonfX07OoonfX6o`0001kooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPGo00008OoonfX00ol0003ooo]Z
oookJP0koookJP?o0000[OoonfX001oooo]Z00?o0000oookJ_oonfX07OoonfX6o`0001kooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o
0000oookJ_oonfX07ooonfX3o`0001gooo]Z1?l0001PoookJP03o`000?oonf[ooo]Z0:cooo]Z000O
oookJP03o`000?oonf[ooo]Z01kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01cooo]Z1_l0000N
oookJP?o0000oooonfX@oookJP007ooonfX00ol0003ooo]ZoookJP0NoookJPGo00007_oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0LoookJPKo00007_oonfX3o`000?oooo]Z4?oonfX001oooo]Z00?o0000oookJ_oo
nfX07ooonfX4o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX5o`0001oooo]Z0_l0003ooookJQ3o
oo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJPCo00007?oonfX5o`0001oooo]Z
0_l0003ooookJQ3ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000OoookJP?o00007_oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01cooo]Z1_l0000MoookJPCo00008?oo
nfX00ol0003ooo]ZoookJP3ooookJPkooo]Z000OoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0000L
oookJPKo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01cooo]Z1_l0000N
oookJP?o0000oooonfX=oookJP03o`000?oonf[ooo]Z027ooo]Z000OoookJP03o`000?oonf[ooo]Z
027ooo]Z0_l0000LoookJPKo00007_oonfX00ol0003ooo]ZoookJP0OoookJPCo00007?oonfX5o`00
01kooo]Z0ol0003ooookJPgooo]Z00?o0000oookJ_oonfX08OoonfX001oooo]Z00?o0000oookJ_oo
nfX08_oonfX00ol0003ooo]ZoookJP0KoookJPGo00007ooonfX3o`0001cooo]Z1_l0000LoookJPGo
00007ooonfX2o`000>[ooo]Z00?o0000oookJ_oonfX07_oonfX2o`0002?ooo]Z000OoookJP03o`00
0?oonf[ooo]Z043ooo]Z1Ol0000LoookJPKo00007?oonfX6o`0001gooo]Z1?l0000OoookJP;o0000
j_oonfX00ol0003ooo]ZoookJP0NoookJP;o00008ooonfX001oooo]Z00?o0000oookJ_oonfX0@Ooo
nfX4o`0001cooo]Z1_l0000MoookJPGo00007OoonfX3o`00027ooo]Z00?o0000oookJ_oonfX0iooo
nfX2o`0001oooo]Z0ol0000SoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPCo00007OoonfX5
o`0001gooo]Z1Ol0000MoookJP?o0000j_oonfX00ol0003ooo]ZoookJP0NoookJP;o00007ooonfX3
o`0002?ooo]Z000OoookJP?o0000@_oonfX3o`0001gooo]Z1Ol0000MoookJPGo00007_oonfX2o`00
0>[ooo]Z00?o0000oookJ_oonfX07OoonfX3o`0001oooo]Z1?l0000RoookJP007ooonfX00ol0003o
oo]ZoookJP12oookJP?o00007OoonfX5o`0001kooo]Z0ol0000OoookJP;o0000jOoonfX2o`0001oo
oo]Z0ol0000NoookJPGo00008_oonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001kooo]Z
0ol0000OoookJP?o00008?oonfX00ol0003ooo]ZoookJP3WoookJP;o00007ooonfX4o`0001gooo]Z
1Ol0000RoookJP007ooonfX00ol0003ooo]ZoookJP13oookJP;o00007_oonfX3o`00023ooo]Z0_l0
003ZoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJPGo00007?oonfX6o`0002;ooo]Z000O
oookJP03o`000?oonf[ooo]Z04Cooo]Z00?o0000oookJ_oonfX07OoonfX2o`00023ooo]Z0_l0003Z
oookJP03o`000?oonf[ooo]Z01cooo]Z0ol0000NoookJPGo00007_oonfX01?l0003ooo]Zo`000?l0
000RoookJP007ooonfX00ol0003ooo]ZoookJP1ToookJP;o00008?oonfX2o`000>Wooo]Z0_l0000N
oookJPCo00007?oonfX6o`0001kooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oook
J_oonfX0I?oonfX2o`00027ooo]Z00?o0000oookJ_oonfX0iooonfX2o`0001gooo]Z1Ol0000Ooook
JP?o00007_oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP1UoookJP03
o`000?oonf[ooo]Z0>Sooo]Z00?o0000oookJ_oonfX07OoonfX3o`0001gooo]Z1Ol0000NoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0
oooonfYAoookJP03o`000?oonf[ooo]Z01cooo]Z1?l0000LoookJPKo00007_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]ZD?oo
nfX2o`0001kooo]Z1?l0000NoookJP04o`000?oonf[o0000o`0001kooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP3ooookJToooo]Z0ol0
000MoookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfX6oookJP;o0000AooonfX3
o`0001gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP3ooookJPKooo]Z0ol0000Voook
JP;o00007OoonfX4o`0001cooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP3ooookJPGo
oo]Z1Ol0000ToookJP?o00007OoonfX3o`0001oooo]Z00Co0000oookJ_l0003o00007_oonfX00ol0
003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09?oonfX001So
oo]Z1?l00003oookJP03o`000?oonf[ooo]Z0>Wooo]Z0_l0000IoookJPKo00008OoonfX4o`0001go
oo]Z1?l0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Gooo]Z000HoookJPWo0000iooonfX5o`0001Wooo]Z
1ol0000OoookJPGo00007?oonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09OoonfX001Sooo]Z2ol0
000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0KoookJPKo00006?oonfX9o`0001cooo]Z1_l0000OoookJP?o00007_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0UoookJP006?oonfX8o`00027ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01_ooo]Z1_l0000LoookJPKo00006_oonfX6o`0002;ooo]Z00?o0000
oookJ_oonfX0ZOoonfX001Sooo]Z1Ol00002oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01cooo]Z1Ol0000Qoook
JP;o00006?oonfX7o`000<kooo]Z000?oookJPGo001o1?oonfX2o`0000Gooo]Z00?o0000oookJ_oo
nfX08?oonfX00ol0003ooo]ZoookJP0MoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oo
nfX07?oonfX4o`0003gooo]Z1?l0003?oookJP003_oonfX7o`00O`[ooo]Z00?o0000oookJ_oonfX0
8?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000MoookJPCo0000
?OoonfX3o`000<oooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX08?oo
nfX3o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX5o`0001gooo]Z1?l0000noookJP03o`000?oo
nf[ooo]Z0<kooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX07OoonfX6
o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX07?oonfX6o`0001kooo]Z0ol0003ooookJQ3ooo]Z000=oook
JP?o001o0ooonfX3o`00O`Wooo]Z1?l0000LoookJPKo00007_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Loook
JPKo00007ooonfX2o`000>_ooo]Z00?o0000oookJ_oonfX08OoonfX000gooo]Z0ol007l3oookJP?o
001o2OoonfX00ol0003ooo]ZoookJP0NoookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo
00008?oonfX00ol0003ooo]ZoookJP3YoookJP03o`000?oonf[ooo]Z027ooo]Z000>oookJPOo001o
2_oonfX00ol0003ooo]ZoookJP0NoookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo0000
j_oonfX00ol0003ooo]ZoookJP0NoookJP;o00008ooonfX000kooo]Z1ol007l:oookJP03o`000?oo
nf[ooo]Z01oooo]Z1?l0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0NoookJPCo00007OoonfX4o`000>[ooo]Z00?o0000oookJ_oonfX07_oo
nfX2o`0002?ooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX08?oonfX3
o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01cooo]Z1_l0000NoookJP?o0000b?oonfX00ol0003ooo]ZoookJP0NoookJP;o00007ooonfX3
o`0002?ooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX08?oonfX3o`00
01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01cooo]Z1_l0000NoookJP?o0000b?oonfX00ol0003ooo]ZoookJP0NoookJP;o00007ooonfX3o`00
02?ooo]Z000=oookJP?o001o0ooonfX3o`00O`Wooo]Z00?o0000oookJ_oonfX08OoonfX2o`0001oo
oo]Z1?l0000MoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX5o`0001oo
oo]Z0_l00037oookJP;o00007ooonfX3o`0001oooo]Z1?l0000RoookJP003_oonfX7o`00O`[ooo]Z
00?o0000oookJ_oonfX08OoonfX2o`0001gooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX07OoonfX5o`0001oooo]Z0_l00037oookJP;o00007ooonfX3o`0001kooo]Z
1Ol0000RoookJP003ooonfX5o`00O`_ooo]Z00?o0000oookJ_oonfX08_oonfX00ol0003ooo]Zoook
JP0KoookJPKo00007_oonfX00ol0003ooo]ZoookJP0NoookJPCo00007?oonfX5o`00023ooo]Z00?o
0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0MoookJP;o00007ooonfX4o`0001gooo]Z1Ol0
000RoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo00007_oonfX3o`0001cooo]Z1_l0000M
oookJP?o0000bOoonfX00ol0003ooo]ZoookJP0LoookJP?o00007_oonfX5o`0001cooo]Z1_l0000R
oookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo00006ooonfX6o`0001cooo]Z1_l0000Moook
JP?o0000b?oonfX2o`0001kooo]Z1?l0000MoookJPGo00007ooonfX3o`0002;ooo]Z000OoookJP03
o`000?oonf[ooo]Z047ooo]Z1Ol0000KoookJPKo00007OoonfX5o`0001kooo]Z0_l00038oookJP;o
00007OoonfX5o`0001cooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`00
0?oonf[ooo]Z04;ooo]Z0ol0000MoookJPGo00007OoonfX5o`0001kooo]Z0_l00037oookJP?o0000
7OoonfX5o`0001oooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oo
nf[ooo]Z04;ooo]Z0ol0000MoookJPGo00007_oonfX4o`0001kooo]Z0_l0002WoookJP03o`000?oo
nf[ooo]Z01gooo]Z0ol0000MoookJPGo00007ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000MoookJPGo00007_oonfX3
o`00023ooo]Z00?o0000oookJ_oonfX0YOoonfX00ol0003ooo]ZoookJP0MoookJP?o00007?oonfX6
o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0
003ooo]ZoookJP13oookJP;o00007_oonfX3o`0001oooo]Z0ol00037oookJP;o00007_oonfX4o`00
01oooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX001oo
oo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001kooo]Z0ol0000PoookJP;o0000aooonfX2o`0001ko
oo]Z1?l0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP14oookJP03o`000?oonf[ooo]Z01gooo]Z
0_l0000PoookJP;o0000a_oonfX3o`0001gooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]Zoook
JP1ToookJP;o00008OoonfX00ol0003ooo]ZoookJP2UoookJP03o`000?oonf[ooo]Z01cooo]Z0ol0
000OoookJP?o00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0I?oonfX2o`000<Wooo]Z00?o0000
oookJ_oonfX07?oonfX3o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oook
J_oonfX0IOoonfX00ol0003ooo]ZoookJP36oookJP;o00007OoonfX4o`0001oooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oook
J_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfX^oookJP?o00007OoonfX4o`0001ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonfX^oookJP;o0000
7OoonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0j?oo
nfX2o`0004;ooo]Z0ol0000OoookJP?o00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJP006?oonfX3
o`0000Cooo]Z0ol0003UoookJPGo0000@OoonfX4o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0ToookJP006?oonfX6o`000003oookJ_l0003ooo]Z0>Gooo]Z1_l0000Qoook
JP?o00007OoonfX4o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Uoook
JP006?oonfX9o`000>Gooo]Z1ol0000MoookJPCo00007_oonfX5o`0001kooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0UoookJP006?oonfX;o`0001kooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01_ooo]Z1_l0000JoookJPKo0000
7_oonfX5o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0UoookJP006?oo
nfX8o`00027ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01cooo]Z1Ol0000HoookJPOo00008OoonfX3o`000<gooo]Z000HoookJP?o00001?oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0MoookJPCo00006?oonfX6o`0002Cooo]Z00?o0000oookJ_oonfX0booonfX0
01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
023ooo]Z0ol0000MoookJP?o00006OoonfX4o`000<oooo]Z00?o0000oookJ_oonfX08OoonfX001oo
oo]Z00?o0000oookJ_oonfX08?oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01co
oo]Z1_l0000NoookJP?o00006?oonfX3o`000:kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003o
oo]ZoookJP0QoookJP007ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX07?oonfX6o`0001oooo]Z0_l0000IoookJP03o`000?oonf[ooo]Z0:gooo]Z
00?o0000oookJ_oonfX07_oonfX2o`0002?ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0
000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01gooo]Z1Ol0000PoookJP03o`000?oonf[ooo]Z0:Gooo]Z00?o
0000oookJ_oonfX07_oonfX2o`00023ooo]Z0_l0000SoookJP007ooonfX00ol0003ooo]ZoookJP0M
oookJPKo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo0000b?oonfX00ol0003ooo]ZoookJP0N
oookJP;o00007ooonfX3o`0002?ooo]Z000OoookJP03o`000?oonf[ooo]Z01gooo]Z1_l0000Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01kooo]Z1?l00038oookJP03o`000?oonf[ooo]Z01gooo]Z0ol0000Ooook
JP?o00008ooonfX001oooo]Z00?o0000oookJ_oonfX07_oonfX5o`0001kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07ooonfX3o`000<Oooo]Z0ol0000NoookJP?o00007ooonfX4o`0002;ooo]Z000OoookJP03o`00
0?oonf[ooo]Z01kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0002WoookJP03o`00
0?oonf[ooo]Z01gooo]Z0ol0000NoookJPCo00007OoonfX5o`0002;ooo]Z000OoookJP03o`000?oo
nf[ooo]Z01oooo]Z1?l0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0LoookJPKo00007ooonfX2o`000:Oooo]Z00?o0000oookJ_oonfX07Ooo
nfX3o`0001gooo]Z1Ol0000MoookJPGo00008_oonfX001oooo]Z00?o0000oookJ_oonfX08?oonfX3
o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01cooo]Z1_l0000OoookJP;o0000Y_oonfX2o`0001kooo]Z1?l0000MoookJPGo00007?oonfX6
o`0002;ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo00008?oonfX00ol0
003ooo]ZoookJP2ToookJP;o00007_oonfX4o`0001cooo]Z1_l0000OoookJP?o00008_oonfX001oo
oo]Z00?o0000oookJ_oonfX08OoonfX2o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01gooo]Z1Ol0002VoookJP03o`000?oonf[ooo]Z01go
oo]Z0ol0000NoookJPGo00007_oonfX3o`0001oooo]Z00?o0000oookJ_oonfX08_oonfX001oooo]Z
00?o0000oookJ_oonfX08OoonfX2o`0001oooo]Z1?l0000NoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX07OoonfX5o`000:Kooo]Z00?o0000oookJ_oonfX07OoonfX3o`0001gooo]Z
1_l0000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o
0000oookJ_oonfX08_oonfX00ol0003ooo]ZoookJP0KoookJPKo00007_oonfX00ol0003ooo]Zoook
JP0NoookJPCo00007OoonfX4o`000:Gooo]Z0_l0000OoookJPCo00007?oonfX6o`0001kooo]Z00?o
0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP10
oookJPKo00007_oonfX00ol0003ooo]ZoookJP0LoookJPKo00007OoonfX3o`000:Kooo]Z0_l0000N
oookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0@OoonfX5o`0001kooo]Z0ol0000Loook
JPKo00007_oonfX2o`000:Kooo]Z0_l0000NoookJPGo00007_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oo
nfX0@OoonfX5o`0001_ooo]Z1_l0000MoookJPGo00007_oonfX2o`000:Gooo]Z0ol0000MoookJPKo
00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX08ooonfX001oooo]Z0ol00011oookJPGo00006ooonfX6o`0001gooo]Z1Ol0000NoookJP;o0000
YOoonfX4o`0001kooo]Z00Co0000oookJ_l0003o00007OoonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0
@_oonfX3o`0001gooo]Z1Ol0000NoookJPCo00007ooonfX00ol0003ooo]ZoookJP24oookJP03o`00
0?oonf[ooo]Z01_ooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oo
nf[ooo]Z04;ooo]Z0ol0000MoookJPGo00007_oonfX3o`000:Oooo]Z00?o0000oookJ_oonfX06ooo
nfX5o`0001kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2
o`0001gooo]Z1Ol0000NoookJP?o0000Y_oonfX2o`0001gooo]Z1Ol0000NoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[o
oo]Z02Cooo]Z000OoookJP03o`000?oonf[ooo]Z04?ooo]Z0_l0000NoookJP?o00008?oonfX2o`00
0:Kooo]Z0_l0000LoookJPKo00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003o
oo]ZoookJP13oookJP;o00007_oonfX3o`00023ooo]Z0_l0002UoookJP?o00007_oonfX01?l0003o
oo]Zo`000?l0000MoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z02Cooo]Z000OoookJP03o`000?oonf[ooo]Z04Co
oo]Z00?o0000oookJ_oonfX07OoonfX2o`00027ooo]Z00?o0000oookJ_oonfX0X_oonfX4o`0001ko
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oo
oo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]Z
oookJP1ToookJP;o0000a_oonfX4o`0001kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000P?oonfX00ol0003ooo]Zoook
JP0ToookJP03o`000?oonf[ooo]Z01_ooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1n
oookJP03o`000?oonf[ooo]Z02?ooo]Z0_l0000MoookJPGo00007_oonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0O
oookJP03o`000?oonf[ooo]Z02Cooo]Z000OoookJP03o`000?oonf[ooo]Z0>Gooo]Z0ol0000Soook
JP?o00007?oonfX6o`0001kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Uoook
JP006?oonfX4o`0000?ooo]Z00?o0000oookJ_oonfX0i?oonfX4o`0002;ooo]Z0ol0000OoookJP04
o`000?oonf[o0000o`0001gooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0Uoook
JP006?oonfX9o`000>Cooo]Z1_l0000PoookJPCo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX09OoonfX001Sooo]Z2ol0000NoookJP03o`00
0?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0KoookJPGo0000
7_oonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z02Gooo]Z000HoookJPSo00008OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07?oonfX4o`0001gooo]Z1Ol0002YoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08OoonfX001Sooo]Z1Ol00002oookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01kooo]Z0ol0000KoookJPKo0000QooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01oooo]Z00?o0000oookJ_oonfX08OoonfX001Sooo]Z0_l00005oookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0PoookJP?o00007ooonfX00ol0
003ooo]ZoookJP0KoookJPCo0000QooonfX00ol0003ooo]ZoookJP0NoookJP;o00008?oonfX2o`00
02?ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX07OoonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0MoookJPKo00008?oonfX00ol0003ooo]ZoookJP0KoookJP;o0000R?oonfX00ol0003o
oo]ZoookJP0NoookJP;o00008?oonfX2o`0002?ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPKo0000?ooonfX00ol0003ooo]Z
oookJP1UoookJP03o`000?oonf[ooo]Z01gooo]Z0_l0000PoookJP;o00007ooonfX3o`0002?ooo]Z
000OoookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Zoook
JP0MoookJPGo0000YooonfX00ol0003ooo]ZoookJP0MoookJP?o00007_oonfX3o`0001oooo]Z0ol0
000SoookJP007ooonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX07OoonfX5o`000:Kooo]Z0_l0000OoookJP?o00007_oonfX4o`0001kooo]Z1?l0000R
oookJP007ooonfX00ol0003ooo]ZoookJP0PoookJP?o00007_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JPCo0000Y_oonfX2o`0001kooo]Z1?l0000MoookJPGo00007OoonfX5o`0002;ooo]Z000OoookJP03
o`000?oonf[ooo]Z01kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0002VoookJP;o
00007_oonfX4o`0001gooo]Z1Ol0000MoookJPGo00008_oonfX001oooo]Z00?o0000oookJ_oonfX0
7_oonfX5o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX3o`0008Gooo]Z00?o0000oookJ_oonfX0
7OoonfX3o`0001kooo]Z1?l0000MoookJPGo00007?oonfX6o`0002;ooo]Z000OoookJP?o00007ooo
nfX4o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01kooo]Z1?l0000OoookJP;o0000QOoonfX00ol0003ooo]ZoookJP0MoookJPCo00007?oo
nfX6o`0001_ooo]Z1_l0000OoookJP?o00008_oonfX001oooo]Z00?o0000oookJ_oonfX07ooonfX4
o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z01cooo]Z1_l0000OoookJP;o0000Q?oonfX2o`0001kooo]Z1Ol0000LoookJPKo00007_oonfX0
0ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02;ooo]Z000OoookJP03o`000?oonf[ooo]Z
023ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0LoookJPKo00008?oonfX00ol0003ooo]ZoookJP22oookJP;o00007_oonfX5o`00
01kooo]Z00Co0000oookJ_l0003o00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[o
oo]Z02;ooo]Z000OoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0MoookJPGo0000YOoonfX2o`00
01kooo]Z1Ol0000NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0
003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP0PoookJP?o00007ooonfX00ol0003o
oo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX5o`000:Co
oo]Z0ol0000MoookJPKo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01ko
oo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX08OoonfX2o`0001oooo]Z
00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01gooo]Z
1Ol0002ToookJPCo00007ooonfX3o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z02?ooo]Z000OoookJP03o`000?oonf[ooo]Z027ooo]Z0_l0
000OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0NoookJP?o0000Q_oonfX00ol0003ooo]ZoookJP0KoookJPGo00007_oonfX00ol0003ooo]Zoook
JP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Zoook
JP0SoookJP007ooonfX00ol0003ooo]ZoookJP0RoookJP03o`000?oonf[ooo]Z01gooo]Z1?l0000N
oookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000MoookJP?o0000Q_oonfX00ol0003ooo]ZoookJP0K
oookJPGo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP10oook
JPKo00007_oonfX00ol0003ooo]ZoookJP0LoookJPKo00007_oonfX2o`0008Gooo]Z0_l0000Moook
JPGo00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX07ooonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP10oookJPKo
00007_oonfX00ol0003ooo]ZoookJP0LoookJPKo00007_oonfX2o`0008Gooo]Z0_l0000LoookJPKo
00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo0000
7_oonfX3o`0001gooo]Z1Ol0000NoookJP;o0000Q?oonfX3o`0001oooo]Z00?o0000oookJ_oonfX0
7_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX0
7ooonfX00ol0003ooo]ZoookJP0SoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo00007?oo
nfX5o`0001gooo]Z1Ol0000OoookJP03o`000?oonf[ooo]Z087ooo]Z1?l0000OoookJP03o`000?oo
nf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oo
nf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08ooonfX001oooo]Z00?o0000oookJ_oonfX0@OoonfX5
o`0001cooo]Z1Ol0000NoookJPCo0000XooonfX4o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX0
0ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX0
0ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP12oookJP?o00007OoonfX5o`00
01kooo]Z0ol0002SoookJPGo00007_oonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z
02Cooo]Z000OoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000NoookJPCo00007_oonfX3o`0008Go
oo]Z00?o0000oookJ_oonfX06ooonfX5o`0001kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003o
oo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP13oookJP;o00007_oonfX4o`0001oooo]Z
0_l00025oookJP03o`000?oonf[ooo]Z01[ooo]Z1_l0000NoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z
00?o0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001kooo]Z0ol0
000PoookJP;o0000Q?oonfX2o`0001oooo]Z0ol0000NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX09?oonfX001oooo]Z00?o0000oookJ_oonfX0@ooonfX2o`0001oooo]Z0_l0000Q
oookJP03o`000?oonf[ooo]Z087ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0ToookJP007ooonfX00ol0003ooo]ZoookJP14oook
JP03o`000?oonf[ooo]Z01gooo]Z0_l0002ToookJPCo00007_oonfX00ol0003ooo]ZoookJP0Ooook
JP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0Noook
JP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX09?oonfX000Oooo]Z0ol007l5oookJPGo
001o2ooonfX00ol0003ooo]ZoookJP1ToookJP;o0000Y?oonfX4o`0001kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oo
nfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z02Cooo]Z0007oookJP?o001o
1?oonfX7o`00O`[ooo]Z00?o0000oookJ_oonfX0IOoonfX00ol0003ooo]ZoookJP1joookJP;o0000
9OoonfX4o`0001oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`00
0?oonf[ooo]Z02Gooo]Z0007oookJP?o001o1?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z
1?l00003oookJP03o`000?oonf[ooo]Z06Gooo]Z00?o0000oookJ_oonfX0N_oonfX4o`0002;ooo]Z
1Ol0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0UoookJP001ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o0_oonfX9o`000>?ooo]Z1ol0
000NoookJPKo00007_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o
0000oookJ_oonfX09OoonfX000Oooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`;ooo]Z2ol0000N
oookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0G
oookJP[o00007_oonfX4o`0001kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0N
oookJP03o`000?oonf[ooo]Z02Gooo]Z0007oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l2oook
JPSo00008OoonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oook
J_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z0ol0000Goook
JP_o00008?oonfX00ol0003ooo]ZoookJP3/oookJP001ooonfX3o`00O`?ooo]Z0ol007l3oookJP?o
001o0_oonfX5o`0000;ooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03
o`000?oonf[ooo]Z01gooo]Z1Ol0000GoookJPGo0000oooonfXFoookJP001ooonfX3o`00O`?ooo]Z
0ol007l3oookJP?o001o0_oonfX2o`0000Gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07_oonfX00ol0003ooo]Z
oookJP0OoookJP03o`000?oonf[ooo]Z01gooo]Z1Ol0003ooookJS;ooo]Z0007oookJP?o001o0ooo
nfX3o`00O`?ooo]Z0ol007l9oookJP03o`000?oonf[ooo]Z023ooo]Z00?o0000oookJ_oonfX07Ooo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX08?oo
nfX00ol0003ooo]ZoookJP0MoookJPCo0000oooonfXboookJP001?oonfX6o`00O`?ooo]Z0ol007l3
oookJP?o001o2OoonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07_oonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX07OoonfX4o`000?oooo]Z<_oonfX000Cooo]Z1_l007l4oookJP?o001o00Cooo]Zo`00
Ool007oo001o2_oonfX00ol0003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000
oookJ_oonfX07_oonfX3o`000?oooo]Z<_oonfX000Kooo]Z1?l007l4oookJPOo001o2_oonfX00ol0
003ooo]ZoookJP0PoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0
003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX3o`00
0?oooo]Z<OoonfX000Oooo]Z0ol007l5oookJPGo001o2ooonfX00ol0003ooo]ZoookJP0PoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07ooonfX3o`000?oooo]Z<OoonfX001oooo]Z
00?o0000oookJ_oonfX08?oonfX4o`0001gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08?oonfX2o`000?oooo]Z
<OoonfX001oooo]Z00?o0000oookJ_oonfX07_oonfX6o`0001gooo]Z00?o0000oookJ_oonfX07ooo
nfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX08?oo
nfX2o`000?oooo]Z<OoonfX001oooo]Z00?o0000oookJ_oonfX07_oonfX6o`0001gooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000P
oookJP03o`000?oonf[ooo]Z0?oooo]Z;ooonfX001oooo]Z00?o0000oookJ_oonfX07ooonfX5o`00
01gooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01cooo]Z1_l0003ooookJU;ooo]Z000OoookJP03o`000?oonf[ooo]Z01oooo]Z1Ol0000NoookJP03
o`000?oonf[ooo]Z01kooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0LoookJPKo
0000oooonfYBoookJP007ooonfX00ol0003ooo]ZoookJP0PoookJPCo00007_oonfX00ol0003ooo]Z
oookJP0NoookJP03o`000?oonf[ooo]Z01oooo]Z00?o0000oookJ_oonfX07OoonfX5o`000?oooo]Z
D_oonfX001oooo]Z00?o0000oookJ_oonfX08?oonfX3o`0001oooo]Z00?o0000oookJ_oonfX07_oo
nfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01gooo]Z1Ol0003ooookJU;ooo]Z000O
oookJP03o`000?oonf[ooo]Z023ooo]Z0ol0000OoookJP03o`000?oonf[ooo]Z01kooo]Z00?o0000
oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJPCo0000oooonfYBoookJP007ooonfX00ol0
003ooo]ZoookJP0QoookJP;o00007ooonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z
01kooo]Z00?o0000oookJ_oonfX07_oonfX3o`000?oooo]ZDooonfX001oooo]Z00?o0000oookJ_oo
nfX08OoonfX2o`0001oooo]Z00?o0000oookJ_oonfX07ooonfX00ol0003ooo]ZoookJP0NoookJP03
o`000?oonf[ooo]Z01kooo]Z0ol0003ooookJU?ooo]Z000OoookJP03o`000?oonf[ooo]Z02;ooo]Z
00?o0000oookJ_oonfX07OoonfX00ol0003ooo]ZoookJP0OoookJP03o`000?oonf[ooo]Z01kooo]Z
1?l0000NoookJP;o0000oooonfYCoookJP007ooonfX00ol0003ooo]ZoookJP13oookJP?o00007_oo
nfX00ol0003ooo]ZoookJP0LoookJPKo00007_oonfX2o`000?oooo]ZDooonfX001oooo]Z00?o0000
oookJ_oonfX0@?oonfX6o`0001kooo]Z00?o0000oookJ_oonfX07?oonfX6o`0001oooo]Z00?o0000
oookJ_oonfX0oooonfYAoookJP007ooonfX00ol0003ooo]ZoookJP10oookJPKo00007_oonfX00ol0
003ooo]ZoookJP0MoookJPGo0000oooonfYcoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo
00007_oonfX4o`0001cooo]Z1Ol0003ooookJW?ooo]Z000OoookJP?o0000@OoonfX5o`0001cooo]Z
1_l0000LoookJPGo0000oooonfYcoookJP007ooonfX00ol0003ooo]ZoookJP11oookJPGo00007?oo
nfX6o`0001gooo]Z0ol0003ooookJWCooo]Z000OoookJP03o`000?oonf[ooo]Z04;ooo]Z0ol0000N
oookJPCo00007_oonfX3o`000?oooo]ZM?oonfX001oooo]Z00?o0000oookJ_oonfX0@_oonfX3o`00
01kooo]Z1?l0000OoookJP;o0000oooonfYdoookJP007ooonfX00ol0003ooo]ZoookJP13oookJP;o
00007_oonfX4o`0001oooo]Z0_l0003ooookJWCooo]Z000OoookJP03o`000?oonf[ooo]Z04?ooo]Z
0_l0000OoookJP?o00007ooonfX2o`000?oooo]ZM?oonfX001oooo]Z00?o0000oookJ_oonfX0@ooo
nfX2o`0001oooo]Z0ol0000PoookJP03o`000?oonf[ooo]Z0?oooo]ZL_oonfX001oooo]Z00?o0000
oookJ_oonfX0A?oonfX00ol0003ooo]ZoookJP0MoookJP;o0000oooonfZFoookJP007ooonfX00ol0
003ooo]ZoookJP1UoookJP03o`000?oonf[ooo]Z0?oooo]ZU?oonfX001oooo]Z00?o0000oookJ_oo
nfX0IOoonfX00ol0003ooo]ZoookJP3ooookJYCooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Z
o?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3o
oookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oo
nfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oo
nf[ooo]Z0?oooo]Zo?oonfX001oooo]Z00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0
003ooo]ZoookJP3ooookJ_cooo]Z000OoookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX001oooo]Z
00?o0000oookJ_oonfX0oooonf[loookJP007ooonfX00ol0003ooo]ZoookJP3ooookJ_cooo]Z000O
oookJP03o`000?oonf[ooo]Z0?oooo]Zo?oonfX00?oooo]ZoooonfXOoookJP00oooonf[ooookJQoo
oo]Z003ooookJ_oooo]Z7ooonfX00?oooo]ZoooonfXOoookJP00oooonf[ooookJQoooo]Z003ooook
J_oooo]Z7ooonfX00?oooo]ZoooonfXOoookJP00oooonf[ooookJQoooo]Z003ooookJ_oooo]Z7ooo
nfX00?oooo]ZoooonfXOoookJP00oooonf[ooookJQoooo]Z003ooookJ_oooo]Z7ooonfX00?oooo]Z
oooonfXOoookJP006ooonfX4o`00Oooooo]ZoooonfX001_ooo]Z1Ol007oooookJ_kooo]Z000Noook
JP?o001ooooonf[moookJP007_oonfX3o`00Oooooo]ZoOoonfX001gooo]Z1Ol007oooookJ_cooo]Z
000MoookJPGo001ooooonf[loookJP007?oonfX3o`00O`04oookJ_l007oo001oo`00Oooooo]Znooo
nfX001cooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJ__ooo]Z000LoookJP?o001o00Cooo]Z
o`00Ool007oo001ooooonf[koookJP007?oonfX3o`00O`04oookJ_l007oo001oo`00Oooooo]Znooo
nfX001_ooo]Z0ol007l3oookJP?o001ooooonf[joookJP006ooonfX3o`00O`?ooo]Z0ol007oooook
J_[ooo]Z000KoookJP?o001o0ooonfX3o`00Oooooo]Zn_oonfX001[ooo]Z0ol007l5oookJP?o001o
oooonf[ioookJP00oooonf[ooookJQoooo]Z003ooookJ_oooo]Z7ooonfX00?oooo]ZoooonfXOoook
JP00oooonf[ooookJQoooo]Z003ooookJ_oooo]Z7ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 540.562}, {574.875, 0}} -> {-0.669845, -0.557573, \
0.0212663, 0.0212663}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
To summarize this part, we have seen how first-order differential \
equations have associated trajectories in the plane of the dependent \
variables, analogous to what we simulated above by incrementing a certain \
functional relationship. Numerical differential equation solvers use similar \
techniques.\
\>", "Subsubsection"],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s DSolve function"
}], "Subtitle"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  " function finds closed-form expressions for solutions to differential \
equations, when possible. There is a related function called ",
  StyleBox["NDSolve",
    FontWeight->"Bold"],
  " that finds numerical solutions that can be used when ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  " gives up. Here are some examples of using ",
  StyleBox["DSolve",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dsol\  = \ 
      DSolve[\ \(y'\)[x]\ \  + x\ *y[x]\  \[Equal] 0, y[x], x]\)], "Input",
  CellTags->"mmtag:19:DSolve[]"],

Cell[BoxData[
    \({{y[x] \[Rule] \[ExponentialE]\^\(-\(x\^2\/2\)\)\ C[1]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that the solution is given as a rule, just like for the function ",
  StyleBox["Solve",
    FontWeight->"Bold"],
  ". Because no initial condition was specified, the solution involves an \
unknown constant, C[1]."
}], "Text",
  CellTags->
  "mmtag:19:ordinary_differential_equations__constants_of_integration"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dsol\  = \ 
      DSolve[\ {\(y'\)[x]\ \  + \ Sin[x]\ *y[x]\  \[Equal] 0, 
          y[0] \[Equal] 1}, y[x], x]\)], "Input"],

Cell[BoxData[
    \({{y[x] \[Rule] \[ExponentialE]\^\(\(-1\) + Cos[x]\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
In this case an initial condition was specified for the \
differential equation, so there is no undetermined constant in the solution. \
The next statement extracts y(x) for plotting...\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(exactplot\  = Plot[y[x] /. Flatten[dsol], {x, 0, 10}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -7 -20 ]
[.21429 .00222 7 0 ]
[.40476 .00222 -7 -20 ]
[.40476 .00222 7 0 ]
[.59524 .00222 -7 -20 ]
[.59524 .00222 7 0 ]
[.78571 .00222 -7 -20 ]
[.78571 .00222 7 0 ]
[.97619 .00222 -12 -20 ]
[.97619 .00222 12 0 ]
[.01131 .13244 -29 -10 ]
[.01131 .13244 0 10 ]
[.01131 .25016 -29 -10 ]
[.01131 .25016 0 10 ]
[.01131 .36788 -29 -10 ]
[.01131 .36788 0 10 ]
[.01131 .4856 -29 -10 ]
[.01131 .4856 0 10 ]
[.01131 .60332 -14 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0075 w
.02381 .60332 m
.02499 .60327 L
.02605 .60316 L
.02729 .60293 L
.02846 .60262 L
.03053 .60185 L
.03279 .60071 L
.03527 .59908 L
.0379 .59693 L
.04262 .59199 L
.05205 .57818 L
.06244 .55743 L
.0842 .49933 L
.10458 .43426 L
.14335 .31006 L
.16306 .25605 L
.18458 .20734 L
.20517 .17081 L
.22428 .14485 L
.24481 .12426 L
.26341 .11099 L
.27344 .10565 L
.28266 .10174 L
.29279 .09845 L
.29788 .09718 L
.30348 .09606 L
.30599 .09565 L
.30872 .09527 L
.31113 .095 L
.31369 .09476 L
.31598 .09459 L
.31729 .09452 L
.31852 .09446 L
.31964 .09442 L
.32067 .0944 L
.3218 .09438 L
.32299 .09437 L
.3243 .09438 L
.32549 .0944 L
.32615 .09442 L
.32687 .09444 L
.32816 .09449 L
.32938 .09455 L
.33067 .09463 L
.33298 .09481 L
.33567 .09508 L
.33818 .09539 L
.34391 .09631 L
.34888 .09735 L
.35431 .09875 L
Mistroke
.36419 .10205 L
.37381 .10625 L
.38273 .11107 L
.40329 .12605 L
.42191 .14506 L
.4412 .17134 L
.46203 .20853 L
.50309 .3113 L
.54262 .43818 L
.56253 .50146 L
.58065 .55067 L
.59069 .57224 L
.6002 .58787 L
.60541 .59426 L
.61023 .59869 L
.61274 .60042 L
.61552 .60187 L
.61691 .60241 L
.61764 .60264 L
.61841 .60285 L
.61909 .603 L
.61983 .60314 L
.62113 .60328 L
.62177 .60331 L
.62245 .60332 L
.62367 .60325 L
.62498 .60307 L
.62573 .60292 L
.62643 .60274 L
.62884 .60189 L
.63019 .60126 L
.63143 .60057 L
.63623 .59699 L
.64077 .59227 L
.65081 .57755 L
.66174 .5554 L
.68149 .50266 L
.70249 .43588 L
.74021 .31463 L
.76115 .25682 L
.78038 .21264 L
.80039 .17582 L
.81903 .14927 L
.83793 .12891 L
.84857 .11995 L
.85862 .11294 L
.86842 .10734 L
.87906 .10251 L
.88872 .09916 L
.89764 .09688 L
Mistroke
.9023 .09599 L
.90487 .09558 L
.90732 .09525 L
.90958 .09499 L
.91205 .09476 L
.91429 .0946 L
.91638 .09449 L
.91767 .09444 L
.9184 .09441 L
.91908 .0944 L
.92031 .09438 L
.92162 .09437 L
.92279 .09438 L
.92388 .0944 L
.92508 .09443 L
.92637 .09448 L
.92774 .09455 L
.92923 .09464 L
.93193 .09486 L
.93457 .09514 L
.93701 .09545 L
.94163 .09618 L
.94662 .0972 L
.95564 .09963 L
.96636 .10358 L
.97619 .10828 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00R_oonfX9o`00Of?ooo]Z0ol007mPoook
JPGo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o3ooonfX008[ooo]Z2Ol007mSoookJP?o
001oGooonfX7o`00Of3ooo]Z1ol007mNoookJP?o001o1?oonfX7o`00O`kooo]Z002:oookJPCo001o
J?oonfX3o`00Oeoooo]Z0ol007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`kooo]Z002;oookJPCo001oH_oonfX9o`00Oegooo]Z
0ol007l3oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l=oookJP00S?oonfX5o`00Of3ooo]Z2Ol007mMoookJP?o001o0ooonfX3o`00Oekooo]Z0ol0
07l3oookJP?o001oGOoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o3OoonfX008kooo]Z1?l007mO
oookJP;o001o0ooonfX3o`00Oekooo]Z1?l007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mM
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00SooonfX3o`00Of3ooo]Z0_l007l2oook
JP?o001oG_oonfX8o`00Of3ooo]Z1ol007mNoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oook
JP00T?oonfX3o`00Oeoooo]Z0ol007l01?oonf[o001oo`00Ool007mNoookJP?o001o00Cooo]Zo`00
Ool007oo001oHOoonfX7o`00Oekooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`gooo]Z002:oook
JP?o001o0ooonfX3o`00Of3ooo]Z0_l007l01?oonf[o001oo`00Ool007mNoookJP?o001oI?oonfX3
o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00R_oonfX3o`00
O`?ooo]Z0ol007mQoookJPGo001oG_oonfX3o`00OfCooo]Z0ol007l3oookJP?o001oF_oonfX6o`00
O`?ooo]Z0ol007l3oookJP?o001o3OoonfX002Kooo]Z1Ol0001OoookJPCo001o0_oonfX3o`00Of7o
oo]Z1Ol007mOoookJP?o001o0_oonfX3o`00Oekooo]Z0ol007l3oookJP?o001oF_oonfX6o`00O`Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l>oookJP009_oonfX5o`00063ooo]Z1ol007mSoookJPCo
001oGooonfX7o`00Of3ooo]Z1ol007mMoookJPCo001o1?oonfX7o`00O`kooo]Z000VoookJPGo0000
HOoonfX5o`00OfGooo]Z0ol007mQoookJPCo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o
3ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003o
o`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o
00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX002Kooo]Z1Ol0001ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0001ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oo
oo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooo
nfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oo
oo]Z5ooonfX002Kooo]Z1Ol0002GoookJPko0000oooonfXfoookJPko0000;OoonfX002Kooo]Z1Ol0
002AoookJQgo0000oooonfXWoookJQco00009OoonfX002Kooo]Z1Ol0002;oookJRKo0000oooonfXQ
oookJR?o00008OoonfX002Kooo]Z1Ol00028oookJRgo0000oooonfXIoookJR_o00007OoonfX002Ko
oo]Z1Ol00026oookJQCo00002?oonfXFo`000?oooo]Z4ooonfXCo`0000Sooo]Z5_l0000JoookJP00
9_oonfX5o`0008?ooo]Z4Ol0000GoookJPoo0000oooonfX?oookJPoo00005_oonfX@o`0001Sooo]Z
000VoookJPGo0000POoonfX=o`00023ooo]Z3Ol0003ooookJP_ooo]Z3ol0000MoookJPko00005_oo
nfX002Kooo]Z1Ol0001ooookJPco00009ooonfX;o`000?oooo]Z1_oonfX>o`0002Gooo]Z2ol0000E
oookJP009_oonfX5o`0007gooo]Z3?l0000/oookJP_o0000oooonfX1oookJPgo0000:ooonfX9o`00
01Cooo]Z000VoookJPGo0000NooonfX;o`00037ooo]Z2ol0003moookJPco0000;ooonfX7o`0001Co
oo]Z000VoookJPGo0000N_oonfX:o`0003Cooo]Z2ol0003joookJP_o0000=?oonfX5o`0001Cooo]Z
000VoookJPGo0000N?oonfX:o`0003Sooo]Z2_l0003hoookJPWo0000>?oonfX4o`0001Cooo]Z000V
oookJPGo0000MooonfX9o`0003gooo]Z2Ol0003doookJPWo0000D_oonfX002Kooo]Z1Ol0001foook
JPSo0000@OoonfX8o`000?;ooo]Z2Ol0001CoookJP009_oonfX5o`0007Cooo]Z2Ol00013oookJPWo
0000k_oonfX9o`0005Gooo]Z000VoookJPGo0000LooonfX8o`0004Kooo]Z2Ol0003/oookJPWo0000
E_oonfX002Kooo]Z1Ol0001boookJPSo0000BOoonfX8o`000>[ooo]Z2?l0001HoookJP009_oonfX5
o`0007;ooo]Z1ol0001;oookJPSo0000j?oonfX8o`0005Wooo]Z0009oookJPGo001o1?oonfX3o`00
O`03oookJ_l007oo001o00Oo001o1ooonfX5o`00077ooo]Z1_l0001?oookJPKo0000iooonfX7o`00
05_ooo]Z0008oookJPOo001o0ooonfX3o`00O`03oookJ_l007oo001o00Oo001o1ooonfX5o`00073o
oo]Z1_l0001AoookJPKo0000iOoonfX7o`0005cooo]Z0008oookJP?o001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`03oookJ_l007oo001o00;o001o3?oonfX5o`0006oooo]Z1ol0001BoookJPKo
0000i?oonfX6o`0005gooo]Z0007oookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l;oookJPGo0000
K_oonfX7o`0005?ooo]Z1ol0003RoookJPKo0000G_oonfX000Oooo]Z0ol007l3oookJP?o001o2?oo
nfX5o`00O`Wooo]Z1ol0001[oookJPOo0000EOoonfX7o`000>3ooo]Z1_l0001OoookJP001ooonfX3
o`00O`?ooo]Z0ol007l:oookJPCo001o2?oonfX5o`0006cooo]Z1ol0001GoookJPOo0000g_oonfX7
o`0005oooo]Z0007oookJP?o001o0ooonfX3o`00O`_ooo]Z0ol007l8oookJPGo0000JooonfX7o`00
05Wooo]Z1ol0003LoookJPOo0000H?oonfX000Oooo]Z0ol007l3oookJP?o001o3?oonfX3o`00O`Oo
oo]Z1Ol0001ZoookJPOo0000FooonfX7o`000=[ooo]Z1ol0001QoookJP001ooonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0001YoookJPOo0000GOoonfX7o`000=Sooo]Z
1ol0001RoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
001XoookJPOo0000GooonfX7o`000=Kooo]Z1ol0001SoookJP002?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z1?l007l2oookJP?o001o1ooonfX5o`0006Oooo]Z1ol0001QoookJPOo0000e?oo
nfX7o`0006Cooo]Z0008oookJPOo001o2?oonfX7o`00O`Sooo]Z1Ol0001WoookJPKo0000HooonfX6
o`000=?ooo]Z1ol0001UoookJP002OoonfX5o`00O`[ooo]Z1Ol007l9oookJPGo0000I_oonfX6o`00
06Gooo]Z1_l0003AoookJPOo0000I_oonfX002Kooo]Z1Ol0001UoookJPKo0000IooonfX6o`000=3o
oo]Z1_l0001WoookJP009_oonfX5o`0006Cooo]Z1ol0001WoookJPOo0000c_oonfX6o`0006Sooo]Z
000VoookJPGo0000I?oonfX6o`0006Wooo]Z1_l0003=oookJPKo0000JOoonfX002Kooo]Z1Ol0001S
oookJPKo0000JooonfX6o`000<_ooo]Z1ol0001YoookJP009_oonfX5o`0006;ooo]Z1_l0001]oook
JPKo0000b_oonfX6o`0006[ooo]Z000VoookJPGo0000H_oonfX6o`0006gooo]Z1_l00039oookJPKo
0000JooonfX002Kooo]Z1Ol0001QoookJPKo0000KooonfX6o`000<Oooo]Z1_l0001/oookJP009_oo
nfX5o`00063ooo]Z1_l0001aoookJPKo0000a_oonfX6o`0006cooo]Z000VoookJPGo0000GooonfX7
o`00077ooo]Z1ol00034oookJPKo0000KOoonfX002Kooo]Z1Ol0001OoookJPKo0000LooonfX6o`00
0<?ooo]Z1_l0001^oookJP009_oonfX5o`0005kooo]Z1_l0001eoookJPKo0000`OoonfX7o`0006ko
oo]Z000VoookJPGo0000GOoonfX6o`0007Oooo]Z1_l00030oookJPKo0000KooonfX002Kooo]Z1Ol0
001MoookJPKo0000MooonfX6o`000;oooo]Z1_l0001`oookJP009_oonfX5o`0005cooo]Z1_l0001i
oookJPKo0000_OoonfX6o`00077ooo]Z000VoookJPGo0000G?oonfX5o`0007_ooo]Z1_l0002loook
JPKo0000LOoonfX002Kooo]Z1Ol0001KoookJPKo0000NooonfX6o`000;_ooo]Z1_l0001boookJP00
9_oonfX5o`0005[ooo]Z1_l0001moookJPKo0000^_oonfX5o`0007?ooo]Z000VoookJPGo0000F_oo
nfX6o`0007kooo]Z1Ol0002ioookJPKo0000LooonfX002Kooo]Z1Ol0001IoookJPKo0000OooonfX6
o`000;Sooo]Z1Ol0001doookJP009_oonfX5o`0005Wooo]Z1Ol00021oookJPKo0000]_oonfX6o`00
07Cooo]Z000VoookJPGo0000F?oonfX6o`00087ooo]Z1_l0002eoookJPKo0000MOoonfX002Kooo]Z
1Ol0001GoookJPKo0000PooonfX6o`000;Cooo]Z1_l0001eoookJP009_oonfX5o`0005Oooo]Z1_l0
0024oookJPGo0000/ooonfX6o`0007Kooo]Z000VoookJPGo0000E_oonfX6o`0008Gooo]Z1_l0002b
oookJPGo0000MooonfX002Kooo]Z1Ol0001FoookJPGo0000QooonfX6o`000;3ooo]Z1_l0001goook
JP009_oonfX5o`0005Gooo]Z1_l00027oookJPKo0000/?oonfX5o`0007Sooo]Z000VoookJPGo0000
EOoonfX5o`0008Wooo]Z1_l0002^oookJPKo0000N?oonfX002Kooo]Z1Ol0001DoookJPKo0000R_oo
nfX5o`000:kooo]Z1Ol0001ioookJP009_oonfX5o`0005?ooo]Z1_l0002;oookJPKo0000[?oonfX6
o`0007Wooo]Z000VoookJPGo0000DooonfX6o`0008cooo]Z1_l0002ZoookJPKo0000N_oonfX002Ko
oo]Z1Ol0001BoookJPKo0000SOoonfX6o`000:[ooo]Z1_l0001joookJP009_oonfX5o`0005;ooo]Z
1Ol0002?oookJPKo0000Z?oonfX6o`0007_ooo]Z000VoookJPGo0000DOoonfX6o`00093ooo]Z1Ol0
002XoookJPGo0000O?oonfX002Kooo]Z1Ol0001AoookJPGo0000TOoonfX6o`000:Kooo]Z1_l0001l
oookJP009_oonfX5o`00053ooo]Z1_l0002BoookJPGo0000Y_oonfX5o`0007gooo]Z000VoookJPGo
0000D?oonfX5o`0009?ooo]Z1Ol0002UoookJPKo0000OOoonfX002Kooo]Z1Ol0001@oookJPGo0000
U?oonfX5o`000:Cooo]Z1Ol0001noookJP009_oonfX5o`0004oooo]Z1Ol0002EoookJPGo0000Y?oo
nfX5o`0007kooo]Z000VoookJPGo0000CooonfX5o`0009Gooo]Z1_l0002RoookJPGo0000OooonfX0
02Kooo]Z1Ol0001>oookJPKo0000U_oonfX5o`000:;ooo]Z1Ol0001ooookJP009_oonfX5o`0004ko
oo]Z1Ol0002GoookJPGo0000XOoonfX6o`0007oooo]Z000VoookJPGo0000COoonfX6o`0009Sooo]Z
1Ol0002PoookJPGo0000P?oonfX002Kooo]Z1Ol0001=oookJPGo0000VOoonfX5o`0009oooo]Z1_l0
0020oookJP009_oonfX5o`0004cooo]Z1_l0002IoookJPKo0000W_oonfX5o`00087ooo]Z000Voook
JPGo0000C?oonfX5o`0009_ooo]Z1Ol0002NoookJPGo0000POoonfX002Kooo]Z1Ol0001<oookJPGo
0000VooonfX5o`0009gooo]Z1Ol00022oookJP009_oonfX5o`0004_ooo]Z1Ol0002MoookJPGo0000
W?oonfX5o`0008;ooo]Z000VoookJPGo0000BooonfX5o`0009gooo]Z1Ol0002KoookJPKo0000P_oo
nfX002Kooo]Z1Ol0001:oookJPKo0000WOoonfX6o`0009[ooo]Z1Ol00023oookJP009_oonfX5o`00
04[ooo]Z1Ol0002OoookJPGo0000V_oonfX5o`0008?ooo]Z0009oookJPGo001o1?oonfX3o`00O`Ko
oo]Z0ol007l8oookJPGo0000BOoonfX6o`0009oooo]Z1Ol0002IoookJPGo0000Q?oonfX000Sooo]Z
1ol007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol00019oookJPGo0000XOoonfX5o`0009Sooo]Z
1Ol00024oookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l6oookJP?o001o
2?oonfX5o`0004Sooo]Z1_l0002QoookJPGo0000UooonfX6o`0008Cooo]Z0007oookJP?o001o0ooo
nfX3o`00O`Kooo]Z2Ol007l7oookJPGo0000B?oonfX5o`000:;ooo]Z1_l0002FoookJPGo0000QOoo
nfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1ol00016oookJPGo0000XooonfX5
o`0009Gooo]Z1_l00025oookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooonfX3o`00
O`Sooo]Z1Ol00017oookJPGo0000Y?oonfX5o`0009Gooo]Z1Ol00026oookJP001ooonfX3o`00O`?o
oo]Z0ol007l7oookJP;o001o0_oonfX3o`00O`Sooo]Z1Ol00017oookJPGo0000YOoonfX5o`0009Co
oo]Z1Ol00026oookJP001ooonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo
001o2?oonfX5o`0004Kooo]Z1_l0002UoookJPGo0000TooonfX5o`0008Oooo]Z0007oookJP?o001o
0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o001oo`00Ool007l8oookJPGo0000A_oonfX5o`000:Ko
oo]Z1_l0002BoookJPGo0000QooonfX000Oooo]Z0ol007l3oookJP?o001o2OoonfX5o`00O`Sooo]Z
1Ol00015oookJPKo0000YooonfX5o`00097ooo]Z1_l00027oookJP002?oonfX3o`00O`04oookJ_l0
07oo001oo`00O`[ooo]Z1Ol007l8oookJPGo0000AOoonfX5o`000:Sooo]Z1Ol0002AoookJPGo0000
R?oonfX000Sooo]Z1ol007l;oookJPCo001o2?oonfX5o`0004Gooo]Z1Ol0002YoookJPGo0000T?oo
nfX5o`0008Sooo]Z0009oookJPGo001o3OoonfX3o`00O`Sooo]Z1Ol00014oookJPGo0000Z_oonfX5
o`0008oooo]Z1Ol00029oookJP009_oonfX5o`0004Cooo]Z1Ol0002ZoookJPKo0000S_oonfX5o`00
08Wooo]Z000VoookJPGo0000A?oonfX5o`000:_ooo]Z1Ol0002>oookJPGo0000ROoonfX002Kooo]Z
1Ol00013oookJPGo0000[?oonfX5o`0008gooo]Z1Ol0002:oookJP009_oonfX5o`0004?ooo]Z1Ol0
002]oookJPGo0000S?oonfX5o`0008[ooo]Z000VoookJPGo0000@ooonfX5o`000:gooo]Z1Ol0002<
oookJPGo0000R_oonfX002Kooo]Z1Ol00012oookJPGo0000[_oonfX6o`0008[ooo]Z1Ol0002;oook
JP009_oonfX5o`0004;ooo]Z1Ol0002_oookJPGo0000R_oonfX5o`0008_ooo]Z000VoookJPGo0000
@_oonfX5o`000:oooo]Z1Ol0002:oookJPGo0000RooonfX002Kooo]Z1Ol00011oookJPGo0000/Ooo
nfX5o`0008Sooo]Z1Ol0002<oookJP009_oonfX5o`00047ooo]Z1Ol0002aoookJPGo0000R?oonfX5
o`0008cooo]Z000VoookJPGo0000@OoonfX5o`000;7ooo]Z1_l00026oookJPKo0000S?oonfX002Ko
oo]Z1Ol00010oookJPGo0000/ooonfX5o`0008Kooo]Z1Ol0002=oookJP009_oonfX5o`00043ooo]Z
1Ol0002coookJPGo0000Q_oonfX5o`0008gooo]Z000VoookJPGo0000@?oonfX5o`000;Cooo]Z1Ol0
0024oookJPGo0000S_oonfX002Kooo]Z1Ol0000ooookJPGo0000]OoonfX5o`0008Cooo]Z1Ol0002>
oookJP009_oonfX5o`0003oooo]Z1Ol0002eoookJPKo0000PooonfX5o`0008kooo]Z000VoookJPGo
0000?ooonfX5o`000;Kooo]Z1Ol00022oookJPGo0000SooonfX002Kooo]Z1Ol0000noookJPGo0000
]ooonfX5o`0008;ooo]Z1Ol0002?oookJP009_oonfX5o`0003kooo]Z1Ol0002hoookJPGo0000POoo
nfX5o`0008oooo]Z000VoookJPGo0000?_oonfX5o`000;Sooo]Z1Ol00020oookJPGo0000T?oonfX0
02Kooo]Z1Ol0000moookJPGo0000^OoonfX6o`0007oooo]Z1Ol0002@oookJP009_oonfX5o`0003go
oo]Z1Ol0002joookJPGo0000OooonfX5o`00093ooo]Z000VoookJPGo0000?OoonfX5o`000;[ooo]Z
1Ol0001noookJPGo0000TOoonfX002Kooo]Z1Ol0000loookJPGo0000_?oonfX5o`0007gooo]Z1Ol0
002AoookJP009_oonfX5o`0003cooo]Z1Ol0002loookJPGo0000OOoonfX5o`00097ooo]Z000Voook
JPGo0000??oonfX5o`000;cooo]Z1Ol0001loookJPGo0000T_oonfX002Kooo]Z1Ol0000koookJPGo
0000__oonfX5o`0007_ooo]Z1Ol0002BoookJP009_oonfX5o`0003_ooo]Z1Ol0002noookJPGo0000
NooonfX5o`0009;ooo]Z000VoookJPGo0000>ooonfX5o`000;kooo]Z1Ol0001joookJPGo0000Tooo
nfX002Kooo]Z1Ol0000joookJPGo0000`?oonfX5o`0007Wooo]Z1Ol0002CoookJP009_oonfX5o`00
03[ooo]Z1Ol00030oookJPGo0000NOoonfX5o`0009?ooo]Z000VoookJPGo0000>_oonfX5o`000<3o
oo]Z1Ol0001hoookJPGo0000U?oonfX002Kooo]Z1Ol0000ioookJPGo0000`_oonfX5o`0007Oooo]Z
1Ol0002DoookJP009_oonfX5o`0003Wooo]Z1Ol00032oookJPGo0000MooonfX5o`0009Cooo]Z000V
oookJPGo0000>OoonfX5o`000<;ooo]Z1Ol0001foookJPGo0000UOoonfX002Kooo]Z1Ol0000hoook
JPGo0000a?oonfX5o`0007Gooo]Z1Ol0002EoookJP009_oonfX5o`0003Sooo]Z1Ol00034oookJPGo
0000MOoonfX5o`0009Gooo]Z000VoookJPGo0000>?oonfX5o`000<Cooo]Z1Ol0001doookJPGo0000
U_oonfX002Kooo]Z1Ol0000goookJPGo0000a_oonfX4o`0007Cooo]Z1Ol0002FoookJP009_oonfX5
o`0003Oooo]Z1Ol00036oookJPGo0000LooonfX5o`0009Kooo]Z000VoookJPGo0000=ooonfX5o`00
0<Kooo]Z1Ol0001boookJPGo0000UooonfX002Kooo]Z1Ol0000goookJPCo0000aooonfX5o`0007;o
oo]Z1Ol0002GoookJP009_oonfX5o`0003Kooo]Z1Ol00038oookJPGo0000LOoonfX5o`0009Oooo]Z
000VoookJPGo0000=_oonfX5o`000<Sooo]Z1Ol0001`oookJPGo0000V?oonfX002Kooo]Z1Ol0000f
oookJPGo0000b?oonfX5o`00073ooo]Z1Ol0002HoookJP009_oonfX5o`0003Gooo]Z1Ol0003:oook
JPGo0000KooonfX5o`0009Sooo]Z000VoookJPGo0000=OoonfX5o`000<[ooo]Z1Ol0001^oookJPGo
0000VOoonfX002Kooo]Z1Ol0000eoookJPGo0000b_oonfX5o`0006kooo]Z1Ol0002IoookJP009_oo
nfX5o`0003Cooo]Z1Ol0003<oookJPCo0000K_oonfX5o`0009Wooo]Z000VoookJPGo0000=?oonfX5
o`000<cooo]Z1Ol0001]oookJPCo0000V_oonfX002Kooo]Z1Ol0000doookJPGo0000c?oonfX5o`00
06cooo]Z1Ol0002JoookJP002OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`0003?o
oo]Z1Ol0003=oookJPGo0000K?oonfX5o`0009[ooo]Z0008oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l8oookJPGo0000<ooonfX5o`000<kooo]Z1Ol0001[oookJPGo0000V_oonfX000Sooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l7oookJPGo0000
<ooonfX5o`000<kooo]Z1Ol0001ZoookJPGo0000VooonfX000Oooo]Z0ol007l3oookJP?o001o1_oo
nfX3o`00O`?ooo]Z0ol007l7oookJPGo0000<_oonfX5o`000<oooo]Z1Ol0001ZoookJPGo0000Vooo
nfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPOo0000<?oonfX5
o`000=3ooo]Z1Ol0001YoookJPGo0000VooonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX4o`00
O`;ooo]Z0ol007l7oookJPGo0000<_oonfX5o`000=3ooo]Z1Ol0001XoookJPGo0000W?oonfX000Oo
oo]Z0ol007l3oookJP?o001o1_oonfX8o`00O`Sooo]Z1Ol0000aoookJPGo0000dOoonfX5o`0006So
oo]Z1Ol0002LoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo
001o2OoonfX5o`00037ooo]Z1Ol0003BoookJPGo0000IooonfX5o`0009cooo]Z0007oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l=oookJPGo0000<OoonfX5o`000=;ooo]Z1Ol0001VoookJPGo0000
WOoonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`gooo]Z1Ol0000aoookJPCo0000dooo
nfX5o`0006Kooo]Z1Ol0002MoookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol0
07l2oookJP?o001o1ooonfX5o`00033ooo]Z1Ol0003DoookJPCo0000I_oonfX5o`0009gooo]Z0008
oookJPOo001o2?oonfX7o`00O`Sooo]Z1Ol0000`oookJPGo0000e?oonfX5o`0006Cooo]Z1Ol0002N
oookJP002OoonfX5o`00O`_ooo]Z1?l007l9oookJPGo0000<?oonfX5o`000=Cooo]Z1Ol0001Toook
JPGo0000W_oonfX002Kooo]Z1Ol0000_oookJPGo0000eOoonfX5o`0006Cooo]Z1Ol0002NoookJP00
9_oonfX5o`0002oooo]Z1Ol0003FoookJPGo0000H_oonfX5o`0009oooo]Z000VoookJPGo0000;ooo
nfX5o`000=Kooo]Z1Ol0001RoookJPGo0000WooonfX002Kooo]Z1Ol0000^oookJPGo0000eooonfX5
o`0006;ooo]Z1Ol0002OoookJP009_oonfX5o`0002kooo]Z1Ol0003HoookJPGo0000H?oonfX5o`00
0:3ooo]Z000VoookJPGo0000;_oonfX5o`000=Sooo]Z1Ol0001PoookJPGo0000X?oonfX002Kooo]Z
1Ol0000]oookJPGo0000fOoonfX5o`00063ooo]Z1Ol0002PoookJP009_oonfX5o`0002gooo]Z1Ol0
003JoookJPCo0000H?oonfX4o`000:7ooo]Z000VoookJPGo0000;OoonfX5o`000=[ooo]Z1Ol0001N
oookJPGo0000XOoonfX002Kooo]Z1Ol0000/oookJPGo0000fooonfX5o`0005kooo]Z1Ol0002Qoook
JP009_oonfX5o`0002cooo]Z1Ol0003KoookJPGo0000G_oonfX5o`000:7ooo]Z000VoookJPGo0000
;?oonfX5o`000=cooo]Z1Ol0001LoookJPGo0000X_oonfX002Kooo]Z1Ol0000/oookJPCo0000gOoo
nfX5o`0005cooo]Z1Ol0002RoookJP009_oonfX5o`0002_ooo]Z1Ol0003MoookJPGo0000G?oonfX5
o`000:;ooo]Z000VoookJPGo0000:ooonfX5o`000=kooo]Z1Ol0001JoookJPGo0000XooonfX002Ko
oo]Z1Ol0000[oookJPGo0000g_oonfX5o`0005[ooo]Z1Ol0002SoookJP009_oonfX5o`0002[ooo]Z
1Ol0003OoookJPGo0000F_oonfX5o`000:?ooo]Z000VoookJPGo0000:_oonfX5o`000>3ooo]Z1Ol0
001HoookJPGo0000Y?oonfX002Kooo]Z1Ol0000ZoookJPGo0000h?oonfX5o`0005Sooo]Z1Ol0002T
oookJP009_oonfX5o`0002Wooo]Z1Ol0003QoookJPGo0000F?oonfX5o`000:Cooo]Z000VoookJPGo
0000:OoonfX5o`000>;ooo]Z1?l0001GoookJPGo0000YOoonfX002Kooo]Z1Ol0000YoookJPGo0000
h_oonfX5o`0005Kooo]Z1Ol0002UoookJP009_oonfX5o`0002Sooo]Z1Ol0003SoookJPGo0000E_oo
nfX5o`000:Gooo]Z000VoookJPGo0000:?oonfX5o`000>?ooo]Z1Ol0001EoookJPGo0000Y_oonfX0
02Kooo]Z1Ol0000XoookJPGo0000i?oonfX5o`0005Cooo]Z1Ol0002VoookJP009_oonfX5o`0002Oo
oo]Z1Ol0003UoookJPGo0000E?oonfX5o`000:Kooo]Z000VoookJPGo00009ooonfX5o`000>Gooo]Z
1Ol0001CoookJPGo0000YooonfX002Kooo]Z1Ol0000WoookJPGo0000i_oonfX5o`0005;ooo]Z1Ol0
002WoookJP009_oonfX5o`0002Oooo]Z1?l0003WoookJPGo0000D_oonfX5o`000:Oooo]Z000Voook
JPGo00009_oonfX5o`000>Oooo]Z1Ol0001BoookJPCo0000Z?oonfX002Kooo]Z1Ol0000VoookJPGo
0000j?oonfX4o`00057ooo]Z1Ol0002XoookJP009_oonfX5o`0002Kooo]Z1Ol0003XoookJPGo0000
D?oonfX5o`000:Sooo]Z000VoookJPGo00009OoonfX5o`000>Wooo]Z1Ol0001@oookJPGo0000Z?oo
nfX002Kooo]Z1Ol0000UoookJPGo0000jOoonfX5o`0004oooo]Z1Ol0002YoookJP009_oonfX5o`00
02Gooo]Z1Ol0003ZoookJPGo0000C_oonfX5o`000:Wooo]Z000VoookJPGo00009?oonfX5o`000>_o
oo]Z1Ol0001>oookJPGo0000ZOoonfX002Kooo]Z1Ol0000ToookJPGo0000jooonfX5o`0004gooo]Z
1Ol0002ZoookJP009_oonfX5o`0002Cooo]Z1Ol0003/oookJPGo0000C?oonfX5o`000:[ooo]Z000V
oookJPGo00008ooonfX5o`000>gooo]Z1Ol0001<oookJPGo0000Z_oonfX002Kooo]Z1Ol0000Soook
JPGo0000kOoonfX5o`0004_ooo]Z1Ol0002[oookJP009_oonfX5o`0002?ooo]Z1Ol0003^oookJPGo
0000B_oonfX5o`000:_ooo]Z000VoookJPGo00008_oonfX5o`000>oooo]Z1Ol0001:oookJPGo0000
ZooonfX002Kooo]Z1Ol0000RoookJPGo0000kooonfX5o`0004[ooo]Z1?l0002/oookJP009_oonfX5
o`0002;ooo]Z1Ol0003`oookJPGo0000B?oonfX5o`000:cooo]Z000VoookJPGo00008OoonfX5o`00
0?7ooo]Z1Ol00018oookJPGo0000[?oonfX002Kooo]Z1Ol0000QoookJPGo0000lOoonfX5o`0004So
oo]Z1Ol0002/oookJP009_oonfX5o`00027ooo]Z1Ol0003boookJPGo0000A_oonfX5o`000:gooo]Z
000VoookJPGo00008OoonfX4o`000??ooo]Z1Ol00016oookJPGo0000[OoonfX002Kooo]Z1Ol0000P
oookJPGo0000looonfX5o`0004Kooo]Z1Ol0002]oookJP009_oonfX5o`00023ooo]Z1Ol0003doook
JPGo0000A?oonfX5o`000:kooo]Z0009oookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l9oookJPGo
00008?oonfX5o`000?Cooo]Z1Ol00014oookJPGo0000[_oonfX000Sooo]Z1ol007l3oookJP?o001o
0_oonfX7o`00O`Sooo]Z1Ol0000OoookJPGo0000mOoonfX5o`0004Cooo]Z1Ol0002^oookJP002?oo
nfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o1ooonfX5o`0001oooo]Z1Ol0003foookJPGo0000@ooonfX4o`000:oooo]Z0007oookJP?o001o
0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0001oooo]Z1Ol0003foookJPGo0000
@_oonfX5o`000:oooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX7o`0001cooo]Z1Ol0003goookJPGo0000@_oonfX5o`000:oooo]Z0007oookJP?o001o0ooonfX3
o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX5o`0001kooo]Z1Ol0003hoookJPGo0000@OoonfX5
o`000:oooo]Z0007oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo00007_oonfX5o`00
0?Sooo]Z1Ol00010oookJPGo0000/?oonfX000Oooo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`So
oo]Z1Ol0000MoookJPGo0000nOoonfX5o`00043ooo]Z1Ol0002`oookJP001ooonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000MoookJPGo0000n_oonfX5o`0003oooo]Z
1Ol0002`oookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
000MoookJPGo0000n_oonfX5o`0003kooo]Z1Ol0002aoookJP002?oonfX3o`00O`04oookJ_l007oo
001oo`00O`Oooo]Z0ol007l3oookJP?o001o1ooonfX5o`0001cooo]Z1Ol0003koookJPGo0000?_oo
nfX5o`000;7ooo]Z0008oookJPOo001o2?oonfX7o`00O`Sooo]Z1Ol0000LoookJPGo0000o?oonfX5
o`0003gooo]Z1Ol0002aoookJP002OoonfX5o`00O`[ooo]Z1Ol007l9oookJPGo00007?oonfX5o`00
0?cooo]Z1Ol0000loookJPGo0000/_oonfX002Kooo]Z1Ol0000KoookJPGo0000oOoonfX5o`0003co
oo]Z1Ol0002boookJP009_oonfX5o`0001_ooo]Z1Ol0003noookJPGo0000>ooonfX5o`000;;ooo]Z
000VoookJPGo00006ooonfX5o`000?kooo]Z1Ol0000joookJPGo0000/ooonfX002Kooo]Z1Ol0000J
oookJPGo0000oooonfX5o`0003[ooo]Z1Ol0002coookJP009_oonfX5o`0001[ooo]Z1Ol0003ooook
JP7ooo]Z1Ol0000ioookJPGo0000/ooonfX002Kooo]Z1Ol0000IoookJPKo0000oooonfX1oookJPGo
0000>?oonfX5o`000;Cooo]Z000VoookJPGo00006OoonfX5o`000?oooo]Z0_oonfX6o`0003Oooo]Z
1Ol0002doookJP009_oonfX5o`0001Wooo]Z1Ol0003ooookJP?ooo]Z1Ol0000foookJPKo0000]?oo
nfX002Kooo]Z1Ol0000HoookJPGo0000oooonfX4oookJPGo0000=_oonfX5o`000;Gooo]Z000Voook
JPGo00006?oonfX5o`000?oooo]Z1OoonfX5o`0003Gooo]Z1Ol0002eoookJP009_oonfX5o`0001So
oo]Z1Ol0003ooookJPGooo]Z1Ol0000doookJPGo0000]_oonfX002Kooo]Z1Ol0000GoookJPGo0000
oooonfX6oookJPGo0000=?oonfX5o`000;Kooo]Z000VoookJPGo00005ooonfX5o`000?oooo]Z1ooo
nfX5o`0003;ooo]Z1_l0002foookJP009_oonfX5o`0001Kooo]Z1_l0003ooookJPOooo]Z1Ol0000b
oookJPGo0000]ooonfX002Kooo]Z1Ol0000FoookJPGo0000oooonfX8oookJPKo0000<OoonfX5o`00
0;Oooo]Z000VoookJPGo00005_oonfX5o`000?oooo]Z2OoonfX5o`00033ooo]Z1Ol0002hoookJP00
9_oonfX5o`0001Gooo]Z1Ol0003ooookJP[ooo]Z1Ol0000`oookJPGo0000^?oonfX002Kooo]Z1Ol0
000EoookJPGo0000oooonfX;oookJPGo0000;ooonfX5o`000;Sooo]Z000VoookJPGo00005?oonfX6
o`000?oooo]Z2ooonfX5o`0002kooo]Z1Ol0002ioookJP009_oonfX5o`0001Cooo]Z1Ol0003ooook
JPcooo]Z1_l0000]oookJPGo0000^OoonfX002Kooo]Z1Ol0000DoookJPGo0000oooonfX=oookJPGo
0000;?oonfX6o`000;Wooo]Z000VoookJPGo00004ooonfX5o`000?oooo]Z3_oonfX5o`0002cooo]Z
1Ol0002joookJP009_oonfX5o`0001?ooo]Z1Ol0003ooookJPoooo]Z1Ol0000[oookJPGo0000^_oo
nfX002Kooo]Z1Ol0000CoookJPGo0000oooonfX?oookJPGo0000:_oonfX5o`000;_ooo]Z000Voook
JPGo00004_oonfX5o`000?oooo]Z4?oonfX5o`0002[ooo]Z1Ol0002koookJP009_oonfX5o`0001;o
oo]Z1Ol0003ooookJQ7ooo]Z1Ol0000XoookJPKo0000^ooonfX002Kooo]Z1Ol0000AoookJPKo0000
oooonfXAoookJPGo0000:?oonfX5o`000;cooo]Z000VoookJPGo00004OoonfX5o`000?oooo]Z4_oo
nfX6o`0002Oooo]Z1Ol0002loookJP009_oonfX5o`00017ooo]Z1Ol0003ooookJQ?ooo]Z1Ol0000V
oookJPGo0000_OoonfX002Kooo]Z1Ol0000@oookJPGo0000oooonfXDoookJPGo00009_oonfX5o`00
0;gooo]Z000VoookJPGo00004?oonfX5o`000?oooo]Z5OoonfX5o`0002Cooo]Z1_l0002moookJP00
9_oonfX5o`0000oooo]Z1_l0003ooookJQGooo]Z1Ol0000ToookJPGo0000__oonfX002Kooo]Z1Ol0
000?oookJPGo0000oooonfXFoookJPKo00008_oonfX6o`000;kooo]Z000VoookJPGo00003_oonfX6
o`000?oooo]Z5ooonfX5o`0002;ooo]Z1Ol0002ooookJP009_oonfX5o`0000kooo]Z1Ol0003ooook
JQSooo]Z1_l0000PoookJPKo0000_ooonfX002Kooo]Z1Ol0000=oookJPKo0000oooonfXIoookJPGo
00008?oonfX5o`000<3ooo]Z000VoookJPGo00003?oonfX6o`000?oooo]Z6_oonfX5o`0001oooo]Z
1_l00030oookJP009_oonfX5o`0000cooo]Z1_l0003ooookJQ_ooo]Z1Ol0000NoookJPGo0000`Ooo
nfX002Kooo]Z1Ol0000;oookJPKo0000oooonfXLoookJPGo00007OoonfX6o`000<7ooo]Z000Voook
JPGo00002ooonfX5o`000?oooo]Z7OoonfX6o`0001cooo]Z1Ol00032oookJP009_oonfX5o`0000[o
oo]Z1_l0003ooookJQkooo]Z1Ol0000KoookJPKo0000`_oonfX002Kooo]Z1Ol0000:oookJPGo0000
oooonfXOoookJPKo00006_oonfX5o`000<?ooo]Z000VoookJPGo00002OoonfX6o`000?oooo]Z8?oo
nfX6o`0001Sooo]Z1_l00033oookJP009_oonfX5o`0000Sooo]Z1_l0003ooookJR7ooo]Z1_l0000G
oookJPKo0000a?oonfX002Kooo]Z1Ol00008oookJPKo0000oooonfXRoookJPKo00005_oonfX6o`00
0<Cooo]Z000VoookJPGo00001ooonfX6o`000?oooo]Z9?oonfX5o`0001Gooo]Z1_l00035oookJP00
9_oonfX5o`0000Oooo]Z1Ol0003ooookJRGooo]Z1_l0000DoookJPGo0000a_oonfX002Kooo]Z1Ol0
0006oookJPKo0000oooonfXVoookJPKo00004_oonfX6o`000<Kooo]Z000VoookJPGo00001OoonfX6
o`000?oooo]Z9ooonfX7o`00013ooo]Z1_l00037oookJP009_oonfX5o`0000Cooo]Z1ol0003ooook
JRSooo]Z2?l0000=oookJPOo0000aooonfX002Kooo]Z1Ol00003oookJPOo0000oooonfXZoookJPSo
00002_oonfX8o`000<Sooo]Z000JoookJP?o001o2OoonfX5o`0000;ooo]Z1ol0003ooookJRcooo]Z
2?l00008oookJPSo0000bOoonfX001[ooo]Z0ol007l9oookJPgo0000oooonfX^oookJPSo00001_oo
nfX8o`000<[ooo]Z000JoookJP?o001o2OoonfX<o`000?oooo]Z<OoonfX9o`000003oookJ_l0003o
000000Oo0000booonfX001[ooo]Z0ol007l9oookJP_o0000oooonfXcoookJQ3o0000cOoonfX001[o
oo]Z0ol007l9oookJP[o0000oooonfXeoookJPko0000c_oonfX001[ooo]Z0ol007l9oookJPSo0000
oooonfXhoookJPco0000cooonfX001[ooo]Z0ol007l9oookJPKo0000oooonfXloookJPSo0000dOoo
nfX001[ooo]Z0ol007l9oookJPGo0000oooonf[ooookJQOooo]Z000JoookJP?o001o2OoonfX5o`00
0?oooo]ZoooonfXGoookJP005ooonfX6o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX001Oooo]Z
1_l007l9oookJPGo0000oooonf[ooookJQOooo]Z000IoookJPCo001o2OoonfX5o`000?oooo]Zoooo
nfXGoookJP006_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.791911, -0.0842141, \
0.019462, 0.00314902}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Compare this to the forward differencing scheme:\nRecall how\n",
  Cell[BoxData[
      \(exampleFunction[x_]\  := \ 0.1\ x\)], "Input"],
  "\n",
  Cell[BoxData[
      \(StepOnce[{x_, y_}, \ AFunction_, \ delta_]\  := \ {x + \ delta, \ 
          y\  + \ delta\ AFunction[y]}\)], "Input"],
  "\n",
  Cell[BoxData[{
      \(OurStepOnce[{x_\ , \ y_}]\  := \ 
        StepOnce[{x, y}, exampleFunction, \ 0.01]\), "\n", 
      \(\(result\  = \ NestList[OurStepOnce, {0, 1}, 400];\)\), "\n", 
      \(ListPlot[result]\)}], "Input"],
  "\nwere used to create a plot for a function that grew at a rate that was \
0.1 times its current size, try this for the ODE that was solved for above, \
let the new function be y':"
}], "Text"],

Cell[BoxData[
    \(NewExampleFunction[x_\ , \ y_]\  := \ \(-Sin[x]\)\ y\)], "Input"]
}, Open  ]],

Cell[BoxData[
    \(NewStepOnce[{x_, \ y_}, \ AFunctionXY_\ , \ 
        delta_]\  := \ {x\  + \ delta, \ 
        y\  + \ delta\ AFunctionXY[x, y]}\)], "Input"],

Cell[BoxData[
    \(NewOurStepOnce[{x_, \ y_}]\  := \ 
      NewStepOnce[{x, y}, NewExampleFunction, 0.01]\)], "Input"],

Cell[BoxData[
    \(\(result\  = \ NestList[NewOurStepOnce, {0, 1}, 1000];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(result // Short\)], "Input"],

Cell[BoxData[
    TagBox[\({{0, 1}, {0.01`, 
          1}, \[LeftSkeleton]998\[RightSkeleton], {9.999999999999831`, 
          0.15479210677489474`}}\),
      Short]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(forwarddifferenceplot\  = 
      ListPlot[result, PlotStyle \[Rule] {Hue[1]}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -7 -20 ]
[.21429 .00222 7 0 ]
[.40476 .00222 -7 -20 ]
[.40476 .00222 7 0 ]
[.59524 .00222 -7 -20 ]
[.59524 .00222 7 0 ]
[.78571 .00222 -7 -20 ]
[.78571 .00222 7 0 ]
[.97619 .00222 -12 -20 ]
[.97619 .00222 12 0 ]
[.01131 .13244 -29 -10 ]
[.01131 .13244 0 10 ]
[.01131 .25016 -29 -10 ]
[.01131 .25016 0 10 ]
[.01131 .36788 -29 -10 ]
[.01131 .36788 0 10 ]
[.01131 .4856 -29 -10 ]
[.01131 .4856 0 10 ]
[.01131 .60332 -14 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .60332 Mdot
.02476 .60332 Mdot
.02571 .60326 Mdot
.02667 .60314 Mdot
.02762 .60297 Mdot
.02857 .60273 Mdot
.02952 .60244 Mdot
.03048 .60208 Mdot
.03143 .60167 Mdot
.03238 .6012 Mdot
.03333 .60068 Mdot
.03429 .60009 Mdot
.03524 .59945 Mdot
.03619 .59875 Mdot
.03714 .59799 Mdot
.0381 .59718 Mdot
.03905 .59631 Mdot
.04 .59538 Mdot
.04095 .5944 Mdot
.0419 .59336 Mdot
.04286 .59227 Mdot
.04381 .59112 Mdot
.04476 .58992 Mdot
.04571 .58866 Mdot
.04667 .58736 Mdot
.04762 .58599 Mdot
.04857 .58458 Mdot
.04952 .58312 Mdot
.05048 .5816 Mdot
.05143 .58003 Mdot
.05238 .57842 Mdot
.05333 .57675 Mdot
.05429 .57504 Mdot
.05524 .57327 Mdot
.05619 .57146 Mdot
.05714 .56961 Mdot
.0581 .5677 Mdot
.05905 .56576 Mdot
.06 .56376 Mdot
.06095 .56173 Mdot
.0619 .55965 Mdot
.06286 .55753 Mdot
.06381 .55536 Mdot
.06476 .55316 Mdot
.06571 .55091 Mdot
.06667 .54863 Mdot
.06762 .54631 Mdot
.06857 .54395 Mdot
.06952 .54155 Mdot
.07048 .53912 Mdot
.07143 .53665 Mdot
.07238 .53415 Mdot
.07333 .53161 Mdot
.07429 .52904 Mdot
.07524 .52644 Mdot
.07619 .52381 Mdot
.07714 .52115 Mdot
.0781 .51846 Mdot
.07905 .51574 Mdot
.08 .513 Mdot
.08095 .51022 Mdot
.0819 .50743 Mdot
.08286 .5046 Mdot
.08381 .50176 Mdot
.08476 .49889 Mdot
.08571 .496 Mdot
.08667 .49308 Mdot
.08762 .49015 Mdot
.08857 .4872 Mdot
.08952 .48423 Mdot
.09048 .48124 Mdot
.09143 .47823 Mdot
.09238 .47521 Mdot
.09333 .47218 Mdot
.09429 .46912 Mdot
.09524 .46606 Mdot
.09619 .46298 Mdot
.09714 .4599 Mdot
.0981 .4568 Mdot
.09905 .45369 Mdot
.1 .45057 Mdot
.10095 .44744 Mdot
.1019 .44431 Mdot
.10286 .44117 Mdot
.10381 .43802 Mdot
.10476 .43487 Mdot
.10571 .43171 Mdot
.10667 .42855 Mdot
.10762 .42539 Mdot
.10857 .42222 Mdot
.10952 .41906 Mdot
.11048 .41589 Mdot
.11143 .41272 Mdot
.11238 .40956 Mdot
.11333 .40639 Mdot
.11429 .40323 Mdot
.11524 .40007 Mdot
.11619 .39691 Mdot
.11714 .39376 Mdot
.1181 .39061 Mdot
.11905 .38747 Mdot
.12 .38433 Mdot
.12095 .3812 Mdot
.1219 .37808 Mdot
.12286 .37496 Mdot
.12381 .37186 Mdot
.12476 .36876 Mdot
.12571 .36567 Mdot
.12667 .36259 Mdot
.12762 .35952 Mdot
.12857 .35647 Mdot
.12952 .35342 Mdot
.13048 .35039 Mdot
.13143 .34737 Mdot
.13238 .34436 Mdot
.13333 .34136 Mdot
.13429 .33838 Mdot
.13524 .33541 Mdot
.13619 .33246 Mdot
.13714 .32952 Mdot
.1381 .3266 Mdot
.13905 .32369 Mdot
.14 .3208 Mdot
.14095 .31793 Mdot
.1419 .31507 Mdot
.14286 .31223 Mdot
.14381 .30941 Mdot
.14476 .3066 Mdot
.14571 .30381 Mdot
.14667 .30104 Mdot
.14762 .29829 Mdot
.14857 .29556 Mdot
.14952 .29285 Mdot
.15048 .29015 Mdot
.15143 .28748 Mdot
.15238 .28482 Mdot
.15333 .28219 Mdot
.15429 .27957 Mdot
.15524 .27697 Mdot
.15619 .2744 Mdot
.15714 .27184 Mdot
.1581 .26931 Mdot
.15905 .2668 Mdot
.16 .26431 Mdot
.16095 .26183 Mdot
.1619 .25938 Mdot
.16286 .25696 Mdot
.16381 .25455 Mdot
.16476 .25216 Mdot
.16571 .2498 Mdot
.16667 .24745 Mdot
.16762 .24513 Mdot
.16857 .24283 Mdot
.16952 .24055 Mdot
.17048 .2383 Mdot
.17143 .23606 Mdot
.17238 .23385 Mdot
.17333 .23166 Mdot
.17429 .22949 Mdot
.17524 .22734 Mdot
.17619 .22522 Mdot
.17714 .22311 Mdot
.1781 .22103 Mdot
.17905 .21897 Mdot
.18 .21693 Mdot
.18095 .21491 Mdot
.1819 .21292 Mdot
.18286 .21094 Mdot
.18381 .20899 Mdot
.18476 .20706 Mdot
.18571 .20515 Mdot
.18667 .20326 Mdot
.18762 .20139 Mdot
.18857 .19955 Mdot
.18952 .19772 Mdot
.19048 .19592 Mdot
.19143 .19414 Mdot
.19238 .19237 Mdot
.19333 .19063 Mdot
.19429 .18891 Mdot
.19524 .18721 Mdot
.19619 .18553 Mdot
.19714 .18387 Mdot
.1981 .18223 Mdot
.19905 .18061 Mdot
.2 .17901 Mdot
.20095 .17743 Mdot
.2019 .17587 Mdot
.20286 .17433 Mdot
.20381 .17281 Mdot
.20476 .17131 Mdot
.20571 .16983 Mdot
.20667 .16837 Mdot
.20762 .16692 Mdot
.20857 .1655 Mdot
.20952 .16409 Mdot
.21048 .16271 Mdot
.21143 .16134 Mdot
.21238 .15999 Mdot
.21333 .15865 Mdot
.21429 .15734 Mdot
.21524 .15604 Mdot
.21619 .15476 Mdot
.21714 .1535 Mdot
.2181 .15226 Mdot
.21905 .15103 Mdot
.22 .14982 Mdot
.22095 .14863 Mdot
.2219 .14745 Mdot
.22286 .14629 Mdot
.22381 .14515 Mdot
.22476 .14402 Mdot
.22571 .14291 Mdot
.22667 .14182 Mdot
.22762 .14074 Mdot
.22857 .13968 Mdot
.22952 .13864 Mdot
.23048 .13761 Mdot
.23143 .13659 Mdot
.23238 .13559 Mdot
.23333 .13461 Mdot
.23429 .13364 Mdot
.23524 .13268 Mdot
.23619 .13174 Mdot
.23714 .13082 Mdot
.2381 .12991 Mdot
.23905 .12901 Mdot
.24 .12813 Mdot
.24095 .12726 Mdot
.2419 .12641 Mdot
.24286 .12557 Mdot
.24381 .12474 Mdot
.24476 .12393 Mdot
.24571 .12313 Mdot
.24667 .12234 Mdot
.24762 .12157 Mdot
.24857 .12081 Mdot
.24952 .12006 Mdot
.25048 .11933 Mdot
.25143 .1186 Mdot
.25238 .1179 Mdot
.25333 .1172 Mdot
.25429 .11651 Mdot
.25524 .11584 Mdot
.25619 .11518 Mdot
.25714 .11453 Mdot
.2581 .1139 Mdot
.25905 .11327 Mdot
.26 .11266 Mdot
.26095 .11206 Mdot
.2619 .11147 Mdot
.26286 .11089 Mdot
.26381 .11032 Mdot
.26476 .10976 Mdot
.26571 .10922 Mdot
.26667 .10868 Mdot
.26762 .10816 Mdot
.26857 .10764 Mdot
.26952 .10714 Mdot
.27048 .10665 Mdot
.27143 .10617 Mdot
.27238 .1057 Mdot
.27333 .10523 Mdot
.27429 .10478 Mdot
.27524 .10434 Mdot
.27619 .10391 Mdot
.27714 .10349 Mdot
.2781 .10308 Mdot
.27905 .10268 Mdot
.28 .10229 Mdot
.28095 .1019 Mdot
.2819 .10153 Mdot
.28286 .10117 Mdot
.28381 .10081 Mdot
.28476 .10047 Mdot
.28571 .10013 Mdot
.28667 .09981 Mdot
.28762 .09949 Mdot
.28857 .09918 Mdot
.28952 .09889 Mdot
.29048 .0986 Mdot
.29143 .09831 Mdot
.29238 .09804 Mdot
.29333 .09778 Mdot
.29429 .09752 Mdot
.29524 .09728 Mdot
.29619 .09704 Mdot
.29714 .09681 Mdot
.2981 .09659 Mdot
.29905 .09638 Mdot
.3 .09618 Mdot
.30095 .09598 Mdot
.3019 .0958 Mdot
.30286 .09562 Mdot
.30381 .09545 Mdot
.30476 .09529 Mdot
.30571 .09513 Mdot
.30667 .09499 Mdot
.30762 .09485 Mdot
.30857 .09472 Mdot
.30952 .0946 Mdot
.31048 .09449 Mdot
.31143 .09438 Mdot
.31238 .09429 Mdot
.31333 .0942 Mdot
.31429 .09412 Mdot
.31524 .09404 Mdot
.31619 .09398 Mdot
.31714 .09392 Mdot
.3181 .09387 Mdot
.31905 .09383 Mdot
.32 .0938 Mdot
.32095 .09378 Mdot
.3219 .09376 Mdot
.32286 .09375 Mdot
.32381 .09375 Mdot
.32476 .09375 Mdot
.32571 .09377 Mdot
.32667 .09379 Mdot
.32762 .09382 Mdot
.32857 .09386 Mdot
.32952 .09391 Mdot
.33048 .09396 Mdot
.33143 .09402 Mdot
.33238 .09409 Mdot
.33333 .09417 Mdot
.33429 .09426 Mdot
.33524 .09435 Mdot
.33619 .09445 Mdot
.33714 .09456 Mdot
.3381 .09468 Mdot
.33905 .09481 Mdot
.34 .09494 Mdot
.34095 .09508 Mdot
.3419 .09523 Mdot
.34286 .09539 Mdot
.34381 .09556 Mdot
.34476 .09573 Mdot
.34571 .09592 Mdot
.34667 .09611 Mdot
.34762 .09631 Mdot
.34857 .09652 Mdot
.34952 .09674 Mdot
.35048 .09696 Mdot
.35143 .09719 Mdot
.35238 .09744 Mdot
.35333 .09769 Mdot
.35429 .09795 Mdot
.35524 .09822 Mdot
.35619 .09849 Mdot
.35714 .09878 Mdot
.3581 .09907 Mdot
.35905 .09938 Mdot
.36 .09969 Mdot
.36095 .10001 Mdot
.3619 .10034 Mdot
.36286 .10068 Mdot
.36381 .10103 Mdot
.36476 .10139 Mdot
.36571 .10176 Mdot
.36667 .10214 Mdot
.36762 .10252 Mdot
.36857 .10292 Mdot
.36952 .10333 Mdot
.37048 .10374 Mdot
.37143 .10417 Mdot
.37238 .1046 Mdot
.37333 .10505 Mdot
.37429 .1055 Mdot
.37524 .10597 Mdot
.37619 .10645 Mdot
.37714 .10693 Mdot
.3781 .10743 Mdot
.37905 .10793 Mdot
.38 .10845 Mdot
.38095 .10898 Mdot
.3819 .10952 Mdot
.38286 .11007 Mdot
.38381 .11063 Mdot
.38476 .1112 Mdot
.38571 .11178 Mdot
.38667 .11238 Mdot
.38762 .11298 Mdot
.38857 .1136 Mdot
.38952 .11423 Mdot
.39048 .11487 Mdot
.39143 .11552 Mdot
.39238 .11618 Mdot
.39333 .11686 Mdot
.39429 .11755 Mdot
.39524 .11825 Mdot
.39619 .11896 Mdot
.39714 .11968 Mdot
.3981 .12042 Mdot
.39905 .12117 Mdot
.4 .12193 Mdot
.40095 .12271 Mdot
.4019 .12349 Mdot
.40286 .1243 Mdot
.40381 .12511 Mdot
.40476 .12594 Mdot
.40571 .12678 Mdot
.40667 .12764 Mdot
.40762 .12851 Mdot
.40857 .12939 Mdot
.40952 .13029 Mdot
.41048 .1312 Mdot
.41143 .13212 Mdot
.41238 .13306 Mdot
.41333 .13402 Mdot
.41429 .13499 Mdot
.41524 .13597 Mdot
.41619 .13697 Mdot
.41714 .13798 Mdot
.4181 .13901 Mdot
.41905 .14006 Mdot
.42 .14112 Mdot
.42095 .1422 Mdot
.4219 .14329 Mdot
.42286 .14439 Mdot
.42381 .14552 Mdot
.42476 .14666 Mdot
.42571 .14782 Mdot
.42667 .14899 Mdot
.42762 .15018 Mdot
.42857 .15138 Mdot
.42952 .15261 Mdot
.43048 .15385 Mdot
.43143 .1551 Mdot
.43238 .15638 Mdot
.43333 .15767 Mdot
.43429 .15898 Mdot
.43524 .16031 Mdot
.43619 .16165 Mdot
.43714 .16302 Mdot
.4381 .1644 Mdot
.43905 .1658 Mdot
.44 .16722 Mdot
.44095 .16865 Mdot
.4419 .17011 Mdot
.44286 .17158 Mdot
.44381 .17307 Mdot
.44476 .17459 Mdot
.44571 .17612 Mdot
.44667 .17767 Mdot
.44762 .17924 Mdot
.44857 .18083 Mdot
.44952 .18243 Mdot
.45048 .18406 Mdot
.45143 .18571 Mdot
.45238 .18738 Mdot
.45333 .18907 Mdot
.45429 .19077 Mdot
.45524 .1925 Mdot
.45619 .19425 Mdot
.45714 .19602 Mdot
.4581 .19781 Mdot
.45905 .19962 Mdot
.46 .20145 Mdot
.46095 .2033 Mdot
.4619 .20517 Mdot
.46286 .20706 Mdot
.46381 .20898 Mdot
.46476 .21091 Mdot
.46571 .21287 Mdot
.46667 .21484 Mdot
.46762 .21684 Mdot
.46857 .21886 Mdot
.46952 .2209 Mdot
.47048 .22296 Mdot
.47143 .22504 Mdot
.47238 .22714 Mdot
.47333 .22927 Mdot
.47429 .23141 Mdot
.47524 .23358 Mdot
.47619 .23577 Mdot
.47714 .23798 Mdot
.4781 .24021 Mdot
.47905 .24246 Mdot
.48 .24473 Mdot
.48095 .24702 Mdot
.4819 .24934 Mdot
.48286 .25167 Mdot
.48381 .25403 Mdot
.48476 .25641 Mdot
.48571 .2588 Mdot
.48667 .26122 Mdot
.48762 .26366 Mdot
.48857 .26612 Mdot
.48952 .2686 Mdot
.49048 .27109 Mdot
.49143 .27361 Mdot
.49238 .27615 Mdot
.49333 .27871 Mdot
.49429 .28129 Mdot
.49524 .28389 Mdot
.49619 .2865 Mdot
.49714 .28914 Mdot
.4981 .29179 Mdot
.49905 .29446 Mdot
.5 .29715 Mdot
.50095 .29986 Mdot
.5019 .30259 Mdot
.50286 .30533 Mdot
.50381 .30809 Mdot
.50476 .31087 Mdot
.50571 .31366 Mdot
.50667 .31647 Mdot
.50762 .3193 Mdot
.50857 .32214 Mdot
.50952 .325 Mdot
.51048 .32787 Mdot
.51143 .33076 Mdot
.51238 .33366 Mdot
.51333 .33658 Mdot
.51429 .33951 Mdot
.51524 .34245 Mdot
.51619 .3454 Mdot
.51714 .34837 Mdot
.5181 .35135 Mdot
.51905 .35434 Mdot
.52 .35734 Mdot
.52095 .36035 Mdot
.5219 .36337 Mdot
.52286 .3664 Mdot
.52381 .36944 Mdot
.52476 .37248 Mdot
.52571 .37554 Mdot
.52667 .3786 Mdot
.52762 .38167 Mdot
.52857 .38474 Mdot
.52952 .38782 Mdot
.53048 .39091 Mdot
.53143 .394 Mdot
.53238 .39709 Mdot
.53333 .40018 Mdot
.53429 .40328 Mdot
.53524 .40638 Mdot
.53619 .40948 Mdot
.53714 .41258 Mdot
.5381 .41568 Mdot
.53905 .41878 Mdot
.54 .42187 Mdot
.54095 .42497 Mdot
.5419 .42806 Mdot
.54286 .43114 Mdot
.54381 .43423 Mdot
.54476 .4373 Mdot
.54571 .44037 Mdot
.54667 .44344 Mdot
.54762 .44649 Mdot
.54857 .44954 Mdot
.54952 .45257 Mdot
.55048 .4556 Mdot
.55143 .45862 Mdot
.55238 .46162 Mdot
.55333 .46461 Mdot
.55429 .46759 Mdot
.55524 .47055 Mdot
.55619 .4735 Mdot
.55714 .47643 Mdot
.5581 .47935 Mdot
.55905 .48224 Mdot
.56 .48512 Mdot
.56095 .48798 Mdot
.5619 .49082 Mdot
.56286 .49363 Mdot
.56381 .49643 Mdot
.56476 .4992 Mdot
.56571 .50195 Mdot
.56667 .50467 Mdot
.56762 .50737 Mdot
.56857 .51004 Mdot
.56952 .51269 Mdot
.57048 .5153 Mdot
.57143 .51789 Mdot
.57238 .52045 Mdot
.57333 .52298 Mdot
.57429 .52547 Mdot
.57524 .52793 Mdot
.57619 .53036 Mdot
.57714 .53276 Mdot
.5781 .53512 Mdot
.57905 .53745 Mdot
.58 .53973 Mdot
.58095 .54199 Mdot
.5819 .5442 Mdot
.58286 .54637 Mdot
.58381 .54851 Mdot
.58476 .5506 Mdot
.58571 .55266 Mdot
.58667 .55467 Mdot
.58762 .55664 Mdot
.58857 .55856 Mdot
.58952 .56044 Mdot
.59048 .56228 Mdot
.59143 .56407 Mdot
.59238 .56581 Mdot
.59333 .56751 Mdot
.59429 .56916 Mdot
.59524 .57076 Mdot
.59619 .57232 Mdot
.59714 .57382 Mdot
.5981 .57528 Mdot
.59905 .57668 Mdot
.6 .57803 Mdot
.60095 .57934 Mdot
.6019 .58059 Mdot
.60286 .58178 Mdot
.60381 .58293 Mdot
.60476 .58402 Mdot
.60571 .58506 Mdot
.60667 .58604 Mdot
.60762 .58697 Mdot
.60857 .58784 Mdot
.60952 .58866 Mdot
.61048 .58942 Mdot
.61143 .59013 Mdot
.61238 .59078 Mdot
.61333 .59137 Mdot
.61429 .59191 Mdot
.61524 .59239 Mdot
.61619 .59281 Mdot
.61714 .59317 Mdot
.6181 .59348 Mdot
.61905 .59373 Mdot
.62 .59392 Mdot
.62095 .59406 Mdot
.6219 .59413 Mdot
.62286 .59415 Mdot
.62381 .59411 Mdot
.62476 .59401 Mdot
.62571 .59386 Mdot
.62667 .59365 Mdot
.62762 .59337 Mdot
.62857 .59305 Mdot
.62952 .59266 Mdot
.63048 .59222 Mdot
.63143 .59172 Mdot
.63238 .59116 Mdot
.63333 .59054 Mdot
.63429 .58987 Mdot
.63524 .58915 Mdot
.63619 .58836 Mdot
.63714 .58752 Mdot
.6381 .58663 Mdot
.63905 .58568 Mdot
.64 .58467 Mdot
.64095 .58362 Mdot
.6419 .5825 Mdot
.64286 .58134 Mdot
.64381 .58012 Mdot
.64476 .57885 Mdot
.64571 .57752 Mdot
.64667 .57615 Mdot
.64762 .57472 Mdot
.64857 .57325 Mdot
.64952 .57172 Mdot
.65048 .57014 Mdot
.65143 .56852 Mdot
.65238 .56685 Mdot
.65333 .56513 Mdot
.65429 .56336 Mdot
.65524 .56155 Mdot
.65619 .55969 Mdot
.65714 .55778 Mdot
.6581 .55584 Mdot
.65905 .55385 Mdot
.66 .55181 Mdot
.66095 .54974 Mdot
.6619 .54762 Mdot
.66286 .54546 Mdot
.66381 .54326 Mdot
.66476 .54103 Mdot
.66571 .53875 Mdot
.66667 .53644 Mdot
.66762 .53409 Mdot
.66857 .53171 Mdot
.66952 .52929 Mdot
.67048 .52684 Mdot
.67143 .52435 Mdot
.67238 .52184 Mdot
.67333 .51929 Mdot
.67429 .51671 Mdot
.67524 .51409 Mdot
.67619 .51146 Mdot
.67714 .50879 Mdot
.6781 .50609 Mdot
.67905 .50337 Mdot
.68 .50063 Mdot
.68095 .49786 Mdot
.6819 .49506 Mdot
.68286 .49224 Mdot
.68381 .4894 Mdot
.68476 .48654 Mdot
.68571 .48366 Mdot
.68667 .48076 Mdot
.68762 .47784 Mdot
.68857 .47491 Mdot
.68952 .47195 Mdot
.69048 .46898 Mdot
.69143 .466 Mdot
.69238 .463 Mdot
.69333 .45999 Mdot
.69429 .45696 Mdot
.69524 .45393 Mdot
.69619 .45088 Mdot
.69714 .44782 Mdot
.6981 .44476 Mdot
.69905 .44168 Mdot
.7 .4386 Mdot
.70095 .43551 Mdot
.7019 .43241 Mdot
.70286 .42931 Mdot
.70381 .4262 Mdot
.70476 .42309 Mdot
.70571 .41998 Mdot
.70667 .41687 Mdot
.70762 .41375 Mdot
.70857 .41063 Mdot
.70952 .40751 Mdot
.71048 .4044 Mdot
.71143 .40128 Mdot
.71238 .39816 Mdot
.71333 .39505 Mdot
.71429 .39194 Mdot
.71524 .38884 Mdot
.71619 .38574 Mdot
.71714 .38264 Mdot
.7181 .37955 Mdot
.71905 .37647 Mdot
.72 .37339 Mdot
.72095 .37032 Mdot
.7219 .36726 Mdot
.72286 .36421 Mdot
.72381 .36117 Mdot
.72476 .35813 Mdot
.72571 .35511 Mdot
.72667 .3521 Mdot
.72762 .3491 Mdot
.72857 .3461 Mdot
.72952 .34313 Mdot
.73048 .34016 Mdot
.73143 .33721 Mdot
.73238 .33427 Mdot
.73333 .33134 Mdot
.73429 .32843 Mdot
.73524 .32553 Mdot
.73619 .32265 Mdot
.73714 .31979 Mdot
.7381 .31694 Mdot
.73905 .3141 Mdot
.74 .31128 Mdot
.74095 .30848 Mdot
.7419 .3057 Mdot
.74286 .30293 Mdot
.74381 .30018 Mdot
.74476 .29745 Mdot
.74571 .29473 Mdot
.74667 .29204 Mdot
.74762 .28936 Mdot
.74857 .2867 Mdot
.74952 .28406 Mdot
.75048 .28144 Mdot
.75143 .27884 Mdot
.75238 .27626 Mdot
.75333 .2737 Mdot
.75429 .27116 Mdot
.75524 .26864 Mdot
.75619 .26614 Mdot
.75714 .26365 Mdot
.7581 .26119 Mdot
.75905 .25876 Mdot
.76 .25634 Mdot
.76095 .25394 Mdot
.7619 .25156 Mdot
.76286 .24921 Mdot
.76381 .24687 Mdot
.76476 .24456 Mdot
.76571 .24227 Mdot
.76667 .24 Mdot
.76762 .23775 Mdot
.76857 .23552 Mdot
.76952 .23331 Mdot
.77048 .23113 Mdot
.77143 .22896 Mdot
.77238 .22682 Mdot
.77333 .2247 Mdot
.77429 .2226 Mdot
.77524 .22052 Mdot
.77619 .21846 Mdot
.77714 .21643 Mdot
.7781 .21442 Mdot
.77905 .21242 Mdot
.78 .21045 Mdot
.78095 .2085 Mdot
.7819 .20657 Mdot
.78286 .20466 Mdot
.78381 .20278 Mdot
.78476 .20091 Mdot
.78571 .19907 Mdot
.78667 .19724 Mdot
.78762 .19544 Mdot
.78857 .19366 Mdot
.78952 .1919 Mdot
.79048 .19015 Mdot
.79143 .18843 Mdot
.79238 .18673 Mdot
.79333 .18505 Mdot
.79429 .18339 Mdot
.79524 .18175 Mdot
.79619 .18013 Mdot
.79714 .17853 Mdot
.7981 .17695 Mdot
.79905 .17539 Mdot
.8 .17385 Mdot
.80095 .17233 Mdot
.8019 .17082 Mdot
.80286 .16934 Mdot
.80381 .16788 Mdot
.80476 .16643 Mdot
.80571 .165 Mdot
.80667 .16359 Mdot
.80762 .1622 Mdot
.80857 .16083 Mdot
.80952 .15948 Mdot
.81048 .15814 Mdot
.81143 .15683 Mdot
.81238 .15553 Mdot
.81333 .15424 Mdot
.81429 .15298 Mdot
.81524 .15173 Mdot
.81619 .1505 Mdot
.81714 .14929 Mdot
.8181 .14809 Mdot
.81905 .14691 Mdot
.82 .14575 Mdot
.82095 .1446 Mdot
.8219 .14347 Mdot
.82286 .14236 Mdot
.82381 .14126 Mdot
.82476 .14018 Mdot
.82571 .13912 Mdot
.82667 .13807 Mdot
.82762 .13703 Mdot
.82857 .13601 Mdot
.82952 .13501 Mdot
.83048 .13402 Mdot
.83143 .13305 Mdot
.83238 .13209 Mdot
.83333 .13114 Mdot
.83429 .13021 Mdot
.83524 .1293 Mdot
.83619 .1284 Mdot
.83714 .12751 Mdot
.8381 .12664 Mdot
.83905 .12578 Mdot
.84 .12493 Mdot
.84095 .1241 Mdot
.8419 .12328 Mdot
.84286 .12248 Mdot
.84381 .12169 Mdot
.84476 .12091 Mdot
.84571 .12014 Mdot
.84667 .11939 Mdot
.84762 .11865 Mdot
.84857 .11792 Mdot
.84952 .11721 Mdot
.85048 .11651 Mdot
.85143 .11582 Mdot
.85238 .11514 Mdot
.85333 .11447 Mdot
.85429 .11382 Mdot
.85524 .11318 Mdot
.85619 .11255 Mdot
.85714 .11193 Mdot
.8581 .11132 Mdot
.85905 .11073 Mdot
.86 .11014 Mdot
.86095 .10957 Mdot
.8619 .10901 Mdot
.86286 .10845 Mdot
.86381 .10791 Mdot
.86476 .10738 Mdot
.86571 .10686 Mdot
.86667 .10636 Mdot
.86762 .10586 Mdot
.86857 .10537 Mdot
.86952 .10489 Mdot
.87048 .10442 Mdot
.87143 .10397 Mdot
.87238 .10352 Mdot
.87333 .10308 Mdot
.87429 .10266 Mdot
.87524 .10224 Mdot
.87619 .10183 Mdot
.87714 .10143 Mdot
.8781 .10104 Mdot
.87905 .10066 Mdot
.88 .10029 Mdot
.88095 .09993 Mdot
.8819 .09958 Mdot
.88286 .09924 Mdot
.88381 .09891 Mdot
.88476 .09858 Mdot
.88571 .09827 Mdot
.88667 .09796 Mdot
.88762 .09767 Mdot
.88857 .09738 Mdot
.88952 .0971 Mdot
.89048 .09683 Mdot
.89143 .09657 Mdot
.89238 .09631 Mdot
.89333 .09607 Mdot
.89429 .09583 Mdot
.89524 .0956 Mdot
.89619 .09538 Mdot
.89714 .09517 Mdot
.8981 .09497 Mdot
.89905 .09478 Mdot
.9 .09459 Mdot
.90095 .09441 Mdot
.9019 .09424 Mdot
.90286 .09408 Mdot
.90381 .09393 Mdot
.90476 .09378 Mdot
.90571 .09364 Mdot
.90667 .09351 Mdot
.90762 .09339 Mdot
.90857 .09328 Mdot
.90952 .09317 Mdot
.91048 .09308 Mdot
.91143 .09299 Mdot
.91238 .0929 Mdot
.91333 .09283 Mdot
.91429 .09276 Mdot
.91524 .09271 Mdot
.91619 .09265 Mdot
.91714 .09261 Mdot
.9181 .09258 Mdot
.91905 .09255 Mdot
.92 .09253 Mdot
.92095 .09252 Mdot
.9219 .09252 Mdot
.92286 .09252 Mdot
.92381 .09253 Mdot
.92476 .09255 Mdot
.92571 .09258 Mdot
.92667 .09261 Mdot
.92762 .09266 Mdot
.92857 .09271 Mdot
.92952 .09277 Mdot
.93048 .09283 Mdot
.93143 .09291 Mdot
.93238 .09299 Mdot
.93333 .09308 Mdot
.93429 .09318 Mdot
.93524 .09328 Mdot
.93619 .0934 Mdot
.93714 .09352 Mdot
.9381 .09365 Mdot
.93905 .09379 Mdot
.94 .09393 Mdot
.94095 .09408 Mdot
.9419 .09425 Mdot
.94286 .09442 Mdot
.94381 .09459 Mdot
.94476 .09478 Mdot
.94571 .09497 Mdot
.94667 .09518 Mdot
.94762 .09539 Mdot
.94857 .09561 Mdot
.94952 .09584 Mdot
.95048 .09607 Mdot
.95143 .09632 Mdot
.95238 .09657 Mdot
.95333 .09683 Mdot
.95429 .0971 Mdot
.95524 .09738 Mdot
.95619 .09767 Mdot
.95714 .09796 Mdot
.9581 .09827 Mdot
.95905 .09858 Mdot
.96 .0989 Mdot
.96095 .09924 Mdot
.9619 .09958 Mdot
.96286 .09993 Mdot
.96381 .10029 Mdot
.96476 .10066 Mdot
.96571 .10103 Mdot
.96667 .10142 Mdot
.96762 .10182 Mdot
.96857 .10222 Mdot
.96952 .10264 Mdot
.97048 .10306 Mdot
.97143 .1035 Mdot
.97238 .10395 Mdot
.97333 .1044 Mdot
.97429 .10487 Mdot
.97524 .10534 Mdot
.97619 .10583 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00R_oonfX9o`00Of?ooo]Z0ol007mPoook
JPGo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o3ooonfX008[ooo]Z2Ol007mSoookJP?o
001oGooonfX7o`00Of3ooo]Z1ol007mNoookJP?o001o1?oonfX7o`00O`kooo]Z002:oookJPCo001o
J?oonfX3o`00Oeoooo]Z0ol007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`kooo]Z002;oookJPCo001oH_oonfX9o`00Oegooo]Z
0ol007l3oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l=oookJP00S?oonfX5o`00Of3ooo]Z2Ol007mMoookJP?o001o0ooonfX3o`00Oekooo]Z0ol0
07l3oookJP?o001oGOoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o3OoonfX008kooo]Z1?l007mO
oookJP;o001o0ooonfX3o`00Oekooo]Z1?l007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mM
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00SooonfX3o`00Of3ooo]Z0_l007l2oook
JP?o001oG_oonfX8o`00Of3ooo]Z1ol007mNoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oook
JP00T?oonfX3o`00Oeoooo]Z0ol007l01?oonf[o001oo`00Ool007mNoookJP?o001o00Cooo]Zo`00
Ool007oo001oHOoonfX7o`00Oekooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`gooo]Z002:oook
JP?o001o0ooonfX3o`00Of3ooo]Z0_l007l01?oonf[o001oo`00Ool007mNoookJP?o001oI?oonfX3
o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00R_oonfX3o`00
O`?ooo]Z0ol007mQoookJPGo001oG_oonfX3o`00OfCooo]Z0ol007l3oookJP?o001oF_oonfX6o`00
O`?ooo]Z0ol007l3oookJP?o001o3OoonfX002Kooo]Z1Ol0001OoookJPCo001o0_oonfX3o`00Of7o
oo]Z1Ol007mOoookJP?o001o0_oonfX3o`00Oekooo]Z0ol007l3oookJP?o001oF_oonfX6o`00O`Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l>oookJP009_oonfX5o`00063ooo]Z1ol007mSoookJPCo
001oGooonfX7o`00Of3ooo]Z1ol007mMoookJPCo001o1?oonfX7o`00O`kooo]Z000VoookJPGo0000
HOoonfX5o`00OfGooo]Z0ol007mQoookJPCo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o
3ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003o
o`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o
00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX002Kooo]Z1Ol0001ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0001ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oo
oo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooo
nfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ][o
oo]Z4_oo000ZoookJP009_oonfX5o`0009Cooo]Z5ooo003ooookJRWooo]Z7_oo000ToookJP009_oo
nfX5o`0008oooo]Z8?oo003ooookJR;ooo]Z9Ooo000PoookJP009_oonfX5o`0008_ooo]Z:?oo003o
oookJQ_ooo]Z:ooo000MoookJP009_oonfX5o`0008Wooo]Z;Ooo003ooookJQGooo]Z4?oo000@oook
JQ7oo`006_oonfX002Kooo]Z1Ol00026oookJPooo`005?oonfX?ool00?oooo]Z4?oonfX>ool001[o
oo]Z3_oo000HoookJP009_oonfX5o`0008Cooo]Z3?oo000NoookJPgoo`00oooonfX;oookJPcoo`00
8_oonfX<ool001Kooo]Z000VoookJPGo0000P_oonfX;ool002Cooo]Z3?oo003ooookJPOooo]Z2ooo
000XoookJP[oo`005OoonfX002Kooo]Z1Ol00020oookJP[oo`00:ooonfX:ool00?oooo]Z0ooonfX:
ool002kooo]Z2?oo000DoookJP009_oonfX5o`0007oooo]Z2Ooo000_oookJPWoo`00oooonfX1oook
JPWoo`00<_oonfX6ool001Cooo]Z000VoookJPGo0000OOoonfX9ool003?ooo]Z2Ooo003loookJPWo
o`00=_oonfX3ool001Gooo]Z000VoookJPGo0000NooonfX9ool003Oooo]Z2?oo003joookJPSoo`00
D?oonfX002Kooo]Z1Ol0001ioookJPWoo`00>ooonfX8ool00?Kooo]Z2?oo001BoookJP009_oonfX5
o`0007Sooo]Z2?oo000ooookJPOoo`00m?oonfX7ool005Cooo]Z000VoookJPGo0000MooonfX7ool0
04;ooo]Z1ooo003boookJPOoo`00EOoonfX002Kooo]Z1Ol0001foookJPKoo`00A_oonfX7ool00>ko
oo]Z1ooo001GoookJP009_oonfX5o`0007Cooo]Z1ooo0018oookJPOoo`00k?oonfX7ool005Sooo]Z
000VoookJPGo0000LooonfX7ool004_ooo]Z1ooo003YoookJPOoo`00FOoonfX002Kooo]Z1Ol0001b
oookJPKoo`00C_oonfX7ool00>Oooo]Z1_oo001KoookJP002OoonfX5o`00O`Cooo]Z0ol007l00ooo
nf[o001oo`00O`07o`00O`Oooo]Z1Ol0001aoookJPKoo`00DOoonfX6ool00>Gooo]Z1_oo001Loook
JP002?oonfX7o`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0001`oookJPKo
o`00DooonfX6ool00>?ooo]Z1_oo001MoookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l00ooonf[o001oo`00O`02o`00O`cooo]Z1Ol0001_oookJPKoo`00EOoonfX6ool00>7o
oo]Z1Ooo001OoookJP001ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o2ooonfX5o`0006kooo]Z
1_oo001GoookJPKoo`00gooonfX5ool0063ooo]Z0007oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0
07l9oookJPOo0000JooonfX6ool005Wooo]Z1_oo003MoookJPGoo`00HOoonfX000Oooo]Z0ol007l3
oookJP?o001o2_oonfX4o`00O`Sooo]Z1Ol0001/oookJPKoo`00FooonfX6ool00=_ooo]Z1Ooo001R
oookJP001ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`0006_ooo]Z1_oo001Moook
JPKoo`00fOoonfX5ool006?ooo]Z0007oookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJPGo
0000J_oonfX6ool005oooo]Z1Ooo003HoookJPGoo`00I?oonfX000Oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000JOoonfX6ool0067ooo]Z1Ooo003FoookJPGoo`00
IOoonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo0000J?oo
nfX6ool006?ooo]Z1Ooo003DoookJPKoo`00IOoonfX000Sooo]Z0ol007l01?oonf[o001oo`00Ool0
07l7oookJPCo001o0_oonfX3o`00O`Oooo]Z1Ol0001WoookJPKoo`00IOoonfX5ool00=?ooo]Z1Ooo
001VoookJP002?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo0000IooonfX5ool006Oooo]Z1Ooo003A
oookJPGoo`00IooonfX000Wooo]Z1Ol007l:oookJPGo001o2OoonfX5o`0006Kooo]Z1Ooo001Yoook
JPGoo`00cooonfX5ool006Sooo]Z000VoookJPGo0000IOoonfX5ool006[ooo]Z1Ooo003>oookJPGo
o`00JOoonfX002Kooo]Z1Ol0001ToookJPGoo`00K?oonfX5ool00<gooo]Z1Ooo001YoookJP009_oo
nfX5o`0006?ooo]Z1Ooo001^oookJPGoo`00booonfX5ool006[ooo]Z000VoookJPGo0000HooonfX5
ool006oooo]Z1Ooo0039oookJPGoo`00JooonfX002Kooo]Z1Ol0001RoookJPGoo`00L?oonfX6ool0
0<Oooo]Z1Ooo001/oookJP009_oonfX5o`00067ooo]Z1Ooo001boookJPKoo`00aOoonfX5ool006go
oo]Z000VoookJPGo0000HOoonfX5ool007?ooo]Z1Ooo0034oookJPGoo`00K_oonfX002Kooo]Z1Ol0
001PoookJPGoo`00MOoonfX5ool00<?ooo]Z1Ooo001^oookJP009_oonfX5o`0005oooo]Z1Ooo001g
oookJPGoo`00`OoonfX5ool006oooo]Z000VoookJPGo0000GooonfX5ool007Oooo]Z1Ooo0031oook
JPCoo`00L?oonfX002Kooo]Z1Ol0001NoookJPGoo`00NOoonfX5ool00;oooo]Z1Ooo001`oookJP00
9_oonfX5o`0005gooo]Z1Ooo001koookJPCoo`00__oonfX5ool0077ooo]Z000VoookJPGo0000GOoo
nfX5ool007_ooo]Z1Ooo002moookJPCoo`00L_oonfX002Kooo]Z1Ol0001LoookJPGoo`00OOoonfX5
ool00;_ooo]Z1Ooo001boookJP009_oonfX5o`0005cooo]Z1?oo001ooookJPCoo`00^_oonfX5ool0
07?ooo]Z000VoookJPGo0000FooonfX5ool007oooo]Z1Ooo002ioookJPGoo`00LooonfX002Kooo]Z
1Ol0001JoookJPGoo`00POoonfX4ool00;Sooo]Z1Ooo001doookJP009_oonfX5o`0005[ooo]Z1Ooo
0021oookJPGoo`00]ooonfX4ool007Gooo]Z000VoookJPGo0000FOoonfX5ool008?ooo]Z1Ooo002e
oookJPGoo`00MOoonfX002Kooo]Z1Ol0001IoookJPCoo`00QOoonfX4ool00;Gooo]Z1?oo001foook
JP009_oonfX5o`0005Sooo]Z1Ooo0025oookJPGoo`00/ooonfX5ool007Kooo]Z000VoookJPGo0000
F?oonfX4ool008Oooo]Z1?oo002coookJPCoo`00MooonfX002Kooo]Z1Ol0001GoookJPGoo`00Qooo
nfX5ool00;7ooo]Z1Ooo001goookJP009_oonfX5o`0005Oooo]Z1?oo0029oookJPCoo`00/?oonfX5
ool007Sooo]Z000VoookJPGo0000E_oonfX5ool008Wooo]Z1Ooo002_oookJPGoo`00N?oonfX002Ko
oo]Z1Ol0001EoookJPGoo`00RooonfX4ool00:kooo]Z1Ooo001ioookJP009_oonfX5o`0005Gooo]Z
1?oo002<oookJPGoo`00[OoonfX4ool007[ooo]Z000VoookJPGo0000E?oonfX5ool008gooo]Z1?oo
002/oookJPGoo`00N_oonfX002Kooo]Z1Ol0001DoookJPCoo`00S_oonfX5ool00:_ooo]Z1?oo001k
oookJP009_oonfX5o`0005?ooo]Z1Ooo002?oookJPCoo`00Z_oonfX5ool007_ooo]Z000VoookJPGo
0000DooonfX4ool0093ooo]Z1Ooo002YoookJPCoo`00O?oonfX002Kooo]Z1Ol0001BoookJPGoo`00
TOoonfX4ool00:Sooo]Z1Ooo001loookJP009_oonfX5o`0005;ooo]Z1?oo002BoookJPGoo`00Yooo
nfX4ool007gooo]Z000VoookJPGo0000DOoonfX5ool009?ooo]Z1?oo002WoookJPCoo`00OOoonfX0
02Kooo]Z1Ol0001AoookJPCoo`00U?oonfX5ool00:Gooo]Z1Ooo001moookJP009_oonfX5o`00053o
oo]Z1Ooo002EoookJPCoo`00YOoonfX4ool007kooo]Z000VoookJPGo0000D?oonfX4ool009Kooo]Z
1Ooo002SoookJPGoo`00O_oonfX002Kooo]Z1Ol0001?oookJPGoo`00UooonfX5ool00:7ooo]Z1Ooo
001ooookJP009_oonfX5o`0004oooo]Z1?oo002IoookJPCoo`00XOoonfX4ool0083ooo]Z000Voook
JPGo0000C_oonfX5ool009Wooo]Z1Ooo002OoookJPGoo`00P?oonfX002Kooo]Z1Ol0001>oookJPCo
o`00VooonfX4ool009oooo]Z1?oo0021oookJP009_oonfX5o`0004kooo]Z1?oo002KoookJPCoo`00
W_oonfX5ool0087ooo]Z000VoookJPGo0000COoonfX4ool009gooo]Z1?oo002MoookJPCoo`00P_oo
nfX002Kooo]Z1Ol0001=oookJPCoo`00WOoonfX4ool009gooo]Z1?oo0022oookJP009_oonfX5o`00
04cooo]Z1Ooo002MoookJPGoo`00VooonfX5ool008;ooo]Z000VoookJPGo0000C?oonfX4ool009oo
oo]Z1?oo002KoookJPCoo`00PooonfX002Kooo]Z1Ol0001;oookJPGoo`00WooonfX5ool009Wooo]Z
1Ooo0023oookJP009_oonfX5o`0004_ooo]Z1?oo002QoookJPCoo`00VOoonfX4ool008Cooo]Z000V
oookJPGo0000BooonfX4ool00:7ooo]Z1?oo002HoookJPGoo`00Q?oonfX002Kooo]Z1Ol0001:oook
JPGoo`00X_oonfX4ool009Oooo]Z1?oo0025oookJP002OoonfX5o`00O`Cooo]Z0ol007l6oookJP?o
001o2?oonfX5o`0004[ooo]Z1?oo002SoookJPCoo`00UooonfX4ool008Gooo]Z0008oookJPOo001o
0ooonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000BOoonfX5ool00:?ooo]Z1Ooo002EoookJPGoo`00
QOoonfX000Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z
1Ol00019oookJPCoo`00YOoonfX4ool009Gooo]Z1?oo0026oookJP001ooonfX3o`00O`?ooo]Z0ol0
07l6oookJPWo001o1ooonfX5o`0004Wooo]Z1?oo002UoookJPCoo`00U?oonfX5ool008Kooo]Z0007
oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJPOo0000A_oonfX4ool00:Oooo]Z1?oo002C
oookJPCoo`00QooonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol007l8oook
JPGo0000B?oonfX4ool00:Oooo]Z1?oo002CoookJPCoo`00QooonfX000Oooo]Z0ol007l3oookJP?o
001o1ooonfX2o`00O`;ooo]Z0ol007l8oookJPGo0000AooonfX5ool00:Oooo]Z1Ooo002AoookJPGo
o`00QooonfX000Oooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00O`So
oo]Z1Ol00017oookJPCoo`00ZOoonfX4ool0097ooo]Z1?oo0028oookJP001ooonfX3o`00O`?ooo]Z
0ol007l8oookJP;o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Oooo]Z1?oo002YoookJPCo
o`00TOoonfX4ool008Sooo]Z0007oookJP?o001o0ooonfX3o`00O`Wooo]Z1Ol007l8oookJPGo0000
A_oonfX5ool00:[ooo]Z1?oo002?oookJPCoo`00ROoonfX000Sooo]Z0ol007l01?oonf[o001oo`00
Ool007l:oookJPGo001o2?oonfX5o`0004Kooo]Z1?oo002[oookJPCoo`00SooonfX4ool008Wooo]Z
0008oookJPOo001o2ooonfX4o`00O`Sooo]Z1Ol00016oookJPCoo`00ZooonfX5ool008gooo]Z1Ooo
0029oookJP002OoonfX5o`00O`gooo]Z0ol007l8oookJPGo0000AOoonfX4ool00:gooo]Z1?oo002=
oookJPCoo`00R_oonfX002Kooo]Z1Ol00015oookJPCoo`00[OoonfX4ool008gooo]Z1?oo002:oook
JP009_oonfX5o`0004Cooo]Z1Ooo002]oookJPGoo`00RooonfX5ool008[ooo]Z000VoookJPGo0000
A?oonfX4ool00:oooo]Z1?oo002;oookJPCoo`00RooonfX002Kooo]Z1Ol00014oookJPCoo`00[ooo
nfX4ool008_ooo]Z1?oo002;oookJP009_oonfX5o`0004?ooo]Z1Ooo002`oookJPCoo`00ROoonfX4
ool008cooo]Z000VoookJPGo0000@_oonfX5ool00;7ooo]Z1?oo0029oookJPCoo`00S?oonfX002Ko
oo]Z1Ol00012oookJPCoo`00/_oonfX5ool008Oooo]Z1Ooo002<oookJP009_oonfX5o`0004;ooo]Z
1?oo002coookJPCoo`00QooonfX4ool008gooo]Z000VoookJPGo0000@OoonfX5ool00;?ooo]Z1?oo
0027oookJPCoo`00SOoonfX002Kooo]Z1Ol00011oookJPCoo`00]?oonfX5ool008Gooo]Z1Ooo002=
oookJP009_oonfX5o`00047ooo]Z1?oo002eoookJPCoo`00QOoonfX4ool008kooo]Z000VoookJPGo
0000@?oonfX5ool00;Gooo]Z1?oo0025oookJPCoo`00S_oonfX002Kooo]Z1Ol00010oookJPCoo`00
]_oonfX5ool008?ooo]Z1Ooo002>oookJP009_oonfX5o`00043ooo]Z1?oo002goookJPCoo`00Pooo
nfX4ool008oooo]Z000VoookJPGo0000?ooonfX5ool00;Oooo]Z1?oo0023oookJPCoo`00SooonfX0
02Kooo]Z1Ol0000ooookJPCoo`00^OoonfX4ool0087ooo]Z1Ooo002?oookJP009_oonfX5o`0003oo
oo]Z1?oo002ioookJPCoo`00POoonfX4ool0093ooo]Z000VoookJPGo0000?_oonfX4ool00;[ooo]Z
1?oo0021oookJPCoo`00T?oonfX002Kooo]Z1Ol0000noookJPCoo`00^ooonfX4ool007oooo]Z1?oo
002AoookJP009_oonfX5o`0003kooo]Z1?oo002koookJPGoo`00O_oonfX4ool0097ooo]Z000Voook
JPGo0000?OoonfX4ool00;gooo]Z1?oo001noookJPCoo`00TOoonfX002Kooo]Z1Ol0000moookJPCo
o`00_OoonfX4ool007gooo]Z1?oo002BoookJP009_oonfX5o`0003gooo]Z1?oo002moookJPGoo`00
NooonfX5ool009;ooo]Z000VoookJPGo0000??oonfX4ool00;oooo]Z1?oo001koookJPCoo`00Tooo
nfX002Kooo]Z1Ol0000loookJPCoo`00_ooonfX4ool007_ooo]Z1?oo002CoookJP009_oonfX5o`00
03cooo]Z1?oo002ooookJPGoo`00NOoonfX5ool009?ooo]Z000VoookJPGo0000>ooonfX4ool00<7o
oo]Z1?oo001ioookJPCoo`00U?oonfX002Kooo]Z1Ol0000koookJPCoo`00`OoonfX4ool007Wooo]Z
1?oo002DoookJP009_oonfX5o`0003_ooo]Z1?oo0031oookJPGoo`00N?oonfX4ool009Cooo]Z000V
oookJPGo0000>_oonfX5ool00<;ooo]Z1?oo001goookJPCoo`00UOoonfX002Kooo]Z1Ol0000joook
JPCoo`00`ooonfX4ool007Oooo]Z1?oo002EoookJP009_oonfX5o`0003[ooo]Z1?oo0033oookJPGo
o`00M_oonfX4ool009Gooo]Z000VoookJPGo0000>OoonfX5ool00<Cooo]Z1?oo001eoookJPCoo`00
U_oonfX002Kooo]Z1Ol0000ioookJPCoo`00aOoonfX4ool007Gooo]Z1?oo002FoookJP009_oonfX5
o`0003Wooo]Z1?oo0035oookJPGoo`00M?oonfX4ool009Kooo]Z000VoookJPGo0000>?oonfX5ool0
0<Kooo]Z1?oo001coookJPCoo`00UooonfX002Kooo]Z1Ol0000hoookJPCoo`00aooonfX4ool007?o
oo]Z1?oo002GoookJP009_oonfX5o`0003Sooo]Z1?oo0037oookJPCoo`00LooonfX4ool009Oooo]Z
000VoookJPGo0000>?oonfX4ool00<Sooo]Z1?oo001aoookJPCoo`00V?oonfX002Kooo]Z1Ol0000g
oookJPCoo`00bOoonfX4ool0077ooo]Z1?oo002HoookJP009_oonfX5o`0003Oooo]Z1?oo0039oook
JPCoo`00LOoonfX4ool009Sooo]Z000VoookJPGo0000=ooonfX4ool00<[ooo]Z1?oo001_oookJPGo
o`00V?oonfX002Kooo]Z1Ol0000foookJPCoo`00booonfX4ool006oooo]Z1?oo002IoookJP009_oo
nfX5o`0003Kooo]Z1?oo003;oookJPCoo`00KooonfX4ool009Wooo]Z000VoookJPGo0000=_oonfX4
ool00<cooo]Z1?oo001]oookJPGoo`00VOoonfX002Kooo]Z1Ol0000eoookJPCoo`00cOoonfX4ool0
06gooo]Z1?oo002JoookJP009_oonfX5o`0003Gooo]Z1?oo003=oookJPCoo`00KOoonfX4ool009[o
oo]Z000VoookJPGo0000=OoonfX4ool00<gooo]Z1Ooo001/oookJPCoo`00V_oonfX002Kooo]Z1Ol0
000doookJPGoo`00c_oonfX4ool006_ooo]Z1?oo002KoookJP009_oonfX5o`0003Cooo]Z1?oo003?
oookJPCoo`00JooonfX4ool009_ooo]Z000VoookJPGo0000=?oonfX4ool00<oooo]Z1Ooo001Zoook
JPCoo`00VooonfX000Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Wooo]Z1Ol0000doookJPCo
o`00d?oonfX4ool006Wooo]Z1?oo002LoookJP002?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o
2?oonfX5o`0003?ooo]Z1?oo003AoookJPCoo`00JOoonfX4ool009cooo]Z0008oookJP?o001o00Co
oo]Zo`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o1ooonfX5o`0003?ooo]Z
1?oo003AoookJPCoo`00JOoonfX4ool009cooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol0
07l3oookJP?o001o1ooonfX5o`0003?ooo]Z1?oo003BoookJPCoo`00IooonfX4ool009gooo]Z0007
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00033ooo]Z1?oo003C
oookJPCoo`00IooonfX4ool009gooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l007l2oook
JP?o001o1ooonfX5o`0003;ooo]Z1?oo003CoookJPCoo`00IooonfX4ool009gooo]Z0007oookJP?o
001o0ooonfX3o`00O`Kooo]Z2?l007l8oookJPGo0000<_oonfX4ool00=Cooo]Z1?oo001UoookJPGo
o`00WOoonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0000aoookJPGoo`00e?oonfX4ool006Gooo]Z1?oo002NoookJP001ooonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o3OoonfX5o`00037ooo]Z1?oo003EoookJPCoo`00IOoonfX4ool009kooo]Z
0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l=oookJPGo0000<?oonfX4ool00=Kooo]Z1Ooo
001ToookJPCoo`00W_oonfX000Sooo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o0_oo
nfX3o`00O`Oooo]Z1Ol0000`oookJPCoo`00eooonfX4ool006?ooo]Z1?oo002OoookJP002?oonfX7
o`00O`Sooo]Z1ol007l8oookJPGo0000<?oonfX4ool00=Oooo]Z1?oo001SoookJPCoo`00WooonfX0
00Wooo]Z1Ol007l;oookJPCo001o2OoonfX5o`0002oooo]Z1Ooo003GoookJPCoo`00HooonfX4ool0
09oooo]Z000VoookJPGo0000;ooonfX4ool00=Wooo]Z1?oo001QoookJPCoo`00X?oonfX002Kooo]Z
1Ol0000_oookJPCoo`00fOoonfX4ool0067ooo]Z1?oo002PoookJP009_oonfX5o`0002oooo]Z1?oo
003IoookJPCoo`00HOoonfX4ool00:3ooo]Z000VoookJPGo0000;_oonfX4ool00=_ooo]Z1?oo001O
oookJPGoo`00X?oonfX002Kooo]Z1Ol0000^oookJPCoo`00fooonfX4ool005oooo]Z1?oo002Qoook
JP009_oonfX5o`0002kooo]Z1?oo003KoookJPCoo`00GooonfX4ool00:7ooo]Z000VoookJPGo0000
;OoonfX4ool00=cooo]Z1Ooo001NoookJPCoo`00XOoonfX002Kooo]Z1Ol0000]oookJPCoo`00gOoo
nfX4ool005gooo]Z1?oo002RoookJP009_oonfX5o`0002gooo]Z1?oo003MoookJPCoo`00GOoonfX4
ool00:;ooo]Z000VoookJPGo0000;OoonfX4ool00=gooo]Z1?oo001MoookJPCoo`00X_oonfX002Ko
oo]Z1Ol0000/oookJPCoo`00gooonfX4ool005_ooo]Z1?oo002SoookJP009_oonfX5o`0002cooo]Z
1?oo003OoookJPCoo`00FooonfX4ool00:?ooo]Z000VoookJPGo0000;?oonfX4ool00=oooo]Z1?oo
001KoookJPCoo`00XooonfX002Kooo]Z1Ol0000[oookJPCoo`00hOoonfX4ool005[ooo]Z1?oo002S
oookJP009_oonfX5o`0002_ooo]Z1?oo003QoookJPCoo`00FOoonfX4ool00:Cooo]Z000VoookJPGo
0000:ooonfX4ool00>;ooo]Z1?oo001GoookJPGoo`00Y?oonfX002Kooo]Z1Ol0000ZoookJPGoo`00
h_oonfX4ool005Oooo]Z1?oo002UoookJP009_oonfX5o`0002[ooo]Z1?oo003SoookJPCoo`00Eooo
nfX4ool00:Gooo]Z000VoookJPGo0000:_oonfX4ool00>Cooo]Z1?oo001FoookJPCoo`00YOoonfX0
02Kooo]Z1Ol0000ZoookJPCoo`00i?oonfX4ool005Gooo]Z1?oo002VoookJP009_oonfX5o`0002Wo
oo]Z1?oo003UoookJPCoo`00EOoonfX4ool00:Kooo]Z000VoookJPGo0000:OoonfX4ool00>Gooo]Z
1Ooo001DoookJPCoo`00Y_oonfX002Kooo]Z1Ol0000YoookJPCoo`00i_oonfX4ool005?ooo]Z1?oo
002WoookJP009_oonfX5o`0002Sooo]Z1?oo003WoookJPCoo`00DooonfX4ool00:Oooo]Z000Voook
JPGo0000:?oonfX4ool00>Oooo]Z1?oo001CoookJPCoo`00YooonfX002Kooo]Z1Ol0000XoookJPCo
o`00j?oonfX4ool0057ooo]Z1Ooo002WoookJP009_oonfX5o`0002Sooo]Z1?oo003XoookJPCoo`00
DOoonfX4ool00:Sooo]Z000VoookJPGo00009ooonfX4ool00>Wooo]Z1?oo001AoookJPCoo`00Z?oo
nfX002Kooo]Z1Ol0000WoookJPCoo`00j_oonfX4ool0053ooo]Z1?oo002XoookJP009_oonfX5o`00
02Oooo]Z1?oo003ZoookJPCoo`00CooonfX4ool00:Wooo]Z000VoookJPGo00009_oonfX4ool00>_o
oo]Z1?oo001?oookJPCoo`00ZOoonfX002Kooo]Z1Ol0000VoookJPCoo`00jooonfX5ool004kooo]Z
1?oo002YoookJP009_oonfX5o`0002Kooo]Z1?oo003/oookJPCoo`00COoonfX4ool00:[ooo]Z000V
oookJPGo00009OoonfX5ool00>cooo]Z1?oo001=oookJPCoo`00Z_oonfX002Kooo]Z1Ol0000Uoook
JPCoo`00kOoonfX4ool004gooo]Z1?oo002ZoookJP009_oonfX5o`0002Gooo]Z1?oo003^oookJPCo
o`00BooonfX5ool00:[ooo]Z000VoookJPGo00009OoonfX4ool00>kooo]Z1?oo001;oookJPCoo`00
ZooonfX002Kooo]Z1Ol0000ToookJPCoo`00kooonfX4ool004_ooo]Z1?oo002[oookJP009_oonfX5
o`0002Cooo]Z1?oo003`oookJPCoo`00B_oonfX4ool00:_ooo]Z000VoookJPGo00009?oonfX4ool0
0?3ooo]Z1?oo0019oookJPCoo`00[?oonfX002Kooo]Z1Ol0000SoookJPCoo`00lOoonfX4ool004Wo
oo]Z1?oo002/oookJP009_oonfX5o`0002?ooo]Z1?oo003boookJPCoo`00B?oonfX4ool00:cooo]Z
000VoookJPGo00008ooonfX4ool00?;ooo]Z1?oo0017oookJPCoo`00[OoonfX002Kooo]Z1Ol0000R
oookJPGoo`00l_oonfX4ool004Oooo]Z1?oo002]oookJP009_oonfX5o`0002;ooo]Z1?oo003coook
JPGoo`00A_oonfX4ool00:gooo]Z000VoookJPGo00008_oonfX4ool00?Cooo]Z1?oo0015oookJPCo
o`00[_oonfX002Kooo]Z1Ol0000RoookJPCoo`00m?oonfX4ool004Gooo]Z1?oo002^oookJP009_oo
nfX5o`00027ooo]Z1?oo003eoookJPGoo`00A?oonfX4ool00:kooo]Z000VoookJPGo00008OoonfX4
ool00?Kooo]Z1?oo0013oookJPGoo`00[_oonfX002Kooo]Z1Ol0000QoookJPCoo`00m_oonfX4ool0
04?ooo]Z1?oo002_oookJP002OoonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o2OoonfX5o`00023o
oo]Z1?oo003goookJPCoo`00@ooonfX4ool00:oooo]Z0008oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007l8oookJPGo00008?oonfX4ool00?Sooo]Z1?oo0011oookJPGoo`00[ooonfX000Sooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oo
oo]Z1Ol0000PoookJPCoo`00n?oonfX4ool0047ooo]Z1?oo002`oookJP001ooonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000OoookJPGoo`00n?oonfX4ool0047ooo]Z
1?oo002`oookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0
000MoookJPCoo`00n_oonfX4ool003oooo]Z1Ooo002`oookJP001ooonfX3o`00O`?ooo]Z0ol007l6
oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000OoookJPCoo`00n_oonfX4ool003oooo]Z1?oo002a
oookJP001ooonfX3o`00O`?ooo]Z0ol007l7oookJPOo001o2?oonfX5o`0001kooo]Z1Ooo003joook
JPCoo`00?ooonfX4ool00;7ooo]Z0007oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oookJPGo
00007_oonfX4ool00?cooo]Z1?oo000noookJPCoo`00/OoonfX000Oooo]Z0ol007l3oookJP?o001o
1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007OoonfX4ool00?gooo]Z1?oo000moookJPCoo`00
/_oonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007Ooo
nfX4ool00?gooo]Z1?oo000moookJPCoo`00/_oonfX000Sooo]Z0ol007l01?oonf[o001oo`00Ool0
07l7oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000MoookJPCoo`00o_oonfX4ool003cooo]Z1?oo
002boookJP002?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo00007?oonfX5ool00?kooo]Z1?oo000k
oookJPCoo`00/ooonfX000Wooo]Z1Ol007l:oookJPGo001o2OoonfX5o`0001cooo]Z1?oo003ooook
JPCoo`00>ooonfX4ool00;?ooo]Z000VoookJPGo00007?oonfX4ool00?oooo]Z0OoonfX4ool003[o
oo]Z1?oo002coookJP009_oonfX5o`0001_ooo]Z1Ooo003ooookJP7ooo]Z1?oo000ioookJPCoo`00
]?oonfX002Kooo]Z1Ol0000KoookJPCoo`00oooonfX2oookJPCoo`00>OoonfX4ool00;Cooo]Z000V
oookJPGo00006ooonfX4ool00?oooo]Z0ooonfX4ool003Oooo]Z1Ooo002doookJP009_oonfX5o`00
01[ooo]Z1Ooo003ooookJP?ooo]Z1?oo000goookJPCoo`00]OoonfX002Kooo]Z1Ol0000JoookJPCo
o`00oooonfX4oookJPCoo`00=ooonfX4ool00;Gooo]Z000VoookJPGo00006_oonfX4ool00?oooo]Z
1OoonfX4ool003Gooo]Z1Ooo002eoookJP009_oonfX5o`0001Wooo]Z1Ooo003ooookJPGooo]Z1Ooo
000doookJPCoo`00]_oonfX002Kooo]Z1Ol0000IoookJPCoo`00oooonfX7oookJPCoo`00=?oonfX4
ool00;Kooo]Z000VoookJPGo00006OoonfX4ool00?oooo]Z1ooonfX4ool003?ooo]Z1Ooo002foook
JP009_oonfX5o`0001Sooo]Z1Ooo003ooookJPSooo]Z1?oo000boookJPCoo`00]ooonfX002Kooo]Z
1Ol0000HoookJPCoo`00oooonfX9oookJPCoo`00<OoonfX4ool00;Sooo]Z000VoookJPGo00006?oo
nfX4ool00?oooo]Z2OoonfX5ool0033ooo]Z1?oo002hoookJP009_oonfX5o`0001Oooo]Z1Ooo003o
oookJP[ooo]Z1?oo000_oookJPGoo`00^?oonfX002Kooo]Z1Ol0000GoookJPCoo`00oooonfX;oook
JPCoo`00;ooonfX4ool00;Wooo]Z000VoookJPGo00005ooonfX4ool00?oooo]Z2ooonfX5ool002ko
oo]Z1?oo002ioookJP009_oonfX5o`0001Kooo]Z1?oo003ooookJPgooo]Z1?oo000]oookJPGoo`00
^OoonfX002Kooo]Z1Ol0000FoookJPCoo`00oooonfX=oookJPCoo`00;OoonfX4ool00;[ooo]Z000V
oookJPGo00005_oonfX4ool00?oooo]Z3_oonfX4ool002_ooo]Z1Ooo002joookJP009_oonfX5o`00
01Gooo]Z1?oo003ooookJPoooo]Z1?oo000[oookJPCoo`00^ooonfX002Kooo]Z1Ol0000EoookJPCo
o`00oooonfX?oookJPGoo`00:_oonfX4ool00;_ooo]Z000VoookJPGo00005?oonfX5ool00?oooo]Z
4?oonfX4ool002Wooo]Z1Ooo002koookJP009_oonfX5o`0001Cooo]Z1?oo003ooookJQ7ooo]Z1?oo
000YoookJPCoo`00_?oonfX002Kooo]Z1Ol0000DoookJPCoo`00oooonfXBoookJPCoo`009ooonfX5
ool00;cooo]Z000VoookJPGo00004ooonfX4ool00?oooo]Z4ooonfX4ool002Oooo]Z1?oo002moook
JP009_oonfX5o`0001?ooo]Z1?oo003ooookJQ?ooo]Z1Ooo000VoookJPCoo`00_OoonfX002Kooo]Z
1Ol0000BoookJPGoo`00oooonfXDoookJPCoo`009OoonfX4ool00;kooo]Z000VoookJPGo00004_oo
nfX4ool00?oooo]Z5OoonfX5ool002Cooo]Z1?oo002noookJP009_oonfX5o`0001;ooo]Z1?oo003o
oookJQKooo]Z1?oo000SoookJPGoo`00__oonfX002Kooo]Z1Ol0000AoookJPCoo`00oooonfXGoook
JPGoo`008_oonfX4ool00;oooo]Z000VoookJPGo00004OoonfX4ool00?oooo]Z6?oonfX4ool0027o
oo]Z1Ooo002ooookJP009_oonfX5o`00013ooo]Z1Ooo003ooookJQSooo]Z1Ooo000PoookJPCoo`00
`?oonfX002Kooo]Z1Ol0000@oookJPCoo`00oooonfXJoookJPCoo`007ooonfX5ool00<3ooo]Z000V
oookJPGo00003ooonfX5ool00?oooo]Z6_oonfX5ool001kooo]Z1?oo0031oookJP009_oonfX5o`00
00oooo]Z1?oo003ooookJQcooo]Z1?oo000MoookJPGoo`00`OoonfX002Kooo]Z1Ol0000>oookJPGo
o`00oooonfXLoookJPGoo`007?oonfX4ool00<;ooo]Z000VoookJPGo00003_oonfX4ool00?oooo]Z
7_oonfX4ool001_ooo]Z1Ooo0032oookJP009_oonfX5o`0000gooo]Z1Ooo003ooookJQkooo]Z1Ooo
000IoookJPGoo`00`ooonfX002Kooo]Z1Ol0000=oookJPCoo`00oooonfXPoookJPCoo`006OoonfX5
ool00<?ooo]Z000VoookJPGo00003?oonfX5ool00?oooo]Z8?oonfX5ool001Oooo]Z1Ooo0034oook
JP009_oonfX5o`0000_ooo]Z1Ooo003ooookJR;ooo]Z1Ooo000FoookJPCoo`00aOoonfX002Kooo]Z
1Ol0000;oookJPCoo`00oooonfXToookJPCoo`005OoonfX5ool00<Gooo]Z000VoookJPGo00002_oo
nfX5ool00?oooo]Z9?oonfX5ool001?ooo]Z1Ooo0036oookJP009_oonfX5o`0000[ooo]Z1?oo003o
oookJRKooo]Z1Ooo000AoookJPGoo`00aooonfX002Kooo]Z1Ol00009oookJPGoo`00oooonfXWoook
JPGoo`003ooonfX6ool00<Oooo]Z000VoookJPGo00002?oonfX5ool00?oooo]Z:OoonfX5ool000go
oo]Z1_oo0038oookJP009_oonfX5o`0000Sooo]Z1?oo003ooookJR_ooo]Z1_oo000:oookJPKoo`00
bOoonfX002Kooo]Z1Ol00007oookJPGoo`00oooonfX/oookJPKoo`001ooonfX6ool00<_ooo]Z000V
oookJPGo00001_oonfX5ool00?oooo]Z;_oonfXAool00<cooo]Z000VoookJPGo00001OoonfX5ool0
0?oooo]Z<?oonfX?ool00<gooo]Z000VoookJPGo00001?oonfX6ool00?oooo]Z<OoonfX=ool00<ko
oo]Z000JoookJP?o001o2OoonfX5o`0000?ooo]Z1_oo003ooookJSCooo]Z2Ooo003@oookJP006_oo
nfX3o`00O`Wooo]Z1Ol000000ooonf[oo`00ool00005ool00?oooo]Z>?oonfX3ool00=?ooo]Z000J
oookJP?o001o2OoonfX2o`0000[oo`00oooonf[ooookJQ3ooo]Z000JoookJP?o001o2OoonfX00ol0
003oo`00ool00008ool00?oooo]ZoooonfXAoookJP006_oonfX3o`00O`Wooo]Z00?o0000ool00?oo
00001_oo003ooookJ_oooo]Z4ooonfX001[ooo]Z0ol007l9oookJP;o00001_oo003ooookJ_oooo]Z
5?oonfX001[ooo]Z0ol007l9oookJPGo0000oooonf[ooookJQOooo]Z000JoookJP?o001o2OoonfX5
o`000?oooo]ZoooonfXGoookJP006_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX001Oo
oo]Z1_l007l9oookJPGo0000oooonf[ooookJQOooo]Z000GoookJPKo001o2OoonfX5o`000?oooo]Z
oooonfXGoookJP006OoonfX4o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX001[ooo]Z0ol007l9
oookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo0000oooonf[ooookJQOooo]Z000VoookJPGo
0000oooonf[ooookJQOooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.791911, -0.0842141, \
0.019462, 0.00314902}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now we superpose the exact solution with that obtained by the \
forward-differencing approximation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[forwarddifferenceplot, exactplot]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.588604 [
[.21429 .00222 -7 -20 ]
[.21429 .00222 7 0 ]
[.40476 .00222 -7 -20 ]
[.40476 .00222 7 0 ]
[.59524 .00222 -7 -20 ]
[.59524 .00222 7 0 ]
[.78571 .00222 -7 -20 ]
[.78571 .00222 7 0 ]
[.97619 .00222 -12 -20 ]
[.97619 .00222 12 0 ]
[.01131 .13244 -29 -10 ]
[.01131 .13244 0 10 ]
[.01131 .25016 -29 -10 ]
[.01131 .25016 0 10 ]
[.01131 .36788 -29 -10 ]
[.01131 .36788 0 10 ]
[.01131 .4856 -29 -10 ]
[.01131 .4856 0 10 ]
[.01131 .60332 -14 -10 ]
[.01131 .60332 0 10 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
gsave
.21429 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.40476 .01472 m
.40476 .02097 L
s
gsave
.40476 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.59524 .01472 m
.59524 .02097 L
s
gsave
.59524 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.78571 .01472 m
.78571 .02097 L
s
gsave
.78571 .00222 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -73 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.01 w
0 .01472 m
1 .01472 L
s
.25 Mabswid
.02381 .13244 m
.03006 .13244 L
s
gsave
.01131 .13244 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .25016 m
.03006 .25016 L
s
gsave
.01131 .25016 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .36788 m
.03006 .36788 L
s
gsave
.01131 .36788 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .4856 m
.03006 .4856 L
s
gsave
.01131 .4856 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .60332 m
.03006 .60332 L
s
gsave
.01131 .60332 -75 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.01 w
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .60332 Mdot
.02476 .60332 Mdot
.02571 .60326 Mdot
.02667 .60314 Mdot
.02762 .60297 Mdot
.02857 .60273 Mdot
.02952 .60244 Mdot
.03048 .60208 Mdot
.03143 .60167 Mdot
.03238 .6012 Mdot
.03333 .60068 Mdot
.03429 .60009 Mdot
.03524 .59945 Mdot
.03619 .59875 Mdot
.03714 .59799 Mdot
.0381 .59718 Mdot
.03905 .59631 Mdot
.04 .59538 Mdot
.04095 .5944 Mdot
.0419 .59336 Mdot
.04286 .59227 Mdot
.04381 .59112 Mdot
.04476 .58992 Mdot
.04571 .58866 Mdot
.04667 .58736 Mdot
.04762 .58599 Mdot
.04857 .58458 Mdot
.04952 .58312 Mdot
.05048 .5816 Mdot
.05143 .58003 Mdot
.05238 .57842 Mdot
.05333 .57675 Mdot
.05429 .57504 Mdot
.05524 .57327 Mdot
.05619 .57146 Mdot
.05714 .56961 Mdot
.0581 .5677 Mdot
.05905 .56576 Mdot
.06 .56376 Mdot
.06095 .56173 Mdot
.0619 .55965 Mdot
.06286 .55753 Mdot
.06381 .55536 Mdot
.06476 .55316 Mdot
.06571 .55091 Mdot
.06667 .54863 Mdot
.06762 .54631 Mdot
.06857 .54395 Mdot
.06952 .54155 Mdot
.07048 .53912 Mdot
.07143 .53665 Mdot
.07238 .53415 Mdot
.07333 .53161 Mdot
.07429 .52904 Mdot
.07524 .52644 Mdot
.07619 .52381 Mdot
.07714 .52115 Mdot
.0781 .51846 Mdot
.07905 .51574 Mdot
.08 .513 Mdot
.08095 .51022 Mdot
.0819 .50743 Mdot
.08286 .5046 Mdot
.08381 .50176 Mdot
.08476 .49889 Mdot
.08571 .496 Mdot
.08667 .49308 Mdot
.08762 .49015 Mdot
.08857 .4872 Mdot
.08952 .48423 Mdot
.09048 .48124 Mdot
.09143 .47823 Mdot
.09238 .47521 Mdot
.09333 .47218 Mdot
.09429 .46912 Mdot
.09524 .46606 Mdot
.09619 .46298 Mdot
.09714 .4599 Mdot
.0981 .4568 Mdot
.09905 .45369 Mdot
.1 .45057 Mdot
.10095 .44744 Mdot
.1019 .44431 Mdot
.10286 .44117 Mdot
.10381 .43802 Mdot
.10476 .43487 Mdot
.10571 .43171 Mdot
.10667 .42855 Mdot
.10762 .42539 Mdot
.10857 .42222 Mdot
.10952 .41906 Mdot
.11048 .41589 Mdot
.11143 .41272 Mdot
.11238 .40956 Mdot
.11333 .40639 Mdot
.11429 .40323 Mdot
.11524 .40007 Mdot
.11619 .39691 Mdot
.11714 .39376 Mdot
.1181 .39061 Mdot
.11905 .38747 Mdot
.12 .38433 Mdot
.12095 .3812 Mdot
.1219 .37808 Mdot
.12286 .37496 Mdot
.12381 .37186 Mdot
.12476 .36876 Mdot
.12571 .36567 Mdot
.12667 .36259 Mdot
.12762 .35952 Mdot
.12857 .35647 Mdot
.12952 .35342 Mdot
.13048 .35039 Mdot
.13143 .34737 Mdot
.13238 .34436 Mdot
.13333 .34136 Mdot
.13429 .33838 Mdot
.13524 .33541 Mdot
.13619 .33246 Mdot
.13714 .32952 Mdot
.1381 .3266 Mdot
.13905 .32369 Mdot
.14 .3208 Mdot
.14095 .31793 Mdot
.1419 .31507 Mdot
.14286 .31223 Mdot
.14381 .30941 Mdot
.14476 .3066 Mdot
.14571 .30381 Mdot
.14667 .30104 Mdot
.14762 .29829 Mdot
.14857 .29556 Mdot
.14952 .29285 Mdot
.15048 .29015 Mdot
.15143 .28748 Mdot
.15238 .28482 Mdot
.15333 .28219 Mdot
.15429 .27957 Mdot
.15524 .27697 Mdot
.15619 .2744 Mdot
.15714 .27184 Mdot
.1581 .26931 Mdot
.15905 .2668 Mdot
.16 .26431 Mdot
.16095 .26183 Mdot
.1619 .25938 Mdot
.16286 .25696 Mdot
.16381 .25455 Mdot
.16476 .25216 Mdot
.16571 .2498 Mdot
.16667 .24745 Mdot
.16762 .24513 Mdot
.16857 .24283 Mdot
.16952 .24055 Mdot
.17048 .2383 Mdot
.17143 .23606 Mdot
.17238 .23385 Mdot
.17333 .23166 Mdot
.17429 .22949 Mdot
.17524 .22734 Mdot
.17619 .22522 Mdot
.17714 .22311 Mdot
.1781 .22103 Mdot
.17905 .21897 Mdot
.18 .21693 Mdot
.18095 .21491 Mdot
.1819 .21292 Mdot
.18286 .21094 Mdot
.18381 .20899 Mdot
.18476 .20706 Mdot
.18571 .20515 Mdot
.18667 .20326 Mdot
.18762 .20139 Mdot
.18857 .19955 Mdot
.18952 .19772 Mdot
.19048 .19592 Mdot
.19143 .19414 Mdot
.19238 .19237 Mdot
.19333 .19063 Mdot
.19429 .18891 Mdot
.19524 .18721 Mdot
.19619 .18553 Mdot
.19714 .18387 Mdot
.1981 .18223 Mdot
.19905 .18061 Mdot
.2 .17901 Mdot
.20095 .17743 Mdot
.2019 .17587 Mdot
.20286 .17433 Mdot
.20381 .17281 Mdot
.20476 .17131 Mdot
.20571 .16983 Mdot
.20667 .16837 Mdot
.20762 .16692 Mdot
.20857 .1655 Mdot
.20952 .16409 Mdot
.21048 .16271 Mdot
.21143 .16134 Mdot
.21238 .15999 Mdot
.21333 .15865 Mdot
.21429 .15734 Mdot
.21524 .15604 Mdot
.21619 .15476 Mdot
.21714 .1535 Mdot
.2181 .15226 Mdot
.21905 .15103 Mdot
.22 .14982 Mdot
.22095 .14863 Mdot
.2219 .14745 Mdot
.22286 .14629 Mdot
.22381 .14515 Mdot
.22476 .14402 Mdot
.22571 .14291 Mdot
.22667 .14182 Mdot
.22762 .14074 Mdot
.22857 .13968 Mdot
.22952 .13864 Mdot
.23048 .13761 Mdot
.23143 .13659 Mdot
.23238 .13559 Mdot
.23333 .13461 Mdot
.23429 .13364 Mdot
.23524 .13268 Mdot
.23619 .13174 Mdot
.23714 .13082 Mdot
.2381 .12991 Mdot
.23905 .12901 Mdot
.24 .12813 Mdot
.24095 .12726 Mdot
.2419 .12641 Mdot
.24286 .12557 Mdot
.24381 .12474 Mdot
.24476 .12393 Mdot
.24571 .12313 Mdot
.24667 .12234 Mdot
.24762 .12157 Mdot
.24857 .12081 Mdot
.24952 .12006 Mdot
.25048 .11933 Mdot
.25143 .1186 Mdot
.25238 .1179 Mdot
.25333 .1172 Mdot
.25429 .11651 Mdot
.25524 .11584 Mdot
.25619 .11518 Mdot
.25714 .11453 Mdot
.2581 .1139 Mdot
.25905 .11327 Mdot
.26 .11266 Mdot
.26095 .11206 Mdot
.2619 .11147 Mdot
.26286 .11089 Mdot
.26381 .11032 Mdot
.26476 .10976 Mdot
.26571 .10922 Mdot
.26667 .10868 Mdot
.26762 .10816 Mdot
.26857 .10764 Mdot
.26952 .10714 Mdot
.27048 .10665 Mdot
.27143 .10617 Mdot
.27238 .1057 Mdot
.27333 .10523 Mdot
.27429 .10478 Mdot
.27524 .10434 Mdot
.27619 .10391 Mdot
.27714 .10349 Mdot
.2781 .10308 Mdot
.27905 .10268 Mdot
.28 .10229 Mdot
.28095 .1019 Mdot
.2819 .10153 Mdot
.28286 .10117 Mdot
.28381 .10081 Mdot
.28476 .10047 Mdot
.28571 .10013 Mdot
.28667 .09981 Mdot
.28762 .09949 Mdot
.28857 .09918 Mdot
.28952 .09889 Mdot
.29048 .0986 Mdot
.29143 .09831 Mdot
.29238 .09804 Mdot
.29333 .09778 Mdot
.29429 .09752 Mdot
.29524 .09728 Mdot
.29619 .09704 Mdot
.29714 .09681 Mdot
.2981 .09659 Mdot
.29905 .09638 Mdot
.3 .09618 Mdot
.30095 .09598 Mdot
.3019 .0958 Mdot
.30286 .09562 Mdot
.30381 .09545 Mdot
.30476 .09529 Mdot
.30571 .09513 Mdot
.30667 .09499 Mdot
.30762 .09485 Mdot
.30857 .09472 Mdot
.30952 .0946 Mdot
.31048 .09449 Mdot
.31143 .09438 Mdot
.31238 .09429 Mdot
.31333 .0942 Mdot
.31429 .09412 Mdot
.31524 .09404 Mdot
.31619 .09398 Mdot
.31714 .09392 Mdot
.3181 .09387 Mdot
.31905 .09383 Mdot
.32 .0938 Mdot
.32095 .09378 Mdot
.3219 .09376 Mdot
.32286 .09375 Mdot
.32381 .09375 Mdot
.32476 .09375 Mdot
.32571 .09377 Mdot
.32667 .09379 Mdot
.32762 .09382 Mdot
.32857 .09386 Mdot
.32952 .09391 Mdot
.33048 .09396 Mdot
.33143 .09402 Mdot
.33238 .09409 Mdot
.33333 .09417 Mdot
.33429 .09426 Mdot
.33524 .09435 Mdot
.33619 .09445 Mdot
.33714 .09456 Mdot
.3381 .09468 Mdot
.33905 .09481 Mdot
.34 .09494 Mdot
.34095 .09508 Mdot
.3419 .09523 Mdot
.34286 .09539 Mdot
.34381 .09556 Mdot
.34476 .09573 Mdot
.34571 .09592 Mdot
.34667 .09611 Mdot
.34762 .09631 Mdot
.34857 .09652 Mdot
.34952 .09674 Mdot
.35048 .09696 Mdot
.35143 .09719 Mdot
.35238 .09744 Mdot
.35333 .09769 Mdot
.35429 .09795 Mdot
.35524 .09822 Mdot
.35619 .09849 Mdot
.35714 .09878 Mdot
.3581 .09907 Mdot
.35905 .09938 Mdot
.36 .09969 Mdot
.36095 .10001 Mdot
.3619 .10034 Mdot
.36286 .10068 Mdot
.36381 .10103 Mdot
.36476 .10139 Mdot
.36571 .10176 Mdot
.36667 .10214 Mdot
.36762 .10252 Mdot
.36857 .10292 Mdot
.36952 .10333 Mdot
.37048 .10374 Mdot
.37143 .10417 Mdot
.37238 .1046 Mdot
.37333 .10505 Mdot
.37429 .1055 Mdot
.37524 .10597 Mdot
.37619 .10645 Mdot
.37714 .10693 Mdot
.3781 .10743 Mdot
.37905 .10793 Mdot
.38 .10845 Mdot
.38095 .10898 Mdot
.3819 .10952 Mdot
.38286 .11007 Mdot
.38381 .11063 Mdot
.38476 .1112 Mdot
.38571 .11178 Mdot
.38667 .11238 Mdot
.38762 .11298 Mdot
.38857 .1136 Mdot
.38952 .11423 Mdot
.39048 .11487 Mdot
.39143 .11552 Mdot
.39238 .11618 Mdot
.39333 .11686 Mdot
.39429 .11755 Mdot
.39524 .11825 Mdot
.39619 .11896 Mdot
.39714 .11968 Mdot
.3981 .12042 Mdot
.39905 .12117 Mdot
.4 .12193 Mdot
.40095 .12271 Mdot
.4019 .12349 Mdot
.40286 .1243 Mdot
.40381 .12511 Mdot
.40476 .12594 Mdot
.40571 .12678 Mdot
.40667 .12764 Mdot
.40762 .12851 Mdot
.40857 .12939 Mdot
.40952 .13029 Mdot
.41048 .1312 Mdot
.41143 .13212 Mdot
.41238 .13306 Mdot
.41333 .13402 Mdot
.41429 .13499 Mdot
.41524 .13597 Mdot
.41619 .13697 Mdot
.41714 .13798 Mdot
.4181 .13901 Mdot
.41905 .14006 Mdot
.42 .14112 Mdot
.42095 .1422 Mdot
.4219 .14329 Mdot
.42286 .14439 Mdot
.42381 .14552 Mdot
.42476 .14666 Mdot
.42571 .14782 Mdot
.42667 .14899 Mdot
.42762 .15018 Mdot
.42857 .15138 Mdot
.42952 .15261 Mdot
.43048 .15385 Mdot
.43143 .1551 Mdot
.43238 .15638 Mdot
.43333 .15767 Mdot
.43429 .15898 Mdot
.43524 .16031 Mdot
.43619 .16165 Mdot
.43714 .16302 Mdot
.4381 .1644 Mdot
.43905 .1658 Mdot
.44 .16722 Mdot
.44095 .16865 Mdot
.4419 .17011 Mdot
.44286 .17158 Mdot
.44381 .17307 Mdot
.44476 .17459 Mdot
.44571 .17612 Mdot
.44667 .17767 Mdot
.44762 .17924 Mdot
.44857 .18083 Mdot
.44952 .18243 Mdot
.45048 .18406 Mdot
.45143 .18571 Mdot
.45238 .18738 Mdot
.45333 .18907 Mdot
.45429 .19077 Mdot
.45524 .1925 Mdot
.45619 .19425 Mdot
.45714 .19602 Mdot
.4581 .19781 Mdot
.45905 .19962 Mdot
.46 .20145 Mdot
.46095 .2033 Mdot
.4619 .20517 Mdot
.46286 .20706 Mdot
.46381 .20898 Mdot
.46476 .21091 Mdot
.46571 .21287 Mdot
.46667 .21484 Mdot
.46762 .21684 Mdot
.46857 .21886 Mdot
.46952 .2209 Mdot
.47048 .22296 Mdot
.47143 .22504 Mdot
.47238 .22714 Mdot
.47333 .22927 Mdot
.47429 .23141 Mdot
.47524 .23358 Mdot
.47619 .23577 Mdot
.47714 .23798 Mdot
.4781 .24021 Mdot
.47905 .24246 Mdot
.48 .24473 Mdot
.48095 .24702 Mdot
.4819 .24934 Mdot
.48286 .25167 Mdot
.48381 .25403 Mdot
.48476 .25641 Mdot
.48571 .2588 Mdot
.48667 .26122 Mdot
.48762 .26366 Mdot
.48857 .26612 Mdot
.48952 .2686 Mdot
.49048 .27109 Mdot
.49143 .27361 Mdot
.49238 .27615 Mdot
.49333 .27871 Mdot
.49429 .28129 Mdot
.49524 .28389 Mdot
.49619 .2865 Mdot
.49714 .28914 Mdot
.4981 .29179 Mdot
.49905 .29446 Mdot
.5 .29715 Mdot
.50095 .29986 Mdot
.5019 .30259 Mdot
.50286 .30533 Mdot
.50381 .30809 Mdot
.50476 .31087 Mdot
.50571 .31366 Mdot
.50667 .31647 Mdot
.50762 .3193 Mdot
.50857 .32214 Mdot
.50952 .325 Mdot
.51048 .32787 Mdot
.51143 .33076 Mdot
.51238 .33366 Mdot
.51333 .33658 Mdot
.51429 .33951 Mdot
.51524 .34245 Mdot
.51619 .3454 Mdot
.51714 .34837 Mdot
.5181 .35135 Mdot
.51905 .35434 Mdot
.52 .35734 Mdot
.52095 .36035 Mdot
.5219 .36337 Mdot
.52286 .3664 Mdot
.52381 .36944 Mdot
.52476 .37248 Mdot
.52571 .37554 Mdot
.52667 .3786 Mdot
.52762 .38167 Mdot
.52857 .38474 Mdot
.52952 .38782 Mdot
.53048 .39091 Mdot
.53143 .394 Mdot
.53238 .39709 Mdot
.53333 .40018 Mdot
.53429 .40328 Mdot
.53524 .40638 Mdot
.53619 .40948 Mdot
.53714 .41258 Mdot
.5381 .41568 Mdot
.53905 .41878 Mdot
.54 .42187 Mdot
.54095 .42497 Mdot
.5419 .42806 Mdot
.54286 .43114 Mdot
.54381 .43423 Mdot
.54476 .4373 Mdot
.54571 .44037 Mdot
.54667 .44344 Mdot
.54762 .44649 Mdot
.54857 .44954 Mdot
.54952 .45257 Mdot
.55048 .4556 Mdot
.55143 .45862 Mdot
.55238 .46162 Mdot
.55333 .46461 Mdot
.55429 .46759 Mdot
.55524 .47055 Mdot
.55619 .4735 Mdot
.55714 .47643 Mdot
.5581 .47935 Mdot
.55905 .48224 Mdot
.56 .48512 Mdot
.56095 .48798 Mdot
.5619 .49082 Mdot
.56286 .49363 Mdot
.56381 .49643 Mdot
.56476 .4992 Mdot
.56571 .50195 Mdot
.56667 .50467 Mdot
.56762 .50737 Mdot
.56857 .51004 Mdot
.56952 .51269 Mdot
.57048 .5153 Mdot
.57143 .51789 Mdot
.57238 .52045 Mdot
.57333 .52298 Mdot
.57429 .52547 Mdot
.57524 .52793 Mdot
.57619 .53036 Mdot
.57714 .53276 Mdot
.5781 .53512 Mdot
.57905 .53745 Mdot
.58 .53973 Mdot
.58095 .54199 Mdot
.5819 .5442 Mdot
.58286 .54637 Mdot
.58381 .54851 Mdot
.58476 .5506 Mdot
.58571 .55266 Mdot
.58667 .55467 Mdot
.58762 .55664 Mdot
.58857 .55856 Mdot
.58952 .56044 Mdot
.59048 .56228 Mdot
.59143 .56407 Mdot
.59238 .56581 Mdot
.59333 .56751 Mdot
.59429 .56916 Mdot
.59524 .57076 Mdot
.59619 .57232 Mdot
.59714 .57382 Mdot
.5981 .57528 Mdot
.59905 .57668 Mdot
.6 .57803 Mdot
.60095 .57934 Mdot
.6019 .58059 Mdot
.60286 .58178 Mdot
.60381 .58293 Mdot
.60476 .58402 Mdot
.60571 .58506 Mdot
.60667 .58604 Mdot
.60762 .58697 Mdot
.60857 .58784 Mdot
.60952 .58866 Mdot
.61048 .58942 Mdot
.61143 .59013 Mdot
.61238 .59078 Mdot
.61333 .59137 Mdot
.61429 .59191 Mdot
.61524 .59239 Mdot
.61619 .59281 Mdot
.61714 .59317 Mdot
.6181 .59348 Mdot
.61905 .59373 Mdot
.62 .59392 Mdot
.62095 .59406 Mdot
.6219 .59413 Mdot
.62286 .59415 Mdot
.62381 .59411 Mdot
.62476 .59401 Mdot
.62571 .59386 Mdot
.62667 .59365 Mdot
.62762 .59337 Mdot
.62857 .59305 Mdot
.62952 .59266 Mdot
.63048 .59222 Mdot
.63143 .59172 Mdot
.63238 .59116 Mdot
.63333 .59054 Mdot
.63429 .58987 Mdot
.63524 .58915 Mdot
.63619 .58836 Mdot
.63714 .58752 Mdot
.6381 .58663 Mdot
.63905 .58568 Mdot
.64 .58467 Mdot
.64095 .58362 Mdot
.6419 .5825 Mdot
.64286 .58134 Mdot
.64381 .58012 Mdot
.64476 .57885 Mdot
.64571 .57752 Mdot
.64667 .57615 Mdot
.64762 .57472 Mdot
.64857 .57325 Mdot
.64952 .57172 Mdot
.65048 .57014 Mdot
.65143 .56852 Mdot
.65238 .56685 Mdot
.65333 .56513 Mdot
.65429 .56336 Mdot
.65524 .56155 Mdot
.65619 .55969 Mdot
.65714 .55778 Mdot
.6581 .55584 Mdot
.65905 .55385 Mdot
.66 .55181 Mdot
.66095 .54974 Mdot
.6619 .54762 Mdot
.66286 .54546 Mdot
.66381 .54326 Mdot
.66476 .54103 Mdot
.66571 .53875 Mdot
.66667 .53644 Mdot
.66762 .53409 Mdot
.66857 .53171 Mdot
.66952 .52929 Mdot
.67048 .52684 Mdot
.67143 .52435 Mdot
.67238 .52184 Mdot
.67333 .51929 Mdot
.67429 .51671 Mdot
.67524 .51409 Mdot
.67619 .51146 Mdot
.67714 .50879 Mdot
.6781 .50609 Mdot
.67905 .50337 Mdot
.68 .50063 Mdot
.68095 .49786 Mdot
.6819 .49506 Mdot
.68286 .49224 Mdot
.68381 .4894 Mdot
.68476 .48654 Mdot
.68571 .48366 Mdot
.68667 .48076 Mdot
.68762 .47784 Mdot
.68857 .47491 Mdot
.68952 .47195 Mdot
.69048 .46898 Mdot
.69143 .466 Mdot
.69238 .463 Mdot
.69333 .45999 Mdot
.69429 .45696 Mdot
.69524 .45393 Mdot
.69619 .45088 Mdot
.69714 .44782 Mdot
.6981 .44476 Mdot
.69905 .44168 Mdot
.7 .4386 Mdot
.70095 .43551 Mdot
.7019 .43241 Mdot
.70286 .42931 Mdot
.70381 .4262 Mdot
.70476 .42309 Mdot
.70571 .41998 Mdot
.70667 .41687 Mdot
.70762 .41375 Mdot
.70857 .41063 Mdot
.70952 .40751 Mdot
.71048 .4044 Mdot
.71143 .40128 Mdot
.71238 .39816 Mdot
.71333 .39505 Mdot
.71429 .39194 Mdot
.71524 .38884 Mdot
.71619 .38574 Mdot
.71714 .38264 Mdot
.7181 .37955 Mdot
.71905 .37647 Mdot
.72 .37339 Mdot
.72095 .37032 Mdot
.7219 .36726 Mdot
.72286 .36421 Mdot
.72381 .36117 Mdot
.72476 .35813 Mdot
.72571 .35511 Mdot
.72667 .3521 Mdot
.72762 .3491 Mdot
.72857 .3461 Mdot
.72952 .34313 Mdot
.73048 .34016 Mdot
.73143 .33721 Mdot
.73238 .33427 Mdot
.73333 .33134 Mdot
.73429 .32843 Mdot
.73524 .32553 Mdot
.73619 .32265 Mdot
.73714 .31979 Mdot
.7381 .31694 Mdot
.73905 .3141 Mdot
.74 .31128 Mdot
.74095 .30848 Mdot
.7419 .3057 Mdot
.74286 .30293 Mdot
.74381 .30018 Mdot
.74476 .29745 Mdot
.74571 .29473 Mdot
.74667 .29204 Mdot
.74762 .28936 Mdot
.74857 .2867 Mdot
.74952 .28406 Mdot
.75048 .28144 Mdot
.75143 .27884 Mdot
.75238 .27626 Mdot
.75333 .2737 Mdot
.75429 .27116 Mdot
.75524 .26864 Mdot
.75619 .26614 Mdot
.75714 .26365 Mdot
.7581 .26119 Mdot
.75905 .25876 Mdot
.76 .25634 Mdot
.76095 .25394 Mdot
.7619 .25156 Mdot
.76286 .24921 Mdot
.76381 .24687 Mdot
.76476 .24456 Mdot
.76571 .24227 Mdot
.76667 .24 Mdot
.76762 .23775 Mdot
.76857 .23552 Mdot
.76952 .23331 Mdot
.77048 .23113 Mdot
.77143 .22896 Mdot
.77238 .22682 Mdot
.77333 .2247 Mdot
.77429 .2226 Mdot
.77524 .22052 Mdot
.77619 .21846 Mdot
.77714 .21643 Mdot
.7781 .21442 Mdot
.77905 .21242 Mdot
.78 .21045 Mdot
.78095 .2085 Mdot
.7819 .20657 Mdot
.78286 .20466 Mdot
.78381 .20278 Mdot
.78476 .20091 Mdot
.78571 .19907 Mdot
.78667 .19724 Mdot
.78762 .19544 Mdot
.78857 .19366 Mdot
.78952 .1919 Mdot
.79048 .19015 Mdot
.79143 .18843 Mdot
.79238 .18673 Mdot
.79333 .18505 Mdot
.79429 .18339 Mdot
.79524 .18175 Mdot
.79619 .18013 Mdot
.79714 .17853 Mdot
.7981 .17695 Mdot
.79905 .17539 Mdot
.8 .17385 Mdot
.80095 .17233 Mdot
.8019 .17082 Mdot
.80286 .16934 Mdot
.80381 .16788 Mdot
.80476 .16643 Mdot
.80571 .165 Mdot
.80667 .16359 Mdot
.80762 .1622 Mdot
.80857 .16083 Mdot
.80952 .15948 Mdot
.81048 .15814 Mdot
.81143 .15683 Mdot
.81238 .15553 Mdot
.81333 .15424 Mdot
.81429 .15298 Mdot
.81524 .15173 Mdot
.81619 .1505 Mdot
.81714 .14929 Mdot
.8181 .14809 Mdot
.81905 .14691 Mdot
.82 .14575 Mdot
.82095 .1446 Mdot
.8219 .14347 Mdot
.82286 .14236 Mdot
.82381 .14126 Mdot
.82476 .14018 Mdot
.82571 .13912 Mdot
.82667 .13807 Mdot
.82762 .13703 Mdot
.82857 .13601 Mdot
.82952 .13501 Mdot
.83048 .13402 Mdot
.83143 .13305 Mdot
.83238 .13209 Mdot
.83333 .13114 Mdot
.83429 .13021 Mdot
.83524 .1293 Mdot
.83619 .1284 Mdot
.83714 .12751 Mdot
.8381 .12664 Mdot
.83905 .12578 Mdot
.84 .12493 Mdot
.84095 .1241 Mdot
.8419 .12328 Mdot
.84286 .12248 Mdot
.84381 .12169 Mdot
.84476 .12091 Mdot
.84571 .12014 Mdot
.84667 .11939 Mdot
.84762 .11865 Mdot
.84857 .11792 Mdot
.84952 .11721 Mdot
.85048 .11651 Mdot
.85143 .11582 Mdot
.85238 .11514 Mdot
.85333 .11447 Mdot
.85429 .11382 Mdot
.85524 .11318 Mdot
.85619 .11255 Mdot
.85714 .11193 Mdot
.8581 .11132 Mdot
.85905 .11073 Mdot
.86 .11014 Mdot
.86095 .10957 Mdot
.8619 .10901 Mdot
.86286 .10845 Mdot
.86381 .10791 Mdot
.86476 .10738 Mdot
.86571 .10686 Mdot
.86667 .10636 Mdot
.86762 .10586 Mdot
.86857 .10537 Mdot
.86952 .10489 Mdot
.87048 .10442 Mdot
.87143 .10397 Mdot
.87238 .10352 Mdot
.87333 .10308 Mdot
.87429 .10266 Mdot
.87524 .10224 Mdot
.87619 .10183 Mdot
.87714 .10143 Mdot
.8781 .10104 Mdot
.87905 .10066 Mdot
.88 .10029 Mdot
.88095 .09993 Mdot
.8819 .09958 Mdot
.88286 .09924 Mdot
.88381 .09891 Mdot
.88476 .09858 Mdot
.88571 .09827 Mdot
.88667 .09796 Mdot
.88762 .09767 Mdot
.88857 .09738 Mdot
.88952 .0971 Mdot
.89048 .09683 Mdot
.89143 .09657 Mdot
.89238 .09631 Mdot
.89333 .09607 Mdot
.89429 .09583 Mdot
.89524 .0956 Mdot
.89619 .09538 Mdot
.89714 .09517 Mdot
.8981 .09497 Mdot
.89905 .09478 Mdot
.9 .09459 Mdot
.90095 .09441 Mdot
.9019 .09424 Mdot
.90286 .09408 Mdot
.90381 .09393 Mdot
.90476 .09378 Mdot
.90571 .09364 Mdot
.90667 .09351 Mdot
.90762 .09339 Mdot
.90857 .09328 Mdot
.90952 .09317 Mdot
.91048 .09308 Mdot
.91143 .09299 Mdot
.91238 .0929 Mdot
.91333 .09283 Mdot
.91429 .09276 Mdot
.91524 .09271 Mdot
.91619 .09265 Mdot
.91714 .09261 Mdot
.9181 .09258 Mdot
.91905 .09255 Mdot
.92 .09253 Mdot
.92095 .09252 Mdot
.9219 .09252 Mdot
.92286 .09252 Mdot
.92381 .09253 Mdot
.92476 .09255 Mdot
.92571 .09258 Mdot
.92667 .09261 Mdot
.92762 .09266 Mdot
.92857 .09271 Mdot
.92952 .09277 Mdot
.93048 .09283 Mdot
.93143 .09291 Mdot
.93238 .09299 Mdot
.93333 .09308 Mdot
.93429 .09318 Mdot
.93524 .09328 Mdot
.93619 .0934 Mdot
.93714 .09352 Mdot
.9381 .09365 Mdot
.93905 .09379 Mdot
.94 .09393 Mdot
.94095 .09408 Mdot
.9419 .09425 Mdot
.94286 .09442 Mdot
.94381 .09459 Mdot
.94476 .09478 Mdot
.94571 .09497 Mdot
.94667 .09518 Mdot
.94762 .09539 Mdot
.94857 .09561 Mdot
.94952 .09584 Mdot
.95048 .09607 Mdot
.95143 .09632 Mdot
.95238 .09657 Mdot
.95333 .09683 Mdot
.95429 .0971 Mdot
.95524 .09738 Mdot
.95619 .09767 Mdot
.95714 .09796 Mdot
.9581 .09827 Mdot
.95905 .09858 Mdot
.96 .0989 Mdot
.96095 .09924 Mdot
.9619 .09958 Mdot
.96286 .09993 Mdot
.96381 .10029 Mdot
.96476 .10066 Mdot
.96571 .10103 Mdot
.96667 .10142 Mdot
.96762 .10182 Mdot
.96857 .10222 Mdot
.96952 .10264 Mdot
.97048 .10306 Mdot
.97143 .1035 Mdot
.97238 .10395 Mdot
.97333 .1044 Mdot
.97429 .10487 Mdot
.97524 .10534 Mdot
.97619 .10583 Mdot
0 g
.0075 w
.02381 .60332 m
.02499 .60327 L
.02605 .60316 L
.02729 .60293 L
.02846 .60262 L
.03053 .60185 L
.03279 .60071 L
.03527 .59908 L
.0379 .59693 L
.04262 .59199 L
.05205 .57818 L
.06244 .55743 L
.0842 .49933 L
.10458 .43426 L
.14335 .31006 L
.16306 .25605 L
.18458 .20734 L
.20517 .17081 L
.22428 .14485 L
.24481 .12426 L
.26341 .11099 L
.27344 .10565 L
.28266 .10174 L
.29279 .09845 L
.29788 .09718 L
.30348 .09606 L
.30599 .09565 L
.30872 .09527 L
.31113 .095 L
.31369 .09476 L
.31598 .09459 L
.31729 .09452 L
.31852 .09446 L
.31964 .09442 L
.32067 .0944 L
.3218 .09438 L
.32299 .09437 L
.3243 .09438 L
.32549 .0944 L
.32615 .09442 L
.32687 .09444 L
.32816 .09449 L
.32938 .09455 L
.33067 .09463 L
.33298 .09481 L
.33567 .09508 L
.33818 .09539 L
.34391 .09631 L
.34888 .09735 L
.35431 .09875 L
Mistroke
.36419 .10205 L
.37381 .10625 L
.38273 .11107 L
.40329 .12605 L
.42191 .14506 L
.4412 .17134 L
.46203 .20853 L
.50309 .3113 L
.54262 .43818 L
.56253 .50146 L
.58065 .55067 L
.59069 .57224 L
.6002 .58787 L
.60541 .59426 L
.61023 .59869 L
.61274 .60042 L
.61552 .60187 L
.61691 .60241 L
.61764 .60264 L
.61841 .60285 L
.61909 .603 L
.61983 .60314 L
.62113 .60328 L
.62177 .60331 L
.62245 .60332 L
.62367 .60325 L
.62498 .60307 L
.62573 .60292 L
.62643 .60274 L
.62884 .60189 L
.63019 .60126 L
.63143 .60057 L
.63623 .59699 L
.64077 .59227 L
.65081 .57755 L
.66174 .5554 L
.68149 .50266 L
.70249 .43588 L
.74021 .31463 L
.76115 .25682 L
.78038 .21264 L
.80039 .17582 L
.81903 .14927 L
.83793 .12891 L
.84857 .11995 L
.85862 .11294 L
.86842 .10734 L
.87906 .10251 L
.88872 .09916 L
.89764 .09688 L
Mistroke
.9023 .09599 L
.90487 .09558 L
.90732 .09525 L
.90958 .09499 L
.91205 .09476 L
.91429 .0946 L
.91638 .09449 L
.91767 .09444 L
.9184 .09441 L
.91908 .0944 L
.92031 .09438 L
.92162 .09437 L
.92279 .09438 L
.92388 .0944 L
.92508 .09443 L
.92637 .09448 L
.92774 .09455 L
.92923 .09464 L
.93193 .09486 L
.93457 .09514 L
.93701 .09545 L
.94163 .09618 L
.94662 .0972 L
.95564 .09963 L
.96636 .10358 L
.97619 .10828 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00R_oonfX9o`00Of?ooo]Z0ol007mPoook
JPGo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o3ooonfX008[ooo]Z2Ol007mSoookJP?o
001oGooonfX7o`00Of3ooo]Z1ol007mNoookJP?o001o1?oonfX7o`00O`kooo]Z002:oookJPCo001o
J?oonfX3o`00Oeoooo]Z0ol007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o
1?oonfX3o`00O`04oookJ_l007oo001oo`00O`kooo]Z002;oookJPCo001oH_oonfX9o`00Oegooo]Z
0ol007l3oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z
0ol007l=oookJP00S?oonfX5o`00Of3ooo]Z2Ol007mMoookJP?o001o0ooonfX3o`00Oekooo]Z0ol0
07l3oookJP?o001oGOoonfX3o`00O`?ooo]Z0ol007l3oookJP?o001o3OoonfX008kooo]Z1?l007mO
oookJP;o001o0ooonfX3o`00Oekooo]Z1?l007l2oookJP?o001oG_oonfX3o`00O`?ooo]Z0ol007mM
oookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00SooonfX3o`00Of3ooo]Z0_l007l2oook
JP?o001oG_oonfX8o`00Of3ooo]Z1ol007mNoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oook
JP00T?oonfX3o`00Oeoooo]Z0ol007l01?oonf[o001oo`00Ool007mNoookJP?o001o00Cooo]Zo`00
Ool007oo001oHOoonfX7o`00Oekooo]Z0ol007l3oookJP?o001o0ooonfX3o`00O`gooo]Z002:oook
JP?o001o0ooonfX3o`00Of3ooo]Z0_l007l01?oonf[o001oo`00Ool007mNoookJP?o001oI?oonfX3
o`00O`?ooo]Z0ol007mMoookJP?o001o0ooonfX3o`00O`?ooo]Z0ol007l=oookJP00R_oonfX3o`00
O`?ooo]Z0ol007mQoookJPGo001oG_oonfX3o`00OfCooo]Z0ol007l3oookJP?o001oF_oonfX6o`00
O`?ooo]Z0ol007l3oookJP?o001o3OoonfX002Kooo]Z1Ol0001OoookJPCo001o0_oonfX3o`00Of7o
oo]Z1Ol007mOoookJP?o001o0_oonfX3o`00Oekooo]Z0ol007l3oookJP?o001oF_oonfX6o`00O`Co
oo]Z0ol007l01?oonf[o001oo`00Ool007l>oookJP009_oonfX5o`00063ooo]Z1ol007mSoookJPCo
001oGooonfX7o`00Of3ooo]Z1ol007mMoookJPCo001o1?oonfX7o`00O`kooo]Z000VoookJPGo0000
HOoonfX5o`00OfGooo]Z0ol007mQoookJPCo001oH_oonfX5o`00Oeoooo]Z0ol007l5oookJPGo001o
3ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003o
o`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX001Wooo]Zool0003oo`0002?o
00001_oonfX001Wooo]Zool0003oo`0002?o00001_oonfX002Kooo]Z1Ol0001ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oo
nf[ooo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0001ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX0HooonfX00ol0003ooo]ZoookJP1ToookJP03o`000?oonf[o
oo]Z06Cooo]Z00?o0000oookJ_oonfX04ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oo
oo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooo
nfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Ko
oo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0
003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z
5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX0
02Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z
1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003o
oookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ][o
oo]Z4_oo000ZoookJP009_oonfX5o`0009Cooo]Z0ooo000>o`0000Koo`00oooonfXYoookJPOoo`00
3_l00009ool002Cooo]Z000VoookJPGo0000SooonfX2ool001go000000?oo`00oookJ_oonfX0oooo
nfXPoookJPCoo`007?l00005ool0023ooo]Z000VoookJPGo0000RooonfXVo`0000;oo`00oooonfXK
oookJPCoo`008ol00004ool001gooo]Z000VoookJPGo0000R?oonfX]o`000003ool00?oonf[ooo]Z
0?oooo]Z4ooonfX3ool002_o00000ooo000JoookJP009_oonfX5o`0008Kooo]Z5?l00008oookJQKo
0000oooonfX@oookJP?oo`004ol00008oookJQKo00000_oo000HoookJP009_oonfX5o`0008?ooo]Z
4Ol0000GoookJPoo000000?oo`00oookJ_oonfX0oooonfX9oookJP?oo`003ol0000FoookJQ3o0000
0_oo000FoookJP009_oonfX5o`00087ooo]Z3Ol0000PoookJPgo00000_oo003ooookJPOooo]Z0_oo
000?o`0001gooo]Z3_l000000ooo003ooo]ZoookJP0CoookJP009_oonfX5o`0007oooo]Z3?l0000W
oookJP_o00000_oo003ooookJP?ooo]Z00?oo`00o`000?l000003?l0000UoookJP_o000000?oo`00
oookJ_oonfX04_oonfX002Kooo]Z1Ol0001moookJPco0000;?oonfX;o`000?oooo]Z0OoonfX=o`00
02_ooo]Z2Ol0000DoookJP009_oonfX5o`0007_ooo]Z2ol0000aoookJP_o0000o?oonfX00ooo003o
0000o`00000:o`0002oooo]Z1ol0000DoookJP009_oonfX5o`0007[ooo]Z2_l0000doookJP_o0000
n_oonfX;o`0003Cooo]Z1Ol0000DoookJP009_oonfX5o`0007Sooo]Z2_l0000hoookJP[o000000?o
o`00oookJ_oonfX0m?oonfX00ooo003o0000o`000007o`0003Sooo]Z1?l0000DoookJP009_oonfX5
o`0007Oooo]Z2Ol0000moookJPWo0000m?oonfX9o`0005;ooo]Z000VoookJPGo0000M_oonfX8o`00
047ooo]Z2?l0003boookJPWo0000DooonfX002Kooo]Z1Ol0001doookJPWo0000@ooonfX9o`000>ko
oo]Z2Ol0001EoookJP009_oonfX5o`0007?ooo]Z2?l00016oookJPWo0000k?oonfX9o`0005Kooo]Z
000VoookJPGo0000L_oonfX8o`0004Wooo]Z2?l000000ooo003ooo]ZoookJP3WoookJPSo0000F?oo
nfX002Kooo]Z1Ol0001boookJPOo0000BooonfX8o`000003ool00?oonf[ooo]Z0>Gooo]Z2?l0001I
oookJP002OoonfX5o`00O`Cooo]Z0ol007l00ooonf[o001oo`00O`07o`00O`Oooo]Z1Ol0001aoook
JPKo0000CooonfX6o`0000;oo`00iOoonfX7o`0005_ooo]Z0008oookJPOo001o0ooonfX3o`00O`03
oookJ_l007oo001o00Oo001o1ooonfX5o`00073ooo]Z1_l0001AoookJPKo00000_oo003SoookJPOo
0000G?oonfX000Sooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o00?ooo]Zo`00Ool0
07l00_l007l<oookJPGo0000KooonfX7o`0005;ooo]Z1_l00002ool00>7ooo]Z00?oo`00o`000?l0
00001?l0001MoookJP001ooonfX3o`00O`?ooo]Z0ol007l7oookJPCo001o2ooonfX5o`0006kooo]Z
1ol0001CoookJPOo00000_oo003OoookJP03ool00?l0003o000000Co0000G_oonfX000Oooo]Z0ol0
07l3oookJP?o001o2?oonfX5o`00O`Wooo]Z1ol0001[oookJPOo0000EOoonfX7o`0000;oo`00gOoo
nfX00ooo003o0000o`000004o`0005oooo]Z0007oookJP?o001o0ooonfX3o`00O`[ooo]Z1?l007l8
oookJPGo0000K?oonfX7o`0005Oooo]Z1ol00002ool00=_ooo]Z00?oo`00o`000?l000001Ol0001O
oookJP001ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o2?oonfX5o`0006_ooo]Z1ol0001Ioook
JPOo00000_oo003IoookJP03ool00?l0003o000000Go0000H?oonfX000Oooo]Z0ol007l3oookJP?o
001o3?oonfX3o`00O`Oooo]Z1Ol0001ZoookJPOo0000FooonfX7o`000003ool00?oonf[ooo]Z0=Ko
oo]Z00?oo`00o`000?l000001Ol0001QoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o
0ooonfX3o`00O`Oooo]Z1Ol0001YoookJPOo0000GOoonfX7o`000003ool00?oonf[ooo]Z0=Cooo]Z
00?oo`00o`000?l000001Ol0001RoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooo
nfX3o`00O`Oooo]Z1Ol0001XoookJPOo0000GooonfX7o`000003ool00?oonf[ooo]Z0=;ooo]Z00?o
o`00o`000?l000001Ol0001SoookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z1?l0
07l2oookJP?o001o1ooonfX5o`0006Oooo]Z1ol0001QoookJPOo000000?oo`00oookJ_oonfX0dOoo
nfX7o`0006Cooo]Z0008oookJPOo001o2?oonfX7o`00O`Sooo]Z1Ol0001WoookJPKo0000HooonfX6
o`0000;oo`00dOoonfX7o`0006Gooo]Z0009oookJPGo001o2_oonfX5o`00O`Wooo]Z1Ol0001Voook
JPKo0000IOoonfX6o`0000;oo`00cooonfX7o`0006Kooo]Z000VoookJPGo0000IOoonfX6o`0006Oo
oo]Z1_l000000ooo003ooo]ZoookJP3<oookJP03ool00?l0003o000000Co0000IooonfX002Kooo]Z
1Ol0001ToookJPOo0000IooonfX7o`000003ool00?oonf[ooo]Z0<_ooo]Z1_l0001XoookJP009_oo
nfX5o`0006?ooo]Z00?oo`00o`000?l000001?l0001YoookJPKo00000_oo003;oookJPKo0000JOoo
nfX002Kooo]Z1Ol0001SoookJPKo0000JooonfX6o`0000;oo`00bOoonfX7o`0006Wooo]Z000Voook
JPGo0000H_oonfX6o`0006gooo]Z1_l00002ool00<Oooo]Z00?oo`00o`000?l000001?l0001Zoook
JP009_oonfX5o`00067ooo]Z00?oo`00o`000?l000001?l0001]oookJPKo00000ooo0035oookJP03
ool00?l0003o000000Co0000JooonfX002Kooo]Z1Ol0001QoookJPKo0000KooonfX6o`0000;oo`00
a?oonfX00ooo003o0000o`000004o`0006cooo]Z000VoookJPGo0000H?oonfX6o`00077ooo]Z1_l0
0002ool00<?ooo]Z00?oo`00o`000?l000001?l0001/oookJP009_oonfX5o`0005oooo]Z1ol0001a
oookJPOo00000_oo0031oookJP03ool00?l0003o000000Co0000KOoonfX002Kooo]Z1Ol0001Ooook
JPKo0000LooonfX6o`0000;oo`00`OoonfX6o`0006kooo]Z000VoookJPGo0000G_oonfX6o`0007Go
oo]Z1_l00002ool00;oooo]Z1ol0001^oookJP009_oonfX5o`0005gooo]Z1_l0001goookJPKo0000
00?oo`00oookJ_oonfX0_?oonfX00ooo003o0000o`000004o`0006oooo]Z000VoookJPGo0000GOoo
nfX6o`0007Oooo]Z1_l00002ool00;gooo]Z1_l0001`oookJP009_oonfX5o`0005cooo]Z1_l0001i
oookJPKo00000_oo002koookJPKo0000LOoonfX002Kooo]Z1Ol0001LoookJPGo0000NooonfX6o`00
0003ool00?oonf[ooo]Z0;Sooo]Z00?oo`00o`000?l000001?l0001aoookJP009_oonfX5o`0005_o
oo]Z1_l0001koookJPKo00000_oo002ioookJPKo0000L_oonfX002Kooo]Z1Ol0001JoookJPKo0000
OOoonfX6o`000003ool00?oonf[ooo]Z0;Kooo]Z00?oo`00o`000?l000000ol0001coookJP009_oo
nfX5o`0005[ooo]Z1_l0001noookJPGo00000_oo002goookJPKo0000LooonfX002Kooo]Z1Ol0001I
oookJPKo0000OooonfX6o`0000;oo`00]OoonfX00ooo003o0000o`000003o`0007Cooo]Z000Voook
JPGo0000FOoonfX5o`00087ooo]Z1_l000000ooo003ooo]ZoookJP2coookJPKo0000M?oonfX002Ko
oo]Z1Ol0001HoookJPKo0000POoonfX6o`0000;oo`00/ooonfX6o`0007Gooo]Z000VoookJPGo0000
EooonfX6o`0008?ooo]Z1_l000000ooo003ooo]ZoookJP2aoookJPKo0000MOoonfX002Kooo]Z1Ol0
001GoookJPKo0000Q?oonfX5o`0000;oo`00/OoonfX6o`0007Kooo]Z000VoookJPGo0000E_oonfX6
o`0008Gooo]Z1_l000000ooo003ooo]ZoookJP2^oookJP03ool00?l0003o000000?o0000MooonfX0
02Kooo]Z1Ol0001FoookJPGo0000QooonfX6o`000003ool00?oonf[ooo]Z0:gooo]Z1_l0001goook
JP009_oonfX5o`0005Gooo]Z1_l00027oookJPKo000000?oo`00oookJ_oonfX0[?oonfX00ooo003o
0000o`000003o`0007Sooo]Z000VoookJPGo0000EOoonfX5o`0008Wooo]Z1_l000000ooo003ooo]Z
oookJP2[oookJPKo0000N?oonfX002Kooo]Z1Ol0001DoookJPKo0000R_oonfX5o`000003ool00?oo
nf[ooo]Z0:[ooo]Z00?oo`00o`000?l000000ol0001ioookJP009_oonfX5o`0005?ooo]Z1_l0002;
oookJPKo000000?oo`00oookJ_oonfX0ZOoonfX6o`0007Wooo]Z000VoookJPGo0000DooonfX6o`00
08cooo]Z1_l0002ZoookJPKo0000N_oonfX002Kooo]Z1Ol0001BoookJPKo0000SOoonfX6o`000003
ool00?oonf[ooo]Z0:Oooo]Z1_l0001joookJP009_oonfX5o`0005;ooo]Z1Ol0002?oookJPKo0000
Z?oonfX6o`0007_ooo]Z000VoookJPGo0000DOoonfX6o`00093ooo]Z1Ol000000ooo003ooo]Zoook
JP2UoookJPGo0000O?oonfX002Kooo]Z1Ol0001AoookJPGo0000TOoonfX6o`000:Kooo]Z1_l0001l
oookJP009_oonfX5o`00053ooo]Z1_l0002BoookJPGo000000?oo`00oookJ_oonfX0XooonfX5o`00
07gooo]Z000VoookJPGo0000D?oonfX5o`0009?ooo]Z1Ol000000ooo003ooo]ZoookJP2RoookJPKo
0000OOoonfX002Kooo]Z1Ol0001@oookJPGo0000U?oonfX5o`000003ool00?oonf[ooo]Z0:7ooo]Z
1Ol0001noookJP009_oonfX5o`0004oooo]Z1Ol0002EoookJPGo00000_oo002QoookJP03ool00?l0
003o000000?o0000O_oonfX002Kooo]Z1Ol0001?oookJPGo0000UOoonfX6o`000003ool00?oonf[o
oo]Z09oooo]Z1Ol0001ooookJP009_oonfX5o`0004kooo]Z1_l0002FoookJPGo00000_oo002Ooook
JP03ool00?l0003o000000?o0000OooonfX002Kooo]Z1Ol0001>oookJPGo0000UooonfX5o`0000;o
o`00WooonfX6o`0007oooo]Z000VoookJPGo0000COoonfX6o`0009Sooo]Z1Ol000000ooo003ooo]Z
oookJP2LoookJP03ool00?l0003o000000?o0000P?oonfX002Kooo]Z1Ol0001=oookJPGo0000VOoo
nfX5o`0000;oo`00WOoonfX6o`00083ooo]Z000VoookJPGo0000C?oonfX6o`0009Wooo]Z1_l00000
0ooo003ooo]ZoookJP2KoookJPGo0000POoonfX002Kooo]Z1Ol0001<oookJPGo0000VooonfX5o`00
00;oo`00VooonfX00ooo003o0000o`000003o`00087ooo]Z000VoookJPGo0000C?oonfX5o`0009_o
oo]Z1Ol00002ool009_ooo]Z1Ol00022oookJP009_oonfX5o`0004_ooo]Z1Ol0002MoookJPGo0000
0_oo002IoookJP03ool00?l0003o000000?o0000P_oonfX002Kooo]Z1Ol0001;oookJPGo0000WOoo
nfX5o`0000;oo`00VOoonfX6o`0008;ooo]Z000VoookJPGo0000B_oonfX6o`0009gooo]Z1_l00000
0ooo003ooo]ZoookJP2FoookJP03ool00?l0003o000000?o0000PooonfX002Kooo]Z1Ol0001:oook
JPGo0000WooonfX5o`0000;oo`00UooonfX00ooo003o0000o`000003o`0008?ooo]Z0009oookJPGo
001o1?oonfX3o`00O`Kooo]Z0ol007l8oookJPGo0000BOoonfX6o`0009oooo]Z1Ol00002ool009Oo
oo]Z1Ol00024oookJP002?oonfX7o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX5o`0004Wooo]Z
1Ol0002QoookJPGo00000_oo002EoookJP03ool00?l0003o000000?o0000Q?oonfX000Sooo]Z0ol0
07l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z1Ol00018oookJPKo0000
XOoonfX5o`0000;oo`00UOoonfX6o`0008Cooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol0
07l7oookJPGo0000B?oonfX5o`000:;ooo]Z1_l000000ooo003ooo]ZoookJP2BoookJP03ool00?l0
003o000000?o0000QOoonfX000Oooo]Z0ol007l3oookJP?o001o1_oonfX9o`00O`Oooo]Z1ol00016
oookJPGo0000XooonfX5o`0000;oo`00TooonfX6o`0008Gooo]Z0007oookJP?o001o0ooonfX3o`00
O`Kooo]Z0_l007l3oookJP?o001o2?oonfX5o`0004Oooo]Z1Ol0002ToookJPGo00000_oo002Coook
JPGo0000Q_oonfX000Oooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007l8oookJPGo
0000AooonfX5o`000:Gooo]Z1Ol00002ool0097ooo]Z00?oo`00o`000?l000000ol00026oookJP00
1ooonfX3o`00O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX5o`0004Ko
oo]Z1_l0002UoookJPGo00000_oo002AoookJPGo0000QooonfX000Oooo]Z0ol007l3oookJP?o001o
2?oonfX2o`00O`04oookJ_l007oo001oo`00O`Sooo]Z1Ol00016oookJPGo0000Y_oonfX6o`000003
ool00?oonf[ooo]Z08oooo]Z1Ol00027oookJP001ooonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o
2?oonfX5o`0004Gooo]Z1_l0002WoookJPGo00000_oo002?oookJPKo0000QooonfX000Sooo]Z0ol0
07l01?oonf[o001oo`00Ool007l:oookJPGo001o2?oonfX5o`0004Gooo]Z1Ol0002XoookJPGo0000
0_oo002?oookJPGo0000R?oonfX000Sooo]Z1ol007l;oookJPCo001o2?oonfX5o`0004Gooo]Z1Ol0
002YoookJPGo00000_oo002=oookJP03ool00?l0003o000000?o0000R?oonfX000Wooo]Z1Ol007l=
oookJP?o001o2?oonfX5o`0004Cooo]Z1Ol0002ZoookJPGo00000_oo002=oookJPGo0000ROoonfX0
02Kooo]Z1Ol00014oookJPGo0000Z_oonfX6o`000003ool00?oonf[ooo]Z08_ooo]Z1Ol00029oook
JP009_oonfX5o`0004Cooo]Z1Ol0002[oookJPGo00000_oo002;oookJP03ool00?l0003o000000?o
0000ROoonfX002Kooo]Z1Ol00013oookJPGo0000[?oonfX5o`0000;oo`00RooonfX5o`0008[ooo]Z
000VoookJPGo0000@ooonfX5o`000:gooo]Z1Ol000000ooo003ooo]ZoookJP29oookJPGo0000R_oo
nfX002Kooo]Z1Ol00013oookJPGo0000[OoonfX5o`0000;oo`00ROoonfX00ooo003o0000o`000003
o`0008[ooo]Z000VoookJPGo0000@_oonfX5o`000:kooo]Z1_l000000ooo003ooo]ZoookJP27oook
JPGo0000RooonfX002Kooo]Z1Ol00012oookJPGo0000[ooonfX5o`0000;oo`00QooonfX00ooo003o
0000o`000003o`0008_ooo]Z000VoookJPGo0000@_oonfX5o`000:oooo]Z1Ol00002ool008Oooo]Z
00?oo`00o`000?l000000ol0002;oookJP009_oonfX5o`00047ooo]Z1Ol0002aoookJPGo000000?o
o`00oookJ_oonfX0QOoonfX5o`0008cooo]Z000VoookJPGo0000@OoonfX5o`000;7ooo]Z1Ol00002
ool008Gooo]Z00?oo`00o`000?l000000ol0002<oookJP009_oonfX5o`00047ooo]Z1Ol0002aoook
JPKo000000?oo`00oookJ_oonfX0PooonfX6o`0008cooo]Z000VoookJPGo0000@?oonfX5o`000;?o
oo]Z1Ol000000ooo003ooo]ZoookJP23oookJPGo0000SOoonfX002Kooo]Z1Ol00010oookJPGo0000
/ooonfX5o`0000;oo`00PooonfX00ooo003o0000o`000003o`0008gooo]Z000VoookJPGo0000@?oo
nfX5o`000;Cooo]Z1Ol000000ooo003ooo]ZoookJP21oookJPGo0000S_oonfX002Kooo]Z1Ol0000o
oookJPGo0000]OoonfX5o`000003ool00?oonf[ooo]Z087ooo]Z1Ol0002>oookJP009_oonfX5o`00
03oooo]Z1Ol0002eoookJPKo000000?oo`00oookJ_oonfX0OooonfX00ooo003o0000o`000003o`00
08kooo]Z000VoookJPGo0000?ooonfX5o`000;Kooo]Z1Ol000000ooo003ooo]ZoookJP1ooookJPGo
0000SooonfX002Kooo]Z1Ol0000noookJPGo0000]ooonfX5o`000003ool00?oonf[ooo]Z07oooo]Z
1Ol0002?oookJP009_oonfX5o`0003kooo]Z1Ol0002hoookJPGo000000?oo`00oookJ_oonfX0OOoo
nfX00ooo003o0000o`000003o`0008oooo]Z000VoookJPGo0000?_oonfX5o`000;Sooo]Z1Ol00002
ool007kooo]Z1Ol0002@oookJP009_oonfX5o`0003gooo]Z1Ol0002ioookJPKo000000?oo`00oook
J_oonfX0O?oonfX5o`00093ooo]Z000VoookJPGo0000?OoonfX5o`000;[ooo]Z1Ol000000ooo003o
oo]ZoookJP1koookJP03ool00?l0003o000000?o0000T?oonfX002Kooo]Z1Ol0000moookJPGo0000
^_oonfX5o`0000;oo`00NooonfX00ooo003o0000o`000003o`00097ooo]Z000VoookJPGo0000??oo
nfX5o`000;cooo]Z1Ol000000ooo003ooo]ZoookJP1ioookJP03ool00?l0003o000000?o0000TOoo
nfX002Kooo]Z1Ol0000loookJPGo0000_?oonfX5o`000003ool00?oonf[ooo]Z07Wooo]Z00?oo`00
o`000?l000000ol0002AoookJP009_oonfX5o`0003cooo]Z1Ol0002loookJPGo00000_oo001ioook
JP03ool00?l0003o000000?o0000T_oonfX002Kooo]Z1Ol0000koookJPGo0000__oonfX5o`000003
ool00?oonf[ooo]Z07Oooo]Z00?oo`00o`000?l000000ol0002BoookJP009_oonfX5o`0003_ooo]Z
1Ol0002noookJPGo000000?oo`00oookJ_oonfX0MooonfX00ooo003o0000o`000003o`0009;ooo]Z
000VoookJPGo0000>ooonfX5o`000;kooo]Z1Ol00002ool007Sooo]Z1Ol0002CoookJP009_oonfX5
o`0003[ooo]Z1Ol00030oookJPGo000000?oo`00oookJ_oonfX0MOoonfX00ooo003o0000o`000003
o`0009?ooo]Z000VoookJPGo0000>_oonfX5o`000<3ooo]Z1Ol000000ooo003ooo]ZoookJP1eoook
JP03ool00?l0003o000000?o0000TooonfX002Kooo]Z1Ol0000joookJPGo0000`?oonfX5o`0000;o
o`00M_oonfX5o`0009Cooo]Z000VoookJPGo0000>OoonfX5o`000<;ooo]Z1Ol000000ooo003ooo]Z
oookJP1coookJP03ool00?l0003o000000?o0000U?oonfX002Kooo]Z1Ol0000ioookJPGo0000`_oo
nfX5o`000003ool00?oonf[ooo]Z07?ooo]Z00?oo`00o`000?l000000ol0002DoookJP009_oonfX5
o`0003Wooo]Z1Ol00032oookJPGo00000_oo001doookJPGo0000UOoonfX002Kooo]Z1Ol0000hoook
JPGo0000a?oonfX5o`000003ool00?oonf[ooo]Z077ooo]Z00?oo`00o`000?l000000ol0002Eoook
JP009_oonfX5o`0003Sooo]Z1Ol00034oookJPGo000000?oo`00oookJ_oonfX0LOoonfX00ooo003o
0000o`000003o`0009Gooo]Z000VoookJPGo0000>?oonfX5o`000<Cooo]Z1Ol000000ooo003ooo]Z
oookJP1aoookJPGo0000U_oonfX002Kooo]Z1Ol0000goookJPGo0000a_oonfX4o`0000;oo`00LOoo
nfX00ooo003o0000o`000003o`0009Kooo]Z000VoookJPGo0000=ooonfX5o`000<Kooo]Z1Ol00000
0ooo003ooo]ZoookJP1_oookJP03ool00?l0003o000000?o0000U_oonfX002Kooo]Z1Ol0000goook
JPGo0000a_oonfX5o`000003ool00?oonf[ooo]Z06oooo]Z1Ol0002GoookJP009_oonfX5o`0003Oo
oo]Z1?l00037oookJPGo00000_oo001_oookJP03ool00?l0003o000000?o0000UooonfX002Kooo]Z
1Ol0000foookJPGo0000b?oonfX5o`000003ool00?oonf[ooo]Z06gooo]Z00?oo`00o`000?l00000
0ol0002GoookJP009_oonfX5o`0003Kooo]Z1Ol00038oookJPGo000000?oo`00oookJ_oonfX0KOoo
nfX5o`0009Sooo]Z000VoookJPGo0000=_oonfX5o`000<Sooo]Z1Ol00002ool006gooo]Z00?oo`00
o`000?l000000ol0002HoookJP009_oonfX5o`0003Gooo]Z1Ol0003:oookJPGo000000?oo`00oook
J_oonfX0JooonfX00ooo003o0000o`000003o`0009Sooo]Z000VoookJPGo0000=OoonfX5o`000<[o
oo]Z1Ol000000ooo003ooo]ZoookJP1[oookJPGo0000VOoonfX002Kooo]Z1Ol0000eoookJPGo0000
b_oonfX5o`0000;oo`00K?oonfX5o`0009Wooo]Z000VoookJPGo0000=?oonfX5o`000<cooo]Z1?l0
0002ool006_ooo]Z00?oo`00o`000?l000000ol0002IoookJP009_oonfX5o`0003Cooo]Z1Ol0003<
oookJPGo000000?oo`00oookJ_oonfX0JOoonfX00ooo003o0000o`000002o`0009[ooo]Z000Voook
JPGo0000=?oonfX5o`000<cooo]Z1Ol00002ool006[ooo]Z1Ol0002JoookJP002OoonfX5o`00O`Co
oo]Z0ol007l3oookJPGo001o2OoonfX5o`0003?ooo]Z1Ol0003=oookJPGo00000_oo001YoookJP03
ool00?l0003o000000?o0000V_oonfX000Sooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Sooo]Z
1Ol0000coookJPGo0000c_oonfX5o`000003ool00?oonf[ooo]Z06Oooo]Z00?oo`00o`000?l00000
0ol0002JoookJP002?oonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l2oookJP?o001o
0_oonfX3o`00O`Oooo]Z1Ol0000coookJPGo0000c_oonfX5o`000003ool00?oonf[ooo]Z06Oooo]Z
1Ol0002KoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0
000boookJPGo0000cooonfX5o`0000;oo`00IooonfX00ooo003o0000o`000003o`0009_ooo]Z0007
oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooonfX7o`00033ooo]Z1Ol0003@
oookJPGo000000?oo`00oookJ_oonfX0IOoonfX00ooo003o0000o`000003o`0009_ooo]Z0007oook
JP?o001o0ooonfX3o`00O`Kooo]Z1?l007l2oookJP?o001o1ooonfX5o`0003;ooo]Z1Ol0003@oook
JPGo000000?oo`00oookJ_oonfX0IOoonfX5o`0009cooo]Z0007oookJP?o001o0ooonfX3o`00O`Ko
oo]Z2?l007l8oookJPGo0000<OoonfX5o`000=7ooo]Z1Ol00002ool006Gooo]Z00?oo`00o`000?l0
00000ol0002LoookJP001ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo
001o2OoonfX5o`00037ooo]Z1Ol0003BoookJPGo000000?oo`00oookJ_oonfX0HooonfX00ooo003o
0000o`000003o`0009cooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l=oookJPGo0000
<OoonfX5o`000=;ooo]Z1Ol000000ooo003ooo]ZoookJP1SoookJPGo0000WOoonfX000Oooo]Z0ol0
07l3oookJP?o001o1_oonfX3o`00O`gooo]Z1Ol0000`oookJP03ool00?l0003o000000;o0000dooo
nfX5o`0000;oo`00I?oonfX5o`0009gooo]Z0008oookJP?o001o00Cooo]Zo`00Ool007oo001o2?oo
nfX3o`00O`;ooo]Z0ol007l7oookJPGo0000<?oonfX5o`000=Cooo]Z1?l00002ool006?ooo]Z00?o
o`00o`000?l000000ol0002MoookJP002?oonfX7o`00O`Sooo]Z1ol007l8oookJPGo0000<?oonfX5
o`000=Cooo]Z1Ol000000ooo003ooo]ZoookJP1QoookJPGo0000W_oonfX000Wooo]Z1Ol007l;oook
JPCo001o2OoonfX5o`0002oooo]Z00?oo`00o`000?l000000ol0003DoookJPGo000000?oo`00oook
J_oonfX0HOoonfX5o`0009kooo]Z000VoookJPGo0000;ooonfX5o`000=Gooo]Z1Ol00002ool0067o
oo]Z00?oo`00o`000?l000000ol0002NoookJP009_oonfX5o`0002oooo]Z1Ol0003FoookJPGo0000
00?oo`00oookJ_oonfX0GooonfX5o`0009oooo]Z000VoookJPGo0000;ooonfX5o`000=Kooo]Z1Ol0
00000ooo003ooo]ZoookJP1OoookJPGo0000WooonfX002Kooo]Z1Ol0000^oookJPGo0000eooonfX5
o`0000;oo`00GooonfX00ooo003o0000o`000003o`0009oooo]Z000VoookJPGo0000;_oonfX5o`00
0=Sooo]Z1Ol000000ooo003ooo]ZoookJP1MoookJPGo0000X?oonfX002Kooo]Z1Ol0000^oookJPGo
0000f?oonfX5o`000003ool00?oonf[ooo]Z05gooo]Z1Ol0002PoookJP009_oonfX5o`0002gooo]Z
1Ol0003IoookJPGo00000_oo001NoookJPGo0000X?oonfX002Kooo]Z1Ol0000]oookJPGo0000f_oo
nfX4o`0000;oo`00GOoonfX00ooo003o0000o`000002o`000:7ooo]Z000VoookJPGo0000;OoonfX5
o`000=[ooo]Z1Ol000000ooo003ooo]ZoookJP1KoookJPGo0000XOoonfX002Kooo]Z1Ol0000/oook
JPGo0000fooonfX5o`000003ool00?oonf[ooo]Z05_ooo]Z1Ol0002QoookJP009_oonfX5o`0002co
oo]Z1Ol0003KoookJPGo00000_oo001KoookJP03ool00?l0003o000000?o0000XOoonfX002Kooo]Z
1Ol0000/oookJPGo0000g?oonfX5o`000003ool00?oonf[ooo]Z05Wooo]Z1Ol0002RoookJP009_oo
nfX5o`0002cooo]Z1?l0003MoookJPGo000000?oo`00oookJ_oonfX0FOoonfX5o`000:;ooo]Z000V
oookJPGo0000:ooonfX5o`000=gooo]Z1Ol00002ool005[ooo]Z1Ol0002RoookJP009_oonfX5o`00
02_ooo]Z1Ol0003NoookJPGo000000?oo`00oookJ_oonfX0EooonfX5o`000:?ooo]Z000VoookJPGo
0000:ooonfX5o`000=kooo]Z1Ol00002ool005Oooo]Z00?oo`00o`000?l000000ol0002SoookJP00
9_oonfX5o`0002[ooo]Z1Ol0003OoookJPGo00000_oo001GoookJP03ool00?l0003o000000?o0000
XooonfX002Kooo]Z1Ol0000ZoookJPGo0000h?oonfX5o`000003ool00?oonf[ooo]Z05Gooo]Z1Ol0
002ToookJP009_oonfX5o`0002[ooo]Z1Ol0003PoookJPGo00000_oo001FoookJPGo0000Y?oonfX0
02Kooo]Z1Ol0000YoookJPGo0000hOoonfX5o`0000;oo`00EOoonfX00ooo003o0000o`000003o`00
0:Cooo]Z000VoookJPGo0000:OoonfX5o`000>;ooo]Z1?l00002ool005Gooo]Z1Ol0002UoookJP00
9_oonfX5o`0002Wooo]Z1Ol0003RoookJPGo00000_oo001DoookJPGo0000YOoonfX002Kooo]Z1Ol0
000XoookJPGo0000hooonfX5o`0000;oo`00DooonfX00ooo003o0000o`000003o`000:Gooo]Z000V
oookJPGo0000:?oonfX5o`000>?ooo]Z1Ol00002ool005?ooo]Z1Ol0002VoookJP009_oonfX5o`00
02Sooo]Z1Ol0003ToookJPGo000000?oo`00oookJ_oonfX0DOoonfX5o`000:Kooo]Z000VoookJPGo
00009ooonfX5o`000>Gooo]Z1Ol00002ool0057ooo]Z00?oo`00o`000?l000000ol0002VoookJP00
9_oonfX5o`0002Oooo]Z1Ol0003UoookJPGo00000_oo001AoookJPGo0000YooonfX002Kooo]Z1Ol0
000WoookJPGo0000i_oonfX5o`000003ool00?oonf[ooo]Z04oooo]Z1Ol0002WoookJP009_oonfX5
o`0002Oooo]Z1?l0003WoookJPGo00000_oo001@oookJPGo0000YooonfX002Kooo]Z1Ol0000Voook
JPGo0000iooonfX5o`0000;oo`00CooonfX00ooo003o0000o`000002o`000:Sooo]Z000VoookJPGo
00009_oonfX5o`000>Sooo]Z1?l00002ool004oooo]Z1Ol0002XoookJP009_oonfX5o`0002Kooo]Z
1Ol0003XoookJPGo00000_oo001>oookJPGo0000Z?oonfX002Kooo]Z1Ol0000UoookJPGo0000jOoo
nfX5o`0000;oo`00COoonfX00ooo003o0000o`000003o`000:Sooo]Z000VoookJPGo00009OoonfX5
o`000>Wooo]Z1Ol00002ool004gooo]Z1Ol0002YoookJP009_oonfX5o`0002Gooo]Z1Ol0003Zoook
JPGo000000?oo`00oookJ_oonfX0BooonfX5o`000:Wooo]Z000VoookJPGo00009?oonfX5o`000>_o
oo]Z1Ol00002ool004_ooo]Z00?oo`00o`000?l000000ol0002YoookJP009_oonfX5o`0002Cooo]Z
1Ol0003[oookJPGo00000_oo001;oookJPGo0000Z_oonfX002Kooo]Z1Ol0000ToookJPGo0000k?oo
nfX5o`000003ool00?oonf[ooo]Z04Wooo]Z1Ol0002ZoookJP009_oonfX5o`0002?ooo]Z1Ol0003]
oookJPGo00000_oo001:oookJPGo0000Z_oonfX002Kooo]Z1Ol0000SoookJPGo0000kOoonfX5o`00
00;oo`00BOoonfX5o`000:_ooo]Z000VoookJPGo00008ooonfX5o`000>kooo]Z1Ol000000ooo003o
oo]ZoookJP17oookJPGo0000ZooonfX002Kooo]Z1Ol0000RoookJPGo0000kooonfX5o`0000;oo`00
B?oonfX5o`000:_ooo]Z000VoookJPGo00008_oonfX5o`000>oooo]Z1Ol00002ool004Oooo]Z00?o
o`00o`000?l000000_l0002/oookJP009_oonfX5o`0002;ooo]Z1Ol0003`oookJPGo000000?oo`00
oookJ_oonfX0AOoonfX5o`000:cooo]Z000VoookJPGo00008OoonfX5o`000?7ooo]Z1Ol00002ool0
04Kooo]Z1Ol0002/oookJP009_oonfX5o`00027ooo]Z1Ol0003aoookJPGo00000_oo0015oookJP03
ool00?l0003o000000?o0000[?oonfX002Kooo]Z1Ol0000QoookJPGo0000l_oonfX5o`000003ool0
0?oonf[ooo]Z04?ooo]Z1Ol0002]oookJP009_oonfX5o`00027ooo]Z1?l0003coookJPGo00000_oo
0014oookJPGo0000[OoonfX002Kooo]Z1Ol0000PoookJPGo0000looonfX5o`0000;oo`00@ooonfX0
0ooo003o0000o`000003o`000:gooo]Z000VoookJPGo00008?oonfX5o`000?Cooo]Z1Ol000000ooo
003ooo]ZoookJP11oookJPGo0000[_oonfX000Wooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Wo
oo]Z1Ol0000PoookJPGo0000m?oonfX5o`000003ool00?oonf[ooo]Z047ooo]Z1Ol0002^oookJP00
2?oonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o2?oonfX5o`0001oooo]Z1Ol0003eoookJPGo0000
0_oo0011oookJP03ool00?l0003o000000?o0000[_oonfX000Sooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Oooo]Z1Ol0000OoookJPGo
0000m_oonfX5o`000003ool00?oonf[ooo]Z03oooo]Z00?oo`00o`000?l000000_l0002_oookJP00
1ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1Ol0000OoookJPGo0000
m_oonfX5o`000003ool00?oonf[ooo]Z03oooo]Z1Ol0002_oookJP001ooonfX3o`00O`?ooo]Z0ol0
07l6oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol0000LoookJPGo0000mooonfX5o`0000;oo`00?ooo
nfX00ooo003o0000o`000003o`000:oooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3
oookJP?o001o1ooonfX5o`0001kooo]Z1Ol0003hoookJPGo000000?oo`00oookJ_oonfX0?OoonfX0
0ooo003o0000o`000003o`000:oooo]Z0007oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007l8oook
JPGo00007_oonfX5o`000?Sooo]Z1Ol000000ooo003ooo]ZoookJP0moookJPGo0000/?oonfX000Oo
oo]Z0ol007l3oookJP?o001o1ooonfX7o`00O`Sooo]Z1Ol0000MoookJPGo0000nOoonfX5o`0000;o
o`00?_oonfX5o`000;3ooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
1ooonfX5o`0001gooo]Z1Ol0003joookJPGo000000?oo`00oookJ_oonfX0>ooonfX00ooo003o0000
o`000003o`000;3ooo]Z0007oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1ooo
nfX5o`0001gooo]Z1Ol0003joookJPGo000000?oo`00oookJ_oonfX0>ooonfX5o`000;7ooo]Z0008
oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX3o`00O`?ooo]Z0ol007l7oookJPGo00007?oo
nfX5o`000?_ooo]Z1Ol00002ool003cooo]Z1Ol0002aoookJP002?oonfX7o`00O`Sooo]Z1ol007l8
oookJPGo00007?oonfX5o`000?cooo]Z1Ol000000ooo003ooo]ZoookJP0ioookJP03ool00?l0003o
000000?o0000/OoonfX000Wooo]Z1Ol007l:oookJPGo001o2OoonfX5o`0001cooo]Z1Ol0003loook
JPGo000000?oo`00oookJ_oonfX0>OoonfX5o`000;;ooo]Z000VoookJPGo00006ooonfX5o`000?go
oo]Z1Ol00002ool003[ooo]Z1Ol0002boookJP009_oonfX5o`0001_ooo]Z1Ol0003noookJPGo0000
00?oo`00oookJ_oonfX0=ooonfX00ooo003o0000o`000003o`000;;ooo]Z000VoookJPGo00006ooo
nfX5o`000?kooo]Z1Ol000000ooo003ooo]ZoookJP0goookJPGo0000/ooonfX002Kooo]Z1Ol0000J
oookJPGo0000oooonfX5o`0000;oo`00=ooonfX00ooo003o0000o`000003o`000;?ooo]Z000Voook
JPGo00006_oonfX5o`000?oooo]Z0OoonfX5o`000003ool00?oonf[ooo]Z03Gooo]Z00?oo`00o`00
0?l000000ol0002coookJP009_oonfX5o`0001Wooo]Z1_l0003ooookJP7ooo]Z1Ol000000ooo003o
oo]ZoookJP0eoookJPGo0000]?oonfX002Kooo]Z1Ol0000IoookJPGo0000oooonfX2oookJPKo0000
00?oo`00oookJ_oonfX0<ooonfX00ooo003o0000o`000003o`000;Cooo]Z000VoookJPGo00006Ooo
nfX5o`000?oooo]Z0ooonfX5o`0000;oo`00=?oonfX6o`000;Cooo]Z000VoookJPGo00006?oonfX5
o`000?oooo]Z1?oonfX5o`0000;oo`00=?oonfX5o`000;Gooo]Z000VoookJPGo00006?oonfX5o`00
0?oooo]Z1OoonfX5o`000003ool00?oonf[ooo]Z037ooo]Z00?oo`00o`000?l000000ol0002eoook
JP009_oonfX5o`0001Sooo]Z1Ol0003ooookJPGooo]Z1Ol00002ool003;ooo]Z1Ol0002foookJP00
9_oonfX5o`0001Oooo]Z1Ol0003ooookJPKooo]Z1Ol00002ool0037ooo]Z00?oo`00o`000?l00000
0ol0002foookJP009_oonfX5o`0001Oooo]Z1Ol0003ooookJPOooo]Z1Ol00002ool0033ooo]Z1_l0
002foookJP009_oonfX5o`0001Kooo]Z1_l0003ooookJPOooo]Z1Ol00002ool002oooo]Z00?oo`00
o`000?l000000ol0002goookJP009_oonfX5o`0001Kooo]Z1Ol0003ooookJPSooo]Z1_l000000ooo
003ooo]ZoookJP0]oookJP03ool00?l0003o000000?o0000]ooonfX002Kooo]Z1Ol0000FoookJPGo
0000oooonfX9oookJPGo00000_oo000^oookJPGo0000^?oonfX002Kooo]Z1Ol0000EoookJPGo0000
oooonfX:oookJPGo00000_oo000]oookJP03ool00?l0003o000000?o0000^?oonfX002Kooo]Z1Ol0
000EoookJPGo0000oooonfX;oookJPGo000000?oo`00oookJ_oonfX0:ooonfX00ooo003o0000o`00
0003o`000;Sooo]Z000VoookJPGo00005?oonfX6o`000?oooo]Z2ooonfX5o`0000;oo`00:ooonfX0
0ooo003o0000o`000003o`000;Wooo]Z000VoookJPGo00005?oonfX5o`000?oooo]Z3?oonfX6o`00
0003ool00?oonf[ooo]Z02Wooo]Z00?oo`00o`000?l000000ol0002ioookJP009_oonfX5o`0001Co
oo]Z1Ol0003ooookJPgooo]Z1Ol00002ool002[ooo]Z1_l0002ioookJP009_oonfX5o`0001?ooo]Z
1Ol000000ooo003ooo]ZoookJP3ooookJP_ooo]Z1Ol00002ool002Wooo]Z00?oo`00o`000?l00000
0ol0002joookJP009_oonfX5o`0001?ooo]Z1Ol0003ooookJPoooo]Z1Ol000000ooo003ooo]Zoook
JP0WoookJP03ool00?l0003o000000?o0000^_oonfX002Kooo]Z1Ol0000CoookJPGo0000oooonfX?
oookJPGo00000_oo000WoookJP03ool00?l0003o000000?o0000^ooonfX002Kooo]Z1Ol0000Boook
JPGo0000oooonfX@oookJPGo00000_oo000WoookJP03ool00?l0003o000000?o0000^ooonfX002Ko
oo]Z1Ol0000BoookJPGo0000oooonfXAoookJPGo00000_oo000VoookJPKo0000^ooonfX002Kooo]Z
1Ol0000AoookJPKo0000oooonfXAoookJPGo00000_oo000UoookJP03ool00?l0003o000000?o0000
_?oonfX002Kooo]Z1Ol0000AoookJPGo0000oooonfXBoookJPKo00000_oo000ToookJP03ool00?l0
003o000000?o0000_?oonfX002Kooo]Z1Ol0000AoookJPGo0000oooonfXCoookJPGo00000_oo000S
oookJP03ool00?l0003o000000?o0000_OoonfX002Kooo]Z1Ol0000@oookJPGo0000oooonfXDoook
JPGo00000ooo000RoookJP03ool00?l0003o000000?o0000_OoonfX002Kooo]Z1Ol0000@oookJPGo
0000oooonfXEoookJPGo00000_oo000QoookJP03ool00?l0003o000000Co0000_OoonfX002Kooo]Z
1Ol0000?oookJPKo0000oooonfXEoookJPGo00000ooo000PoookJP03ool00?l0003o000000?o0000
__oonfX002Kooo]Z1Ol0000?oookJPGo0000oooonfXFoookJPKo00000_oo000OoookJP03ool00?l0
003o000000Co0000__oonfX002Kooo]Z1Ol0000>oookJPKo0000oooonfXGoookJPGo00000ooo000N
oookJP03ool00?l0003o000000?o0000_ooonfX002Kooo]Z1Ol0000>oookJPGo0000oooonfXHoook
JPKo00000_oo000MoookJP03ool00?l0003o000000Co0000_ooonfX002Kooo]Z1Ol0000=oookJPKo
0000oooonfXIoookJPGo00000ooo000LoookJP03ool00?l0003o000000?o0000`?oonfX002Kooo]Z
1Ol0000<oookJPKo0000oooonfXJoookJPGo00000ooo000KoookJP03ool00?l0003o000000Co0000
`?oonfX002Kooo]Z1Ol0000<oookJPKo0000oooonfXKoookJPGo00000ooo000IoookJP;oo`001Ol0
0031oookJP009_oonfX5o`0000_ooo]Z1_l0003ooookJQcooo]Z1Ol00003ool001Wooo]Z00?oo`00
o`000?l000001?l00031oookJP009_oonfX5o`0000_ooo]Z1Ol000000ooo003ooo]ZoookJP3ooook
JQ[ooo]Z1_l00003ool001Oooo]Z0_oo0005o`000<;ooo]Z000VoookJPGo00002_oonfX6o`000?oo
oo]Z7_oonfX5o`0000Coo`005_oonfX00ooo003o0000o`000004o`000<;ooo]Z000VoookJPGo0000
2_oonfX5o`000?oooo]Z7ooonfX6o`0000?oo`005OoonfX2ool000Go0000`ooonfX002Kooo]Z1Ol0
0009oookJPKo0000oooonfXPoookJPKo00000ooo000CoookJP;oo`001_l00033oookJP009_oonfX5
o`0000Sooo]Z1_l0003ooookJR7ooo]Z1_l00004ool0017ooo]Z0_oo0006o`000<Cooo]Z000Voook
JPGo00002?oonfX6o`000?oooo]Z8_oonfX6o`0000Coo`003ooonfX3ool000Ko0000a?oonfX002Ko
oo]Z1Ol00007oookJPKo0000oooonfXToookJPGo00001Ooo000=oookJP?oo`001_l00035oookJP00
9_oonfX5o`0000Oooo]Z1Ol0003ooookJRGooo]Z1_l00006ool000[ooo]Z1?oo0005o`000<Kooo]Z
000VoookJPGo00001_oonfX6o`000?oooo]Z9_oonfX6o`0000Koo`001ooonfX5ool000Ko0000a_oo
nfX002Kooo]Z1Ol00005oookJPKo0000oooonfXWoookJPOo00004?oo0006o`000<Oooo]Z000Voook
JPGo00001?oonfX7o`000?oooo]Z:?oonfX8o`0000goo`001ol00037oookJP009_oonfX5o`0000?o
oo]Z1ol0003ooookJR[ooo]Z2?l0000:ool000So0000b?oonfX001[ooo]Z0ol007l9oookJPGo0000
0_oonfX7o`000?oooo]Z;?oonfX8o`0000Soo`002?l00039oookJP006_oonfX3o`00O`Wooo]Z3Ol0
003ooookJRkooo]Z2?l00002oookJP?oo`0000?ooo]Zo`000?l000001_l0003:oookJP006_oonfX3
o`00O`Wooo]Z0_l000000ooo003o0000o`000007o`000?oooo]Z<OoonfX9o`000003oookJ_l0003o
000000Oo0000booonfX001[ooo]Z0ol007l9oookJP_o0000oooonfXcoookJQ3o0000cOoonfX001[o
oo]Z0ol007l9oookJP[o0000oooonfXeoookJPko0000c_oonfX001[ooo]Z0ol007l9oookJPSo0000
oooonfXhoookJPco0000cooonfX001[ooo]Z0ol007l9oookJPKo0000oooonfXloookJPSo0000dOoo
nfX001[ooo]Z0ol007l9oookJPGo0000oooonf[ooookJQOooo]Z000JoookJP?o001o2OoonfX5o`00
0?oooo]ZoooonfXGoookJP005ooonfX6o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX001Oooo]Z
1_l007l9oookJPGo0000oooonf[ooookJQOooo]Z000IoookJPCo001o2OoonfX5o`000?oooo]Zoooo
nfXGoookJP006_oonfX3o`00O`Wooo]Z1Ol0003ooookJ_oooo]Z5ooonfX002Kooo]Z1Ol0003ooook
J_oooo]Z5ooonfX002Kooo]Z1Ol0003ooookJ_oooo]Z5ooonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.791911, -0.0842141, \
0.019462, 0.00314902}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"DisplayLater\\\", \
\\\" \\\", \\\"=\\\", \\\" \\\", \\(\\(RowBox[\\(\\({\\\"DisplayFunction\\\", \
\\\"\\\\[Rule]\\\", \\\"Identity\\\"}\\)\\)]\\)\\)}\\)\\)]\\)\\), \
\\\";\\\"}\\)\\)]\\)\\), \\(\\(\\(\\(\[LeftSkeleton] 6 \
\[RightSkeleton]\\)\\)[\\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)]\\)\\)}\
\\) is not a valid box structure. The first argument in \
\\!\\(XML`MathML`BoxesToMathML[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\) must be a valid box structure. \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\"]\\)\
\"\>"}]], "Message"]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
ScreenStyleEnvironment->"Presentation",
CellGrouping->Manual,
WindowSize->{1359, 769},
WindowMargins->{{40, Automatic}, {Automatic, 4}},
WindowTitle->"Lecture 19 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2004",
ShowCellLabel->False,
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:19:simple_forward_time_interation"->{
    Cell[1817, 53, 103, 1, 52, "Subtitle",
      CellTags->"mmtag:19:simple_forward_time_interation"]},
  "mmtag:19:Graphics_Package__MultipleListPlot[]"->{
    Cell[46245, 1331, 123, 2, 77, "Input",
      CellTags->"mmtag:19:Graphics_Package__MultipleListPlot[]"]},
  "mmtag:19:MultipleListPlot[]"->{
    Cell[46713, 1347, 226, 4, 77, "Input",
      CellTags->"mmtag:19:MultipleListPlot[]"]},
  "mmtag:19:Roman_Maeder__Computer_Science_with_Mathematica"->{
    Cell[723591, 20912, 384, 8, 104, "Text",
      CellTags->"mmtag:19:Roman_Maeder__Computer_Science_with_Mathematica"]},
  "mmtag:19:Module[]"->{
    Cell[724132, 20929, 437, 7, 119, "Input",
      CellTags->"mmtag:19:Module[]"]},
  "mmtag:19:increment_operator"->{
    Cell[810217, 23622, 620, 20, 116, "Text",
      CellTags->"mmtag:19:increment_operator"]},
  "mmtag:19:NestList[]"->{
    Cell[811470, 23664, 120, 2, 77, "Input",
      CellTags->"mmtag:19:NestList[]"]},
  "mmtag:19:pure_function"->{
    Cell[848784, 24832, 149, 4, 77, "Input",
      CellTags->"mmtag:19:pure_function"]},
  "mmtag:19:DisplayNow_DisplayLater__example"->{
    Cell[885830, 25987, 262, 5, 98, "Input",
      CellTags->"mmtag:19:DisplayNow_DisplayLater__example"]},
  "mmtag:19:first-order_ODES__visualizing"->{
    Cell[1045502, 33643, 148, 2, 70, "Subtitle",
      CellTags->{
      "mmtag:19:first-order_ODES__visualizing", 
        "mmtag:19:first-order_ODES"}]},
  "mmtag:19:first-order_ODES"->{
    Cell[1045502, 33643, 148, 2, 70, "Subtitle",
      CellTags->{
      "mmtag:19:first-order_ODES__visualizing", 
        "mmtag:19:first-order_ODES"}]},
  "mmtag:19:Graphics_Package__PlotVectorField[]"->{
    Cell[1223684, 37478, 115, 2, 77, "Input",
      CellTags->"mmtag:19:Graphics_Package__PlotVectorField[]"]},
  "mmtag:19:DSolve[]"->{
    Cell[1886510, 51309, 140, 3, 77, "Input",
      CellTags->"mmtag:19:DSolve[]"]},
  "mmtag:19:ordinary_differential_equations__constants_of_integration"->{
    Cell[1886758, 51318, 334, 8, 104, "Text",
      CellTags->
      "mmtag:19:ordinary_differential_equations__constants_of_integration"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:19:simple_forward_time_interation", 2050111, 56352},
  {"mmtag:19:Graphics_Package__MultipleListPlot[]", 2050268, 56355},
  {"mmtag:19:MultipleListPlot[]", 2050413, 56358},
  {"mmtag:19:Roman_Maeder__Computer_Science_with_Mathematica", 2050569, \
56361},
  {"mmtag:19:Module[]", 2050717, 56364},
  {"mmtag:19:increment_operator", 2050837, 56367},
  {"mmtag:19:NestList[]", 2050959, 56370},
  {"mmtag:19:pure_function", 2051075, 56373},
  {"mmtag:19:DisplayNow_DisplayLater__example", 2051213, 56376},
  {"mmtag:19:first-order_ODES__visualizing", 2051367, 56379},
  {"mmtag:19:first-order_ODES", 2051556, 56384},
  {"mmtag:19:Graphics_Package__PlotVectorField[]", 2051764, 56389},
  {"mmtag:19:DSolve[]", 2051901, 56392},
  {"mmtag:19:ordinary_differential_equations__constants_of_integration", \
2052060, 56395}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 60, 0, 60, "Title"],
Cell[1817, 53, 103, 1, 52, "Subtitle",
  CellTags->"mmtag:19:simple_forward_time_interation"],
Cell[1923, 56, 131, 3, 59, "Text"],
Cell[2057, 61, 157, 3, 59, "Input"],
Cell[2217, 66, 173, 4, 55, "Subsubsection"],

Cell[CellGroupData[{
Cell[2415, 74, 129, 2, 80, "Input"],
Cell[2547, 78, 152, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[2724, 85, 71, 1, 59, "Input"],
Cell[2798, 88, 42, 1, 77, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2877, 94, 58, 1, 59, "Input"],
Cell[2938, 97, 53, 1, 56, "Output"]
}, Open  ]]
}, Open  ]],
Cell[3018, 102, 281, 5, 86, "Text"],
Cell[3302, 109, 294, 5, 101, "Input"],
Cell[3599, 116, 28, 0, 59, "Text"],

Cell[CellGroupData[{
Cell[3652, 120, 76, 1, 59, "Input"],
Cell[3731, 123, 411, 6, 95, "Output"]
}, Open  ]],
Cell[4157, 132, 176, 4, 86, "Text"],
Cell[4336, 138, 119, 2, 59, "Input"],

Cell[CellGroupData[{
Cell[4480, 144, 87, 1, 59, "Input"],
Cell[4570, 147, 41527, 1176, 364, 16947, 868, "GraphicsData", "PostScript", \
"Graphics"],
Cell[46100, 1325, 130, 3, 74, "Output"]
}, Open  ]],
Cell[46245, 1331, 123, 2, 77, "Input",
  CellTags->"mmtag:19:Graphics_Package__MultipleListPlot[]"],
Cell[46371, 1335, 119, 2, 59, "Input"],
Cell[46493, 1339, 195, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[46713, 1347, 226, 4, 77, "Input",
  CellTags->"mmtag:19:MultipleListPlot[]"],
Cell[46942, 1353, 334532, 9724, 364, 307381, 9384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[381477, 11079, 130, 3, 74, "Output"]
}, Open  ]],
Cell[381622, 11085, 119, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[381766, 11092, 203, 3, 59, "Input"],
Cell[381972, 11097, 341416, 9805, 364, 307559, 9382, "GraphicsData", \
"PostScript", "Graphics"],
Cell[723391, 20904, 130, 3, 74, "Output"]
}, Open  ]],
Cell[723536, 20910, 52, 0, 52, "Subtitle"],
Cell[723591, 20912, 384, 8, 104, "Text",
  CellTags->"mmtag:19:Roman_Maeder__Computer_Science_with_Mathematica"],
Cell[723978, 20922, 151, 5, 55, "Subsubsection"],
Cell[724132, 20929, 437, 7, 119, "Input",
  CellTags->"mmtag:19:Module[]"],

Cell[CellGroupData[{
Cell[724594, 20940, 66, 1, 59, "Input"],
Cell[724663, 20943, 378, 5, 26, "Message"]
}, Open  ]],
Cell[725056, 20951, 131, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[725212, 20958, 48, 1, 59, "Input"],
Cell[725263, 20961, 163, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[725463, 20969, 74, 1, 59, "Input"],
Cell[725540, 20972, 46112, 1442, 364, 21446, 1133, "GraphicsData", \
"PostScript", "Graphics"],
Cell[771655, 22416, 130, 3, 74, "Output"]
}, Open  ]],
Cell[771800, 22422, 343, 10, 98, "Text"],
Cell[772146, 22434, 63, 1, 59, "Input"],
Cell[772212, 22437, 583, 10, 164, "Input"],
Cell[772798, 22449, 128, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[772951, 22456, 48, 1, 59, "Input"],
Cell[773002, 22459, 165, 4, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[773204, 22468, 49, 1, 59, "Input"],
Cell[773256, 22471, 36746, 1141, 364, 18471, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[810005, 23614, 130, 3, 74, "Output"]
}, Open  ]],
Cell[810150, 23620, 64, 0, 52, "Subtitle"],
Cell[810217, 23622, 620, 20, 116, "Text",
  CellTags->"mmtag:19:increment_operator"],
Cell[810840, 23644, 136, 2, 59, "Input"],
Cell[810979, 23648, 371, 10, 137, "Text"],
Cell[811353, 23660, 114, 2, 59, "Input"],
Cell[811470, 23664, 120, 2, 77, "Input",
  CellTags->"mmtag:19:NestList[]"],

Cell[CellGroupData[{
Cell[811615, 23670, 49, 1, 59, "Input"],
Cell[811667, 23673, 36746, 1141, 364, 18471, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[848416, 24816, 130, 3, 74, "Output"]
}, Open  ]],
Cell[848561, 24822, 198, 6, 59, "Text"],

Cell[CellGroupData[{
Cell[848784, 24832, 149, 4, 77, "Input",
  CellTags->"mmtag:19:pure_function"],
Cell[848936, 24838, 36746, 1141, 364, 18471, 911, "GraphicsData", \
"PostScript", "Graphics"],
Cell[885685, 25981, 130, 3, 74, "Output"]
}, Open  ]],
Cell[885830, 25987, 262, 5, 98, "Input",
  CellTags->"mmtag:19:DisplayNow_DisplayLater__example"],
Cell[886095, 25994, 153, 3, 59, "Input"],
Cell[886251, 25999, 130, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[886406, 26006, 84, 1, 59, "Input"],
Cell[886493, 26009, 158481, 7618, 364, 139628, 7381, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1044977, 33629, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1045122, 33635, 377, 6, 76, "Subsubsection"],
Cell[1045502, 33643, 148, 2, 70, "Subtitle",
  CellTags->{
  "mmtag:19:first-order_ODES__visualizing", "mmtag:19:first-order_ODES"}],
Cell[1045653, 33647, 325, 11, 79, "Text"],
Cell[1045981, 33660, 497, 13, 106, "Text"],

Cell[CellGroupData[{
Cell[1046503, 33677, 243, 5, 85, "Input"],
Cell[1046749, 33684, 176233, 3769, 476, 78331, 2556, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1222985, 37455, 137, 3, 74, "Output"]
}, Open  ]],
Cell[1223137, 37461, 544, 15, 157, "Text"],
Cell[1223684, 37478, 115, 2, 77, "Input",
  CellTags->"mmtag:19:Graphics_Package__PlotVectorField[]"],

Cell[CellGroupData[{
Cell[1223824, 37484, 213, 3, 59, "Input"],
Cell[1224040, 37489, 131908, 3149, 584, 48058, 2109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1355951, 40640, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1356096, 40646, 157, 5, 79, "Text"],
Cell[1356256, 40653, 317, 11, 174, "Subsection"],
Cell[1356576, 40666, 172, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[1356773, 40674, 201, 3, 89, "Input"],
Cell[1356977, 40679, 402345, 7554, 476, 155180, 4498, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1759325, 48235, 137, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1759499, 48243, 191, 3, 88, "Input"],
Cell[1759693, 48248, 125655, 3017, 584, 45729, 2026, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1885351, 51267, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1885496, 51273, 338, 6, 76, "Subsubsection"],
Cell[1885837, 51281, 118, 5, 52, "Subtitle"],
Cell[1885958, 51288, 527, 17, 86, "Text"],

Cell[CellGroupData[{
Cell[1886510, 51309, 140, 3, 77, "Input",
  CellTags->"mmtag:19:DSolve[]"],
Cell[1886653, 51314, 90, 1, 91, "Output"]
}, Open  ]],
Cell[1886758, 51318, 334, 8, 104, "Text",
  CellTags->
  "mmtag:19:ordinary_differential_equations__constants_of_integration"],

Cell[CellGroupData[{
Cell[1887117, 51330, 144, 3, 59, "Input"],
Cell[1887264, 51335, 87, 1, 79, "Output"]
}, Open  ]],
Cell[1887366, 51339, 209, 4, 86, "Text"],

Cell[CellGroupData[{
Cell[1887600, 51347, 86, 1, 59, "Input"],
Cell[1887689, 51350, 39016, 975, 364, 13849, 660, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1926708, 52327, 130, 3, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1926875, 52335, 742, 17, 305, "Text"],
Cell[1927620, 52354, 85, 1, 59, "Input"]
}, Open  ]],
Cell[1927720, 52358, 161, 3, 59, "Input"],
Cell[1927884, 52363, 119, 2, 59, "Input"],
Cell[1928006, 52367, 89, 1, 59, "Input"],

Cell[CellGroupData[{
Cell[1928120, 52372, 48, 1, 59, "Input"],
Cell[1928171, 52375, 177, 4, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1928385, 52384, 110, 2, 59, "Input"],
Cell[1928498, 52388, 55644, 1848, 364, 30505, 1533, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1984145, 54238, 130, 3, 74, "Output"]
}, Open  ]],
Cell[1984290, 54244, 123, 3, 59, "Text"],

Cell[CellGroupData[{
Cell[1984438, 54251, 71, 1, 59, "Input"],
Cell[1984512, 54254, 63782, 2054, 364, 32540, 1664, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2048297, 56310, 130, 3, 56, "Output"]
}, Open  ]],
Cell[2048442, 56316, 806, 12, 58, "Message"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

